#
# Copyright (C) 2014-2020 Red Hat, Inc.
#
# Cockpit is free software; you can redistribute it and/or modify it
# under the terms of the GNU Lesser General Public License as published by
# the Free Software Foundation; either version 2.1 of the License, or
# (at your option) any later version.
#
# Cockpit is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with Cockpit; If not, see <https://www.gnu.org/licenses/>.
#

# This file is maintained at the following location:
# https://github.com/cockpit-project/cockpit/blob/main/tools/cockpit.spec
#
# If you are editing this file in another location, changes will likely
# be clobbered the next time an automated release is done.
#
# Check first cockpit-devel@lists.fedorahosted.org
#

# earliest base that the subpackages work on; this is still required as long as
# we maintain the basic/optional split, then it can be replaced with just %{version}.
%define required_base 266

# we generally want CentOS packages to be like RHEL; special cases need to check %{centos} explicitly
%if 0%{?centos}
%define rhel %{centos}
%endif

%define _hardened_build 1

%define __lib lib

%if %{defined _pamdir}
%define pamdir %{_pamdir}
%else
%define pamdir %{_libdir}/security
%endif

Name:           cockpit
Summary:        Web Console for Linux servers

License:        LGPL-2.1-or-later
URL:            https://cockpit-project.org/

Version:        249
Release:        1.20250310122736734136.pr148.6042.ga68c4a171%{?dist}
Source0:        cockpit-249.dev6042+ga68c4a171.tar.xz

%if 0%{?fedora} >= 41 || 0%{?rhel}
ExcludeArch: %{ix86}
%endif

%define enable_multihost 1
%if 0%{?fedora} >= 41 || 0%{?rhel} >= 10
%define enable_multihost 0
%endif

# Ship custom SELinux policy
%define selinuxtype targeted
%define selinux_configure_arg --enable-selinux-policy=%{selinuxtype}

BuildRequires: gcc
BuildRequires: pkgconfig(gio-unix-2.0)
BuildRequires: pkgconfig(json-glib-1.0)
BuildRequires: pkgconfig(polkit-agent-1) >= 0.105
BuildRequires: pam-devel

BuildRequires: autoconf automake
BuildRequires: make
BuildRequires: python3-devel
BuildRequires: gettext >= 0.21
BuildRequires: openssl-devel
BuildRequires: gnutls-devel >= 3.4.3
BuildRequires: zlib-devel
BuildRequires: krb5-devel >= 1.11
BuildRequires: libxslt-devel
BuildRequires: glib-networking
BuildRequires: sed

BuildRequires: glib2-devel >= 2.50.0
# this is for runtimedir in the tls proxy ace21c8879
BuildRequires: systemd-devel >= 235
%if 0%{?suse_version}
BuildRequires: distribution-release
BuildRequires: openssh
BuildRequires: distribution-logos
BuildRequires: wallpaper-branding
%else
BuildRequires: openssh-clients
BuildRequires: docbook-style-xsl
%endif
BuildRequires: krb5-server
BuildRequires: gdb

# For documentation
BuildRequires: xmlto

BuildRequires:  selinux-policy
BuildRequires:  selinux-policy-devel

# This is the "cockpit" metapackage. It should only
# Require, Suggest or Recommend other cockpit-xxx subpackages

Requires: cockpit-bridge
Requires: cockpit-ws
Requires: cockpit-system

# Optional components
Recommends: (cockpit-storaged if udisks2)
Recommends: (cockpit-packagekit if dnf)
Suggests: python3-pcp

%if 0%{?rhel} == 0
Recommends: (cockpit-networkmanager if NetworkManager)
# c-ostree is not in RHEL 8/9
Recommends: (cockpit-ostree if rpm-ostree)
Suggests: cockpit-selinux
%endif
%if 0%{?rhel} && 0%{?centos} == 0
Requires: subscription-manager-cockpit
%endif

BuildRequires:  python3-devel
BuildRequires:  python3-pip
%if 0%{?rhel} == 0 && !0%{?suse_version}
# All of these are only required for running pytest (which we only do on Fedora)
BuildRequires:  procps-ng
BuildRequires:  python3-pytest-asyncio
BuildRequires:  python3-pytest-timeout
%endif

%prep
%setup -q -n cockpit-249.dev6042+ga68c4a171

%build
%configure \
    %{?selinux_configure_arg} \
%if 0%{?suse_version}
    --docdir=%_defaultdocdir/%{name} \
%endif
    --with-pamdir='%{pamdir}' \
%if %{enable_multihost}
    --enable-multihost \
%endif

%make_build

%check
make -j$(nproc) check

%if 0%{?rhel} == 0
export NO_QUNIT=1
%pytest
%endif

%install
%make_install
mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/pam.d
install -p -m 644 tools/cockpit.pam $RPM_BUILD_ROOT%{_sysconfdir}/pam.d/cockpit
rm -f %{buildroot}/%{_libdir}/cockpit/*.so
install -D -p -m 644 AUTHORS COPYING README.md %{buildroot}%{_docdir}/cockpit/

# Build the package lists for resource packages
# cockpit-bridge is the basic dependency for all cockpit-* packages, so centrally own the page directory
echo '%dir %{_datadir}/cockpit' > base.list
echo '%dir %{_datadir}/cockpit/base1' >> base.list
find %{buildroot}%{_datadir}/cockpit/base1 -type f -o -type l >> base.list
echo '%{_sysconfdir}/cockpit/machines.d' >> base.list
echo %{buildroot}%{_datadir}/polkit-1/actions/org.cockpit-project.cockpit-bridge.policy >> base.list

echo '%dir %{_datadir}/cockpit/shell' >> system.list
find %{buildroot}%{_datadir}/cockpit/shell -type f >> system.list

echo '%dir %{_datadir}/cockpit/systemd' >> system.list
find %{buildroot}%{_datadir}/cockpit/systemd -type f >> system.list

echo '%dir %{_datadir}/cockpit/users' >> system.list
find %{buildroot}%{_datadir}/cockpit/users -type f >> system.list

echo '%dir %{_datadir}/cockpit/metrics' >> system.list
find %{buildroot}%{_datadir}/cockpit/metrics -type f >> system.list

echo '%dir %{_datadir}/cockpit/kdump' > kdump.list
find %{buildroot}%{_datadir}/cockpit/kdump -type f >> kdump.list

echo '%dir %{_datadir}/cockpit/sosreport' > sosreport.list
find %{buildroot}%{_datadir}/cockpit/sosreport -type f >> sosreport.list

echo '%dir %{_datadir}/cockpit/storaged' > storaged.list
find %{buildroot}%{_datadir}/cockpit/storaged -type f >> storaged.list

echo '%dir %{_datadir}/cockpit/networkmanager' > networkmanager.list
find %{buildroot}%{_datadir}/cockpit/networkmanager -type f >> networkmanager.list

echo '%dir %{_datadir}/cockpit/packagekit' > packagekit.list
find %{buildroot}%{_datadir}/cockpit/packagekit -type f >> packagekit.list

echo '%dir %{_datadir}/cockpit/apps' >> packagekit.list
find %{buildroot}%{_datadir}/cockpit/apps -type f >> packagekit.list

echo '%dir %{_datadir}/cockpit/selinux' > selinux.list
find %{buildroot}%{_datadir}/cockpit/selinux -type f >> selinux.list

echo '%dir %{_datadir}/cockpit/static' > static.list
echo '%dir %{_datadir}/cockpit/static/fonts' >> static.list
find %{buildroot}%{_datadir}/cockpit/static -type f >> static.list

sed -i "s|%{buildroot}||" *.list

%if ! 0%{?suse_version}
%global _debugsource_packages 1
%global _debuginfo_subpackages 0

%define find_debug_info %{_rpmconfigdir}/find-debuginfo.sh %{?_missing_build_ids_terminate_build:--strict-build-id} %{?_include_minidebuginfo:-m} %{?_find_debuginfo_dwz_opts} %{?_find_debuginfo_opts} %{?_debugsource_packages:-S debugsourcefiles.list} "%{_builddir}/%{?buildsubdir}"

%endif
# /suse_version
rm -rf %{buildroot}/usr/src/debug

# On RHEL kdump, networkmanager, selinux, and sosreport are part of the system package
%if 0%{?rhel}
cat kdump.list sosreport.list networkmanager.list selinux.list >> system.list
rm -f %{buildroot}%{_datadir}/metainfo/org.cockpit_project.cockpit_sosreport.metainfo.xml
rm -f %{buildroot}%{_datadir}/metainfo/org.cockpit_project.cockpit_kdump.metainfo.xml
rm -f %{buildroot}%{_datadir}/metainfo/org.cockpit_project.cockpit_selinux.metainfo.xml
rm -f %{buildroot}%{_datadir}/metainfo/org.cockpit_project.cockpit_networkmanager.metainfo.xml
rm -f %{buildroot}%{_datadir}/icons/hicolor/64x64/apps/cockpit-sosreport.png
%endif

# -------------------------------------------------------------------------------
# Sub-packages

%description
The Cockpit Web Console enables users to administer GNU/Linux servers using a
web browser.

It offers network configuration, log inspection, diagnostic reports, SELinux
troubleshooting, interactive command-line sessions, and more.

%files
%{_docdir}/cockpit/AUTHORS
%{_docdir}/cockpit/COPYING
%{_docdir}/cockpit/README.md
%{_datadir}/metainfo/org.cockpit_project.cockpit.appdata.xml
%{_datadir}/icons/hicolor/128x128/apps/cockpit.png
%doc %{_mandir}/man1/cockpit.1.gz


%package bridge
Summary: Cockpit bridge server-side component

%description bridge
The Cockpit bridge component installed server side and runs commands on the
system on behalf of the web based user interface.

%files bridge -f base.list
%doc %{_mandir}/man1/cockpit-bridge.1.gz
%{_bindir}/cockpit-bridge
%{_libexecdir}/cockpit-askpass
%{python3_sitelib}/%{name}*

%package doc
Summary: Cockpit deployment and developer guide
BuildArch: noarch

%description doc
The Cockpit Deployment and Developer Guide shows sysadmins how to
deploy Cockpit on their machines as well as helps developers who want to
embed or extend Cockpit.

%files doc
%exclude %{_docdir}/cockpit/AUTHORS
%exclude %{_docdir}/cockpit/COPYING
%exclude %{_docdir}/cockpit/README.md
%{_docdir}/cockpit

%package system
Summary: Cockpit admin interface package for configuring and troubleshooting a system
BuildArch: noarch
Requires: cockpit-bridge >= %{version}-%{release}
%if !0%{?suse_version}
Requires: shadow-utils
%endif
Requires: grep
Requires: /usr/bin/pwscore
Requires: /usr/bin/date
Provides: cockpit-shell = %{version}-%{release}
Provides: cockpit-systemd = %{version}-%{release}
Provides: cockpit-tuned = %{version}-%{release}
Provides: cockpit-users = %{version}-%{release}
%if 0%{?rhel}
Requires: NetworkManager >= 1.6
Requires: sos
Requires: sudo
Recommends: PackageKit
Recommends: setroubleshoot-server >= 3.3.3
Recommends: /usr/bin/kdumpctl
Suggests: NetworkManager-team
Suggests: python3-pcp
Provides: cockpit-kdump = %{version}-%{release}
Provides: cockpit-networkmanager = %{version}-%{release}
Provides: cockpit-selinux = %{version}-%{release}
Provides: cockpit-sosreport = %{version}-%{release}
%endif

Provides: bundled(npm(@patternfly/patternfly)) = 5.4.2
Provides: bundled(npm(@patternfly/react-core)) = 5.4.14
Provides: bundled(npm(@patternfly/react-icons)) = 5.4.2
Provides: bundled(npm(@patternfly/react-styles)) = 5.4.1
Provides: bundled(npm(@patternfly/react-table)) = 5.4.16
Provides: bundled(npm(@patternfly/react-tokens)) = 5.4.1
Provides: bundled(npm(@xterm/addon-canvas)) = 0.7.0
Provides: bundled(npm(@xterm/xterm)) = 5.5.0
Provides: bundled(npm(argparse)) = 1.0.10
Provides: bundled(npm(attr-accept)) = 2.2.5
Provides: bundled(npm(autolinker)) = 3.16.2
Provides: bundled(npm(dequal)) = 2.0.3
Provides: bundled(npm(file-selector)) = 2.1.2
Provides: bundled(npm(focus-trap)) = 7.6.2
Provides: bundled(npm(js-tokens)) = 4.0.0
Provides: bundled(npm(json-stable-stringify-without-jsonify)) = 1.0.1
Provides: bundled(npm(lodash)) = 4.17.21
Provides: bundled(npm(loose-envify)) = 1.4.0
Provides: bundled(npm(object-assign)) = 4.1.1
Provides: bundled(npm(prop-types)) = 15.8.1
Provides: bundled(npm(react-dom)) = 18.3.1
Provides: bundled(npm(react-dropzone)) = 14.3.8
Provides: bundled(npm(react-is)) = 16.13.1
Provides: bundled(npm(react)) = 18.3.1
Provides: bundled(npm(remarkable)) = 2.0.1
Provides: bundled(npm(scheduler)) = 0.23.2
Provides: bundled(npm(sprintf-js)) = 1.0.3
Provides: bundled(npm(tabbable)) = 6.2.0
Provides: bundled(npm(throttle-debounce)) = 5.0.2
Provides: bundled(npm(tslib)) = 2.8.1
Provides: bundled(npm(uuid)) = 11.1.0

%description system
This package contains the Cockpit shell and system configuration interfaces.

%files system -f system.list
%dir %{_datadir}/cockpit/shell/images

%package ws
Summary: Cockpit Web Service
Requires: glib-networking
Requires: openssl
Requires: glib2 >= 2.50.0
Requires: (selinux-policy >= %{_selinux_policy_version} if selinux-policy-%{selinuxtype})
Requires(post): (policycoreutils if selinux-policy-%{selinuxtype})
Recommends: sscg >= 2.3
Recommends: system-logos
Suggests: sssd-dbus >= 2.6.2
# for cockpit-desktop
Suggests: python3
Obsoletes: cockpit-tests < 331

# prevent hard python3 dependency for cockpit-desktop, it falls back to other browsers
%global __requires_exclude_from ^%{_libexecdir}/cockpit-client$

%description ws
The Cockpit Web Service listens on the network, and authenticates users.

If sssd-dbus is installed, you can enable client certificate/smart card
authentication via sssd/FreeIPA.

%files ws -f static.list
%doc %{_mandir}/man1/cockpit-desktop.1.gz
%doc %{_mandir}/man5/cockpit.conf.5.gz
%doc %{_mandir}/man8/cockpit-ws.8.gz
%doc %{_mandir}/man8/cockpit-tls.8.gz
%doc %{_mandir}/man8/pam_ssh_add.8.gz
%dir %{_sysconfdir}/cockpit
%config(noreplace) %{_sysconfdir}/cockpit/ws-certs.d
%config(noreplace) %{_sysconfdir}/pam.d/cockpit
# created in %post, so that users can rm the files
%ghost %{_sysconfdir}/issue.d/cockpit.issue
%ghost %{_sysconfdir}/motd.d/cockpit
%ghost %attr(0644, root, root) %{_sysconfdir}/cockpit/disallowed-users
%dir %{_datadir}/cockpit/issue
%{_datadir}/cockpit/issue/update-issue
%{_datadir}/cockpit/issue/inactive.issue
%{_unitdir}/cockpit.service
%{_unitdir}/cockpit-issue.service
%{_unitdir}/cockpit.socket
%{_unitdir}/cockpit-session-socket-user.service
%{_unitdir}/cockpit-session.socket
%{_unitdir}/cockpit-session@.service
%{_unitdir}/cockpit-wsinstance-http.socket
%{_unitdir}/cockpit-wsinstance-http.service
%{_unitdir}/cockpit-wsinstance-https-factory.socket
%{_unitdir}/cockpit-wsinstance-https-factory@.service
%{_unitdir}/cockpit-wsinstance-https@.socket
%{_unitdir}/cockpit-wsinstance-https@.service
%{_unitdir}/cockpit-wsinstance-socket-user.service
%{_unitdir}/system-cockpithttps.slice
%{_prefix}/%{__lib}/tmpfiles.d/cockpit-ws.conf
%{pamdir}/pam_ssh_add.so
%{pamdir}/pam_cockpit_cert.so
%{_libexecdir}/cockpit-ws
%{_libexecdir}/cockpit-wsinstance-factory
%{_libexecdir}/cockpit-tls
%{_libexecdir}/cockpit-client
%{_libexecdir}/cockpit-client.ui
%{_libexecdir}/cockpit-desktop
%{_libexecdir}/cockpit-certificate-ensure
%{_libexecdir}/cockpit-certificate-helper
%{_libexecdir}/cockpit-session
%{_datadir}/cockpit/branding
%{_datadir}/selinux/packages/%{selinuxtype}/%{name}.pp.bz2
%{_mandir}/man8/%{name}_session_selinux.8cockpit.*
%{_mandir}/man8/%{name}_ws_selinux.8cockpit.*
%ghost %{_sharedstatedir}/selinux/%{selinuxtype}/active/modules/200/%{name}

%pre ws
if %{_sbindir}/selinuxenabled 2>/dev/null; then
    %selinux_relabel_pre -s %{selinuxtype}
fi

%post ws
if [ -x %{_sbindir}/selinuxenabled ]; then
    %selinux_modules_install -s %{selinuxtype} %{_datadir}/selinux/packages/%{selinuxtype}/%{name}.pp.bz2
    %selinux_relabel_post -s %{selinuxtype}
fi

# set up dynamic motd/issue symlinks on first-time install; don't bring them back on upgrades if admin removed them
# disable root login on first-time install; so existing installations aren't changed
if [ "$1" = 1 ]; then
    mkdir -p /etc/motd.d /etc/issue.d
    ln -s ../../run/cockpit/issue /etc/motd.d/cockpit
    ln -s ../../run/cockpit/issue /etc/issue.d/cockpit.issue
    printf "# List of users which are not allowed to login to Cockpit\n" > /etc/cockpit/disallowed-users
    printf "root\n" >> /etc/cockpit/disallowed-users
    chmod 644 /etc/cockpit/disallowed-users
fi

# on upgrades, adjust motd/issue links to changed target if they still exist (changed in 331)
if [ "$1" = 2 ]; then
    if [ "$(readlink /etc/motd.d/cockpit 2>/dev/null)" = "../../run/cockpit/motd" ]; then
        ln -sfn ../../run/cockpit/issue /etc/motd.d/cockpit
    fi
    if [ "$(readlink /etc/issue.d/cockpit.issue 2>/dev/null)" = "../../run/cockpit/motd" ]; then
        ln -sfn ../../run/cockpit/issue /etc/issue.d/cockpit.issue
    fi
fi

%tmpfiles_create cockpit-ws.conf
%systemd_post cockpit.socket cockpit.service
# firewalld only partially picks up changes to its services files without this
test -f %{_bindir}/firewall-cmd && firewall-cmd --reload --quiet || true

# check for deprecated PAM config
if test -f %{_sysconfdir}/pam.d/cockpit &&  grep -q pam_cockpit_cert %{_sysconfdir}/pam.d/cockpit; then
    echo '**** WARNING:'
    echo '**** WARNING: pam_cockpit_cert is a no-op and will be removed in a'
    echo '**** WARNING: future release; remove it from your /etc/pam.d/cockpit.'
    echo '**** WARNING:'
fi

# remove obsolete system user on upgrade (replaced with DynamicUser in version 330)
if getent passwd cockpit-wsinstance >/dev/null; then
    userdel cockpit-wsinstance
fi

%preun ws
%systemd_preun cockpit.socket cockpit.service

%postun ws
if [ -x %{_sbindir}/selinuxenabled ]; then
    %selinux_modules_uninstall -s %{selinuxtype} %{name}
    %selinux_relabel_post -s %{selinuxtype}
fi
%systemd_postun_with_restart cockpit.socket cockpit.service

# -------------------------------------------------------------------------------
# Sub-packages that are part of cockpit-system in RHEL/CentOS, but separate in Fedora

%if 0%{?rhel} == 0

%package kdump
Summary: Cockpit user interface for kernel crash dumping
Requires: cockpit-bridge >= %{required_base}
Requires: cockpit-shell >= %{required_base}
Requires: /usr/bin/kdumpctl
BuildArch: noarch

%description kdump
The Cockpit component for configuring kernel crash dumping.

%files kdump -f kdump.list
%{_datadir}/metainfo/org.cockpit_project.cockpit_kdump.metainfo.xml

%package sosreport
Summary: Cockpit user interface for diagnostic reports
Requires: cockpit-bridge >= %{required_base}
Requires: cockpit-shell >= %{required_base}
Requires: sos
BuildArch: noarch

%description sosreport
The Cockpit component for creating diagnostic reports with the
sosreport tool.

%files sosreport -f sosreport.list
%{_datadir}/metainfo/org.cockpit_project.cockpit_sosreport.metainfo.xml
%{_datadir}/icons/hicolor/64x64/apps/cockpit-sosreport.png

%package networkmanager
Summary: Cockpit user interface for networking, using NetworkManager
Requires: cockpit-bridge >= %{required_base}
Requires: cockpit-shell >= %{required_base}
Requires: NetworkManager >= 1.6
# Optional components
Recommends: NetworkManager-team
BuildArch: noarch

%description networkmanager
The Cockpit component for managing networking.  This package uses NetworkManager.

%files networkmanager -f networkmanager.list
%{_datadir}/metainfo/org.cockpit_project.cockpit_networkmanager.metainfo.xml

%endif

%if 0%{?rhel} == 0

%package selinux
Summary: Cockpit SELinux package
Requires: cockpit-bridge >= %{required_base}
Requires: cockpit-shell >= %{required_base}
Requires: setroubleshoot-server >= 3.3.3
BuildArch: noarch

%description selinux
This package contains the Cockpit user interface integration with the
utility setroubleshoot to diagnose and resolve SELinux issues.

%files selinux -f selinux.list
%{_datadir}/metainfo/org.cockpit_project.cockpit_selinux.metainfo.xml

%endif

%package -n cockpit-storaged
Summary: Cockpit user interface for storage, using udisks
Requires: cockpit-shell >= %{required_base}
Requires: udisks2 >= 2.9
Recommends: udisks2-lvm2 >= 2.9
Recommends: udisks2-iscsi >= 2.9
%if ! 0%{?rhel}
Recommends: udisks2-btrfs >= 2.9
%endif
Recommends: device-mapper-multipath
Recommends: clevis-luks
Requires: %{__python3}
%if 0%{?suse_version}
Requires: python3-dbus-python
%else
Requires: python3-dbus
%endif
BuildArch: noarch

%description -n cockpit-storaged
The Cockpit component for managing storage.  This package uses udisks.

%files -n cockpit-storaged -f storaged.list
%{_datadir}/metainfo/org.cockpit_project.cockpit_storaged.metainfo.xml

%post storaged

# version 332 moved the btrfs temp mounts db to /run
if [ "$1" = 2 ] && [ -d /var/lib/cockpit/btrfs ]; then
    rm -rf --one-file-system  /var/lib/cockpit/btrfs || true
fi

%package -n cockpit-packagekit
Summary: Cockpit user interface for packages
BuildArch: noarch
Requires: cockpit-bridge >= %{required_base}
Requires: PackageKit
Recommends: python3-tracer
# HACK: https://bugzilla.redhat.com/show_bug.cgi?id=1800468
Requires: polkit

%description -n cockpit-packagekit
The Cockpit components for installing OS updates and Cockpit add-ons,
via PackageKit.

%files -n cockpit-packagekit -f packagekit.list

# The changelog is automatically generated and merged
%changelog
* Mon Mar 10 2025 Packit <hello@packit.dev> - 249-1.20250310122736734136.pr148.6042.ga68c4a171
- dbg: do not merge (Jelle van der Waa)
- workflows: Move to Fedora 41 (Jelle van der Waa)
- cockpit-ci: Update container to 2025-03-08 (Cockpit Project)
- Bump @typescript-eslint/eslint-plugin in the types group (dependabot[bot])
- users: Remove useless React fragment (Jelle van der Waa)
- Declare all variables on a separate line (Jelle van der Waa)
- apps: The role attribute 'presentation' on an 'img' is redundant (Jelle van der Waa)
- testlib: remove support for setUp(restrict=) kwarg (Allison Karlitskaya)
- test: Take TestSystemInfo-testBasic-overview pixel test without CPU warning (Marius Vollmer)
- lib: Improve http channel debug messages (Martin Pitt)
- Bump the patternfly group with 2 updates (dependabot[bot])
- Bump stylelint from 16.14.1 to 16.15.0 in the stylelint group (dependabot[bot])
- cockpit-ci: Update container to 2025-03-01 (Cockpit Project)
- Bump @typescript-eslint/eslint-plugin in the types group (dependabot[bot])
- po: Update from Fedora Weblate (GitHub Workflow)
- client: Conditionally remove workaround for UDisks2 issue 1206 (Marius Vollmer)
- test: Use daemons instead of zebras to test SELinux alerts (Marius Vollmer)
- test: Update pixel references for tasks container 2025-02-22 (Marius Vollmer)
- test: Workaround chromedriver/chromium issue with large uploads/downloads (Marius Vollmer)
- cockpit-ci: Update container to 2025-02-22 (Cockpit Project)
- po: Update from Fedora Weblate (GitHub Workflow)
- test: Unmount LVM2 thin volume before pixel test (Marius Vollmer)
- lib: update PF expand animation issue (Jelle van der Waa)
- base1: extend dirname test cases with not normalized paths (Jelle van der Waa)
- test: Fail on cdp_command() errors (Martin Pitt)
- systemd: terminal: set initial `user` value in state (Jelle van der Waa)
- systemd: initialise eventlistener after user is available (Jelle van der Waa)
- test: FIPS transition is over, hardcode where it used to be dynamic (Marius Vollmer)
- flatpak: Enable screenshots URL mirror (Martin Pitt)
- testlib: Workaround mysterious disappearing buttons (Marius Vollmer)
- Bump @typescript-eslint/eslint-plugin in the types group (dependabot[bot])
- Bump uuid from 11.0.5 to 11.1.0 (dependabot[bot])
- Bump the patternfly group with 2 updates (dependabot[bot])
- systemd: Drop ABRT/reportd support (Martin Pitt)
- test: Remove obsolete Fedora 39/40 special cases and ABRT testing (Martin Pitt)
- pkg: Remove workaround for empty LEGAL.txt files (Martin Pitt)
- bridge: Only authorize once in noninteractive superuser responder (Martin Pitt)
- ws: Only hand out the saved password to authorize messages once (Martin Pitt)
- test: Configure pam_faillock also in system-auth (Martin Pitt)
- test: Factor out faillock setup (Martin Pitt)
- Bump @typescript-eslint/eslint-plugin in the types group (dependabot[bot])
- test: extend ram_disk with a delay option to add response delay (Jelle van der Waa)
- test: Configure Firefox BiDi logging (Martin Pitt)
- test: Drop obsolete Firefox user prefs (Martin Pitt)
- networkmanager: Lint fixes (Marius Vollmer)
- networkmanager: Test for primary bond (Freya Gustavsson)
- networkmanager: fix primary bond option (Etienne Champetier)
- Bump @typescript-eslint/eslint-plugin in the types group (dependabot[bot])
- Bump the esbuild group with 2 updates (dependabot[bot])
- test: only include relative paths in coverage (Allison Karlitskaya)
- po: Update from Fedora Weblate (GitHub Workflow)
- cockpit-ci: Update container to 2025-02-08 (Allison Karlitskaya)
- test: Re-disable Firefox BiDi async events (Martin Pitt)
- test/common: don't reuse webdriver ids on exceptions (Allison Karlitskaya)
- tls: Stop hardcoding 2048 bit RSA key length (Martin Pitt)
- test: enable tuned tests on Arch Linux (Jelle van der Waa)
- lib: rewrite html2po in Python (Jelle van der Waa)
- lib: drop attribute translation support for HTML (Jelle van der Waa)
- lib: drop support for translatable attribute (Jelle van der Waa)
- packit: Re-disable Fedora 42 (Martin Pitt)
- workflows: Regularly mirror docker.io/bitnami/grafana (Martin Pitt)
- users: disable deleting/logging out current logged in account (Jelle van der Waa)
- test: always umount btrfs on teardown (Jelle van der Waa)
- test: cover the btrfs device card in our tests (Jelle van der Waa)
- test: wait for tuned-button to show text (Jelle van der Waa)
- po: Update from Fedora Weblate (GitHub Workflow)
- base1: Clean up pybridge special cases (Martin Pitt)
- doc: Drop fence group and http-stream2 connection option (Martin Pitt)
- test: Drop remaining pybridge scenario vestiges (Martin Pitt)
- base1: fix deprecated qunit long test without a timeout (Jelle van der Waa)
- build: allow external Python to be used (Chris Wiggins)
- test: extend test coverage by testing user directory cleanup on removal (Jelle van der Waa)
- test: test user logout functionality (Jelle van der Waa)
- packit: Add Fedora 42, drop 40 (Martin Pitt)
- cockpit-ci: Update container to 2025-02-01 (Cockpit Project)
- Bump qunit from 2.23.1 to 2.24.1 (dependabot[bot])
- Bump @typescript-eslint/eslint-plugin in the types group (dependabot[bot])
- Bump stylelint from 16.13.2 to 16.14.1 in the stylelint group (dependabot[bot])
- lib: Make DynamicListForm.itemcomponent a component type instead of instance (Martin Pitt)
- test: Add bootc image preparation (Martin Pitt)
- test: Drop obsolete SSH md5 key comparison from TestMultiMachineKeyAuth (Martin Pitt)
- test: Fix SSH pubkey normalization for ostree home directories (Martin Pitt)
- test: Fix pam_ssh_add condition in TestMultiMachineKeyAuth.testBasic (Martin Pitt)
- selinux: Allow systemd to clean up cockpit's temporary files (Martin Pitt)
- test: Adjust TestConnection.testTls for centos-9-bootc (Martin Pitt)
- test: Adjust TestConnection.ostree_setup_ws() for bootc (Martin Pitt)
- test: Skip cockpit-session damaging on bootc image (Martin Pitt)
- test: Fix TestSystemInfo.testCPUSecurityMitigationsEnable for bootc (Martin Pitt)
- test: Use a ro /usr friendly way of hiding /usr/bin/ssh (Martin Pitt)
- test: Increase image size in TestImageCustomize.testResize (Martin Pitt)
- test: Skip TestMetricsPackages on -bootc images (Martin Pitt)
- test: Skip TestAutoUpdatesInstall on OSTree (Martin Pitt)
- test: Add image-prepare --network option (Martin Pitt)
- networkmanager: move to a fixed width (Jelle van der Waa)
- networkmanager: move to using gap for spacing (Jelle van der Waa)
- Bump @patternfly/react-table in the patternfly group (dependabot[bot])
- lib: rewrite manifest2po in Python (Jelle van der Waa)
- containers/ws: Include cockpit-files (Martin Pitt)
- tools: Drop obsolete glib-networking dependency of bridge (Martin Pitt)
- po: Update from Fedora Weblate (GitHub Workflow)
- configure.ac: Work around autoconf 2.69  bug (Luna)
- users: Add screen reader accessible column (Freya Gustavsson)
- test: remove empty else clause (Jelle van der Waa)
- cockpit-ci: Update container to 2025-01-25 (Cockpit Project)
- test: Don't access out-of-bounds pixels (Marius Vollmer)
- test: Re-enable TestPages.testAllLanguages and TestGrafana.testBasic on chromium (Martin Pitt)
- test: Prefer chromium-browser over -headless (Martin Pitt)
- fix: Spacing for network status (Freya Gustavsson)
- Docs: Add userpass for VM web login (Freya Gustavsson)
- cockpit-ci: Update container to 2025-01-20 (Cockpit Project)
- test: Check NFS home directory (Martin Pitt)
- Bump the stylelint group with 2 updates (dependabot[bot])
- Bump eslint-plugin-react in the eslint group (dependabot[bot])
- build: Let `make` rebuild the bundle on PO changes (Martin Pitt)
- cockpit: retain SELinux context if file exists (Jelle van der Waa)
- test: Drop dummy interface (Jelle van der Waa)
- test: drop duplicate tuned disabling (Jelle van der Waa)
- Switch to the Web Crypto API for generating SHA checksums (Jelle van der Waa)
- login: Beibooting to all supported OSes (Martin Pitt)
- storage: Stop/start btrfs monitor around dialog actions (Marius Vollmer)
- storage: Use private mounts for btrs polling (Marius Vollmer)
- test: follow RUF051 recommendations (Jelle van der Waa)
- po: Update from Fedora Weblate (GitHub Workflow)
- storaged: Move /var/lib/cockpit/btrfs to /run (Martin Pitt)
- bridge: Drop translations from manifests.js, introduce m-i18n.js (Martin Pitt)
- base1: Add unit test for zh_CN (one plural form) ngettext (Martin Pitt)
- shell: Drop obsolete po globs (Martin Pitt)
- guide: Drop manifest.json (Martin Pitt)
- gitignore: Fix appdata.xml (Martin Pitt)
- cockpit-ci: Update container to 2025-01-11 (Cockpit Project)
- Bump @typescript-eslint/eslint-plugin in the types group (dependabot[bot])
- Bump glob from 11.0.0 to 11.0.1 (dependabot[bot])
- Bump uuid from 11.0.3 to 11.0.5 (dependabot[bot])
- Revert "test: apply a workaround for Fedora-CoreOS rebased on Fedora 41" (Martin Pitt)
- login: Fix debug message noise (Martin Pitt)
- test: Don't create group called user in tests (Miika Alikirri)
- test: Set the lease path to /run/dnsmasq (Alice Brooks)
- .gitignore: Ignore test results (Alice Brooks)
- login: Fix quote removal in brand name (Martin Pitt)
- shell: Drop unused hide-before class (Martin Pitt)
- ws: Drop unused variables (Martin Pitt)
- workflows: Run unit tests with -Werror (Martin Pitt)
- shell: Fix bugs found by TypeScript (Marius Vollmer)
- shell: Include many files in type checking (Marius Vollmer)
- shell: Fully type "credentials" (Marius Vollmer)
- shell: Type more of "machines/machines" (Marius Vollmer)
- lib: Export "Keys" class from "credentials". (Marius Vollmer)
- shell: Improve type of host_superuser_storage_key (Marius Vollmer)
- lib: Add types for cockpit.sessionStorage and cockpit.localStorage (Marius Vollmer)
- shell: Make CockpitNav type generic (Marius Vollmer)
- workflows: Move trigger-anaconda and ws build workflows to ubuntu-latest (Martin Pitt)
- workflows: Run nightly on ubuntu-latest (Martin Pitt)
- workflows: Run CodeQL on ubuntu-latest (Martin Pitt)
- workflows: Move unit-tests to ubuntu-latest (Martin Pitt)
- workflows: Move release and node-modules workflows from Ubuntu 20.04 to 24.04 (Martin Pitt)
- test: Allow longer reboot time with fips-mode-setup --disable (Martin Pitt)
- test: Adapt to change in mdadm bitmap default (Marius Vollmer)
- po: Update from Fedora Weblate (GitHub Workflow)
- ws: don't send os-release to login page (Allison Karlitskaya)
- workflows: Keep flatpak-test on Ubuntu 22.04 for now (Martin Pitt)
- cockpit-ci: Update container to 2025-01-04 (Cockpit Project)
- bridge: Fix optional OSError.errno mypy error in FsInfoChannel (Martin Pitt)
- lib: Support headers with SimpleSelect (Marius Vollmer)
- lib: Correct type of SimpleSelect.selected (Marius Vollmer)
- appstream: Fix developer id (AsciiWolf)
- Bump @typescript-eslint/eslint-plugin in the types group (dependabot[bot])
- lib: Improve key navigation in TypeaheadSelect and MultiTypeaheadSelect (Marius Vollmer)
- lib: Support for a footer in TypeaheadSelect (Marius Vollmer)
- po: Update from Fedora Weblate (GitHub Workflow)
- lib: Rewrite "credentials" as a TypeScript class (Marius Vollmer)
- lib: Make ProcessError accessible to TypeScript code (Marius Vollmer)
- cockpit-ci: Update container to 2024-12-28 (Cockpit Project)
- Bump eslint-plugin-react in the eslint group (dependabot[bot])
- Bump @typescript-eslint/eslint-plugin in the types group (dependabot[bot])
- po: Update from Fedora Weblate (GitHub Workflow)
- cockpit-ci: Update container to 2024-12-21 (Cockpit Project)
- Bump stylelint from 16.11.0 to 16.12.0 in the stylelint group (dependabot[bot])
- Bump the patternfly group with 2 updates (dependabot[bot])
- Bump the esbuild group with 2 updates (dependabot[bot])
- shell: Declare two machines helper functions (Martin Pitt)
- storaged: Type contains_rootfs() (Martin Pitt)
- systemd: Clean up availableMitigations() caching (Martin Pitt)
- apps: Fix watch-appstream.py error handling (Martin Pitt)
- base1: Drop obsolete test-no-jquery.js (Martin Pitt)
- lib: Type cockpit.dbus().proxies() (Martin Pitt)
- lib: Clean up "binary" option special-case (Martin Pitt)
- systemd: Avoid setting undefined filter (Martin Pitt)
- containers/ws: Clean /var/cache/libdnf5 (Martin Pitt)
- lib: Make SimpleSelect and CheckboxSelect generic in the option value type (Marius Vollmer)
- Revert "test: Make restore_dir() work for OSTree images" (Marius Vollmer)
- metrics: show system boots in metrics (Jelle van der Waa)
- test: Remove race in TestServices._testBasic (Marius Vollmer)
- metrics: Use CheckboxSelect instead of deprecated Select variant (Marius Vollmer)
- systemd: Use CheckboxSelect instead of deprecated Select variant (Marius Vollmer)
- lib: Make our changes to CheckboxSelect (Marius Vollmer)
- lib: Correct TypeScript errors in CheckboxSelect (Marius Vollmer)
- lib: Import CheckboxSelect template from Patternfly (Marius Vollmer)
- shell: Use Status type from pkg/lib/notifications (Marius Vollmer)
- lib: Add types to pkg/lib/notifications (Marius Vollmer)
- test: Add tests for MultiTypeaheadSelect (Marius Vollmer)
- test: Robustify opening the host switcher in more places (Marius Vollmer)
- shell: Fix bugs found by TypeScript (Marius Vollmer)
- shell: Check types in "shell-modals" (Marius Vollmer)
- shell: Fully type "topnav" (Marius Vollmer)
- shell: Fully type "nav" (Marius Vollmer)
- shell: Improve manifest types (Marius Vollmer)
- shell: Improve Location type a bit (Marius Vollmer)
- containers/ws: Fix build on Fedora 41 (Martin Pitt)
- po: Update from Fedora Weblate (GitHub Workflow)
- cockpit-ci: Update container to 2024-12-16 (Cockpit Project)
- test: Adjust types to python pillow 11.0 (Martin Pitt)
- lib: Type ListingTable (Marius Vollmer)
- storaged: aria-valuemin accepts a number not a string (Jelle van der Waa)
- lib: shell: tabIndex property only accepts integer values (Jelle van der Waa)
- lib: Revert menu toggles to be transparent again (Marius Vollmer)
- cockpit-ci: Update container to 2024-12-14 (Cockpit Project)
- Bump @typescript-eslint/eslint-plugin in the types group (dependabot[bot])
- storage: Don't navigate when clicking on the mobile kebab (Marius Vollmer)
- ws: Prevent search engine indexing with robots.txt (Martin Pitt)
- tls: Don't overwrite an existing TLS key if the cert is missing (Martin Pitt)
- test: Check error reporting with missing or broken TLS key (Martin Pitt)
- tls: Create /etc/cockpit/ws-certs.d if necessary (Martin Pitt)
- src: Stop hardcoding libc soname (Martin Pitt)
- vendor: Update ferny to c8713c4d3ba74a (Martin Pitt)
- containers/ws: Support using an external SSH agent (Martin Pitt)
- test: Ignore bottom panel in TestHistoryMetrics.testEvents pixel test (Martin Pitt)
- test: Use real mouse events with Chromium in the shell (Martin Pitt)
- test: Wait for animation in TestHostSwitching (Martin Pitt)
- test: Speed up and clarify TestHostSwitching.testNoAutoconnect (Martin Pitt)
- test: Close SSH key dialog in TestKeys.testPrivateKeys (Martin Pitt)
- cockpit: send `now` along with the internalmetrics meta (Jelle van der Waa)
- test: Update pixel test references (Marius Vollmer)
- test: Correctly check for tracer presence in TestUpdates.testInfoSecurity (Marius Vollmer)
- test: Remove Browser.select_PF_deprecated (Marius Vollmer)
- lib: Explicitly use white background color for MenuToggle (Marius Vollmer)
- lib: Don't apply double spacing fix globally to all dropdowns (Marius Vollmer)
- lib: Use SimpleSelect for FirewalldRequest (Marius Vollmer)
- lib: Use SimpleSelect for ShutdownModal (Marius Vollmer)
- lib: Use SimpleSelect for ServerTime (Marius Vollmer)
- metrics: Use SimpleSelect instead of deprecated Select (Marius Vollmer)
- logs: Use SimpleSelect instead of deprecated Select (Marius Vollmer)
- lib: Make our changes to SimpleSelect (Marius Vollmer)
- lib: Correct TypeScript errors in SimpleSelect (Marius Vollmer)
- lib: Import SimpleSelect template from PatternFly (Marius Vollmer)
- po: Update from Fedora Weblate (GitHub Workflow)
- shell: Fix bug in "idle", found by TypeScript (Marius Vollmer)
- shell: Fully type "frames" and "idle" (Marius Vollmer)
- shell: Check types in "frames" (Marius Vollmer)
- shell: Full types for "state" (Marius Vollmer)
- lib: Add useOn hook, for our own EventEmitter (Marius Vollmer)
- users: Fix truncated "From" in account logs (Martin Pitt)
- users: Avoid number argument in cockpit.spawn() (Martin Pitt)
- test: Check last login in health card more precisely (Martin Pitt)
- session: Ignore write() error in signal handler (Martin Pitt)
- containers, test: Convert obsolete /var/run paths to /run/ (Martin Pitt)
- Bump the patternfly group with 2 updates (dependabot[bot])
- lib: Adapt TypeaheadSelect and MultiTypeaheadSelect to key navigation changes (Marius Vollmer)
- cockpit-ci: Update container to 2024-12-08 (Cockpit Project)
- test: Avoid focused host selector for pixel test (Martin Pitt)
- test: Skip TestPages.testPageStatus on chromium (Martin Pitt)
- Don't mark used function arguments as dummy (Martin Pitt)
- Use raw strings with `re` functions (Martin Pitt)
- build_backend: Adjust type ignore for mypy 1.13.0 (Martin Pitt)
- bridge: Fix typing of filesystem tag API (Martin Pitt)
- bridge: Rename channels/http.py (Martin Pitt)
- bridge: Silence B901 ruff warning (Martin Pitt)
- bridge: Sort imports (Martin Pitt)
- test: Annotate js_error_codes type (Martin Pitt)
- test: Avoid parentheses for tuples in subscripts (Martin Pitt)
- selinux: stop checking for deleteAlert method of setroubleshoot (Jelle van der Waa)
- systemd, tools: Rename cockpit-motd to cockpit-issue (Martin Pitt)
- dependabot: Ignore all sass 1.x versions (Martin Pitt)
- test: typecheck: output stats of TS errors for JavaScript files (Jelle van der Waa)
- tools: Move cockpit-tests conflict to cockpit-ws (Martin Pitt)
- Bump qunit from 2.22.0 to 2.23.1 (dependabot[bot])
- guide: Fix polkit rules path (Fuko)
- dependabot: Don't update major React version (Martin Pitt)
- Bump @typescript-eslint/eslint-plugin in the types group (dependabot[bot])
- lib: allow cockpit.location to be modified (Jelle van der Waa)
- lib: add DbusClient.watch() in TypeScript typing (Jelle van der Waa)
- lib: correct DbusClient.proxy() typing (Jelle van der Waa)
- metrics: don't divide a number with a string (Jelle van der Waa)
- lib: cockpit: split location into a separate class (Jelle van der Waa)
- base1: explain cockpit.location hashchange test (Jelle van der Waa)
- lib: cockpit: rename location to location-utils (Jelle van der Waa)
- shell: Don't add string and number (Martin Pitt)
- shell: Robustify final_countdown (Martin Pitt)
- playground, shell: Add type assertions for external dict lookups (Martin Pitt)
- lib: cockpit.channel.wait() takes an optional callback (Martin Pitt)
- networkmanager, systemd: Fix boolean or operators (Martin Pitt)
- build: Move to es2021 (Martin Pitt)
- storaged: Avoid Array.findLastIndex() (Martin Pitt)
- lib: correctly check if rows are empty (Jelle van der Waa)
- base1: correct typeof invocation (Jelle van der Waa)
- Drop cockpit-tests package (Martin Pitt)
- test: Clean /usr/local less aggressively in TestMenu.testBasic (Martin Pitt)
- ws: Drop /etc/cockpit creation in make install-tests (Martin Pitt)
- tools: Drop long-obsolete package replacements (Martin Pitt)
- storaged: Use a private mount for "btrfs-tool do" (Marius Vollmer)
- test: Adjust project root path for moved static-code (Martin Pitt)
- test: Move static-code into common/ (Martin Pitt)
- test: Only apply the "Unused JavaScript ignored error codes found" to cockpit itself (Martin Pitt)
- test: Move typecheck to common/ (Martin Pitt)
- test: fail typecheck on ignored but unused typescript erors (Jelle van der Waa)
- storaged: fix typo'd page_category (Jelle van der Waa)
- test: check JavaScript files with TypeScript in typecheck (Jelle van der Waa)
- lib: cockpit: drop old Mozilla window.location.hash hack (Jelle van der Waa)
- systemd: Make timesyncd config drop-in world-readable (Martin Pitt)
- test: Check actual timesyncd custom NTP server status (Martin Pitt)
- test: Change custom NTP servers to *.example.com (Martin Pitt)
- po: Update from Fedora Weblate (GitHub Workflow)
- users: Use MultiTypeaheadSelect instead of deprecated Select variant (Marius Vollmer)
- lib: Make our changes to MultiTypeaheadSelect (Marius Vollmer)
- lib: Correct TypeScript errors in MultiTypeaheadSelect (Marius Vollmer)
- lib: Import MultiTypeaheadSelect template from Patternfly (Marius Vollmer)
- shell: Fix two bugs found by TypeScript (Marius Vollmer)
- shell: Check types in "state" (Marius Vollmer)
- shell: Types for "util" and "machines/machines" (Marius Vollmer)
- lib: Add types for Location.encode and Location.decode (Marius Vollmer)
- shell: Remove build_href (Marius Vollmer)
- test: Run "typecheck" as part of test/static-code (Marius Vollmer)
- test: New "typecheck" utility (Marius Vollmer)
- test: Make TestStorageMdRaid nondestructive (Martin Pitt)
- test: Make TestNetworkingMTU nondestructive (Martin Pitt)
- test: Mark TestNetworkingCheckpoints as nondestructive (Martin Pitt)
- test: Make TestSystemInfo.testOverview nondestructive (Martin Pitt)
- branding: use new Ubuntu logo in favicon (logonoff)
- containers/ws: Move to Fedora 41 (Martin Pitt)
- Bump the stylelint group with 2 updates (dependabot[bot])
- stylelint: Update deprecated at-import-partial-extension (Martin Pitt)
- test: Adjust vm.updates-testing to dnf5 (Martin Pitt)
- test: Add MachineCase reboot wrappers (akshat2jain)
- test: Factorize and robustify mount point cleanup (Martin Pitt)
- apps: Add debug() helper (Martin Pitt)
- apps: Drop nonexisting ProgressBar "title" attribute (Martin Pitt)
- apps: Type utils.jsx (Martin Pitt)
- apps: Fix import order and utils extension (Martin Pitt)
- lib: Fix cockpit.jump() type (Martin Pitt)
- Bump @typescript-eslint/eslint-plugin in the types group (dependabot[bot])
- lib: ensure basename("/") returns "/" (Jelle van der Waa)
- base1: move test-path to base1 (Jelle van der Waa)
- test: Fix reload race condition in TestSystemInfo.testHardwareInfo (Martin Pitt)
- test: Add Browser.have_test_api() (Martin Pitt)
- testlib: Eliminate Browser.valid (Martin Pitt)
- test: Fix some overly long lines in testlib.py (Martin Pitt)
- test: Move reference-image to Fedora 41 (Martin Pitt)
- Fix indent (Marvin A. Ruder)
- Use more specific selector to fix spinner shape (Marvin A. Ruder)
- Fix loading spinner for OAuth / Bearer token validation (Marvin A. Ruder)
- tools: Ignore gnome.org in urls-check (Martin Pitt)
- session: Use pidfd for determining ws peer cgroup (Martin Pitt)
- session: Strengthen getsockopt() validation (Martin Pitt)
- session: Move cockpit-ws peer proc dirfd detection into helper function (Martin Pitt)
- Add systemd-sysext development install mode (Martin Pitt)
- HACKING: Clarify unit test section (Martin Pitt)
- storage: More robust volume group polling (Marius Vollmer)
- test: Wait for LVM2 RAID to be fully synchronized before pixel test (Marius Vollmer)
- test: correct add_machine password argument typing (Jelle van der Waa)
- test: Update pixel references for PCP 6.3.2 (Marius Vollmer)
- po: Update from Fedora Weblate (GitHub Workflow)
- workflows: Build ws container from latest tag, not main (Martin Pitt)
- selinux: Move update-motd out of cockpit_ws_t (Martin Pitt)
- test: Also retry a browser wait when the helper function is missing (Marius Vollmer)
- lib: Support headers with TypeaheadSelect (Marius Vollmer)
- lib: Ignore dividers when key navigating in TypeaheadSelect (Marius Vollmer)
- lib: Translate one more UI string in TypeaheadSelect (Marius Vollmer)
- playground: Enable dark mode for React Patterns (Marius Vollmer)
- systemd: ignore comments in /etc/crypto-policies/config (tomasmatus)
- cockpit.js: Put back cockpit.{resolve,reject} (Martin Pitt)
- systemd: Lock down cockpit-tls networking (Martin Pitt)
- systemd: Clean up cockpit.service.in (Martin Pitt)
- systemd: Lock down cockpit-ws (Martin Pitt)
- Bump @typescript-eslint/eslint-plugin in the types group (dependabot[bot])
- Bump the patternfly group with 2 updates (dependabot[bot])
- doc: enable python bridge related package documentation (Jelle van der Waa)
- systemd: further cleanups for DynamicUser setup (Allison Karlitskaya)
- systemd: remove old compatibility shim (Allison Karlitskaya)
- debian: Drop the DynamicUser= hack (Martin Pitt)
- test: Adapt to new Grafana (Marius Vollmer)
- test: bridge: extend fsreplace1 tests (Jelle van der Waa)
- pkg: cockpit: fix typo value in cockpit.location.decode() (Jelle van der Waa)
- lib: cockpit: replace substr usage with substring (Jelle van der Waa)
- pkg: convert substr() usage to substring() (Jelle van der Waa)
- systemd, tools: stop creating static cockpit-wsinstance user (Allison Karlitskaya)
- .gitignore: only ignore cockpit.socket (Allison Karlitskaya)
- systemd: dynamic group for wsinstance sockets (Allison Karlitskaya)
- systemd: dynamic group for /run/cockpit/session (Allison Karlitskaya)
- tools: Fix dpkg-statoverride cleanup (Martin Pitt)
- session: Only support for cert auth with cockpit-session.socket (Martin Pitt)
- cockpit-session: stop installing setuid root (Allison Karlitskaya)
- ws: connect to cockpit-session via socket (Allison Karlitskaya)
- tools: Move cockpit-session.socket to cockpit-ws package (Martin Pitt)
- session: Support Unix socket mode for client certificates (Martin Pitt)
- test: Add enough TestHistoryMetrics.testEvents wiggle room for PCP 6.3.2 (Martin Pitt)
- session: Sanitize PAM messages (Martin Pitt)
- ws, session: Pass remote peer address in authorize message (Martin Pitt)
- session: Add authorize response timeout (Martin Pitt)
- doc: Clarify that `$COCKPIT_REMOTE_PEER` is optional (Martin Pitt)
- systemd: Clean up /run/cockpit/session (Martin Pitt)
- session: Robustify client certificate mapping errors (Martin Pitt)
- session: Add exit_init_problem() to session-utils (Martin Pitt)
- session: Clean up last_err_msg declaration (Martin Pitt)
- session: Add rhost assertions (Martin Pitt)
- test: Fix illegible comment in TestIPA.testQualifiedUsers (Martin Pitt)
- tls: Fix code reference (Martin Pitt)
- containers/ws: Drop cockpit-session (Martin Pitt)
- ws: Fix reported error if the authentication process is not available (Martin Pitt)
- test: Simplify TestConnection.testBasic (Martin Pitt)
- test: Avoid scrolling race with session menu (Martin Pitt)
- po: Update from Fedora Weblate (GitHub Workflow)
- systemd: add terminal path capabilities to manifest (Ashley Cui)
- systemd: Improve error message (Ashley Cui)
- kdump: Add shell script to enable kdump on microos (Luna D Dragon)
- lib: Make cockpit-components-modifications Ansible optional (Martin Pitt)
- lib: Eliminate ModificationsExportDialog show property (Martin Pitt)
- session: Send no-cockpit init problem if cockpit-bridge fails to exec (Martin Pitt)
- session: Rename my_cgroup* to ws_cgroup* (Martin Pitt)
- systemd: Allow cockpit-session@.service to fail with some known exit codes (Martin Pitt)
- selinux: Fix policy for socket-activated cockpit-session (Martin Pitt)
- ws: Re-use session-utils.c in mock-auth-command.c (Martin Pitt)
- session: Support more keys in authorize JSON message parser (Martin Pitt)
- common: NUL-terminate cockpit_frame_read() result (Martin Pitt)
- session: Exit cleanly on EOF (Martin Pitt)
- test: Ignore session timeout messages in TestIPA.testQualifiedUsers (Martin Pitt)
- test: Add support for querying shadow DOM (Martin Pitt)
- lib: Ignore invalid input keys in Terminal (Martin Pitt)
- pkg: lib: robustify self.path initialisation for cockpit.location (Jelle van der Waa)
-  lib: cockpit: make resolve_dot_paths always return an array (Jelle van der Waa)
- shell: Navigate to a newly added host (Marius Vollmer)
- shell: Require confirmation before connecting to remote machines (Marius Vollmer)
- systemd: Only change FIPS policy with fips-mode-setup (Martin Pitt)
- systemd: Move crypto policies components to useInit() (Martin Pitt)
- systemd: Rewrite crypto policy setting as async (Martin Pitt)
- systemd: Fix detection of current crypto policy in FIPS mode (Martin Pitt)
- lib: cockpit: remove cockpit.when() (Jelle van der Waa)
- shell: allow changing the default landing page (Jelle van der Waa)
- shell: style login close button as secondary button (Aditya Vardhan Singh)
- common: Do not add a body for chunked HEAD request (zwimer)
- session: Drop cgroupsv1 compatibility for certificate authentication (Martin Pitt)
- bridge: Fix crash on invalid cockpit.conf (Martin Pitt)
- test: Rename test_branding (Martin Pitt)
- systemd: Open path in terminal (Ashley Cui)
- test: Drop unused test line (Ashley Cui)
- lib: cockpit: remove cockpit.resolve/cockpit.reject() (Jelle van der Waa)
- build: Allow TS functions to be used before their definition (Marius Vollmer)
- lib: add types to more cockpit-components (tomasmatus)
- po: Update from Fedora Weblate (GitHub Workflow)
- test: disable multihost tests for Fedora CoreOS (Jelle van der Waa)
- test: apply a workaround for Fedora-CoreOS rebased on Fedora 41 (Jelle van der Waa)
- shell: Take docs from the correct manifest item (Marius Vollmer)
- lib: check for null instead of undefined (tomasmatus)
- lib: python.ts add exception type (tomasmatus)
- Bump @typescript-eslint/eslint-plugin in the types group (dependabot[bot])
- test: Fix coverage report for pkg/lib (Marius Vollmer)
- Bump uuid from 11.0.2 to 11.0.3 (dependabot[bot])
- Revert "Bump sass from 1.79.6 to 1.80.6" (Martin Pitt)
- build: Use "projectService" instead of "project" for eslint (Marius Vollmer)
- dependabot: Explicitly ignore PatternFly 6 (Martin Pitt)
- test: Avoid start-limit-hit failure in TestLogin.testClientCertAuthentication (Martin Pitt)
- storage: Update changed storage doc URLs (Martin Pitt)
- Bump @typescript-eslint/eslint-plugin in the types group (dependabot[bot])
- Bump sass from 1.79.6 to 1.80.6 (dependabot[bot])
- doc: Drop documentation of fswatch1 (Martin Pitt)
- lib: Drop watching in credentials.js (Martin Pitt)
- doc: Fix copy-pasta in fsread1 channel description (Martin Pitt)
- lib: override PatternFly's secondary dark theme behaviour (Jelle van der Waa)
- package.json: update PatternFly group to the latest stable version (Jelle van der Waa)
- lib: pam_user_parser.ts add return types (tomasmatus)
- lib: Fix TypeScript error in TypeaheadSelect correctly (Marius Vollmer)
- sosreport: Port to fsinfo (Martin Pitt)
- base1: Make TransportGlobals *actually* global (Martin Pitt)
- cockpit-desktop: Add firefox profile to hide privacy bar/tab and bookmarks (Martin Pitt)
- cockpit-desktop: Support Firefox flatpak (Martin Pitt)
- ws: Disable session timeout for --local-session (Martin Pitt)
- test: Check cockpit-ws --local-session with real browser (Martin Pitt)
- test: Enable testSELinuxRestrictedUser on RHEL 8 (Martin Pitt)
- test: Fix RHEL 8 skip reason for TestLogin.testConversation (Martin Pitt)
- po: Update from Fedora Weblate (GitHub Workflow)
- lib: restrict SASS plugin to scss files (Jelle van der Waa)
- lib: Initial typing of python.js (Martin Pitt)
- systemd: Type shutdownStatus.jsx (Martin Pitt)
- systemd: Type lastlogin.jsx (Martin Pitt)
- lib: Add typing for cockpit.jump() and cockpit.dbus().call() (Martin Pitt)
- lib: Properly type getLastlog2 (Martin Pitt)
- systemd: Typecheck healthCard.tsx (Martin Pitt)
- spec: Drop unneeded build dependency on tox (Miro Hrončok)
- spec: Drop unneeded build dependency on pytest-cov (Miro Hrončok)
- Bump @typescript-eslint/eslint-plugin in the types group (dependabot[bot])
- Bump uuid from 10.0.0 to 11.0.2 (dependabot[bot])
- tls: force write certificates to disk (Jelle van der Waa)
- test: restore fstab/crypttab for RHEL 8 storage tests (Jelle van der Waa)
- storaged: btrfs: show btrfs filesystem "root" subvolume as "top-level" (Jelle van der Waa)
- doc: Document cockpit.permission options (Martin Pitt)
- HACKING.md: Describe the bridge, and stop mentioning the "new Python" one (Martin Pitt)
- test/README.md: Mention some variants of image-prepare (Martin Pitt)
- test/README.md: Replace outdated TEST_OS list with link to testmap (Martin Pitt)
- test/README.md: Format env variables as list (Martin Pitt)
- test: Update pixel references for TypeaheadSelect changes (Marius Vollmer)
- lib: Use TypeaheadSelect instead of deprecated Select for FileAutoComplete (Marius Vollmer)
- systemd: Use TypeaheadSelect instead of deprecated Select (Marius Vollmer)
- lib: Use TypeaheadSelect instead of deprecated Select for timezones (Marius Vollmer)
- storage: Use TypeaheadSelect instead of deprecated Select (Marius Vollmer)
- networking: Use TypeaheadSelect instead of deprecated Select (Marius Vollmer)
- lib: Simplify and translate UI texts in TypeaheadSelect (Marius Vollmer)
- lib: Hide clear button in TypeaheadSelect when it would do nothing (Marius Vollmer)
- lib: Support dividers with TypeaheadSelect (Marius Vollmer)
- lib: Optionally trust selected property in TypeaheadSelect (Marius Vollmer)
- lib: Fix TypeScript error in TypeaheadSelect (Marius Vollmer)
- lib: Copy TypeaheadSelect into our code (Marius Vollmer)
- test: Make ostree/ws container preparation run offline (Martin Pitt)
- test: Increase DHCP machine RAM for network tests (Martin Pitt)
- storage: Update LVM doc link (Martin Pitt)
- pkg: Replace tabs with spaces in our manifests (Martin Pitt)
- test: Robustify TestAccounts.testRootLogin (Martin Pitt)
- users: Stringify `passwd -S --all` console message (Martin Pitt)
- systemd: Add lastlog2 support for "last login" health card item (Martin Pitt)
- users: Get lastlog2 info through SQLite (Martin Pitt)
- systemd: Rewrite LastLogin init with useInit and async (Martin Pitt)
- po: Update from Fedora Weblate (GitHub Workflow)
- test: Enable history metrics tests on RHEL 8 (Martin Pitt)
- test: Fix check-packagekit severity tests for RHEL 8.10 (Martin Pitt)
- test: Fix TestFirewall.testNetworkingPage on RHEL 8 (Martin Pitt)
- test: Enable TestLogin.testExpired on RHEL 8.10 (Martin Pitt)
- test: Skip more LUKS tests on rhel-8-10 (Martin Pitt)
- session: fix copy/paste abort message for setresuid (Jelle van der Waa)
- test: Replace `who` with `loginctl` in TestLogin (Martin Pitt)
- test: Adjust some tests for rhel-8-10/ws-container scenario (Martin Pitt)
- test: Skip tests which currently don't work on rhel-8-10/ws-container (Martin Pitt)
- test: Skip tests which can't work in beiboot mode (Martin Pitt)
- test: Skip host switching tests with beiboot mode (Martin Pitt)
- test: Fix cockpit/ws ostree_image special cases (Martin Pitt)
- test: Add /container scenario (Martin Pitt)
- bridge: Fix AsyncExitStack polyfill (Martin Pitt)
- workflows: teach dependabot workflow to rebase (Jelle van der Waa)
- dependabot: Ignore major PatternFly versions (Martin Pitt)
- Bump the types group with 2 updates (dependabot[bot])
- Bump the eslint group with 2 updates (dependabot[bot])
- login: Split alert into title/description (Martin Pitt)
- beiboot: Use os-release's NAME for no-cockpit errors (Martin Pitt)
- lib: Also apply scrolling fixes to grouped Select components (Marius Vollmer)
- common: Fix memory leak in cockpit_web_response_error_with_body() (Martin Pitt)
- package.json: Revert to sass 1.79 (Martin Pitt)
- containers/ws: Drop obsolete install checks for cockpit (Martin Pitt)
- containers/ws: Drop bad checks from uninstall script (Martin Pitt)
- test: Fix vm.install for images without cockpit packages (Martin Pitt)
- test: Split out VM boot in image-prepare (Martin Pitt)
- test: Split ostree and cockpit/ws install scripts (Martin Pitt)
- test: Drop obsolete todoPybridgeRHEL8 (Martin Pitt)
- test: Remove dead image-prepare --python option (Martin Pitt)
- systemd: Don't open and close tuned DBus connections asynchronously (Marius Vollmer)
- lib: Pass along errors when starting systemd units (Marius Vollmer)
- test: Remove preload workaround in TestPages.testBasic (Marius Vollmer)
- bridge: Report PID for a spawn stream channel (Martin Pitt)
- beiboot: Enable beiboot feature for distro packages for same OS (Martin Pitt)
- bridge: Split out os-release parser (Martin Pitt)
- package.json: Update PatternFly to 5.4.2 (Martin Pitt)
- systemd: Hide "limited access mode" banner without superuser bridges (Martin Pitt)
- Bump sass from 1.79.4 to 1.80.3 (dependabot[bot])
- Bump @typescript-eslint/eslint-plugin in the types group (dependabot[bot])
- systemd: update unit-file.h link (Jelle van der Waa)
- static: Handle no-cockpit error (Martin Pitt)
- test: Clear service errors right before taking the screenshot (Marius Vollmer)
- test: Wait for Shell to be initialized after changing language (Marius Vollmer)
- test: Wait for everything to be there before keyboard navigation (Marius Vollmer)
- shell: Replace frame polling with "load" and "unload" events (Marius Vollmer)
- po: Update from Fedora Weblate (GitHub Workflow)
- containers/ws: Install our other Cockpit pages (Martin Pitt)
- apps: Hide page in beiboot mode (Martin Pitt)
- apps: Hide page if PackageKit is not installed. (Martin Pitt)
- Bump stylelint from 16.9.0 to 16.10.0 in the stylelint group (dependabot[bot])
- Bump the types group with 2 updates (dependabot[bot])
- test: Work around PF tooltip bug in TestMetricsPackages (Jelle van der Waa)
- metrics: remove re-login requirement for loading PCP metrics (Jelle van der Waa)
- debian: Ignore spare-manual-page lintian infos (Martin Pitt)
- debian: Ignore systemd-service-file-missing-install-key lintian info (Martin Pitt)
- debian: Ignore package-contains-documentation-outside-usr-share-doc lintian infos (Martin Pitt)
- debian: Enable hardened build (Martin Pitt)
- debian: Don't install *.LEGAL.txt files (Martin Pitt)
- pkg: Install *.LEGAL.txt as documentation (Martin Pitt)
- debian: Drop outdated licenses (Martin Pitt)
- sosreport: Explicitly specify "host" in download channel options (Marius Vollmer)
- Revert "containers/ws: Rename Dockerfile to Containerfile" (Martin Pitt)
- shell: Use a top-level React component (Marius Vollmer)
- apps: Support "stock" type icons (Martin Pitt)
- appstream: Rename files according to their ID (Martin Pitt)
- appstream: Move icons to type stock and standard directory (Martin Pitt)
- appstream: Explain supported kdump targets (Martin Pitt)
- appstream: Add content rating to ws metadata (Martin Pitt)
- appstream: Add developer info (Martin Pitt)
- debian: Drop obsolete gettext dependency fallback (Martin Pitt)
- debian: Fix cockpit-pcp and lastlog2 relations (Martin Pitt)
- test: Update pixel test references (Marius Vollmer)
- storage: Use groups in the Stratis filesystem creation dialog (Marius Vollmer)
- storage: Explicit support for grouping in dialogs (Marius Vollmer)
- storaged: Adjust stratis fs limits layout in creation dialog (Martin Pitt)
- test: extend internalmetrics coverage by testing `calculate_sample_rate` (Jelle van der Waa)
- test: assert metric result is not Falsy but False (Jelle van der Waa)
- cockpit-ci: Update container to 2024-10-07 (Cockpit Project)
- po: Update from Fedora Weblate (GitHub Workflow)
- src/common: drop cockpitmachinesjson (Jelle van der Waa)
- metrics: collect disk usage from internal metrics (tomasmatus)
- tools/debian/rules: remove unnecessary variable (Allison Karlitskaya)
- src/common: drop two CockpitWebRequest methods (Allison Karlitskaya)
- src/common: drop cockpit_web_server_connect() (Allison Karlitskaya)
- src/common: drop cockpit_template_expand_json() (Allison Karlitskaya)
- src/common: drop cockpit_transport_maybe_frame() (Allison Karlitskaya)
- src/common: drop cockpit_locale_set_language() (Allison Karlitskaya)
- src/common: drop cockpitunixsignal.[ch] (Allison Karlitskaya)
- src/common: drop unused cockpit_system_session_id() (Allison Karlitskaya)
- src/common: drop cockpit_system_process_start_time() (Allison Karlitskaya)
- src/common: drop some misc unused functions (Allison Karlitskaya)
- src/common: drop cockpitversion.[ch] (Allison Karlitskaya)
- src/common: drop cockpitloopback.[ch] (Allison Karlitskaya)
- src/common: drop cockpit_hex_decode() (Allison Karlitskaya)
- src/bridge: move test data to test/data/ (Allison Karlitskaya)
- src/bridge: drop the C bridge (Allison Karlitskaya)
- src: move PolKit policy from bridge/ to systemd/ (Allison Karlitskaya)
- src/systemd: restructure Makefile.am a bit (Allison Karlitskaya)
- Bump the patternfly group with 3 updates (dependabot[bot])
- Bump the eslint group with 2 updates (dependabot[bot])
- Revert "lib: Port cockpit-components-file-autocomplete.jsx to fsinfo" (Marius Vollmer)
- test: pcp: remove conditionals for python3-pcp (Jelle van der Waa)
- Bump the types group with 2 updates (dependabot[bot])
- test: Prepare for Shell rewrite (Marius Vollmer)
- test: enable beiboot PCP tests on Arch Linux (Jelle van der Waa)
- metrics: install required pcp packages instead of cockpit-pcp (Jelle van der Waa)
- test: drop cockpit-pcp journal whitelist (Jelle van der Waa)
- tools: drop cockpit-pcp package (Jelle van der Waa)
- test: Don't explicitly go to x0.cockpit.lan in TestIPA (Marius Vollmer)
- storage: Reimplement btrfs polling with benefits (Marius Vollmer)
- storage: More precise ignoring of "other mounts" (Marius Vollmer)
- networkmanager: remove incorrect preventDefault invocation (Jelle van der Waa)
- lib: drop nested table PatternFly workaround (Jelle van der Waa)
- testlib: add F2 key (tomasmatus)
- containers/ws: Enable beibooting and install standard cockpit pages (Martin Pitt)
- Drop remaining libssh references (Martin Pitt)
- lib: Port cockpit-components-file-autocomplete.jsx to fsinfo (Martin Pitt)
- doc: Drop documentation of fslist1 (Martin Pitt)
- HACKING: Move cockpit.misc.print example to fsinfo (Martin Pitt)
- test: drop cockpit-pcp specific journal allow (Jelle van der Waa)
- login: Drop obsolete cockpit-ssh host key code path (Martin Pitt)
- ssh: Drop cockpit-ssh (Martin Pitt)
- ws: Use cockpit-beiboot for direct remote connections (Martin Pitt)
- bridge: Exit beiboot when ssh exits (Martin Pitt)
- bridge: Fix beiboot problem code for ferny.SshError (Martin Pitt)
- bridge: Implement beiboot superuser handling in bastion mode (Martin Pitt)
- bridge: Fix ssh key auth failures in beiboot (Martin Pitt)
- bridge: Implement $COCKPIT_SSH_KNOWN_HOSTS_FILE in beiboot (Martin Pitt)
- bridge: Relax too aggressive password assertion in beiboot (Martin Pitt)
- bridge: Add beiboot mode to always use the remote cockpit-bridge (Martin Pitt)
- bridge: Implicitly accept 127.0.0.1's SSH host key in beiboot (Martin Pitt)
- bridge: Handle cancel when initializing the beiboot ssh bridge (Martin Pitt)
- test: Drop obsolete commented out check in TestWsBastionContainer (Martin Pitt)
- test: Make TestMultiMachine.testDirectLogin compatible with beiboot/ssh (Martin Pitt)
- Bump the types group with 2 updates (dependabot[bot])
- Bump eslint-plugin-react in the eslint group (dependabot[bot])
- Bump sass from 1.79.3 to 1.79.4 (dependabot[bot])
- containers/ws: Move to Fedora 40 (Martin Pitt)
- containers/ws: Rename Dockerfile to Containerfile (Martin Pitt)
- containers/ws: Support host-specific ssh keys (benniekiss)
- cockpit: Implement PCP metrics channel in the Python bridge (Jelle van der Waa)
- po: Update from Fedora Weblate (GitHub Workflow)
- ws: Conditionally block channel requests to remote hosts (Marius Vollmer)
- beiboot: Handle ssh host key prompts (Martin Pitt)
- beiboot: Send initial authorize request (Martin Pitt)
- bridge: Fix beiboot's IPv6 address parsing (Martin Pitt)
- beiboot: Use distinct X-Conversation nonces (Martin Pitt)
- beiboot: Don't retry bad password three times (Martin Pitt)
- test: Make TestClient use beiboot's "flatpak" code path (Martin Pitt)
- beiboot: support for temporary UserKnownHostsFile (Allison Karlitskaya)
- login: Refactor host key database API (Martin Pitt)
- doc: Clean up Ssh-Login in authentication.md (Martin Pitt)
- Bump @types/react from 18.3.7 to 18.3.8 in the types group (dependabot[bot])
- Bump the esbuild group with 2 updates (dependabot[bot])
- Bump sass from 1.78.0 to 1.79.3 (dependabot[bot])
- doc: Fix formatting (Martin Pitt)
- workflows: drop crufty envvar in flatpak test (Allison Karlitskaya)
- flatpak: bump GNOME depend to 47 (Allison Karlitskaya)
- lib: cockpit: log channel instead of control (Jelle van der Waa)
- test: Wait longer for health check to fail (Marius Vollmer)
- bridge: stop installing our custom PCP log configuration (Jelle van der Waa)
- cockpit: metrics: remove unneeded last_timestamp check (Jelle van der Waa)
- test: Rewrite TestGrafanaClient without relying on Promise (Martin Pitt)
- test: Remove redundant wait_visible() in TestGrafanaClient (Martin Pitt)
- webdriver_bidi: Recursively unpack raw values (Martin Pitt)
- lib: Update old systemd bug reference (Martin Pitt)
- lib: Rename "path" to "cockpit-path" (Marius Vollmer)
- lib: drop pf-v5-u-font-weight-light declaration (Jelle van der Waa)
- po: Update from Fedora Weblate (GitHub Workflow)
- Bump the eslint group across 1 directory with 2 updates (dependabot[bot])
- Bump the types group across 1 directory with 2 updates (dependabot[bot])
- Bump sass from 1.77.8 to 1.78.0 (dependabot[bot])
- lib: Add path functions (Marius Vollmer)
- po: Update from Fedora Weblate (GitHub Workflow)
- test: drop shadow-utils workaround (Jelle van der Waa)
- test: drop Fedora-39 from tests (Jelle van der Waa)
- lib: drop override for wrongly colored select in dark theme (Jelle van der Waa)
- test: drop workaround for duplicate modal ids (Jelle van der Waa)
- systemd: drop old line-height unset (Jelle van der Waa)
- HACKING.md: Clarify installation (Ashley Cui)
- systemd: fix extranous divider when no results are found (Ashley Cui)
- test: bidi: log unpacking raw result before the actual unpacking (Jelle van der Waa)
- test: fix enabling low-level protocol debugging comment (Jelle van der Waa)
- Bump the eslint group with 3 updates (dependabot[bot])
- po: Update from Fedora Weblate (GitHub Workflow)
- Bump @typescript-eslint/eslint-plugin in the types group (dependabot[bot])
- Bump stylelint-formatter-pretty in the stylelint group (dependabot[bot])
- test: stop active mdadm array when test fails (Jelle van der Waa)
- storage: Expose Stratis virtual filesystem sizes (Marius Vollmer)
- selinux: remove deprecated labelOff property of a Switch (Jelle van der Waa)
- test: only run pixel tests code in the pixel tests scenario (Jelle van der Waa)
- test: workaround PF 5.4.0 breakpoint issue with ServiceTabs (Jelle van der Waa)
- Bump the patternfly group with 6 updates (dependabot[bot])
- branding: Drop obsolete kubernetes and registry branding (Martin Pitt)
- branding: Drop #index-brand (Martin Pitt)
- lib/plot: port Dropdown to PF5 (tomasmatus)
- test: navigate to the correct page directly (Jelle van der Waa)
- login: Add debug() helper and initial failure/host key debug messages (Martin Pitt)
- login: Introduce state variable for "Connect to:" remote host (Martin Pitt)
- selinux: Allow cockpit-ws to read systemd config files (Martin Pitt)
- static: Fix confusing key_key variable name (Martin Pitt)
- beiboot: Fix error code for changed host key (Martin Pitt)
- beiboot: split flatpak and bastion code paths (Allison Karlitskaya)
- protocol: add request_authorization_object API (Allison Karlitskaya)
- protocol: sequential IDs for auth messages (Allison Karlitskaya)
- storaged: filter podman btrfs subvolumes (Jelle van der Waa)
- ws: use the failing "init" message as /login result (Allison Karlitskaya)
- ws: on_login_complete: clean up JSON error path (Allison Karlitskaya)
- common: add body to cockpit_web_response_gerror() (Allison Karlitskaya)
- common: add cockpit_web_response_error_with_body() (Allison Karlitskaya)
- ws: g_autoptr()-ify on_login_complete() (Allison Karlitskaya)
- ws: give cockpit_auth_login_finish() the g_autoptr treatment (Allison Karlitskaya)
- Bump the types group with 2 updates (dependabot[bot])
- Bump stylelint from 16.8.2 to 16.9.0 in the stylelint group (dependabot[bot])
- test: drop privileges and then try to upload to /root (Jelle van der Waa)
- test: navigate to the admin page directly (Jelle van der Waa)
- storage: Never install packages on-demand in Anaconda mode (Marius Vollmer)
- packagekit: drop bugs/cve_urls workaround (Jelle van der Waa)
- test: Adjust TestLogin.testBasic for current coreutils (Martin Pitt)
- test: fsinfo: set u+rwx on directories on teardown (Allison Karlitskaya)
- po: Update from Fedora Weblate (GitHub Workflow)
- qunit: add support for precise coverage reporting (Allison Karlitskaya)
- build.js: always emit sourcemaps for qunit output (Allison Karlitskaya)
- HACKING.md: update outdated QUnit running information (Allison Karlitskaya)
- test: Temporarily make self.multihost_enabled dynamic for ubuntu-stable (Martin Pitt)
- test: Copy ubuntu-stable special cases as ubuntu-2404 (Martin Pitt)
- test: Drop obsolete ubuntu-stable special cases (Martin Pitt)
- test: Use fnmatching in OSesWithoutTracer (Martin Pitt)
- test: Determine TestStorageNBDE tang iface dynamically (Martin Pitt)
- Bump the types group with 2 updates (dependabot[bot])
- bridge: use get_int to obtain the metrics interval option (Jelle van der Waa)
- bridge: extend typing in metrics (Jelle van der Waa)
- src/build_backend: sort file list for archives (Allison Karlitskaya)
- Bump qunit from 2.21.1 to 2.22.0 (dependabot[bot])
- Revert "test: Increase RAM for TestKdumpNFS machine" (Marius Vollmer)
- packit: Re-enable Fedora 41 (Martin Pitt)
- test: Use ens15 in the initrd also on fedora-41 (Marius Vollmer)
- test: Don't collect kernel crashes in btrfs subvolumes (Marius Vollmer)
- test: Adjust valkey/redis packages for fedora-41 (Marius Vollmer)
- test: Ensure /var/cache/libdnf5 exists before cleaning it (Marius Vollmer)
- po: Update from Fedora Weblate (GitHub Workflow)
- test: Use documented syntax for pam_env (Marius Vollmer)
- test: Implement "contextmenu" mouse event for BiDi (Martin Pitt)
- pkg: add qunit tests for modify() "" vs null (Allison Karlitskaya)
- lib: Fix cockpit.file().modify() annotation (Martin Pitt)
- test: Use real mouse events in tests on Firefox (Martin Pitt)
- test: Wait for dialogs to close after running their action (Martin Pitt)
- test: Avoid popover click bug in TestJournal.testBasic (Martin Pitt)
- test: Fix double service removal in TestFirewall.testAddServices (Martin Pitt)
- test: Avoid tooltip hiding kebab in TestServices (Martin Pitt)
- test: Fix file chooser test in TestPages.testReactPatterns (Martin Pitt)
- test: Close superuser dialog in TestSuperuser.testNotAdmin (Martin Pitt)
- storage: Drop obsolete `pointerEvents: none` hack in controls (Martin Pitt)
- test: Make TestServices.test{Basic,Logs}{,User} destructive (Martin Pitt)
- tools: Fix license typo in debian/copyright (Martin Pitt)
- systemd: Relax cockpit-ws-user.service dependencies (Martin Pitt)
- test: Don't change context in WebdriverBidi.restore_context() (Martin Pitt)
- test: support Arch Linux's chromium binary name in BiDi (Jelle van der Waa)
- test: Re-teach Browser.input_text() about \n (Martin Pitt)
- packit: Temporarily disable Fedora 41 tests (Martin Pitt)
- login: Prevent multiple logins in a single browser session (Marius Vollmer)
- test: Remove ineffective config change in check-embed (Marius Vollmer)
- cockpit.js: fix cockpit.file().replace('') (Allison Karlitskaya)
- user: use `null` to delete authorized_keys files (Allison Karlitskaya)
- cockpit-ci: Update container to 2024-08-19 (Cockpit Project)
- test: Drop tracer support from CentOS/RHEL 10 (Martin Pitt)
- packagekit: Add special case for not rebooting for kpatch-only updates (Martin Pitt)
- test: Drop rhel4edge special cases (Martin Pitt)
- systemd: Add a meaningful tuned doc link (Martin Pitt)
- pkg: Fix URL redirects (Martin Pitt)
- systemd: Fix broken RHEL 9 FIPS doc link (Martin Pitt)
- systemd: Move RHEL 8 crypto-policies doc link to RHEL 9 (Martin Pitt)
- all: Update RHEL documentation links (Martin Pitt)
- tools: Ignore SVG/XML namespace URLs in urls-check (Martin Pitt)
- tools: Fix handling of redirects in urls-check (Martin Pitt)
- all: Move gnu.org/license URLs to https:// (Martin Pitt)
- Bump stylelint from 16.8.1 to 16.8.2 in the stylelint group (dependabot[bot])
- Bump @typescript-eslint/eslint-plugin in the types group (dependabot[bot])
- Bump the esbuild group with 2 updates (dependabot[bot])
- HACKING: Update default OS to fedora-40 (Martin Pitt)
- packit: Add Fedora 41, drop Fedora 39 (Martin Pitt)
- test_browser: collect coverage for qunit tests (Allison Karlitskaya)
- test_browser: make sure to always kill test-server (Allison Karlitskaya)
- webdriver_bidi: get rid of context manager nominal typing (Allison Karlitskaya)
- test/common: fix TEST_SHOW_BROWSER=0 (Allison Karlitskaya)
- pyproject.toml: tweak pyright config (Allison Karlitskaya)
- lib: table: when using colSpan > 1 adjust the indexes when calculating data labels (Katerina Koukiou)
- test/common: drop cdp vestiges (Allison Karlitskaya)
- test_browser: move from CDP to Webdriver BiDi (Allison Karlitskaya)
- webdriver: make the logging interface more complicated (Allison Karlitskaya)
- webdriver: improve cleanup of reader task (Allison Karlitskaya)
- webdriver_bidi: very minor cleanups (Allison Karlitskaya)
- test/{README,ARCHITECTURE}.md: avoid mentioning CDP (Allison Karlitskaya)
- pyproject.toml: teach pytest about testlib paths (Allison Karlitskaya)
- test: Use non-deprecated CDP setDownloadBehavior() method (Martin Pitt)
- test: Fix --trace logging for CDP commands (Martin Pitt)
- tmt: drop special-casing for RHEL 8 (Allison Karlitskaya)
- build: remove `make test` qunit leftovers (Allison Karlitskaya)
- build: rename fail.html.c to fail-html.c (Allison Karlitskaya)
- lib: Fix race condition in Terminal size calculation (Martin Pitt)
- po: Update from Fedora Weblate (GitHub Workflow)
- test: Fix Browser.wait_js_cond() failures with custom error descriptions (Martin Pitt)
- test: Enable most skipped tests on Firefox (Martin Pitt)
- test: Make Browser.switch_to_frames() work from frames (Martin Pitt)
- bridge: add missing ProtocolChannel._transport initializer (Allison Karlitskaya)
- bridge: call connection_lost "soon" (Allison Karlitskaya)
- test: Make TestConnection cookie check strict again (Martin Pitt)
- build: Drop chrome-remote-interface from release tarballs (Martin Pitt)
- test: Drop Firefox CDP support (Martin Pitt)
- test: Introduce context manager for temporarily switching browser context (Martin Pitt)
- test: Eliminiate Browser.inject_js() (Martin Pitt)
- test: Adjust TestConnection.testReverseProxy for BiDi (Martin Pitt)
- test: Port from CDP to BiDi browser automation (Martin Pitt)
- Bump glob from 7.2.3 to 11.0.0 (dependabot[bot])
- test: Explicitly set mock-insights purpose to CLIENT_AUTH (Marius Vollmer)
- storage: Allow Stratis on-demand installation on rhel-10 (Marius Vollmer)
- test: Continue to use "eth1" on rhel-10-0 (Marius Vollmer)
- test: Split off TestPages.testAllLanguages (Martin Pitt)
- test: Drop redundant _wait_present() calls (Martin Pitt)
- test: Fix unexpected nginx crash message in TestReverseProxy (Martin Pitt)
- test: Close Cockpit browser in TestGrafanaClient.testBasic (Martin Pitt)
- test: Relax cookie value check in TestConnection (Martin Pitt)
- test: Fix error reporting in ph_select() (Martin Pitt)
- Bump uuid from 9.0.1 to 10.0.0 (dependabot[bot])
- Bump @typescript-eslint/eslint-plugin in the types group (dependabot[bot])
- Bump qunit from 2.21.0 to 2.21.1 (dependabot[bot])
- Bump chrome-remote-interface from 0.33.0 to 0.33.2 (dependabot[bot])
- shell: Avoid spurious commas in ssh-keyscan command example (Marius Vollmer)
- build: Switch to @xterm/xterm and @xterm/addon-canvas (Marius Vollmer)
- test: Use ens15 instead of eth1 on centos-10 and rhel-10 (Marius Vollmer)
- test: Only look at "Class: user" sessions (Marius Vollmer)
- metrics: CentOS 10 and RHEL 10 have moved to valkey (Marius Vollmer)
- test: Increase RAM for TestKdumpNFS machine (Martin Pitt)
- test: Better logging for check-kdump Ansible tests (Martin Pitt)
- flatpak: Drop default-branch property from manifest (Martin Pitt)
- test: improve subscription-manager handling & registration (Pino Toscano)
- shell: Don't allow connections to remote machines via URLs... (Marius Vollmer)
- shell: Remove the "half-off" mode of the host switcher (Marius Vollmer)
- po: Update from Fedora Weblate (GitHub Workflow)
- po: Update from Fedora Weblate (GitHub Workflow)
- test: mock-insights: implement upload and delete platform endpoints (Pino Toscano)
- test: mock-insights: fix/improve handling of IDs (Pino Toscano)
- test: mock-insights: refactor of two platform endpoints (Pino Toscano)
- test: mock-insights: return 404 for missing systems in /systems (Pino Toscano)
- test: Make ignore_ssl_certificate_errors() implicit (Martin Pitt)
- test: Fix race condition in TestClient (Martin Pitt)
- test: Properly clean up Grafana Browser (Martin Pitt)
- test: Robustify Browser.assert_no_oops (Martin Pitt)
- test: Drop Browser.close() CDP call (Martin Pitt)
- test: Put test-functions.js helpers on window object (Martin Pitt)
- hosts: Use a cockpit.conf option to disable the host switcher (Marius Vollmer)
- systemd: Use binary channel for Terminal (Martin Pitt)
- bridge: Handle ChannelError in data_received() (Martin Pitt)
- base1: Add unit tests for binary http channel (Martin Pitt)
- Bump @typescript-eslint/eslint-plugin in the types group (dependabot[bot])
- Bump stylelint from 16.7.0 to 16.8.1 in the stylelint group (dependabot[bot])
- Bump eslint-plugin-promise in the eslint group (dependabot[bot])
- pkg: fix typos found by codespell (Jelle van der Waa)
- shell: Enable host switcher also on Fedora 40 (Marius Vollmer)
- test: add pixel tests for the journal filter panel (Jelle van der Waa)
- test: add a test for the tooltip in advanced search (Jelle van der Waa)
- po: Update from Fedora Weblate (GitHub Workflow)
- logs: Fix weird vertical alignment regression (Garrett LeSage)
- logs: Don't use IDs for CSS (Garrett LeSage)
- shell: Deprecate host switcher in current OS releases (Martin Pitt)
- css: Shuffle some code around to make SASS happy (Garrett LeSage)
- lib: Provide reduced SSH host dialogs API as library (Martin Pitt)
- systemd: drop Flex in favour of overriding the button's padding (Jelle van der Waa)
- systemd: fix help icon not being clickable in log filter panel (Jelle van der Waa)
- Bump @typescript-eslint/eslint-plugin in the types group (dependabot[bot])
- Bump sass from 1.77.6 to 1.77.8 (dependabot[bot])
- pkg: fix shebang present by file is not executable (Jelle van der Waa)
- pkg: enable E501 for pkg/ directory (Jelle van der Waa)
- test: Ignore `machine.image_file` type check failure (Martin Pitt)
- test/static-code: Ignore pkg/lib for non-Cockpit projects (Martin Pitt)
- package.json: replace single lodash user to a simple string replace (Jelle van der Waa)
- fmf: Force-upgrade shadow-utils in rawhide (Martin Pitt)
- cockpit-ci: Update container to 2024-07-24 (Cockpit Project)
- po: Update from Fedora Weblate (GitHub Workflow)
- test: Re-relax the `{become,drop}_superuser()` checks (Martin Pitt)
- Bump the stylelint group across 1 directory with 2 updates (dependabot[bot])
- lib, doc: Annotate Firefox specific CSS rules (Martin Pitt)
- test: Fix machine console log in TestKdumpNFSAnsible (Martin Pitt)
- kdump: Fix crash with yet uninitialized kdumpStatus.target (Martin Pitt)
- test: Allow different panel HTML elements in Grafana (Martin Pitt)
- Bump the eslint group with 2 updates (dependabot[bot])
- Bump @typescript-eslint/eslint-plugin in the types group (dependabot[bot])
- storaged: make SelectOneRadio support a vertical option (Jelle van der Waa)
- test: Avoid :contains() in testlib.py (Martin Pitt)
- test: Clean up Browser.select_PF[45]() (Martin Pitt)
- lib: Add onlyDirectories option to FileAutoComplete (Marius Vollmer)
- test: Use input_text("\n") instead of key("Enter") in most places (Marius Vollmer)
- test: Handle "\n" specially with set_input_text and input_text (Marius Vollmer)
- test: Generalize tracer failure message on logout (Martin Pitt)
- test: Drop obsolete expected tracer crash in RHEL 8 (Martin Pitt)
- lib: isInline, type and isLiveRegion are wrongly typed (Jelle van der Waa)
- pkg/lib: add new public "Channel" API (Allison Karlitskaya)
- pkg/lib: port Transport to TypeScript (Allison Karlitskaya)
- pkg/lib: convert transport_globals to a class (Allison Karlitskaya)
- pkg/lib: step up type checking in Transport (Allison Karlitskaya)
- pkg/lib: simplify incoming filter logic (Allison Karlitskaya)
- pkg/lib: eliminate parse_channel in transport.js (Allison Karlitskaya)
- pkg/lib: eliminate "out" filtering (Allison Karlitskaya)
- pkg/lib: remove public_transport hook (Allison Karlitskaya)
- pkg/lib: port ParentWebSocket to TypeScript (Allison Karlitskaya)
- pkg/lib: convert ParentWebSocket to class (Allison Karlitskaya)
- pkg/lib: simplify WebSocket setup code (Allison Karlitskaya)
- pkg/lib: avoid `arguments` in transport.js (Allison Karlitskaya)
- pkg/lib: move methods out of Transport.constructor (Allison Karlitskaya)
- pkg/lib: convert Transport.constructor locals to privates (Allison Karlitskaya)
- pkg/lib: drop `self` in Transport.constructor (Allison Karlitskaya)
- pkg/lib: use arrows in Transport.constructor() (Allison Karlitskaya)
- pkg/lib: use EventEmitter on Transport API (Allison Karlitskaya)
- pkg/lib: transport: Convert function to a class (Allison Karlitskaya)
- pkg/lib: un-"export" Transport API (Allison Karlitskaya)
- pkg/lib: transport: simplify binary frame pasting (Allison Karlitskaya)
- pkg/lib: move event/fsinfo/_internal into cockpit/ (Allison Karlitskaya)
- .eslintrc.json: setup some TypeScript rules (Allison Karlitskaya)
- pytest: fix pytest-asyncio version check (Allison Karlitskaya)
- users: allow clearing the search filter in EmptyStatePanel (Jelle van der Waa)
- lib: make loading explicitly default false in EmptyStatePanel (Jelle van der Waa)
- systemd: use EmptyStatePanel's onAction API (Jelle van der Waa)
- metrics: use onActions EmptyStatePanel API (Jelle van der Waa)
- lib: type cockpit.logout (Jelle van der Waa)
- systemd: drop default loading state for EmptyStatePanel (Jelle van der Waa)
- systemd: show loading state for EmptyStatePanel actions (Jelle van der Waa)
- networkmanager: check if NetworkManager service exists (Jelle van der Waa)
- lib: allow configuring the action variant of an EmptyStatePanel (Jelle van der Waa)
- pytest: skip pidfd ENOSYS on Python 3.12+ (Allison Karlitskaya)
- pytest: drop the 'old python' child watcher test (Allison Karlitskaya)
- pytest: use event_loop_policy fixture, if possible (Allison Karlitskaya)
- pytest: clean up a couple of users of event_loop (Allison Karlitskaya)
- pyproject.toml: Vulture: ignore pytest fixtures (Allison Karlitskaya)
- lib: FormGroup has no `validated` field (Jelle van der Waa)
- storaged: compmoment is a type of component (Jelle van der Waa)
- sosreport: PatternFly supports "grey" not "gray" (Jelle van der Waa)
- all: cockpit.warn does not exists (Jelle van der Waa)
- po: Update from Fedora Weblate (GitHub Workflow)
- po: Add 'zh_TW' language (GitHub Workflow)
- test: unexpected whitespace after decorator (Jelle van der Waa)
- test: Reduce dependency on #host-sel button (Martin Pitt)
- tests: Reduce dependency on #host-toggle (Martin Pitt)
- test: Stop using "Add new host" shell functionality in TestIPA (Martin Pitt)
- test: Drop obsolete "kerberos sudo with S4U ticket" check (Martin Pitt)
- test: Complete and clean up check-shell-multi-os (Martin Pitt)
- test: Move add_machine() and start_machine_troubleshoot() from MachineCase to Browser (Martin Pitt)
- Bump the patternfly group with 2 updates (dependabot[bot])
- Bump eslint-plugin-react in the eslint group (dependabot[bot])
- apps: drop custom content-security-policy (Jelle van der Waa)
- lib: Convert cockpit-components-inline-notification to TypeScript and functional (Martin Pitt)
- shell: Disable shellcheck warning in ssh-add-key.sh (Martin Pitt)
- test: Add MachineCase.login_and_go() `password` argument (Martin Pitt)
- pkg/lib: add reference from cockpit.d.ts to cockpit.js (Allison Karlitskaya)
- test: Wipe lastlog db for TestSystemInfo.testBasic pixel test (Martin Pitt)
- test: Allow other "external channel failed" errors on restarts (Martin Pitt)
- package.json: add missing dependencies (Allison Karlitskaya)
- pkg/lib: clean up node imports (Allison Karlitskaya)
- po: Update from Fedora Weblate (GitHub Workflow)
- tsconfig.json: don't typecheck esbuild plugins (Allison Karlitskaya)
- lib: credentials.js code cleanups (Martin Pitt)
- lib: Drop `two_pass` argument from credentials methods (Martin Pitt)
- lib: Fix race condition in credentials.js (Martin Pitt)
- lib: Fix {Channel,Spawn}.close() annotation (Martin Pitt)
- lib: Declare cockpit.translate() (Martin Pitt)
- lib: Fix and extend channel option types (Martin Pitt)
- lib: Add cockpit.script() type annotations (Martin Pitt)
- test: handle optionally installed python3-pcp in metrics test (Jelle van der Waa)
- doc: protocol: 'pcmd' should be 'pmcd' (Jelle van der Waa)
- metrics: omit loopback device properly in PCP metrics (Jelle van der Waa)
- unit-tests: fix json strings (tomasmatus)
- Bump the esbuild group with 2 updates (dependabot[bot])
- Bump the eslint group with 3 updates (dependabot[bot])
- test: handle optionally installed python3-pcp in beiboot test (Jelle van der Waa)
- lib: Fix server time (Martin Pitt)
- Bump @typescript-eslint/eslint-plugin in the types group (dependabot[bot])
- systemd: don't show dsa host keys (Jelle van der Waa)
- tools, test: Drop cockpit-pcp from Debian testing (Martin Pitt)
- test: Skip TestLogin.testClientCertAuthentication on debian-testing (Martin Pitt)
- test: Fix potential race condition in TestStorageswap (Martin Pitt)
- test: Factorize swap usage assertion in check-storage-swap (Martin Pitt)
- test: Factorize skipOstree in check-metrics (Martin Pitt)
- Revert "test: Adjust to kdump-utils split in Fedora 40" (Martin Pitt)
- fmf: Add missing semanage test dependency (Martin Pitt)
- cockpit.js: Add fsinfo fallback to fswatch1 (Martin Pitt)
- cockpit-ci: Update container to 2024-07-04 (Cockpit Project)
- pytest: Ignore RUF029 in test_immediate_shutdown (Martin Pitt)
- systemd: openssh 9.8 disabled DSA by default (Jelle van der Waa)
- pam-ssh-add: Fix insecure killing of session ssh-agent [CVE-2024-6126] (Martin Pitt)
- test: Restrict ABRT/reportd tests to Fedora 39/40 (Martin Pitt)
- po: Update from Fedora Weblate (GitHub Workflow)
- test/static-code: tweak Typescript config again (Allison Karlitskaya)
- test: wait until the memory usage is the expected bigger value (Jelle van der Waa)
- test: wait till some json appears (Jelle van der Waa)
- test: robustify creating a partition table in a test (Jelle van der Waa)
- test: introduce `run-tests --amplify` for debugging (Jelle van der Waa)
- package.json: Drop date-fns (Martin Pitt)
- sosreport: Read report directory from sos config (Martin Pitt)
- test: Fix overly long lines in check-sosreport (Martin Pitt)
- lib: Reimplement timeformat.distanceToNow() with standard browser API (Martin Pitt)
- storaged: Change "Runtime" duration to "Started" point in time (Martin Pitt)
- systemd: Change "Uptime" duration to "Up since" point in time (Martin Pitt)
- base1: Add unit test for timeformat.distanceToNow of one day (Martin Pitt)
- Bump throttle-debounce from 5.0.0 to 5.0.2 (dependabot[bot])
- Bump sass from 1.77.1 to 1.77.6 (dependabot[bot])
- cockpit.d.ts: fix some `cockpit.file()` annotations (Allison Karlitskaya)
- Use fsinfo for cockpit.file.watch() (Jelle van der Waa)
- test: workaround "should become root" logic (Jelle van der Waa)
- Revert "test: packagelib - robustify disabling of services" (Martin Pitt)
- lib: Drop timeformat.{dateShortFormat,parseShortDate}() (Martin Pitt)
- lib: Always use ISO format for date picker manual input (Martin Pitt)
- fsinfo: use `new Channel` directly (Allison Karlitskaya)
- cockpit.js: tweak "factory" setup. (Allison Karlitskaya)
- cockpit.js: move a function closer to its one user (Allison Karlitskaya)
- cockpit.js: split Channel into its own file (Allison Karlitskaya)
- cockpit.js: split Deferred out to a separate file (Allison Karlitskaya)
- cockpit.js: avoid calling cockpit.defer() (Allison Karlitskaya)
- cockpit.js: split Transport code into its own file (Allison Karlitskaya)
- cockpit.js: split base64 helpers to their own file (Allison Karlitskaya)
- cockpit.js: remove an unused variable (Allison Karlitskaya)
- cockpit.js: combine many transport-related globals (Allison Karlitskaya)
- cockpit.js: split ParentWebSocket into its own file (Allison Karlitskaya)
- pkg/lib: move location.js → location.ts (Allison Karlitskaya)
- cockpit.js: split location helpers to their own file (Allison Karlitskaya)
- cockpit.js: make url_root a constant (Allison Karlitskaya)
- cockpit.js: depend on `window.location.origin` (Allison Karlitskaya)
- cockpit.js: split event_mixin to a separate file (Allison Karlitskaya)
- pkg/lib/_internal/common.ts: add some utility types (Allison Karlitskaya)
- pkg/lib: rename common.js → common.ts (Allison Karlitskaya)
- pkg/lib/_internal/common.js: simplify iterate_data() (Allison Karlitskaya)
- pkg/lib/_internal/common.js: remove some old compat code (Allison Karlitskaya)
- cockpit.js: split helper functions to new file (Allison Karlitskaya)
- cockpit.js: move is_negative() closer to its one user (Allison Karlitskaya)
- test: don't type check pkg/lib outside of cockpit (Jelle van der Waa)
- test: packagelib - robustify disabling of services (Jan Ščotka)
- test: Fix type of MachineCase.machine_class (Martin Pitt)
- node_modules: switch from deep_equal to dequal (Jelle van der Waa)
- test: Tolerate absent /home (Martin Pitt)
- build.js: support outputting esbuild metadata file (Jelle van der Waa)
- lib: Fix timeformat.parseShortDate() (Martin Pitt)
- base1: Add unit test for timeformat library (Martin Pitt)
- lib: Type-annotate timeformat (Martin Pitt)
- pkg: Drop extension in timeformat imports (Martin Pitt)
- test: Adjust to kdump-utils split in Fedora 40 (Martin Pitt)
- po: Update from Fedora Weblate (GitHub Workflow)
- pkg/lib: remove wasOutside check from context menu (Allison Karlitskaya)
- shell: port to Dialogs.run() (Allison Karlitskaya)
- pkg/lib: add `Dialogs.run()` (Allison Karlitskaya)
- pkg/lib: port WithDialogs/useDialogs to TypeScript (Allison Karlitskaya)
- cockpit.d.ts: advertise cockpit.transport (Allison Karlitskaya)
- pkg/lib: Port various components to TypeScript (Allison Karlitskaya)
- tools: Rename README.node_modules to Markdown (Martin Pitt)
- tools: Update README.node_modules (Martin Pitt)
- tools: Disable cockpit-pcp on Fedora 39 on i686 (Martin Pitt)
- Revert "test: Ignore "invalid non-UTF8 @data passed" message" (Martin Pitt)
- bridge: Fix text channels with split UTF8 chars across frames (Martin Pitt)
- bridge: Split Channel.send_data() into send_{bytes,text}() (Martin Pitt)
- bridge: Factorize "binary" option evalution into Channel (Martin Pitt)
- all: Drop UTF-8 argument from .decode()/.encode() (Martin Pitt)
- cockpit.js: Fix exception reporting for cockpit.http() errors (Martin Pitt)
- gitignore: Re-ignore built tmpfiles.d file (Martin Pitt)
- pkg/lib: fix context menu component popdown (Allison Karlitskaya)
- Bump @typescript-eslint/eslint-plugin in the types group (dependabot[bot])
- plans: add cockpit-files reverse dependency testing (Jelle van der Waa)
- base1: add tests for the fsinfo library (Allison Karlitskaya)
- pkg/lib: add 'fsinfo' client library (Allison Karlitskaya)
- tsconfig: switch target to es2020 (Allison Karlitskaya)
- test: allow duplicate key errors on SELinux page (Jelle van der Waa)
- btrfs: show the origin of the snapshot in subvolume details (Jelle van der Waa)
- btrfs: show snapshots of a subvolume in the subvolume details page (Jelle van der Waa)
- btrfs: obtain subvolume snapshot information (Jelle van der Waa)
- bridge: fix multiple close in fswatch1 (Allison Karlitskaya)
- test: Drop Grafana selector class names (Martin Pitt)
- test: Ignore unknown PAM error with closing sessions (Martin Pitt)
- test: Drop is_pybridge() (Martin Pitt)
- test: Move ssh-agent test into TestSession (Martin Pitt)
- flatpak: add cockpit-files to packages list (Allison Karlitskaya)
- systemd: update DBusGError documentation url (Jelle van der Waa)
- lib: follow patternfly issue redirect (Jelle van der Waa)
- pkg/lib: make the upload-helper WebKit-compatible (Allison Karlitskaya)
- tools: URLError has no attribute code (Jelle van der Waa)
- debian: Enable DynamicUser for cockpit-ws (Martin Pitt)
- po: Update from Fedora Weblate (GitHub Workflow)
- test: Avoid `su` to system users (Martin Pitt)
- storage: Move to "r6" of the Stratis D-Bus API (Marius Vollmer)
- lib: import Flex from the Flex directory (Jelle van der Waa)
- build: Drop --enable-old-bridge configure option (Martin Pitt)
- users: Fix user details for lastlog2 (Martin Pitt)
- test: Reset lastlog2 databases (Martin Pitt)
- test: Drop obsolete systemd version parsing (Martin Pitt)
- test: Ignore lastlog 2 PAM module message (Martin Pitt)
- tools: arch: add glib2-devel as makedependency (Jelle van der Waa)
- debian: Clean up AppArmor upgrade workaround (Martin Pitt)
- debian: Add autopkgtest logs for debugging failure (Martin Pitt)
- debian: Add workaround for stable kernel+LXC breaking DynamicUser= (Martin Pitt)
- debian: Make apparmor_parser failures non-fatal again (Martin Pitt)
- test: Stop failing on SELinux messages for all Fedoras (Martin Pitt)
- test: Stop failing on SELinux messages in rawhide and CentOS 10 (Martin Pitt)
- test: Widen pasta hack for newer podman versions (Martin Pitt)
- Bump esbuild from 0.21.4 to 0.21.5 in the esbuild group (dependabot[bot])
- Bump @typescript-eslint/eslint-plugin in the types group (dependabot[bot])
- po: Update from Fedora Weblate (GitHub Workflow)
- test/static-code: make mypy deps configurable (Allison Karlitskaya)
- tools: Suggest lastlog2 in Debian package (Martin Pitt)
- users: Fix crash on nonexisting lastlog (Martin Pitt)
- cockpit-ci: Update container to 2024-06-11 (Cockpit Project)
- typescript: enable --exactOptionalPropertyTypes (Allison Karlitskaya)
- packagekit: mention kpatch/updates in the manifest (Jelle van der Waa)
- test: Drop Browser.key_press(), replace with Browser.input_text() (Martin Pitt)
- test: Port non-text Browser.key_press() to Browser.key() (Martin Pitt)
- test: Add "repeat" argument to Browser.key() (Martin Pitt)
- Bump @typescript-eslint/eslint-plugin in the types group (dependabot[bot])
- Bump qunit from 2.20.1 to 2.21.0 (dependabot[bot])
- Bump esbuild-sass-plugin in the esbuild group (dependabot[bot])
- shell: Fix and test skip links (Martin Pitt)
- test: Introduce testlib API for pressing/releasing a single key (Martin Pitt)
- test: Switch to desktop profile (Martin Pitt)
- test: More precise tuned "balanced profile" selector (Martin Pitt)
- test: Bump PCP config dialog timeout (Martin Pitt)
- pkg/lib: port context-menu component to Typescript (Allison Karlitskaya)
- pkg/lib: allow null messages on form-helper component (Allison Karlitskaya)
- lib: Fix ShutdownModal error type on `shutdown` errors (Martin Pitt)
- tools: Bump Debian Standards-Version to 4.7.0 (Martin Pitt)
- tools: Bring back static cockpit-ws system user creation on Debian (Martin Pitt)
- lib: Accept `false` values in manifest configuration (Martin Pitt)
- base1: Drop cockpit.utf8_{de,en}coder() (Martin Pitt)
- Replace cockpit.utf8_{de,en}coder with standard JS API (Martin Pitt)
- bridge: report target info for '..' on fsinfo (Allison Karlitskaya)
- tools: Drop i686 build on CentOS/RHEL 9 as well (Martin Pitt)
- fmf: Drop NetworkManager-team test dependency (Martin Pitt)
- po: Update from Fedora Weblate (GitHub Workflow)
- cockpit.js: make access to Gid field conditional (Allison Karlitskaya)
- tools: Conditionally install AppArmor profile in Debian/Ubuntu (Martin Pitt)
- tools: Drop Fedora i686 package for Fedora 41/RHEL 10 (Martin Pitt)
- cockpit-ci: Update container to 2024-06-03 (Allison Karlitskaya)
- bridge: fix type annotation on GeneratorChannel (Allison Karlitskaya)
- Bump the eslint group across 1 directory with 2 updates (dependabot[bot])
- test: add a test for `cockpit.user()` information (Jelle van der Waa)
- bridge: add primary group to groups list (Allison Karlitskaya)
- lib: add gid field to UserInfo (Jelle van der Waa)
- Bump @typescript-eslint/eslint-plugin in the types group (dependabot[bot])
- Bump stylelint from 16.6.0 to 16.6.1 in the stylelint group (dependabot[bot])
- po/Makefile.am: run xgettext on typescript sources (Allison Karlitskaya)
- systemd: close the shutdown dropdown on select (Jelle van der Waa)
- systemd: do not pass `spaceItemsSm` key to Flex spacer property (Jelle van der Waa)
- users: KebabDropdown takes a toggleButtonId not an id (Jelle van der Waa)
- metrics: spaceItems has no `modifier` key (Jelle van der Waa)
- systemd: stop passing `{ default: 'spaceItemsSm' } to Flex (Jelle van der Waa)
- packagekit: EmptyStatePanel takes no titleSize property (Jelle van der Waa)
- packagekit: Badge has no property variant (Jelle van der Waa)
- lib: add cockpit.hidden to cockpit typescript defs (Jelle van der Waa)
- storage: Confirmation before erasing actual data (Marius Vollmer)
- metrics: Prefer valkey over redis (Martin Pitt)
- metrics: Rewrite PCPConfigDialog.handleInstall() with `async` (Martin Pitt)
- test: Some small TestHistoryMetrics cleanups (Martin Pitt)
- lib: Generalize manifest config reading (Martin Pitt)
- examples: Drop kubernetes (Martin Pitt)
- fmf: Fix bogus /dev/sda* → nvme* symlinks on TF machines (Martin Pitt)
- fmf: Reorganize and rebalance tests (Martin Pitt)
- po: Update from Fedora Weblate (GitHub Workflow)
- test: Use root as a superuser on SUSE images (Miika Alikirri)
- pkg/lib: port form-helper component to typescript (Allison Karlitskaya)
- users: Correctly catch errors from "useradd -D" (Marius Vollmer)
- test: Drop skipDistroPackage decorator (Martin Pitt)
- Bump the types group with 2 updates (dependabot[bot])
- storaged: fix typo apges => pages (Jelle van der Waa)
- Bump stylelint from 16.5.0 to 16.6.0 in the stylelint group (dependabot[bot])
- Bump esbuild from 0.21.3 to 0.21.4 in the esbuild group (dependabot[bot])
- test: RHEL 10 dropped SHA1 crypto policy module (Martin Pitt)
- test: Skip FreeIPA tests on debian-testing (Martin Pitt)
- users: Replace utmp watching with logind signals (Martin Pitt)
- users: Clean up expiry effect in AccountDetails (Martin Pitt)
- users: Replace `w` with logind ListUsers() (Martin Pitt)
- metrics: Drop obsolete base-10 specifier in format_bytes() call (Martin Pitt)
- packit: Enable CentOS Stream 10 tests (Martin Pitt)
- fmf: Add hack for podman failure in RHEL 10 (Martin Pitt)
- fmf: Add hack around Fedora repository in C10 TF images (Martin Pitt)
- guide: Fix TLS localhost exception (Martin Pitt)
- users: Support for watching lastlog2 and wutmp on overview page (Luna)
- packagekit: Support dnf5-plugin-automatic (Martin Pitt)
- packagekit: Automatic updates getConfig() refactoring (Martin Pitt)
- test: Split "dnf" PackageCase backend into dnf4/5 (Martin Pitt)
- test: Fix DNF5 automatic timer name (Martin Pitt)
- test: Adjust dnf5 condition for fedora-rawhide (Martin Pitt)
- test: Drop redundant dnf-automatic cleanup in check-packagekit (Martin Pitt)
- storage: Remove support for Stratis 2 (Marius Vollmer)
- .eslintrc.json: boolean values are deprecated for globals (Jelle van der Waa)
- Bump the esbuild group across 1 directory with 2 updates (dependabot[bot])
- Bump @typescript-eslint/eslint-plugin in the types group (dependabot[bot])
- workflows: Use Fedora 40 to trigger Anaconda (Marius Vollmer)
- workflows: DNF plugin packages have changed on rawhide (Marius Vollmer)
- Drop flowconfig (Jelle van der Waa)
- test: skip TestAutoUpdates.testWithAvailableUpdates on DNF 5 (Jelle van der Waa)
- test: don't fail tests on DNF5 (Jelle van der Waa)
- test: systemctl stop user@*.service now also kills the root session (Jelle van der Waa)
- test: adjust list-sessions for systemd 256 changes (Jelle van der Waa)
- Bump @types/react from 18.3.1 to 18.3.2 in the types group (dependabot[bot])
- Bump sass from 1.77.0 to 1.77.1 (dependabot[bot])
- storage: Give empty "Th" elements a aria-label attribute (Marius Vollmer)
- pkg/lib: Give empty "Th" elements a aria-label attribute (Marius Vollmer)
- dependabot: Dial down to weekly (Martin Pitt)
- packagekit: Fix kpatch error message (Martin Pitt)
- test: Terminate sessions before restoring files/directories (Martin Pitt)
- lib: deps are optional for useInit (Jelle van der Waa)
- systemd: Use systemd-sysusers to create cockpit-wsinstance user (Timothée Ravier)
- tools: Drop obsolete permission upgrade in Debian package (Martin Pitt)
- tools: Remove cockpit-session statoverride on purging Debian package (Martin Pitt)
- Bump sass from 1.76.0 to 1.77.0 (dependabot[bot])
- tools: Use `DynamicUser` for cockpit.service (Martin Pitt)
- systemd: Consistently put Documentation= below Description= (Martin Pitt)
- systemd: De-template wsinstance socket units (Martin Pitt)
- systemd: Remove wsinstance Unix sockets while not running (Martin Pitt)
- test: Drop obsolete chowning of ws certificate (Martin Pitt)
- lib: cockpit.spawn.input() also accepts null | undefined (Jelle van der Waa)
- po: Update from Fedora Weblate (GitHub Workflow)
- test: Drop CentOS 8 special cases (Martin Pitt)
- test: Move TestMultiOSDirect from centos-8-stream to rhel-8-10 (Martin Pitt)
- test: Fix handling of "closing" sessions in TestSession.testBasic (Martin Pitt)
- tools: Lower kdumpctl dependency to Recommends on RHEL (Martin Pitt)
- Bump sass from 1.75.0 to 1.76.0 (dependabot[bot])
- systemd: Fix state handling with creating repeating timers (Martin Pitt)
- storage: Don't warn about missing bitmap when MDRAID has a journal (Marius Vollmer)
- Bump stylelint from 16.4.0 to 16.5.0 in the stylelint group (dependabot[bot])
- Bump the patternfly group with 6 updates (dependabot[bot])
- users: Support for watching lastlog2 (Luna)
- lib: Fix shellcheck complaint about `test -o` (Martin Pitt)
- storaged: Use kernelopt.sh to set rd.neednet=1 (Martin Pitt)
- test: Drop mobile pixel tests in TestHistoryMetrics.testEvents (Martin Pitt)
- test: disable popup blocking for Cockpit-files (Jelle van der Waa)
- build: Remove cockpit(-ws-instance) user/group config option (Timothée Ravier)
- po: Update from Fedora Weblate (GitHub Workflow)
- cockpit-ci: Update container to 2024-04-25 (Allison Karlitskaya)
- workflows/unit-tests: disable seccomp for podman (Allison Karlitskaya)
- testlib: fix Pillow type annotations (Allison Karlitskaya)
- Rename cockpit-tempfiles.conf to cockpit-ws.conf (Timothée Ravier)
- Bump @typescript-eslint/eslint-plugin in the types group (dependabot[bot])
- test: bump ansible machine memory size (Jelle van der Waa)
- pkg/lib: change API of upload helper to Blob (Allison Karlitskaya)
- bridge: add `size` hint attribute for fsreplace1 (Allison Karlitskaya)
- bridge: split up fsreplace1 code a bit (Allison Karlitskaya)
- bridge: use tempfile.mkstemp() for fsreplace1 (Allison Karlitskaya)
- bridge: add AsyncChannel.in_thread() (Allison Karlitskaya)
- bridge: add 'loop' attribute on AsyncChannel (Allison Karlitskaya)
- channel: modernise type hints a bit (Allison Karlitskaya)
- channel: drop unused ._loop instance variable (Allison Karlitskaya)
- Bump the patternfly group with 3 updates (dependabot[bot])
- test: update reference-image to Fedora-40 (Jelle van der Waa)
- Bump the react group across 1 directory with 3 updates (dependabot[bot])
- test: Adjust for new selinuxuser_execmod flag on Fedora 40 (Martin Pitt)
- Bump eslint-plugin-react-hooks in the eslint group (dependabot[bot])
- Bump the react group across 1 directory with 4 updates (dependabot[bot])
- Bump eslint-plugin-react-hooks in the eslint group (dependabot[bot])
- test: add pixel tests for the help and session menu (Jelle van der Waa)
- test: Fix unexpected "truncated data in external channel" messages (Martin Pitt)
- test: Drop obsolete compat test cases for RHEL/CentOS 7 (Martin Pitt)
- pf: Fix menu items cropping their content (Garrett LeSage)
- lib: allow awaiting Dialogs.show() (Jelle van der Waa)
- pf: Fix double-spacing issue for other dropdowns as well (Garrett LeSage)
- pf: Fix split button double spacing issue (Garrett LeSage)
- HACKING: add information on how to use React Developer Tools (Jelle van der Waa)
- test/README.md: document TEST_BIND_GLOBAL=1 (Allison Karlitskaya)
- storage: Exclude eMMC "boot" non-partitions from multipath logic (Marius Vollmer)
- systemd, storaged: Fix deprecated format_bytes() calls (Martin Pitt)
- base1: Add format_bytes{,_per_sec}() unit tests for 0 value (Martin Pitt)
- Bump stylelint from 16.3.1 to 16.4.0 in the stylelint group (dependabot[bot])
- base1: Fix format_bytes() B unit (Martin Pitt)
- base1: Fix format_bytes() kB unit (Martin Pitt)
- kdump: Clean up formatting of reserved memory (Martin Pitt)
- Bump @typescript-eslint/eslint-plugin in the types group (dependabot[bot])
- eslint: enable no-useless-fragment rule by default (Jelle van der Waa)
- test/static-code: copy mypy setup from bots/ (Allison Karlitskaya)
- various: many typing-related fixups (Allison Karlitskaya)
- testlib: drop todoPybridge decorator (Allison Karlitskaya)
- test/common/__init__.py: drop this file (Allison Karlitskaya)
- tap-cdp: fix a case of module shadowing (Allison Karlitskaya)
- tools: rename vulture(- → _)suppressions (Allison Karlitskaya)
- pywrap: simplify bots python path (Allison Karlitskaya)
- test/static-code: speed up JSON validation (Allison Karlitskaya)
- lib: initial typing for cockpit.spawn (Jelle van der Waa)
- playground: superuser option is a string not a bool (Jelle van der Waa)
- systemd: superuser option is a string not a bool (Jelle van der Waa)
- sosreport: superuser option is a string not a bool (Jelle van der Waa)
- lib: superuser option is a string not a bool (Jelle van der Waa)
- selinux: superuser option is a string not a bool (Jelle van der Waa)
- storaged: superuser option is a string not a bool (Jelle van der Waa)
- lib: add typing for dbus related variant and bytearray functions (Jelle van der Waa)
- Bump the patternfly group with 6 updates (dependabot[bot])
- test: port test-format to typescript (Allison Karlitskaya)
- cockpit.js: add new number formatting API style (Allison Karlitskaya)
- storage: add a testcase for format_fsys_usage() (Allison Karlitskaya)
- test: use f-strings in asserts in test-format (Allison Karlitskaya)
- test: add f`` tagged template string helper (Allison Karlitskaya)
- storaged: simplify utils.get_byte_units() (Allison Karlitskaya)
- base1: drop cockpit.get_byte_units() API (Allison Karlitskaya)
- tools: Depend on kdumpctl binary (Martin Pitt)
- test: Adjust special cases for CentOS/RHEL 10 (Martin Pitt)
- test: Unbreak half of podman on RHEL 10 (Martin Pitt)
- test: Make encrypt_root()'s old root fs destruction less aggressive (Martin Pitt)
- test: stop using deprecated cgi module for multipart post parsing (Jelle van der Waa)
- test: testIdentifierReloading is not destructive (Jelle van der Waa)
- test: testBridgeCLI is not destructive (Jelle van der Waa)
- test: Use `nft` instead of `iptables` (Martin Pitt)
- test: Clean up systemd units after erasing packages (Martin Pitt)
- test: Less aggressive pmlogger log cleaning in TestGrafanaClient (Martin Pitt)
- Bump @types/react from 18.2.78 to 18.2.79 in the types group (dependabot[bot])
- po: Update from Fedora Weblate (GitHub Workflow)
- test: support typescript on qunit tests (Allison Karlitskaya)
- bridge: fix a `(a and b) or c` case (Allison Karlitskaya)
- lib: type all format related functions (Jelle van der Waa)
- test/static-code: drop flake8 (Allison Karlitskaya)
- pyproject: enable 'preview' ruff rules (Allison Karlitskaya)
- test: Update journal check in TestHistoryMetrics.testEvents to current systemd (Martin Pitt)
- users: drop superuser "require" for /etc/login.defs (Jelle van der Waa)
- users: cockpit.spawn's superuser option is not a boolean (Jelle van der Waa)
- lib: introduce an upload() helper for fsreplace1 (Jelle van der Waa)
- bridge: send acks on receiving data (Allison Karlitskaya)
- bridge: tweak a comment in AsyncChannel (Allison Karlitskaya)
- bridge: rewrite fsreplace1 as AsyncChannel (Allison Karlitskaya)
- test: workaround for watch channel issue (Martin Pitt)
- test: Fix race condition with waiting for page load (Martin Pitt)
- Bump the types group with 2 updates (dependabot[bot])
- pytest: Bring back Transport tests (Martin Pitt)
- cockpit-ci: Update container to 2024-04-08 (Cockpit Project)
- Bump sass from 1.74.1 to 1.75.0 (dependabot[bot])
- Bump @types/react from 18.2.76 to 18.2.77 in the types group (dependabot[bot])
- lib: the channel superuser option takes "try" or "require" (Jelle van der Waa)
- test: Add sshd restart workaround on Ubuntu after joining IPA domain (Martin Pitt)
- test: Clean up the kerberos waiting script (Martin Pitt)
- test: Add forgotten SSH service unit constants (Martin Pitt)
- lib: Close Dropdown after selection instead of toggling it (Marius Vollmer)
- Bump the types group with 2 updates (dependabot[bot])
- base1: add cockpit.assert() (Allison Karlitskaya)
- test: lcov: add coverage for ts/x files (Allison Karlitskaya)
- users: Fix handling of failed date parsing (Chris Wiggins)
- Bump the types group with 2 updates (dependabot[bot])
- dependabot: Group react packages (Martin Pitt)
- dependabot: Update all typescript related packages as a group (Martin Pitt)
- Bump @types/react-dom from 18.2.18 to 18.2.24 (dependabot[bot])
- pkg/lib: rename hooks.js to hooks.ts (Allison Karlitskaya)
- test/static-code: add support for typescript (Allison Karlitskaya)
- workflows: Run release on Ubuntu 20.04 (Martin Pitt)
- po: Update from Fedora Weblate (GitHub Workflow)
- systemd: remove useless spread and list (Jelle van der Waa)
- workflows: Run tasks-container-update in "self" environment (Martin Pitt)
- bridge: return tracebacks on internal-error exceptions (Allison Karlitskaya)
- bridge: cancel AsyncChannel task on close (Allison Karlitskaya)
- bridge: fix AsyncChannel handling of empty messages (Allison Karlitskaya)
- bridge: use get_enum() instead of get_str() (Allison Karlitskaya)
- jsonutil: add a new 'get_enum()` helper. (Allison Karlitskaya)
- test: Fix login page flake in TestUpdates.testTracer (Martin Pitt)
- test: Use fixed machine ID for pixel test (Martin Pitt)
- cockpit-ci: Update container to 2024-04-06 (Cockpit Project)
- pkg: fix fragments should contain more then one child (Jelle van der Waa)
- lib: Add optional external open state to KebabDropdown (Martin Pitt)
- Bump sass from 1.72.0 to 1.74.1 (dependabot[bot])
- test: Use proper ssh service unit on Debian/Ubuntu (Martin Pitt)
- systemd: Also check ssh.socket unit for ListenStream (Martin Pitt)
- tmt: Pass TEST_* environment into test container (Marius Vollmer)
- shell: networkmanager: systemd: port to non-deprecated Dropdown (Jelle van der Waa)
- Bump the stylelint group with 1 update (dependabot[bot])
- po: Update from Fedora Weblate (GitHub Workflow)
- tools: add 'release' script (Allison Karlitskaya)
- Move remaining quay.io/cockpit/tasks references to ghcr.io (Martin Pitt)
- test: Also allow modern "mount" error message (Marius Vollmer)
- shell, tuned: Update remaining doc links to RHEL 9 (Martin Pitt)
- shell: lib: handle cockpit.user() failures (Jelle van der Waa)
- lib: port cockpit.user to use standard promises (Jelle van der Waa)
- sosreport: Fix command injection with crafted report names [CVE-2024-2947] (Martin Pitt)
- build: Put .cockpit-ci into source tarballs (Marius Vollmer)
- lib: Avoid infinite layout measurements in plots (Marius Vollmer)
- Bump the stylelint group with 1 update (dependabot[bot])
- po: Update from Fedora Weblate (GitHub Workflow)
- storage: Correctly maintain actual LUKS device readonly-ness (Marius Vollmer)
- storage: Disable "Format" action for read-only devices (Marius Vollmer)
- storage: Always set config on cleartext block during mounting (Marius Vollmer)
- storage: Allow both "readonly" and "read-only" spelling in crypttab (Marius Vollmer)
- lib: useLoggedInUser for obtaining user information (Jelle van der Waa)
- test: don't use the jQuery specific Promise API (Jelle van der Waa)
- storage: Wait for the initial btrfs poll (Marius Vollmer)
- test: Install udisks2-btrfs on Fedora for the "optional" plan (Marius Vollmer)
- storaged: enable modules with the non-deprecated udisks API (Jelle van der Waa)
- workflows: Move tasks-container-update to Sunday night (Martin Pitt)
- Bump the stylelint group with 1 update (dependabot[bot])
- Revert "users: Retain authorized_keys file permissions" (Martin Pitt)
- systemd: Fix motd permissions with tight umask (Martin Pitt)
- bridge: Copy file permissions in fsreplace1 with expected tag (Martin Pitt)
- bridge: Include mode and owner in file tags (Martin Pitt)
- test: Add fsreplace1 unit test for expected tag (Martin Pitt)
- test: drop ubuntu/debian workaround for pcp metrics (Jelle van der Waa)
- test: Move TestAD and TestConnection to the "networking" scenario (Martin Pitt)
- test: Disable debugging with Arch makepkg (Marius Vollmer)
- test: Don't create a empty pacman repo (Marius Vollmer)
- pybridge: Improve beiboot error reporting for fatal login failures (Martin Pitt)
- pybridge: Clarify beiboot AuthorizeResponder messages (Martin Pitt)
- test: Re-download package sets for daily/updates-testing scenarios (Martin Pitt)
- ci: Don't use "make" in tasks-container-update (Marius Vollmer)
- storage: Make initial "at_boot" values consistent (Marius Vollmer)
- lib: all browsers now support visibilitychange (Jelle van der Waa)
- test: move select_pf5 from cockpit-files to Cockpit (Jelle van der Waa)
- storage: Fix "is mounted" check for subvolume size column (Marius Vollmer)
- test: Adjust encrypt_root() for separate /var mount (Martin Pitt)
- test: Adjust TestStorageScaling.testScaling for changed btrfs subvolumes on F40 (Martin Pitt)
- test/browser: run tests in the tasks container (Allison Karlitskaya)
- fmf: Skip TestStorageAnaconda.testBasic (Martin Pitt)
- .cockpit-ci/container: update to the latest version (Allison Karlitskaya)
- test/static-code: quiet superfluous ruff messages (Allison Karlitskaya)
- users: port authorized keys mobile dropdown to a KebabDropdown (Jelle van der Waa)
- workflows: add tasks-container-update workflow (Jelle van der Waa)
- Bump date-fns from 3.5.0 to 3.6.0 (dependabot[bot])
- Bump the patternfly group with 2 updates (dependabot[bot])
- misc: move to new tasks container location (Allison Karlitskaya)
- lib: keep validationFailed in sync with the list state (Jelle van der Waa)
- Bump date-fns from 3.4.0 to 3.5.0 (dependabot[bot])
- Bump the eslint group with 1 update (dependabot[bot])
- tools: Fix pam_listfile PAM stage (Martin Pitt)
- Bump the esbuild group with 2 updates (dependabot[bot])
- test: don't wait twice for wait_not_in_text (Jelle van der Waa)
- test: don't wait twice for wait_in_text (Jelle van der Waa)
- Bump the esbuild group with 1 update (dependabot[bot])
- Bump sass from 1.71.1 to 1.72.0 (dependabot[bot])
- test: don't wait_visible when we click (Jelle van der Waa)
- workflows: run unit-tests in the correct container (Allison Karlitskaya)
- .cockpit-ci: pin our container version (Allison Karlitskaya)
- tools: Print failure details (Martin Pitt)
- workflows: Allow urls-check to write issues (Martin Pitt)
- Bump the patternfly group with 2 updates (dependabot[bot])
- bridge: accept `null` for host/group on kill (Allison Karlitskaya)
- flatpak: lint on install (Allison Karlitskaya)
- flatpak: use org.flatpak.Builder flatpak (Allison Karlitskaya)
- client: update metainfo for latest linting (Allison Karlitskaya)
- tools: Add AppArmor profile for cockpit-desktop (Martin Pitt)
- Bump date-fns from 3.3.1 to 3.4.0 (dependabot[bot])
- pyproject.toml: stop linting in venvs (Allison Karlitskaya)
- test: Add fake default route to work around podman 5 regression (Martin Pitt)
- test: Add `self.machine` shortcut to TestCurrentMetrics.setUp() (Martin Pitt)
- packagekit: Fix crash on unexpected `uname -r` format (Martin Pitt)
- apps: Add missing AppStream metadata paths (Martin Pitt)
- storage: Use a custom property to control indentation in tables (Marius Vollmer)
- storage: Show btrfs subvolumes in a tree (Marius Vollmer)
- test: Convert .format() to f-strings (Martin Pitt)
- test: Drop rhel-8* from supported OSes (Martin Pitt)
- don't try and install pytest requirements on suse for now (Luna)
- logs: Do not use duplicate object to keep state (Matej Marusak)
- logs: Reload identifiers when priority changed (jscotka)
- po: Update from Fedora Weblate (GitHub Workflow)
- lib: support setting an id for the toggle button (Jelle van der Waa)
- lib: port deprecated Dropdown menu's with a KebabToggle (Jelle van der Waa)
- test: switch rtl in set_layout as well (Jelle van der Waa)
- users: drop unused argument from getGroupRow (Jelle van der Waa)
- users: drop unused properties from GroupActions (Jelle van der Waa)
- users: Disable "locked" checkbox when no info is available (Marius Vollmer)
- Bump the eslint group with 1 update (dependabot[bot])
- Bump the patternfly group with 6 updates (dependabot[bot])
- users: circumvent inconsistent loading state (Jelle van der Waa)
- users: drop unused setError (Jelle van der Waa)
- test: Wait for usage bar before mdraid pixel test (Marius Vollmer)
- test: drop unsafe inline warnings (Jelle van der Waa)
- appstream: Fix launchable for Networking (Martin Pitt)
- lib: correct EmptyState propTypes (Jelle van der Waa)
- lib: drop unused titleSize from EmptyStatePanel (Jelle van der Waa)
- test: deal with udisks missing udev events (Jelle van der Waa)
- test: btrfs: umount in a busy loop (Jelle van der Waa)
- test: allow direct rendering to body warnings (Jelle van der Waa)
- users: log exceptions for obtaining locked status (Jelle van der Waa)
- storage: Show stopped mdraids in Anaconda mode (Marius Vollmer)
- storage: Use a StorageCard for the "not found" page (Marius Vollmer)
- po: Update from Fedora Weblate (GitHub Workflow)
- lib: remove PatternFly workaround for DataList's (Jelle van der Waa)
- test: drop packagekit 1.2.4 version check (Jelle van der Waa)
- test: update test-os references after dropping Fedora 38 (Jelle van der Waa)
- test: Wait longer for deletion of LVM2 raid volumes (Marius Vollmer)
- packit: Add Fedora 40, drop Fedora 38 (Martin Pitt)
- workflows: Bump action-release to get github-script@v7 (Martin Pitt)
- build: Force `pip install` to not check for already installed module (Martin Pitt)
- test: Clean up "closing" sessions before polling them (Martin Pitt)
- test: Show `systemd-cgls` on session cleanup failure (Martin Pitt)
- test: Retry disk removal in TestStorageMdRaid.testRaid (Marius Vollmer)
- test: btrfs: umount in a busy loop (Jelle van der Waa)
- test: btrfs: umount in a busy loop (Jelle van der Waa)
- test: lookup ppc boot partition (Jelle van der Waa)
- users: debounce getLogins call (Jelle van der Waa)
- Bump the patternfly group with 6 updates (dependabot[bot])
- sosreport: Fix CSS import (Martin Pitt)
- accounts: Trim the output of lastlog (Miika Alikirri)
- accounts: Resolve datarace issue when creating accountsInfo (Miika Alikirri)
- lib: anounce modals being opened and closed (Katerina Koukiou)
- test: Allow server errors in TestHostSwitching.testBasic (Marius Vollmer)
- test: Wait for two samples in TestHistoryMetrics.testNoDataEnable (Marius Vollmer)
- test: Add Qemu disks sequentially in TestStorageMdRaid (Marius Vollmer)
- Bump the eslint group with 1 update (dependabot[bot])
- Bump the esbuild group with 3 updates (dependabot[bot])
- test: adjust regex matching for newer openssl (Jelle van der Waa)
- test: allow appstream location to be updated easier (Jelle van der Waa)
- test: Fedora-40 moved appstream-data to /usr/share/swcatalog (Jelle van der Waa)
- storage: Allow removing of fstab entries (Marius Vollmer)
- test: ignore usage bar in lvm pixel tests (Jelle van der Waa)
- workflows: Move weblate-sync-pot.yml to cockpit/tasks container (Martin Pitt)
- Bump sass from 1.71.0 to 1.71.1 (dependabot[bot])
- test: also strip the / from log.html (Jelle van der Waa)
- storage: Leave LUKS devices open in Anaconda mode (Marius Vollmer)
- storage: Leave new "empty" LUKS devices open (Marius Vollmer)
- Bump sass from 1.70.0 to 1.71.0 (dependabot[bot])
- po: Update from Fedora Weblate (GitHub Workflow)
- test: Remove mounting race from TestStorageBtrfs.testBasic (Marius Vollmer)
- storage: Improve Format dialog defaults (Marius Vollmer)
- storage: Fix root subvolume identification for Delete action (Marius Vollmer)
- storage: Only offer BTRFS formatting with udisks2-btrfs (Marius Vollmer)
- kdump: use a temporary file for QUnit test (Jelle van der Waa)
- Bump qunit from 2.20.0 to 2.20.1 (dependabot[bot])
- test: currentMetrics don't need to wait on pcp (Jelle van der Waa)
- Drop cockpit-appstream split (Martin Pitt)
- workflows: Switch tarball generation job to the tasks container (Martin Pitt)
- test: loosen documentation link checks (Jelle van der Waa)
- lib: drop webpack support in cockpit-po-plugin (Jelle van der Waa)
- pkg: update documentation links to rhel-9 (Jelle van der Waa)
- ws: switch the default bridge to the Python bridge (Jelle van der Waa)
- test: Make our loopback device partitionable (Marius Vollmer)
- systemd: Prevent insights-client crash when stdout is closed (Marius Vollmer)
- kdump: stop using obsolete cockpit.extend (Jelle van der Waa)
- storage: Include special partition types in table rows (Marius Vollmer)
- lib: update patternfly url to the current version (Jelle van der Waa)
- tools: add dry run option to urls-check (Jelle van der Waa)
- Single device btrfs filesystem presentation (Jelle van der Waa)
- test: Drop check_axe() (Martin Pitt)
- storage: Explicitly round sizes for new partitions (Marius Vollmer)
- HACKING.md: default to running test-server with Python bridge (Jelle van der Waa)
- workflows: Run unit tests in our tasks container (Martin Pitt)
- workflows: Drop clang unit test (Martin Pitt)
- workflows: Drop i386 unit test/container (Martin Pitt)
- workflows: Drop C bridge unit tests (Martin Pitt)
- base1: Explicitly set a $TERM for the "pty window size" unit test (Martin Pitt)
- po: Update from Fedora Weblate (GitHub Workflow)
- bridge: Fix fsreplace1 crash for error cases (Martin Pitt)
- test: Add basic fsreplace1 test case (Martin Pitt)
- bridge: Simplify scandir error handling in FsListChannel (Martin Pitt)
- test: Use standard tmp_path fixture in test_fslist1_no_watch (Martin Pitt)
- test: Add type annotations to test_bridge.py tests (Martin Pitt)
- storage: Remember passphrases and export them to Anaconda (Marius Vollmer)
- bump date-fns from 3.2.0 to 3.3.1 (dependabot[bot])
- common: Fix crash with unsupported HTTP methods (Martin Pitt)
- test: Drop obsolete expected "Returning error-response" message (Martin Pitt)
- pf5: Don't hide long dialog titles (Martin Pitt)
- storage: Improve behavior of size slider text and unit inputs (Marius Vollmer)
- test: Be more specific in TestStoragePartitions.testResize (Marius Vollmer)
- build(deps): bump actions/github-script from 6 to 7 (dependabot[bot])
- build(deps): bump actions/checkout from 3 to 4 (dependabot[bot])
- bump gettext-parser from 7.0.1 to 8.0.0 (dependabot[bot])
- .github: don't run integration tests on actions changes (Jelle van der Waa)
- workflows: stop using actions/setup-python (Allison Karlitskaya)
- storage: Export mount points etc for inactive logical volumes (Marius Vollmer)
- users: use passwd --all to obtain locked user status (Jelle van der Waa)
- users: handle tab's in lastlog output (Jelle van der Waa)
- storage: Put "Edit mount point" into menu in Anaconda mode. (Marius Vollmer)
- storage: No "mismounting" warnings in Anaconda mode (Marius Vollmer)
- build(deps): bump github/codeql-action from 2 to 3 (dependabot[bot])
- build(deps): bump redhat-plumbers-in-action/differential-shellcheck (dependabot[bot])
- .github: update workflow checkout actions to v4 (Jelle van der Waa)
- storage: Remove AnacondaAdvice scaffolding (Marius Vollmer)
- Bump js-sha1 from 0.6.0 to 0.7.0 (dependabot[bot])
- github: allow dependabot to update github workflow actions (Jelle van der Waa)
- users: get rid of the mix of useEffect and useInit (Jelle van der Waa)
- users: drop extraneous getLogins call (Jelle van der Waa)
- users: don't fsread1 on file changes for /var/run/utmp (Jelle van der Waa)
- storage: Navigate to parent after deleting a btrfs subvolume (Marius Vollmer)
- po: Update from Fedora Weblate (GitHub Workflow)
- Bump js-sha256 from 0.10.1 to 0.11.0 (dependabot[bot])
- storage: Don't use o.fd.UDisk2.MDRaid.Running property (Marius Vollmer)
- build: Drop ESLint from esbuild (Martin Pitt)
- test: Fix eslint invocation in static-code (Martin Pitt)
- lib: Fix ESLint error in DynamicListForm (Martin Pitt)
- HACKING: Keep your PR! (Martin Pitt)
- guide: stylelint fixes (Martin Pitt)
- Bump the stylelint group with 5 updates (dependabot[bot])
- CSS: stylelint fixes (Martin Pitt)
- branding: Fix pseudo-element selectors and logical directions (Martin Pitt)
- stylelint: Drop checks which don't exist in version 16 any more (Martin Pitt)
- build: Move stylelint to test/static-code (Martin Pitt)
- lib: Drop obsolete PatternFly checkbox/radio override (Martin Pitt)
- selinux: Cover migration to /run (Zdenek Pytela)
- storage: Don't ignore encryption for new empty partitions (Marius Vollmer)
- test: Allow empty coverage info for the diff (Marius Vollmer)
- pkg: make contextmenu component standalone & re-usable (Jelle van der Waa)
- storage: Allow truncation of ID column (Marius Vollmer)
- po: Update from Fedora Weblate (GitHub Workflow)
- storaged: stop using Array.prototype.toSorted for now (Jelle van der Waa)
- cdp: remove disable-gpu flag from headless Chrome (Katerina Koukiou)
- storage: Fix (and test) exporting of swap devices to Anaconda (Marius Vollmer)
- Update pixels after task container refresh (Allison Karlitskaya)
- storage: Use consistent "running" state for MDRAIDs (Marius Vollmer)
- test: Mark TestStorageLvm2.testRaidRepair as "destructive" (Marius Vollmer)
- storage: Redo mount point exporting for Anaconda (Marius Vollmer)
- storage: Fix btrfs in Anaconda mode (Marius Vollmer)
- WIP (Marius Vollmer)
- tools: update node_modules tool documentation (Jelle van der Waa)
- test: accept /usr/bin/bash as valid path (Allison Karlitskaya)
- ws: don't send a body on 301 redirects (Allison Karlitskaya)
- tls: don't send a body on 301 redirects (Allison Karlitskaya)
- vendor: update to the latest systemd_ctypes (Allison Karlitskaya)
- common: don't send error body on HEAD requests (Allison Karlitskaya)
- Use g_autoptr() in cockpit_web_response_error() (Allison Karlitskaya)
- common: pass method to CockpitWebResponse (Allison Karlitskaya)
- cockpitwebresponse: fix a minor leak (Allison Karlitskaya)
- cockpitwebserver: set method before delayed response (Allison Karlitskaya)
- tests: use `curl --unix-socket`, not `--unix` (Allison Karlitskaya)
- ruff: move linter settings to [lint] section (Allison Karlitskaya)
- storage: adjust paddings for anaconda mode (Katerina Koukiou)
- storaged: drop unused onlyWide in storage controls (Jelle van der Waa)
- storaged: remove unused onlyNarrow option Storage menu's (Jelle van der Waa)
- test: add device is in use test for formatting btrfs (Jelle van der Waa)
- test: Enforce successful loopback cleanup (jscotka)
- storage: Don't bother with mount options in Anaconda mode (Marius Vollmer)
- storaged: anaconda: use devices as keys in the cockpit_mount_points object (Katerina Koukiou)
- transports: fixes for mypy --strict (Allison Karlitskaya)
- protocol: use JSON helpers for control messages (Allison Karlitskaya)
- bridge: clean up kill message forwarding (Allison Karlitskaya)
- protocol: add better typing hints (Allison Karlitskaya)
- protocol: remove all talk of memoryview (Allison Karlitskaya)
- test/static-code: add partial mypy --strict mode (Allison Karlitskaya)
- base1: simplify the Content-Length test (Jelle van der Waa)
- po: Update from Fedora Weblate (GitHub Workflow)
- btrfs: Allow formatting of a single btrfs device volume (Jelle van der Waa)
- test: use ext4 instead of btrfs for the used tests (Jelle van der Waa)
- test: merge btrfs mounting tests back to test-storage-mounting (Jelle van der Waa)
- storaged: allow a user to format btrfs (Jelle van der Waa)
- apps: Search in /usr/share/swcatalog (Martin Pitt)
- ws: Support Content-Length in the fsread1 channel (Jelle van der Waa)
- test: Move to "proxy" sssd ID provider for certificate logins (Martin Pitt)
- systemd: Fix crash report spinner gap (Muhammad Taha Mukhtar)
- storaged: btrfs: allow btrfs subvolumes to be deleted (Jelle van der Waa)
- fsinfo channel: tweak a couple of options (Allison Karlitskaya)
- storage: pass configured swap partition in the cockpit_mount_points (Katerina Koukiou)
- storaged: when a menu item is disabled don't show a warning color (Jelle van der Waa)
- test: add allow_download helper for Browser class (Jelle van der Waa)
- fsinfo: change an if: to an assert (Allison Karlitskaya)
- test: add some more trivial fsinfo test cases (Allison Karlitskaya)
- fsinfo: add "targets" attribute (Allison Karlitskaya)
- test: add unit tests for user/group on fsinfo (Allison Karlitskaya)
- jsonutil: fix handling of None in json patches (Allison Karlitskaya)
- cockpit.print: add fsinfo support (Allison Karlitskaya)
- bridge: add a new fsinfo channel (Allison Karlitskaya)
- bridge: give Channel.send_json() the usual treatment (Allison Karlitskaya)
- storage: Be smart about default filesystem type (Marius Vollmer)
- test: add storage test helper for disabled dropdown actions (Jelle van der Waa)
- test: storaged: use self.dialog({}) where possible (Jelle van der Waa)
- shell: Animate host switcher caret (MeastroZI)
- tools: Rely on pam.pc to get pam's libdir in Debian packaging (Michael Biebl)
- storaged: btrfs: don't break on a btrfs mount without subvol (Jelle van der Waa)
- test: Clean up encrypted swap as well (Marius Vollmer)
- test: Don't use /home in tests (Marius Vollmer)
- packages: lift JSON merge patch code to jsonutil (Allison Karlitskaya)
- jsonutil: reorganize our Json* type names (Allison Karlitskaya)
- kdump: Fix unhandled promise rejection on service start failure (Martin Pitt)
- kdump: Remove service status, use Alert instead (Simon Kobyda)
- kdump: 'Test configuration' should use danger variant button (Simon Kobyda)
- test: More specific confirm button selector in kdump test (Martin Pitt)
- kdump: Show target location on the card (Simon Kobyda)
- kdump: Reorganize content of kdump card (Simon Kobyda)
- kdump: Add title to kdump card (Simon Kobyda)
- storaged: btrfs: add subvolume creation support (Jelle van der Waa)
- storaged: make mounting dialog options re-usable (Jelle van der Waa)
- fmf: Skip TestStorageBtrfs.testNothingMounted (Martin Pitt)
- storage: Fix listing of btrfs subvols in fstab (Marius Vollmer)
- storage: Allow creation of swap and maintain fstab entries (Marius Vollmer)
- Bump sass from 1.69.7 to 1.70.0 (dependabot[bot])
- storage: Robustify btrfs polling (Marius Vollmer)
- storage: Fix border calculations for page tables (Marius Vollmer)
- storage: Export mount points when in Anaconda mode (Marius Vollmer)
- storaged: add btrfs volume integration (Jelle van der Waa)
- test: testing farm requires udisks2-btrfs for testing (Jelle van der Waa)
- tools: debian: suggest udisks2-btrfs (Jelle van der Waa)
- tools: recommend udisks2-btrfs on non-RHEL distro's (Jelle van der Waa)
- storaged: add debug function for storaged (Jelle van der Waa)
- storaged: add BTRFS client integration (Jelle van der Waa)
- storage: Don't offer to mount while formatting in Anaconda mode (Marius Vollmer)
- storage: Allow all actions in a dialog to be specified via "Variants" (Marius Vollmer)
- test: Use explicit name for TestStorageLvm2 loopback device (Marius Vollmer)
- storage: Support for creating biosboot and efi partitions (Marius Vollmer)
- storage: Show partition types symbolically and allow editing (Marius Vollmer)
- cockpit.js: Add debugging marking for translated strings (Matej Marusak)
- storage: Hide breadcrumbs on Overview (Marius Vollmer)
- test: drop leftover testlib.sit() (Jelle van der Waa)
- test: workaround an old (and very common) flake (Allison Karlitskaya)
- session: Drop support for sssd < 2.6.1 (Martin Pitt)
- po: Update from Fedora Weblate (GitHub Workflow)
- Bump date-fns from 3.1.0 to 3.2.0 (dependabot[bot])
- common: Mark our memfds as non-executable (Martin Pitt)
- lib: Fix DynamicListForm state confusion on removals (Martin Pitt)
- lib: Clean up state copies in DynamicListForm (Martin Pitt)
- lib: Rename DynamicListForm.jsx to cockpit-components-dynamic-list.jsx (Martin Pitt)
- storaged: refactor mount point text code into a common function (Jelle van der Waa)
- Bump date-fns from 3.0.6 to 3.1.0 (dependabot[bot])
- test: Robustify scheduled reboot check in TestAutoUpdates.testWithAvailableUpdates (Martin Pitt)
- test: Ignore about: frames in Firefox frame tracking (Martin Pitt)
- testlib: Fix script pre-load race condition on Firefox (Martin Pitt)
- test: Robustify and simplify CDP frame → exec context tracking (Martin Pitt)
- test: Wait until #account-locked gets initialized (Martin Pitt)
- fmf: Re-disable TestStorageLvm2.testRaidRepair on rawhide (Martin Pitt)
- Revert "test: Use bigger disks for TestStorageLvm2.testRaidRepair" (Martin Pitt)
- Bump sass from 1.69.6 to 1.69.7 (dependabot[bot])
- tests: don't crash if no users exist when cleaning up login sessions (Katerina Koukiou)
- Bump sass from 1.69.5 to 1.69.6 (dependabot[bot])
- test: Use bigger disks for TestStorageLvm2.testRaidRepair (Marius Vollmer)
- Revert "fmf: Skip TestStorageLvm2.testRaidRepair on Rawhide" (Marius Vollmer)
- storage: Only write non-null Anaconda configs to console (Marius Vollmer)
- test: Adjust TestIPA.testClientCertAuthentication to changed loginctl 255 output format (Martin Pitt)
- vendor: Pull in ferny fixes for OpenSSH 0.9.6 (Martin Pitt)
- po: Update from Fedora Weblate (GitHub Workflow)
- test: Expect rhcd_t SELinux modification on RHEL (Martin Pitt)
- storage: Anaconda mode (Marius Vollmer)
- storage: Only action failures should disable the apply button (Marius Vollmer)
- Bump the esbuild group with 2 updates (dependabot[bot])
- ssh: Use valid host name in test-sshbridge (Martin Pitt)
- packagekit: Update CVE link to go to the new site (Sludge)
- po: Update from Fedora Weblate (GitHub Workflow)
- lib: Ensure HTML translatable strings don't have surrounding whitespace (Martin Pitt)
- static: Avoid leading/trailing space on browser check message (Neftalí Yagua)
- Bump date-fns from 3.0.5 to 3.0.6 (dependabot[bot])
- Bump date-fns from 3.0.1 to 3.0.5 (dependabot[bot])
- Bump date-fns from 2.30.0 to 3.0.1 (dependabot[bot])
- Bump the esbuild group with 3 updates (dependabot[bot])
- po: Update from Fedora Weblate (GitHub Workflow)
- test: Write attachments to unique filenames (Marius Vollmer)
- test: Factorize and robustify VG cleanup (Martin Pitt)
- lib: Make date-fns/locale import compatible with 3.0 (Martin Pitt)
- Bump the eslint group with 1 update (dependabot[bot])
- test: Drop logind user ID cache (Martin Pitt)
- test: Simplify getUserAddDetails() (Martin Pitt)
- Bump axe-core from 4.8.2 to 4.8.3 (dependabot[bot])
- test: Drop caching from getUserAddDetails() (Martin Pitt)
- test: Reset lastlog in TestAccounts.testUserPasswords (Martin Pitt)
- users: Avoid reading /etc/shadow (Martin Pitt)
- users: Move get_locked() into a new utils.js (Martin Pitt)
- users: Sort imports (Martin Pitt)
- users: Correct bz#853153 documentation (Martin Pitt)
- users: Drop unused `shadow` property from AccountDetails (Martin Pitt)
- lib: Small useFile cleanups (Martin Pitt)
- test: Allow tracer errors in TestPages.testBasic (Martin Pitt)
- Bump the eslint group with 1 update (dependabot[bot])
- storage: Sort tables first by category (Marius Vollmer)
- test: Restore netplan configuration/state in NetworkCase (Martin Pitt)
- networking: Disable interface On/off and MAC editing when unprivileged (Martin Pitt)
- fmf: Skip TestStorageLvm2.testRaidRepair on Rawhide (Martin Pitt)
- po: Update from Fedora Weblate (GitHub Workflow)
- guide: Update packages file loader lookup documentation (Martin Pitt)
- containers/ws: Show how to append extra options to RUN label (Martin Pitt)
- storage: Give all top-level rows an icon (Marius Vollmer)
- Bump the esbuild group with 2 updates (dependabot[bot])
- bridge: Fix disk sample ignoring of device-mapper (Martin Pitt)
- test: Skip NM config file hack test in TestWireGuard (Martin Pitt)
- test: Use defined constants instead of repeated values in TestWireGuard (Martin Pitt)
- storaged: set a hover background color which works on dark/light theme (Jelle van der Waa)
- test: Retry auth in checkClientCertAuthentication (Marius Vollmer)
- unit-tests: Install python3-flake8 from unstable (Marius Vollmer)
- unit-tests: Run "make check" when refreshing the container (Marius Vollmer)
- test: storaged: use a variable for "ext4 filesystem" (Jelle van der Waa)
- bridge: Add back support for x.min.js files (Allison Karlitskaya)
- test: Delay writing of new kdump.conf (Marius Vollmer)
- shell: Trim ssh:// from connection address (Mahmoud Hamdy)
- shell: Fix adding host with user in connection string and "User name:" field (Martin Pitt)
- test: Kill ssh connections in check-shell-host-switching when removing a host (Martin Pitt)
- test: Drop unused `machine` parameter in machine_remove() (Mahmoud Hamdy)
- client: Provide fallback for GLib.get_user_state_dir() (Martin Pitt)
- bridge: Add back menu/tool names to `cockpit-bridge --packages` (Martin Pitt)
- test: Wait for real usage, not just a element with a ".usage-bar" class (Marius Vollmer)
- test: Drop "Task was destroyed but it is pending" ignored traceback (Martin Pitt)
- bridge: try harder to ensure Endpoints exited (Allison Karlitskaya)
- test: Fix "busy CPU" pixel flake on overview page (Martin Pitt)
- test: Factorize getting PF <ProgressBar> value (Martin Pitt)
- Fix flake8 whitespace in f-strings (Martin Pitt)
- test: Adjust method name in #18355 message ignoring (Martin Pitt)
- storaged: allow unmounting without a fstab entry (Jelle van der Waa)
- Bump the patternfly group with 5 updates (dependabot[bot])
- test: Drop remaining vestiges of yum (Martin Pitt)
- po: Update from Fedora Weblate (GitHub Workflow)
- storaged: add max btrfs label size (Jelle van der Waa)
- test: Mock pixels after waiting for animations etc (Marius Vollmer)
- storage: Mock and ignore usage for pixel tests (Marius Vollmer)
- bridge: try logging to systemd-journald (Allison Karlitskaya)
- Bump the eslint group with 1 update (dependabot[bot])
- test: Drop "fix auditd" hack (Martin Pitt)
- fmf: Add missing cockpit-pcp test dep for /optional plan (Martin Pitt)
- test: Disable busy swap on scsi_debug (Martin Pitt)
- test: Increase encrypted root partition size (Martin Pitt)
- storage: Redesign (Marius Vollmer)
- test: Drop plugin update check crash hack (Martin Pitt)
- test: Adjust hack in TestGrafanaClient for non-crashing page (#19667) (Martin Pitt)
- bridge: remove a hack to cancel prompts on EOF (Allison Karlitskaya)
- test: allow add_machine/start_machine_troubleshoot to be re-usable (Jelle van der Waa)
- po: Update from Fedora Weblate (GitHub Workflow)
- test: fix coverage collection for kdump Ansible functionality (Jelle van der Waa)
- test: re-use admin ssh key setup across machines (Jelle van der Waa)
- Bump the esbuild group with 2 updates (dependabot[bot])
- test: Use proper TLS CA for subscription-manager (Martin Pitt)
- kdump: add automation script support (Jelle van der Waa)
- lib: allow Modifications component to be re-used (Jelle van der Waa)
- packagekit: Use dnf-automatic reboot option if available (Martin Pitt)
- test: Merge checkUpgradeRebootDnf() helper into testWithAvailableUpdates() (Martin Pitt)
- packagekit: KpatchSettings privileged is not required (Martin Pitt)
- test: Re-enable TestAutoUpdates (Martin Pitt)
- test: Adjust testClientCertAuthentication to changed loginctl 255 output format (Martin Pitt)
- bridge: unify RoutingError and CockpitProblem (Allison Karlitskaya)
- bridge: unify ChannelError and CockpitProblem (Allison Karlitskaya)
- bridge: rewrite HTTP channel using AsyncChannel (Allison Karlitskaya)
- bridge: clean up handling of control messages (Allison Karlitskaya)
- Bump the esbuild group with 2 updates (dependabot[bot])
- po: Update from Fedora Weblate (GitHub Workflow)
- Bump the eslint group with 2 updates (dependabot[bot])
- kdump: use a constant for the default crash location (Jelle van der Waa)
- tools: Drop cockpit-pcp on ix86 on recent Fedora/RHEL (Martin Pitt)
- build: Don't install pcp manifest with --disable-pcp (Martin Pitt)
- Bump the esbuild group with 2 updates (dependabot[bot])
- testlib: Force page loading with Chromium 119 (Martin Pitt)
- test: Update pixel references to Fedora 39 tasks container (Martin Pitt)
- workflows: Update Anaconda trigger for -webui split (Martin Pitt)
- test: Ignore all tracer crashes on RHEL 8 (Martin Pitt)
- workflows: Drop COCKPITUOUS_TOKEN from trigger-anaconda.yml (Martin Pitt)
- test: Drop obsolete sssd hack (Martin Pitt)
- test: Drop obsolete INSECURELDAP hack (Martin Pitt)
- test: Drop sssd fiddling in testClientCertAuthentication (Martin Pitt)
- kdump: test: make global wait_timeout more specific (Jelle van der Waa)
- test: Increaese IPA leave timeout (Martin Pitt)
- test: Avoid sssd.service restart limit failure in check-system-realms (Martin Pitt)
- test: Factorize and fix timeout for contacting domain (Martin Pitt)
- lib: Fix race condition in "double dialog" error check (Martin Pitt)
- test: Drop obsolete RHEL 8.7 special case (Martin Pitt)
- test: Fix waiting for IdM user (Martin Pitt)
- test: Increase timeout for contacting AD domain (Martin Pitt)
- test: Robustify waiting for candlepin (Martin Pitt)
- test: Adjust TestGrafanaClient to Grafana 10.2 (Martin Pitt)
- test: Replace ldapmodify with samba-tool user edit (Martin Pitt)
- test: Allow samba user creation to take some time (Martin Pitt)
- tests: increase timeout on testCPUSecurityMitigationsEnable (Tomas Matus)
- po: Update from Fedora Weblate (GitHub Workflow)
- test: Relax RHEL 8 expected tracer failure (Martin Pitt)
- test: Kill processes that keep scsi_debug mounts busy (Martin Pitt)
- test: Allow PCP expected messages for "direct" source as well (Martin Pitt)
- test: simplify restoring /var/lib/sudo/lectured (Jelle van der Waa)
- test: sudo stores an uid instead of a username since 1.9.15 (Jelle van der Waa)
- containers: move the ws container to Fedora 39 (Jelle van der Waa)
- lib: provide an optional error callback for validation (Jelle van der Waa)
- lib: Add error message when showing multiple Dialogs (Martin Pitt)
- test: Close modal in TestSystemInfo.testCryptoPolicies (Martin Pitt)
- test: Retry `git fetch` in git-utils.sh (Martin Pitt)
- router: shutdown via endpoints, not channels (Allison Karlitskaya)
- dbus channel: make 'close' message idempotent (Allison Karlitskaya)
- router: explicitly track endpoints (Allison Karlitskaya)
- test: use become_superuser for admin access (Jelle van der Waa)
- Bump deep-equal from 2.2.2 to 2.2.3 (dependabot[bot])
- test: update reference-image to Fedora-39 (Jelle van der Waa)
- test: use become_superuser helper for switching access (Jelle van der Waa)
- vendor: update to the latest version of ferny (Allison Karlitskaya)
- lib: Debounce password quality checking during typing (Marius Vollmer)
- test: wait for journal to rotate in testLogs (Jelle van der Waa)
- storage: Disable "Apply" in Teardown dialogs after error (Marius Vollmer)
- test: Fix wait timeout adjustment in TestIPA.testClientCertAuthentication (Martin Pitt)
- test: Apply currently set wait timeout to waitPageLoad() (Martin Pitt)
- test: Relax kpatch console error pattern (Martin Pitt)
- test: Ignore occasional old tracer error on RHEL 8 (Martin Pitt)
- test: Wait for a page load in Browser.open() (Martin Pitt)
- test: Drop Firefox CDP timeout hack (Martin Pitt)
- test: fix more test_spawn_broken_pipe races (Allison Karlitskaya)
- test: Console printing improvements (Marius Vollmer)
- po: Update from Fedora Weblate (GitHub Workflow)
- test: Retry after UDisks2 timeout in TestStorageUsed.testUsed (Marius Vollmer)
- Bump eslint from 8.52.0 to 8.53.0 (dependabot[bot])
- lib: Add debug logging for cockpit.spawn() arguments (Martin Pitt)
- pybridge: Fix `http` cockpit print channel (Martin Pitt)
- test: Ignore PCP name lookup failure after disk removal (Martin Pitt)
- test: Properly clean up after stratis test failures (Martin Pitt)
- test: Reduce error message expectation for unreachable tang server (Martin Pitt)
- packagekit: Quiesce authentication-failed tracer error message (Martin Pitt)
- test: Ignore "PackageKit crashed" browser errors for kpatch (Martin Pitt)
- Bump the stylelint group with 1 update (dependabot[bot])
- fmf: Uninstall cockpit-packagekit for basic and network plans (Martin Pitt)
- test: Break out NTP related tests into TestSystemInfoTime class (Martin Pitt)
- test: Run mypy on Python scripts (Martin Pitt)
- client: Don't clobber prctl module (Martin Pitt)
- tools: mypy fixes/annotations for build-debian-copyright (Martin Pitt)
- mypy: Ignore external modules without annotations (Martin Pitt)
- test: TEST_OS_DEFAULT is now Fedora-39 (Jelle van der Waa)
- fmf: Fix COPR yum repo globbing (Martin Pitt)
- test: Use `stratis key set --keyfile-path` (Martin Pitt)
- fmf: Fix prioritization of our main-builds COPR (Martin Pitt)
- lib: Show message next to password progress bar (Simon Kobyda)
- lib: Add minimum progress value (Simon Kobyda)
- lib: Change width of password progress (Simon Kobyda)
- lib: Add show/hide feature to password input field (Simon Kobyda)
- fmf: Hack around Testing Farm's tag-repository priority (Martin Pitt)
- fmf: Show all cockpit package versions (Martin Pitt)
- test: don't install weak dependencies for updatest-testing scenario (Jelle van der Waa)
- storage: Don't show LV structure for device-mapper PVs. (Marius Vollmer)
- storage: Support LVM2 RAID configurations (Marius Vollmer)
- test: Retry dropdown menu in storage tests (Marius Vollmer)
- storage: Let Stratis use the regular warnings mechanism for pool alerts (Marius Vollmer)
- storage: Keep order in SelectSpaces (Marius Vollmer)
- Bump sass from 1.69.4 to 1.69.5 (dependabot[bot])
- test: Drop updates-testing-modular repo (Martin Pitt)
- test: apply eslint to .js files as well (Jelle van der Waa)
- lib: Drop unknown noVerticalAlign property from HelpIcon (Martin Pitt)
- test: Generalize RHEL 8 special cases (Martin Pitt)
- storage: Put the minimum of a slider at the far left (Marius Vollmer)
- workflows: drop pybridge-c8s.yml (Allison Karlitskaya)
- packages: fix up parse_accept_language() (Allison Karlitskaya)
- test: Enable kdump on Fedora 39 (Martin Pitt)
- test: Fail on React DOM nesting errors (Martin Pitt)
- storaged: Fix nesting in tang key verification dialog (Martin Pitt)
- storaged: Fix nested Form (Martin Pitt)
- storaged: Fix DOM nesting in UsersPopover (Martin Pitt)
- storaged: Fix nesting in StopProcessesMessage dialog (Martin Pitt)
- test: Define stop_type_opt in TestStorageStratisNBDE (Martin Pitt)
- test: Adjust `stratis pool stop` to stratis-cli 3.6.0 (Martin Pitt)
- storage: Always resize filesystems and LUKS to the maximum possible (Marius Vollmer)
- lib: Fix ListingTable nesting for non-expandable rows (Martin Pitt)
- lib: Support non-string ModalError.dialogErrorDetail (Martin Pitt)
- kdump: Drop unnecessary null check (Martin Pitt)
- test: Show VM console log on TestKdumpNFS failures (Martin Pitt)
- po: Update from Fedora Weblate (GitHub Workflow)
- test: Relax boot timer check in TestServices.testTimerSession (Martin Pitt)
- storage: Remount filesystems after resizing them (Marius Vollmer)
- testlib: when provisioning VMs allow to keep the original machine_class (Katerina Koukiou)
- Bump the eslint group with 2 updates (dependabot[bot])
- lib: Update RedHatMono weight properties (Simon Kobyda)
- tls: Include <poll.h> instead of <sys/poll.h> (Marvin Schmidt)
- tls: Include <fcntl.h> instead of <sys/fcntl.h> (Marvin Schmidt)
- tls: Sort includes (NFC) (Marvin Schmidt)
- session: Use <signal.h> instead of <sys/signal.h> (Marvin Schmidt)
- build: Check if we need to link against libargp (Marvin Schmidt)
- build: Check if we need to link against libfts (Marvin Schmidt)
- session: Include <paths.h> for _PATH_LASTLOG (Marvin Schmidt)
- common: Don't assume that SIGCLD is always available (Marvin Schmidt)
- test: Ignore kpatch check error about repomd.xml (Martin Pitt)
- test: Print objects in console API calls (Martin Pitt)
- sosreport: Quiesce error noise on cancelling (Martin Pitt)
- Add context to all console.error() calls (Martin Pitt)
- shell: Drop leftover property (Martin Pitt)
- users: Properly initialize lastlog default (Martin Pitt)
- test: Drop obsolete null props ignore (Martin Pitt)
- testlib: Drop remaining global ignores of messages from our pages (Martin Pitt)
- shell: Fix cockpit.Machines.Update() error handling (Martin Pitt)
- test: Drop global ignoring of two expected browser error messages (Martin Pitt)
- test: Stop ignoring proptype warnings (Martin Pitt)
- storaged: Use Dialog.titleIconVariant property (Martin Pitt)
- lib: Fix Dialog error prop type (Martin Pitt)
- Bump sass from 1.69.3 to 1.69.4 (dependabot[bot])
- packagekit: Quiesce common tracer browser errors (Martin Pitt)
- shell: Add dummy jump prop to host selector's CockpitNav (Martin Pitt)
- lib: Modifications failed property is not required (Martin Pitt)
- users: Avoid duplicate React component key (Martin Pitt)
- test: Fix unintentional ignoring of console errors (Jelle van der Waa)
- Bump the stylelint group with 1 update (dependabot[bot])
- Bump the esbuild group with 2 updates (dependabot[bot])
- users: TextInput values have to be a string not null (Jelle van der Waa)
- shell: restore search icon in display language input (Jelle van der Waa)
- po: Update from Fedora Weblate (GitHub Workflow)
- workflows: Switch anaconda trigger COPR polling to timestamp comparison (Martin Pitt)
- lib: Fix DynamicListForm's 'Maximum update depth exceeded' flake (Simon Kobyda)
- test: Replace .format() with f-strings (Martin Pitt)
- testlib: fix some of our testlib typing (Jelle van der Waa)
- test: Make some stratis tests nondestructive (Martin Pitt)
- doc: don't escape " when not required (Jelle van der Waa)
- test: configure wireguard server side using the browser object (Subho)
- shell: Fix crash on uninitialized superuser proxy Bridges (Martin Pitt)
- storage: Robustify thin pool resizing (Marius Vollmer)
- storaged: udisks supports CanResize since 2.7.2 (Jelle van der Waa)
- test: cleanup NFS test case (Jelle van der Waa)
- test: fedora-testing image is no more (Jelle van der Waa)
- kdump: RHEL/Fedora now defaults to setting crashkernel (Jelle van der Waa)
- networking: Disable unsupported IPv4/IPv6 methods for wireguard (Subho)
- networking: merge ipv4 and ipv6 method choices (Subho)
- test: Fix pytest race in test_spawn_broken_pipe() (Martin Pitt)
- apps: Warn if appstream data package is missing (Martin Pitt)
- lib: Document and properly initialize packagekit missing_ids (Martin Pitt)
- Bump sass from 1.69.2 to 1.69.3 (dependabot[bot])
- workflows: Trigger anaconda test on bridge/storaged changes (Martin Pitt)
- shell: Redesign untrusted "add host" dialog (Martin Pitt)
- test: Use Machine.write() API in check-shell-multi-machine (Martin Pitt)
- test: Drop obsolete ssh-keygen fallback (Martin Pitt)
- Bump sass from 1.69.0 to 1.69.2 (dependabot[bot])
- po: Update from Fedora Weblate (GitHub Workflow)
- kdump: always set kdump.conf defaults (Jelle van der Waa)
- Update to PatternFly 5.1 (Jelle van der Waa)
- test: Adjust TestFirewall.testNetworkingPage for firewalld 2.0.1 (Martin Pitt)
- lib: Add '/lib' to /get-timesync-backend root directories list (wl-thaumatec)
- Bump the eslint group with 1 update (dependabot[bot])
- kdump: disable test configuration button for non-admin (Jelle van der Waa)
- Bump sass from 1.59.3 to 1.69.0 (dependabot[bot])
- Bump uuid from 7.0.3 to 9.0.1 (dependabot[bot])
- Bump sizzle from 2.3.5 to 2.3.10 (dependabot[bot])
- dependabot: Run in our evenings, reduce limit (Martin Pitt)
- Bump date-fns from 2.22.1 to 2.30.0 (dependabot[bot])
- Bump axe-core from 3.5.2 to 4.8.2 (dependabot[bot])
- Bump throttle-debounce from 2.3.0 to 5.0.0 (dependabot[bot])
- test: Follow ASCII chart instead of browser's keycodes (Simon Kobyda)
- Bump js-sha256 from 0.9.0 to 0.10.1 (dependabot[bot])
- build: Drop ssh manifest.json for pybridge install (Martin Pitt)
- Bump qunit from 2.19.0 to 2.20.0 (dependabot[bot])
- Bump chrome-remote-interface from 0.32.1 to 0.33.0 (dependabot[bot])
- storage: Validate mount point even with "Format only" (Marius Vollmer)
- test: Cleanup volume group in one non-destructive test (Marius Vollmer)
- storage: Don't allow mounting over other mounted filesystems (Marius Vollmer)
- .github: add kdump as page section for bug reports (Jelle van der Waa)
- test: Enable TestClient on debian-stable and ubuntu-2204 (Martin Pitt)
- pybridge: Relax overly strict Transport.write() assertion (Martin Pitt)
- pybridge: Avoid BrokenPipeError crash of SubprocessTransport.write() (Martin Pitt)
- stylelint: Adjust rules to stylelint 15 (Martin Pitt)
- package.json: Drop unused cssnano-preset-lite (Martin Pitt)
- Bump deep-equal from 2.0.5 to 2.2.2 (dependabot[bot])
- Bump the stylelint group with 4 updates (dependabot[bot])
- Bump the eslint group with 4 updates (dependabot[bot])
- Bump the esbuild group with 4 updates (dependabot[bot])
- test: Fix firewall-cmd output parsing for firewalld 2.0.1 (Martin Pitt)
- test: Add pixel test to IP settings dialog (Simon Kobyda)
- networkmanager: Fix alignment of add button and use tooltip (Simon Kobyda)
- networkmanager: Use TrashIcon instead of MinusIcon for field groups (Simon Kobyda)
- lib: make Ansible role the first tab (Jelle van der Waa)
- Switch to dependabot for node_modules updates (Jelle van der Waa)
- systemd: port reporting functionality to functional components (Jelle van der Waa)
- systemd: don't use this.props in a functional component (Jelle van der Waa)
- storage: Partition resizing (Marius Vollmer)
- pybridge: Let cockpit-beiboot use package-installed askpass helper (Martin Pitt)
- pybridge: Restore cockpit.beiboot debug logging (Martin Pitt)
- selinux: Allow cockpit_ws_t to read /sys (Martin Pitt)
- selinux: Allow cockpit-ws to run ssh(1) (Martin Pitt)
- selinux: Document how to quickly iterate policy changes (Martin Pitt)
- test: Accept destroyed execution context when clicking logout (Martin Pitt)
- test: Use standard logout test API in check-client (Martin Pitt)
- test: Factorize cockpit-ws startup in TestClient (Martin Pitt)
- flatpak: Add SSH login test (Martin Pitt)
- flatpak: Add test helper for waiting for a selector to contain a given text (Martin Pitt)
- apps: Fix crash with nonexisting /etc/os-release (Martin Pitt)
- test: Robustify TestApps.testOsMap (Martin Pitt)
- storage: Move some fstab/crypttab to utils.js (Marius Vollmer)
- lib: handle `subdir` being undefined for cockpit projects (Jelle van der Waa)
- tools: Read systemd unit dir from pkgconfig (Helmut Grohne)
- test: Also retry opening of storage content tabs (Marius Vollmer)
- test: Test resizing unsupported filesystems (Marius Vollmer)
- storage: Remove some fallbaks for old versions of UDisks2 (Marius Vollmer)
- storage: Mark safety checks as "not-covered" (Marius Vollmer)
- storage: Move resize related code to its own file (Marius Vollmer)
- shell: python: load translations via manifest.js (Jelle van der Waa)
- ruff: Enable UP032 f-string rule (Jelle van der Waa)
- ws: do argument splitting on --local-session (Allison Karlitskaya)
- client: Spawn cockpit-beiboot via `python3 -m` (Allison Karlitskaya)
- ws: do shell splitting on auth command (Allison Karlitskaya)
- networking: trim spaces before submitting wireguard dialog (Subho)
- test: use delete sed command instead of substitute (Subho)
- workflows: Retry `dnf install` in pybridge-c8s (Martin Pitt)
- po: Update from Fedora Weblate (GitHub Workflow)
- networking: fix page crash when wg properties go missing (Subho)
- test: Disable packagekit in TestStorageLegacyVDO (Martin Pitt)
- cockpit.remote: add init-superuser functionality (Allison Karlitskaya)
- cockpit.jsonutil: add new helper for str|None (Allison Karlitskaya)
- cockpit.remote: minor adjustments to open handling (Allison Karlitskaya)
- cockpit.peer: don't explode on authorize messages (Allison Karlitskaya)
- cockpit.peer: Add **kwargs to Peer.start() (Allison Karlitskaya)
- test: Remove obsolete skipMobile decorator (Marius Vollmer)
- pybridge: Add port parsing to cockpit-beiboot (Martin Pitt)
- client: Drop setting obsolete ReportStderr (Martin Pitt)
- systemd: convert the hwinfo page to functional components (Jelle van der Waa)
- systemd: port trivial components to functional components (Jelle van der Waa)
- fmf: Fix installation of cockpit-tests (Martin Pitt)
- doc: Drop wrong cockpit.user.onchanged() (Martin Pitt)
- lib: move SELinux specific message to selinux page (Jelle van der Waa)
- lib: make modifications components functional (Jelle van der Waa)
- lib: ansible propType is required for Modifications components (Jelle van der Waa)
- lib: add missing "failed" proptype for Modifications (Jelle van der Waa)
- src/build_backend.py: produce deterministic builds (Allison Karlitskaya)
- playground: Add process input speed test (Martin Pitt)
- test: Simplify TestConnection.testFlowControl (Martin Pitt)
- pybridge: fix queue draining bug (Allison Karlitskaya)
- pybridge: add some debugging output (Allison Karlitskaya)
- pybridge: Initialize ProtocolChannel._last_ping (Martin Pitt)
- flatpak/prepare: add newline to end of manifest (Allison Karlitskaya)
- flatpak: Upgrade to GNOME 45 runtime (Allison Karlitskaya)
- package.json: bump xterm.js to 5.3.0 (Jelle van der Waa)
- test: Fix restore_dir() unit restart race (Martin Pitt)
- package.json: Update to gettext-parser 7 (Martin Pitt)
- networkmanager: Debounce unit change handler (Martin Pitt)
- networkmanager: Close old D-Bus connection (Martin Pitt)
- networkmanager: Add initial set of debug messages to firewalld UI (Martin Pitt)
- test: Improve zone testing in TestFirewall.testNetworkingPage (Martin Pitt)
- po: Update from Fedora Weblate (GitHub Workflow)
- test: add avc type=1405 (Jelle van der Waa)
- cockpit.superuser: prevent 'any' from being set (Allison Karlitskaya)
- cockpit.packages: make BridgeConfig subclass dict (Allison Karlitskaya)
- lib: Add validation to DynamicListForm component (Simon Kobyda)
- networking: Fix "can't be managed here" text layout (Marius Vollmer)
- networking: Don't let the user manage loopback devices (Marius Vollmer)
- metrics: Link to network interface (leomoty)
- metrics: Clean up make_rows helper (Martin Pitt)
- cockpit: serialize BridgeConfig using __dict__ (Jelle van der Waa)
- test: More general retrying for Storage content tabs (Marius Vollmer)
- test: Clean up failed units in TestConnection.testUnitLifecycle (Martin Pitt)
- Makefile.am: cockpit_enable_python was dropped (Jelle van der Waa)
- storage: Don't use StorageLink for navigation (Marius Vollmer)
- realmd: Don't initialize proxy twice during page load (Marius Vollmer)
- test: Better cleanup for TestNetworkingOther (Marius Vollmer)
- test: Check Apps page with already installed application (leomoty)
- apps: Fix reading AppStream metadata config (Martin Pitt)
- pf5: Specify form select colors (leomoty)
- metrics: fix rounding of CPU temperature (Tomas Matus)
- shell: handle closing dialog the same as cancel (Jelle van der Waa)
- test: add a document describing Cockpit's test Architecture (Jelle van der Waa)
- test: document scenario's supported by test/run (Jelle van der Waa)
- networking: Add support for WireGuard (Subho)
- tools: sync Arch Linux upstream packaging changes (Jelle van der Waa)
- po: Update from Fedora Weblate (GitHub Workflow)
- test: Update pixel references to current browser version (Martin Pitt)
- tools: BuildRequires: python3-devel (Martin Pitt)
- test: Ignore help icon in bond dialog (Martin Pitt)
- tools: Enable the Python bridge on stable Debian/Ubuntu (Martin Pitt)
- test: Fix TestMultiCPU.testCPUUsage for different scheduling (Martin Pitt)
- test: Robustify TestClient (Martin Pitt)
- test: Fix unpin check in TestServices.testBasic (Martin Pitt)
- test: Fix TypeError in tracing mode (Martin Pitt)
- test: Increase timeout for changing system time (Martin Pitt)
- test: Increase timeout for resizing storage (Martin Pitt)
- test: Drop obsolete fallback for old shells (Martin Pitt)
- test: allow journal message to a known pybridge error (Tomas Matus)
- test: Wait after layout change for some metrics pixels (Marius Vollmer)
- package.json: date-fns is a runtime dependency (Jelle van der Waa)
- tools: Explicitly set admin group on arch (Martin Pitt)
- test: Wait a bit after switching to "mobile" for some metrics pixels (Marius Vollmer)
- test: Wait longer for RTL switch in the motd test. (Marius Vollmer)
- test: Wait for tooltips after scrolling stuff into view (Marius Vollmer)
- package.json: Update @patternfly/patternfly, @patternfly/react-core, @patternfly/react-icons, @patternfly/react-styles, @patternfly/react-table, @patternfly/react-tokens (GitHub Workflow)
- workflows: Run "daily" scenario every night (Martin Pitt)
- workflows: Fix nightly invocation (Martin Pitt)
- .github: add nightly testing scenario (Jelle van der Waa)
- test: Explicitly trigger udev after resizing ext4 (Marius Vollmer)
- build: Make Python bridge the default (Martin Pitt)
- build: Uninstall Python bridge with `make uninstall` (Martin Pitt)
- tools: Change Debian pip install hack to use DEB_PYTHON_INSTALL_LAYOUT (Martin Pitt)
- test: Increase testClientCertAuthentication page load timeout (Martin Pitt)
- bridge: port packages serving to AsyncChannel (Allison Karlitskaya)
- AsyncChannel: add a sendfile() helper (Allison Karlitskaya)
- ruff: enable PIE rules, apply some auto-fixups (Allison Karlitskaya)
- pyproject: add an ignore for a bad error (Allison Karlitskaya)
- modules: rename to vendor (Allison Karlitskaya)
- verify: allow restart messages from a test case (Allison Karlitskaya)
- test: Add another another expected restart message (Allison Karlitskaya)
- apps: Consider ID_LIKE for mapping AppStream data packages (Martin Pitt)
- test: Clean up MachineCase.restore_file() (Martin Pitt)
- test: Reset packagekit.service in between tests (Martin Pitt)
- tools: Fix "only arch all" Debian build (Martin Pitt)
- po: Update from Fedora Weblate (GitHub Workflow)
- test: Add VM's XML and VM's log into link-patterns (Simon Kobyda)
- test: Remove unecessary escaping in link-patterns (Simon Kobyda)
- po: Update from Fedora Weblate (GitHub Workflow)
- networking: don't pass null to input elements (Subho)
- test: include an Fedora updates-testing scenario (Jelle van der Waa)
- network: distinguish create and edit dialogs (Subho)
- Fix application progress bar (leomoty)
- test: Mock MAC and IP addresses for pixel tests (Marius Vollmer)
- test: More careful mocking (Marius Vollmer)
- test: Update TestNetworkingBasic pixel test with shorter MAC (Martin Pitt)
- test: Increase TestSELinux VM memory (Martin Pitt)
- Remove copied checkmark when switching SELinux modifications tab (omarY23)
- pybridge: Implement cockpit-bridge --version (Martin Pitt)
- pybridge: Drop --rules option (Martin Pitt)
- pybridge: Fix superuser rule caching (Martin Pitt)
- pybridge: Add return type annotation to packages_loaded() (Martin Pitt)
- test: Avoid running check-example in regular CI runs (Martin Pitt)
- test: Make TestNetworkingUnmanaged nondestructive (Martin Pitt)
- test: Make TestStorageMountingLUKS nondestructive (Martin Pitt)
- test: Make three TestStorageLuks nondestructive (Martin Pitt)
- test: Make check-storage-hidden nondestructive (Martin Pitt)
- test: Provision more RAM for global machines to fit LUKS tests (Martin Pitt)
- storage: Show alert when a stratis pool is in a degraded state (Marius Vollmer)
- Cleanup for table clickable rows (leomoty)
- test: Drop fedora-37 (Martin Pitt)
- test: Don't encrypt/move the EFI partition in encrypt_root (Martin Pitt)
- test: Ignore "invalid non-UTF8 @data passed" message (Martin Pitt)
- lib: Don't show icon unless 'icon' prop is passed (Simon Kobyda)
- test: Create non-empty dummy kernel file in testCPUSecurityMitigationsEnable (Martin Pitt)
- test: Invert "no crashkernel= by default" expectation in kdump test (Martin Pitt)
- test: Add fedora-39 image to README (Martin Pitt)
- storaged: Fix StorageBarMenu in dark mode (leomoty)
- lib: Fix a dropdown being hidden by a card (Simon Kobyda)
- containers/ws: Move to Fedora 38 (Martin Pitt)
- fmf: Plumb through $TEST_* variables for unexpected messages (Martin Pitt)
- fmf: Drop increased timeout factor on Fedora (Martin Pitt)
- fmf: Drop obsolete standard-test-source support (Martin Pitt)
- pybridge: Move cockpit-beiboot from client into cockpit module (Martin Pitt)
- client: Fix type in cockpit-beiboot's apply_rule() (Martin Pitt)
- client: Fix return type of do_connect_transport() (Martin Pitt)
- client: Quiesce mypy type check for Router vs. Bridge duck typing (Martin Pitt)
- client: Ensure proper data type of init message capabilities option (Martin Pitt)
- client: Drop cockpit-client-ssh (Martin Pitt)
- storage: Write more error messages to the Browser console (Marius Vollmer)
- storage: Detect unused space in Stratis pools in general (Marius Vollmer)
- storage: Resize Stratis blockdevs together with logical volumes (Marius Vollmer)
- storage: Don't swallow resize errors (Marius Vollmer)
- Improve JSON deconstruction static typing (Allison Karlitskaya)
- packages: better path validation (Allison Karlitskaya)
- use JsonObject throughout (Allison Karlitskaya)
- bridge: split JSON type hints to a new file (Allison Karlitskaya)
- storage: Make some functions global in preparation for UI redesign (Marius Vollmer)
- lib: Add Dialog.isActive property (Mahmoud Hamdy)
- lib: Implement missing .pf-v5-u-font-weight-light (Simon Kobyda)
- containers: drop unused personality (Jelle van der Waa)
- containers: echo -n is not posix (Jelle van der Waa)
- test: show a known naughty as a failure (Jelle van der Waa)
- workflows: Drop i386 clang check-memory (Martin Pitt)
- containers/unit-tests: Don't break verbatim command (Martin Pitt)
- cockpit: update cockpit.misc.print examples (Jelle van der Waa)
- HACKING: Add a section about Python bridge and debugging (Jelle van der Waa)
- tools: Fix building Debian source package after binary build (Martin Pitt)
- packit: Add Fedora 39, drop Fedora 37 (Martin Pitt)
- .github: scan JavaScript code with codeql (Jelle van der Waa)
- bridge: Drop unused num_ops in disk samples (Martin Pitt)
- kdump: Show message in 'Test configuration' to verify the crash (Simon Kobyda)
- lib: add showClose as Dialog's prop (Simon Kobyda)
- Update kdump test settings message (Simon Kobyda)
- test: Ignore checkbox pixels in one dialog (Marius Vollmer)
- test: Provide more memory for LUKS Stratis tests (Marius Vollmer)
- storage: Managed filesystems for Stratis (Marius Vollmer)
- tools: Drop obsolete valgrind suppressions (Martin Pitt)
- test: Increase timeout for stratis pool unlocking (Martin Pitt)
- metrics: Show warning progress bars with > 80% (Ian Brown)
- po: Update from Fedora Weblate (GitHub Workflow)
- test: add pytest for fsread1 max_read_size validation (Jelle van der Waa)
- package.json: bump esbuild (Tomas Matus)
- test: ignore mobile layout network interfaces (Jelle van der Waa)
- Remove unused css id #machine_id (Simon Kobyda)
- test: ignore all pytest specific rules (Jelle van der Waa)
- test: do not compare types but use isinstance (Jelle van der Waa)
- test: exclude `pkg/lib` coverage when the project is not Cockpit itself (Jelle van der Waa)
- lib: Add DynamicListForm to /pkg/lib (Simon Kobyda)
- po: Update from Fedora Weblate (GitHub Workflow)
- filesystem: send 'ready' on fsread1 and fslist1 (Allison Karlitskaya)
- storage: Allow adding cache to encrypted pools (Marius Vollmer)
- test: Check that dropdown options are enabled (Marius Vollmer)
- test: update pixel tests for Fedora-38 refresh (Jelle van der Waa)
- storage: Tang keyserver and passphrase management for Stratis (Marius Vollmer)
- storage: Optional spinners in StorageButtons (Marius Vollmer)
- metrics: Disable on-demand cockpit-pcp installation with beibooted bridge (Martin Pitt)
- metrics: Fix on-demand install condition for beiboot case (Martin Pitt)
- metrics: Simplify cockpit.manifests queries (Martin Pitt)
- test: Clarify machines in check-client (Martin Pitt)
- ws: Drop empty cockpit.service.d directory (Martin Pitt)
- po: Update from Fedora Weblate (GitHub Workflow)
- storage: Tell people that big mdraids really should have a bitmap (Marius Vollmer)
- test: Use sparse files to back loopback devices (Marius Vollmer)
- shell: Create superuser proxy only when connected to the machine (Marius Vollmer)
- test: expand the pixel tests section (Jelle van der Waa)
- storage: Allow multiple alerts on details page (Marius Vollmer)
- test: Don't crash in coverage post-processing (Marius Vollmer)
- test: Remove lcov/ before collecting coverage data (Marius Vollmer)
- change file name to pam_user_parser to be more specific (MahmoudHamdy02)
- move parsers.js to pkg/lib, adjust import path in users.js (MahmoudHamdy02)
- test: add test for Automatic or wrong MTU values (Subho)
- test: rename parallel/serial tests to (non)destructive tests (Jelle van der Waa)
- package.json: Update to PatternFly 5 final (Martin Pitt)
- test: Update pixel tests for PatternFly 5.0.0-prerelease.16 (Martin Pitt)
- pf: Fix alignment of radios and checks (Garrett LeSage)
- networkmanager: Space vertical checkboxes properly (Garrett LeSage)
- metrics: Use select PF chart colors in dark style (Garrett LeSage)
- networkmanager: Drop MTU dialog align setting (Martin Pitt)
- Revert "lib: Fix toolbar alignment" (Martin Pitt)
- Revert "systemd: hack for NumberInput not being readonly" (Martin Pitt)
- Revert "systemd: fix centering of toolbar labels" (Martin Pitt)
- pf: Fix horizontal radio buttons for current PF5 (Martin Pitt)
- package.json: Update to @patternfly/patternfly 5.0.0-prerelease.16 (Martin Pitt)
- mocktransport: two async ease-of-use improvements (Allison Karlitskaya)
- bridge: don't require event loop at init (Allison Karlitskaya)
- tests: port a testcase to use fixtures (Allison Karlitskaya)
- bridge: drop an unused instance variable (Allison Karlitskaya)
- bridge: use 'from' import for cockpit.data (Allison Karlitskaya)
- test: Add pixel test for firewall "Add zone" dialog (Martin Pitt)
- test: Move testNeverAuto under TestStorageMountingLUKS (Simon Kobyda)
- fmf: Declare our own dependencies (Martin Pitt)
- Add "macro 'an-trap' not defined" warning to lintian overrides (Simon Kobyda)
- lib: Pre-select autocomplete file when passing file path (Mahmoud Hamdy)
- test: rename logical volume support (Jelle van der Waa)
- po: Update from Fedora Weblate (GitHub Workflow)
- test: document code coverage generation (Jelle van der Waa)
- network: fix MTU dialog error in Automatic mode (Subho)
- packit: Build COPR for main commits (Martin Pitt)
- Update pixel tests for fedora-38 (Simon Kobyda)
- fmf: Run cockpit-podman tests on current Fedora (Martin Pitt)
- test: work around duplicate id's in the PCP settings modal (Jelle van der Waa)
- Only use Sizzle when required (Jelle van der Waa)
- test: add a test for renaming a volume group (Jelle van der Waa)
- tools: don't parse --force as valid SHA (Jelle van der Waa)
- test: handle Anaconda's master branch for coverage (Jelle van der Waa)
- networkmanager: add pixel test for edit checkboxes (Jelle van der Waa)
- pybridge: Fix crash when connecting to nonexisting D-Bus address (Martin Pitt)
- flatpak: Update description (Martin Pitt)
- test: Check configuring manual IPv6 address (Subho)
- pybridge: Asynchronously send package files in chunks (Martin Pitt)
- package.json: eslint-plugin-standard no longer requires eslint-config-standard (Jelle van der Waa)
- test: update all pixel tests (Jelle van der Waa)
- nav: Pass through click on menu icon (Garrett LeSage)
- nav: Fix mobile nav item sizing, host editing (Garrett LeSage)
- networking: Fix edit links on details (Garrett LeSage)
- networking: Fix MTU modal (Garrett LeSage)
- lib: Fix toolbar alignment (Martin Pitt)
- test: Adjust selectors for typeahead input (Martin Pitt)
- systemd: hack for NumberInput not being readonly (Jelle van der Waa)
- systemd: fix centering of toolbar labels (Jelle van der Waa)
- shell: Update hosts sidebar width hack to current PF5 (Martin Pitt)
- networkmanager: workaround input's being wrapped in a div (Jelle van der Waa)
- lib: override default spaving from lg to md (Katerina Koukiou)
- users: space labels with md size instead of lg. (Jelle van der Waa)
- networkmanager: selinux: kdump make Switch/Title spacing consistent (Jelle van der Waa)
- metrics: adjust default metrics background in dark mode (Katerina Koukiou)
- overview: PF5 tables now need more classes for the styling to apply (Katerina Koukiou)
- lib: patternfly now defines gold color in dark mode (Katerina Koukiou)
- test: fix selectors for <div> wrapping (Jelle van der Waa)
- lib: PF5 now uses the pf5 class names for tabs (Jelle van der Waa)
- test: adjust empty-state for new PF5 class names (Jelle van der Waa)
- package.json: Update @patternfly/patternfly, @patternfly/react-core, @patternfly/react-icons, @patternfly/react-styles, @patternfly/react-table, @patternfly/react-tokens (GitHub Workflow)
- po: Update from Fedora Weblate (GitHub Workflow)
- shell: Move "Web Console" doc link into manifest (Martin Pitt)
- Revert "cockpit.js: Support different URL root for the websocket" (Martin Pitt)
- lib: Drop ancient ParentWebSocket fallback (Martin Pitt)
- test: add verification for changing the pretty hostname (Jelle van der Waa)
- test: use standard compatible selectors (Jelle van der Waa)
- users: allow administrators to change the user shell (Jelle van der Waa)
- static: use a unique id for the bypass browser check (Jelle van der Waa)
- base1: Convert test-spawn.js to async tests (Martin Pitt)
- base1: Convert test-spawn-proc.js to async tests and standard Promise API (Martin Pitt)
- base1: Convert the rest of test-dbus-common.js to async tests (Martin Pitt)
- test: Use next() instead of [0] (Martin Pitt)
- all: Convert old jQuery promise API (Martin Pitt)
- shell: Convert test-machines.js to async tests (Martin Pitt)
- pytest: Use recursive glob to find test-machines.js (Martin Pitt)
- base1: Convert test-user.js to async tests (Martin Pitt)
- base1: Convert the first quarter of test-dbus-common.js to async tests (Martin Pitt)
- systemd: Add coverage annotation to SystemInformationCard (Martin Pitt)
- systemd: Use Promise in SystemInformationCard (Martin Pitt)
- systemd: Clean up state handling in SystemInformationCard (Martin Pitt)
- test: add coverage for asset tag (Jelle van der Waa)
- systemd: align properties under each other (Jelle van der Waa)
- networkmanager: drop useless React fragment wrapping (Jelle van der Waa)
- systemd: use braces when expanding variables (Jelle van der Waa)
- ws: test: fix shellcheck's double quote array/re-splitting errors (Jelle van der Waa)
- ws: drop unused srcdir variable (Jelle van der Waa)
- ws: add missing bang to shell shebang (Jelle van der Waa)
- storaged: Fix crash on fstab lines without mntopts (Martin Pitt)
- test: Log out of cockpit in testInsightsStatus (Martin Pitt)
- test: Fix fuser invocation in directory cleanup (Martin Pitt)
- sosreport: Add fallback error message (Martin Pitt)
- po: Update from Fedora Weblate (GitHub Workflow)
- kdump: Test configuration button should use ariaDisabled (Simon Kobyda)
- test: Drop redundant `set -e` calls (Martin Pitt)
- test: Make check-storage-raid1 nondestructive (Martin Pitt)
- test: Make most check-storage-mounting nondestructive (Martin Pitt)
- test: Make check-storage-unused nondestructive (Martin Pitt)
- test: Make check-storage-msdos nondestructive (Martin Pitt)
- test: Restrict long timeout in check-storage-iscsi (Martin Pitt)
- test: Make check-storage-iscsi nondestructive (Martin Pitt)
- test: Make check-storage-format nondestructive (Martin Pitt)
- containers: Document showing the "RUN" label command (Martin Pitt)
- tools: Suggest mdadm for cockpit-storaged (Martin Pitt)
- tools: Enable Python bridge on RHEL/CentOS 9 (Martin Pitt)
- tools: Enable Python bridge on Fedora 38 (Martin Pitt)
- pybridge: Robustify parsing of os-release (Martin Pitt)
- pybridge: Add initial unit test for os-release parsing (Martin Pitt)
- python bridge: rewrite packages serving code (Allison Karlitskaya)
- python bridge: drop CORS headers (Allison Karlitskaya)
- python: change version number approach (Allison Karlitskaya)
- cockpit.print: add helper for packages reloading (Allison Karlitskaya)
- .gitignore: add .tox (Allison Karlitskaya)
- all: Replace onKeyPress with onKeyDown (mukesh kumar)
- metrics: Fix CPU temperature sensor for AMD (Tomas Matus)
- tools: Adjust Debian libblockdev-mdraid dependency for udisks 2.10 (Martin Pitt)
- common: handle non-blocking fd in cockpit_socket_receive_fd() (Martin Pitt)
- lib: update isHoverable to isClickable (Jelle van der Waa)
- selinux: lib: isReadOnly is deprecated for TextArea (Jelle van der Waa)
- systemd: Table: drop unused type (Jelle van der Waa)
- shell: add missing id for FormSelect (Jelle van der Waa)
- terminal: fix unable to use scrollbar (Subho)
- python: use ioctl(TIOCSCTTY) on pty stream channels (Allison Karlitskaya)
- po: Update from Fedora Weblate (GitHub Workflow)
- client: disable DBusActivatable=true in desktop file (Allison Karlitskaya)
- .github/workflows: add a tox-venv test (Allison Karlitskaya)
- modules/checkout: fix with read-only directories (Allison Karlitskaya)
- pytest: improve process leak detection (Allison Karlitskaya)
- pyproject.toml: copy systemd_ctypes tox setup (Allison Karlitskaya)
- pytest: make compatible with Python 3.6 (Allison Karlitskaya)
- test/pytest: various Python compatibility fixes (Allison Karlitskaya)
- test/pytest: set event loop policy from conftest.py (Allison Karlitskaya)
- pytest: drop "auto" asyncio mode (Allison Karlitskaya)
- test_transport.py: port to pytest (Allison Karlitskaya)
- python: don't polyfill .send_fds() (Allison Karlitskaya)
- pytest: don't run linters anymore (Allison Karlitskaya)
- test/static-code: enable mypy (Allison Karlitskaya)
- python: fix up various mypy issues (Allison Karlitskaya)
- test/static-code: stop calling it pyvulture (Allison Karlitskaya)
- .flake8: limit to rules not covered by ruff (Allison Karlitskaya)
- test: don't run testMultipleBridgeConfig in networking scenario (Jelle van der Waa)
- test: Let "pixel-tests fetch" iterate over all scenarios (Marius Vollmer)
- storage: Reword Tang fingerprint verification dialog (Marius Vollmer)
- pybridge: Catch OSError in http channel (Martin Pitt)
- session: Stop ignoring signals (Martin Pitt)
- bridge: Fix error message for SIGHUPed bridge child processes (Martin Pitt)
- test: Make pybridge initial superuser behavior official (Marius Vollmer)
- test: Don't be PatternFly version specific in become_superuser et al (Marius Vollmer)
- systemd: Don't mangle crypto policy names (akshat2jain)
- pkg, examples: Avoid assigning .innerHTML (Martin Pitt)
- users: Fix "user is locked" detection (Martin Pitt)
- metrics: Merge average and top progress bars (Garrett LeSage)
- verify/check-client: skip fedora-testing also (Allison Karlitskaya)
- pybridge: Ignore read errors from cgroup metrics (Martin Pitt)
- test: Reduce timeouts in TestJournal.testBasic (Martin Pitt)
- systemd: Fix journalctl follow invocation race (Martin Pitt)
- systemd, tls: Robustify cockpit-certificate-helper ipa cleanup (Martin Pitt)
- test: Switch check-client from "only" to a "skip" list (Martin Pitt)
- pybridge: Fix cockpit_Machines directory lookup (Martin Pitt)
- pybridge: Fix ssh-agent launching (Martin Pitt)
- tools: Add font related Debian lintian overrides (Martin Pitt)
- tools: Drop unused BSD-3-clause license paragraph from Debian copyright (Martin Pitt)
- tools: Clarify Debian cockpit-packagekit description (Martin Pitt)
- tools: Drop unreproducible dist-info directory from Debian package (Martin Pitt)
- po: Update from Fedora Weblate (GitHub Workflow)
- pybridge: Fix superuser startup vs. package reloading race (Martin Pitt)
- flatpak: Change approach to external packages (Allison Karlitskaya)
- pybridge: Don't scan packages in the --privileged bridge (Martin Pitt)
- shell: Apply host dialogs on form submission (Marius Vollmer)
- test: Drop locale change check from TestPages.testBasic (Martin Pitt)
- test: Increase timeout for insights-client --register (Martin Pitt)
- test: Fix shebang in TestUpdates.testKpatch (Martin Pitt)
- tools: drop perl-json/perl-locale-po from depends as well (Jelle van der Waa)
- test: Allow 20 different pixels (Marius Vollmer)
- pybridge: Ignore OSErrors in MountSampler (Martin Pitt)
- tools: sync arch makedepends (Jelle van der Waa)
- network: Fix "Primary" select menu for creating team (Subho)
- tools: Drop npm-release-time (Martin Pitt)
- test: Fix TestIPA.testQualifiedUsers for Debian (Martin Pitt)
- test: Fix --sit with existing machines (Martin Pitt)
- client: Simplify cockpit-ws startup (Martin Pitt)
- build: Stop storing mtime of css (Bernhard M. Wiedemann)
- ruff: Ignore RUF012 (Martin Pitt)
- workflows: Run pytest-cov scenario in unit-tests-refresh (Martin Pitt)
- containers: Only install ruff into x86_64 unit-tests container (Martin Pitt)
- testlib: change approach for --sit and log captures, take two (Allison Karlitskaya)
- shell: inline the forward_command conditional to make it more explicit (Jelle van der Waa)
- test: Update pixel references for Chromium 114 (Martin Pitt)
- build: Fix spelling of --enable-pybridge option (Marius Vollmer)
- fmf: Replace deprecated dnf --noautoremove option (Martin Pitt)
- test: Apply TestServices extended timeout to all unit status checks (Martin Pitt)
- test: Bump wait_for_iface() timeout (Martin Pitt)
- systemd: Rename "crypto policy" to "cryptographic policy" (akshat2jain)
- networkmanager: fix 'Services' radio button handler in 'Add ports to zone' dialog (Katerina Koukiou)
- test: Increase status update timeout in TestServices.testBasic (Martin Pitt)
- test: Split off TestServices.testOtherTypes (Martin Pitt)
- test: Split off TestServices.testTimer (Martin Pitt)
- test: Split off TestServices.testFilter (Martin Pitt)
- test: Split off TestServices.testServiceMetrics (Martin Pitt)
- test: Refactor check_service_details() (Martin Pitt)
- pybridge: Avoid ruff F821 Undefined name (Martin Pitt)
- test: Fix implicit Optional annotation (Martin Pitt)
- test: Fix sit regression with --machine (Martin Pitt)
- test: Split verify run into four scenarios (Martin Pitt)
- test: prefer list comprehensions over map (Jelle van der Waa)
- test: don't use mutables as default arguments (Jelle van der Waa)
- test: add specific noqa comments for PT015 (Jelle van der Waa)
- tools: Keep C bridge on Debian stable (12) for now (Martin Pitt)
- tools: Enable Python bridge on current Ubuntu releases (Martin Pitt)
- pybridge: Fix ssh-agent cleanup for setgid (Martin Pitt)
- tools: Explicitly skip linter unit tests during Debian package build (Martin Pitt)
- test: Restart libvirtd between tests (Martin Pitt)
- test: Adjust special cases for debian-stable moving to Debian 12 "bookworm" (Martin Pitt)
- test: Refactor CI entry point and allow combining scenarios (Martin Pitt)
- client: Create user cache/data directories if they don't exist (Martin Pitt)
- test: Add cockpit-client browser integration test (Martin Pitt)
- test: sanitize window.location.hash in pixel tests (Jelle van der Waa)
- playground: avoid XSS via external download url (Jelle van der Waa)
- systemd: drop unrequired validated (Jelle van der Waa)
- client: save cookies in XDG_STATE_HOME (Jelle van der Waa)
- storage: Allow passwords to be revealed (Marius Vollmer)
- pkg: correctly call onChange handler (Jelle van der Waa)
- test: Don't unmount restored directories lazily (Martin Pitt)
- test: Fix cockpit-ssh restoration in TestLogin.testBasic (Martin Pitt)
- test: apply boolean positional value function call rule (Jelle van der Waa)
- test: use list destructuring instead of concatenation (Jelle van der Waa)
- python: use importlib.resources only on Python 3.11 (Allison Karlitskaya)
- storaged: prefer command -v over which (Jelle van der Waa)
- test: convert test_bridge.py to pytest (Allison Karlitskaya)
- test: remove mypy crash workaround (Allison Karlitskaya)
- test/verify: change an assertEquals to assertEqual (Allison Karlitskaya)
- test/verify: add sys.path hack for check-* tests (Allison Karlitskaya)
- test/verify: tweak pytest-xdist behaviour (Allison Karlitskaya)
- test/verify: sort tests by nondestructiveness (Allison Karlitskaya)
- testlib: kill global machine when not in use (Allison Karlitskaya)
- Revert "testlib: change approach for --sit and log captures" (Martin Pitt)
- test/verify: teach pytest how to load check-* (Allison Karlitskaya)
- testlib: add a pytest compatibility hack (Allison Karlitskaya)
- testlib: change approach for --sit and log captures (Allison Karlitskaya)
- testlib: tweak label calculation for pixel tests (Allison Karlitskaya)
- test/verify: refactor `from testlib import` statements (Allison Karlitskaya)
- python bridge: don't warn about missing ssh-agent (Allison Karlitskaya)
- flatpak: add envvar for enabling cockpit-beiboot (Allison Karlitskaya)
- cockpit-beiboot: ignore unexpected "authorize" (Allison Karlitskaya)
- tools: Skip test_samples.py::test_descriptions on Debian package builds (Martin Pitt)
- tools: Fix "only arch all" Debian build (Martin Pitt)
- kdump, networkmanager, storaged: Add manifest conditions (Martin Pitt)
- test: unbreak the post-commit hook (Jelle van der Waa)
- selinux: only show SELinux page when semanage is available (Jelle van der Waa)
- cockpit-beipack: better handling of explicit-superuser (Allison Karlitskaya)
- shell: recommend Ctrl+Shift+I for Javascript console (Allison Karlitskaya)
- flatpak: don't dist apps/ or playground/ (Allison Karlitskaya)
- flatpak: small `make install` cleanup (Allison Karlitskaya)
- client: add named arguments for boolean arguments (Jelle van der Waa)
- test: don't use mutable data structures for default arguments (Jelle van der Waa)
- flatpak: explicitly call main.iteration with a named argument (Jelle van der Waa)
- pkg: specify a named argument for vdo code (Jelle van der Waa)
- pkg: enable ruff FBT002 rule (Jelle van der Waa)
- pkg: don't shadow builtin variable names (Jelle van der Waa)
- pkg: don't shadow builtins in variables (Jelle van der Waa)
- pkg: prefer Python list destructuring (Jelle van der Waa)
- tools: switch Arch packaging to the Python bridge (Jelle van der Waa)
- lib: fix plot zoom controls dropdown toggle (Subho)
- cockpit-beiboot: try to run /usr/bin/cockpit-bridge (Allison Karlitskaya)
- python bridge: add support for beipack-over-sudo (Allison Karlitskaya)
- bridge: add 'beipack' mode to disable Packages (Allison Karlitskaya)
- python: move self-beipack code to its own module (Allison Karlitskaya)
- cockpit-beiboot: don't try to do explicit-superuser (Allison Karlitskaya)
- cockpit.print: support for making D-Bus calls (Allison Karlitskaya)
- python: change '''strings''' to """strings""" (Allison Karlitskaya)
- test: prefer command -v over which (Jelle van der Waa)
- po: Update from Fedora Weblate (GitHub Workflow)
- tools: Switch Debian devel series to Python bridge (Martin Pitt)
- tools: Quiesce cockpit-ws lintian message about font-in-non-font-package (Martin Pitt)
- test: Drop python3 -P option (Martin Pitt)
- pkg: sort all imports (Jelle van der Waa)
- test: rename all shadowing builtin variables (Jelle van der Waa)
- test: don't shadow python builtins (Jelle van der Waa)
- test/common/pywrap: add a short help near the top (Allison Karlitskaya)
- test/common/pywrap: disable bytecode, '.' in path (Allison Karlitskaya)
- test: don't use non-standard :first selector (Jelle van der Waa)
- tools: Reduce Python meta-info assumptions in spec (Martin Pitt)
- tools: Enable Python bridge on Fedora ≥ 39 (Martin Pitt)
- ws: Don't capture stderr for Cockpit Client when debugging (Allison Karlitskaya)
- client: add new ssh helper based on beiboot (Allison Karlitskaya)
- modules: bump ferny version (Allison Karlitskaya)
- flatpak: Use install-cockpit-client-symlink rule (Allison Karlitskaya)
- pkg: use "usual" mechanism for make install hooks (Allison Karlitskaya)
- flatpak: factor out `make install` rule dependencies (Allison Karlitskaya)
- test: drop unused for loop variable (Jelle van der Waa)
- src: test: drop false positive noqa FBT003 (Jelle van der Waa)
- test: use strict=True for zip() for equal length checking (Jelle van der Waa)
- test: don't use a naive timezone in tests (Jelle van der Waa)
- ws: Update AppStream screenshot, drop translation tag (Martin Pitt)
- testlib: correctly deal with older shell versions that are not ported to pf5 (Katerina Koukiou)
- test: print message to stderr when no coverage is generated (Jelle van der Waa)
- lib/cockpit-components-dialog: Put spinner into button (Marius Vollmer)
- python: change functionality of Peer.start() (Allison Karlitskaya)
- build: include a beipack in our wheel build (Allison Karlitskaya)
- python: factor packages conditions checks a bit (Allison Karlitskaya)
- python: add a data loading helper (Allison Karlitskaya)
- modules: update systemd_ctypes (Allison Karlitskaya)
- test: make loading sizzle optional for tests (Jelle van der Waa)
- po: Update from Fedora Weblate (GitHub Workflow)
- pybridge: Fix clobbering remote user set in SSH config (Martin Pitt)
- HACKING: Warn against cloning a fork (Martin Pitt)
- pybridge: Respect $XDG_CONFIG_DIRS (Martin Pitt)
- doc: Describe $XDG_CONFIG_DIRS (Martin Pitt)
- test: Test $XDG_CONFIG_DIRS behaviour (Martin Pitt)
- test: Update default TEST_OS to fedora-38 (Akshat Jain)
- workflows: Fix weblate-sync-po for moved make-bots (Martin Pitt)
- pybridge: Detect `no-cockpit` peer error (Martin Pitt)
- pybridge: Use standard error code for disconnected peers (Martin Pitt)
- test: Adjust testTroubleshooting port changing to Python bridge (Martin Pitt)
- pybridge: Fix Machines.Update() to actually update (Martin Pitt)
- lib: add screen reader text for journal log entry badge (Jelle van der Waa)
- pybridge: Fix handling of changed SSH host keys (Martin Pitt)
- test: cleanup possible leftover pacman lockfile (Jelle van der Waa)
- lib: Avoid `which` in python.js (Martin Pitt)
- test: Test "no-cockpit" case realistically (Martin Pitt)
- test: Switch pixel tests to fedora-38 (Marius Vollmer)
- cryptoPolicy: Move strings closer to their usage (Matej Marusak)
- networkmanager: Fix loopback interface recognition (Marius Vollmer)
- pyproject: add test/common to mypy path (Allison Karlitskaya)
- scripts: fix up some shellcheck cruft (Allison Karlitskaya)
- ruff: remove custom isort config for test/common (Allison Karlitskaya)
- all: replace `import parent` with an interpreter line hack (Allison Karlitskaya)
- test/common: add new 'pywrap' script (Allison Karlitskaya)
- tools: move make-bots, git-utils.sh to test/common (Allison Karlitskaya)
- test: Remove "dnf-copr" scenario name (Marius Vollmer)
- test: Clarify test VM SSH configuration (Martin Pitt)
- test: Update "Faster iteration" documentation (Martin Pitt)
- build.js: Run rsync plugin also for $RSYNC env variable (Martin Pitt)
- test/static-code: change approach to running ruff (Allison Karlitskaya)
- image-prepare: clean up shell script pasting (Allison Karlitskaya)
- tap-cdp: remove some Python 2 compatibility stuff (Allison Karlitskaya)
- various: fix up issues identified by ruff (Allison Karlitskaya)
- pkg/apps: unset +x on a utility script (Allison Karlitskaya)
- test/verify: isort (Allison Karlitskaya)
- test: Don't use CSS to replace DOM elements with arbitrary text (Marius Vollmer)
- all: fix some usages of FormHelperText (Katerina Koukiou)
- python: update ferny, implement cockpit.send-stderr (Allison Karlitskaya)
- bridge: Add polkit responder to Python bridge (Martin Pitt)
- storage: Raise Stratis test coverage (Marius Vollmer)
- storage: Refactor Stratis code a bit (Marius Vollmer)
- pkg: Fix all HTML pages to be XHTML compliant (Martin Pitt)
- playground: Drop &nbsp from speed page (Martin Pitt)
- static: Make dynamic content tag valid HTML (Martin Pitt)
- static: Drop ancient IE NoteList.forEach hack (Martin Pitt)
- lib: Rename qunit-template.html to *.in (Martin Pitt)
- testlib: Adjust expected pybridge traceback for Fedora 38 (Martin Pitt)
- po: Update from Fedora Weblate (GitHub Workflow)
- storage: Account for overhead in Stratis pools (Marius Vollmer)
- test: Ignore known pybridge error "Event loop is closed" (Martin Pitt)
- test: Allow more time for initial service memory to appear (Martin Pitt)
- test: Allow D-Bus disconnect messages in TestPages.testAllNavEntries (Martin Pitt)
- po: Also include pkg/lib translations (Matej Marusak)
- src: fix typos (lvgenggeng)
- lib: plot: add missing -v5- prefix in the chart variables for plots (Katerina Koukiou)
- python: add 'pygrep-hooks' to ruff config (Allison Karlitskaya)
- python: forbid boolean positional arguments (Allison Karlitskaya)
- pyproject.toml: add a bunch of ruff rules (Allison Karlitskaya)
- python: use f'{exc!s}' instead of f'{str(exc)}' (Allison Karlitskaya)
- python: let ruff rewrite some comprehensions (Allison Karlitskaya)
- python: add pytest checks to ruff config (Allison Karlitskaya)
- python: include clean-ups for isort (Allison Karlitskaya)
- python: enable ruff "G" (logging) checks (Allison Karlitskaya)
- python: enable ruff "A" (builtins) checks, minus one (Allison Karlitskaya)
- python: enable ruff bugbear checking (Allison Karlitskaya)
- python: various fixups to exception chaining (Allison Karlitskaya)
- test: Allow more time for configuring chrony (Martin Pitt)
- test: Set correct SELinux context for PCP (Martin Pitt)
- Update pixel tests (Katerina Koukiou)
- users: the desired spacing is the default no need to specify it (Katerina Koukiou)
- users: remove redundant css imports (Katerina Koukiou)
- all: adjust parameter position for the onChange callback of the Slider (Katerina Koukiou)
- all: adjust parameter position for the onChange callback of the Nav (Katerina Koukiou)
- all: adjust parameter position for the onChange callback of the ToggleGroupItem (Katerina Koukiou)
- all: adjust parameter position for the onChange callback of the TextArea (Katerina Koukiou)
- all: adjust parameter position for the onChange callback of the Switch (Katerina Koukiou)
- all: adjust parameter position for the onChange callback of the TextInput (Katerina Koukiou)
- all: LabelGroup changed import path (Katerina Koukiou)
- all: some classes updates were forgotten to use pf5 prefix (Katerina Koukiou)
- all: remove pf-m-redhat-font class (Katerina Koukiou)
- all: adopt pf-v5-m-tabular-nums naming (Katerina Koukiou)
- all: adopt pf-theme-dark naming (Katerina Koukiou)
- Update all selectors, [s]css vars to include v5 (Katerina Koukiou)
- package.json: Update @patternfly/patternfly, @patternfly/react-core, @patternfly/react-icons, @patternfly/react-styles, @patternfly/react-table (GitHub Workflow)
- logs: remove redundant CSS - toolbar paddings are fine (Katerina Koukiou)
- python: fix 'type' field on D-Bus replies (Allison Karlitskaya)
- python: isort everything via ruff (Allison Karlitskaya)
- bridge: Prefer label as superuser rule ID (Martin Pitt)
- po: Update from Fedora Weblate (GitHub Workflow)
- test: Check for leaked processes after browser logout and cockpit-desktop (Martin Pitt)
- test: Apply Sizzle document hack also on Chromium (Marius Vollmer)
- python: try a different approach with Peer.start() (Allison Karlitskaya)
- python: handle cancellation in superuser rule (Allison Karlitskaya)
- python: report superuser auth errors properly (Allison Karlitskaya)
- test: Adapt tests to upcoming udisks2 2.10 release (Marius Vollmer)
- test: New "daily" scenario for dnf and udisks2 daily builds (Marius Vollmer)
- test: include vulture as part of pytest (Allison Karlitskaya)
- pyproject.toml: fix vulture suppressions path (Allison Karlitskaya)
- test/pytest: unify linters (Allison Karlitskaya)
- build: write a bare minimal PEP 517 build backend (Allison Karlitskaya)
- patternfly-overrides: Fix RTL for masthead, menus, and expandables (Garrett LeSage)
- test: Update pixel references for recent RTL fixes (Martin Pitt)
- metrics: Shift order to use, sat, use(c), sat(c) (Garrett LeSage)
- metrics: Fix scaling and normalize to scale() (Garrett LeSage)
- metrics: Fix opacity for compressed saturated (Garrett LeSage)
- metrics: Fix min-height var for LTR & RTL (Garrett LeSage)
- nav: Fix search icon spacing (Garrett LeSage)
- patternfly-overrides: More RTL fixes (Garrett LeSage)
- all: Manually fix usage of logical properties for spacing based on stylelint errors (Garrett LeSage)
- package.json: stylelint: Add logical property checker (Garrett LeSage)
- python: Generalize subprocess cleanup, and use TERM instead of HUP (Martin Pitt)
- Use 'type' instead of 'which' which is standard unix (Katerina Koukiou)
- test/static-code: don't do eslint in partial trees (Allison Karlitskaya)
- metrics: Fix y-flipped history polygons for saturation, and RTL orientation (Martin Pitt)
- build: drop support for compile_commands.json (Allison Karlitskaya)
- python: abort outstanding sudo auth in various cases (Allison Karlitskaya)
- testlib: tweak @todoPybridge decorator implementation (Allison Karlitskaya)
- Revert "pkg: Enable dark theme by default with PF class" (Katerina Koukiou)
- logs: Mobile filter popup doesn't need offset (Garrett LeSage)
- logs: Fix filter alignment (Garrett LeSage)
- storage: Mock partition UUID for pixel testing (Marius Vollmer)
- test: Allow replacing of DOM elements with arbitrary text (Marius Vollmer)
- storage: Don't require a mount point when creating filesystems (Mahmoud Hamdy)
- tools/git-hook-post-commit: checkout extra files (Allison Karlitskaya)
- test/static-code: fix our vulture setup (Allison Karlitskaya)
- python: many vulture fixes (Allison Karlitskaya)
- test: drop code from mock-bugzilla-server.py (Allison Karlitskaya)
- python: remove Spooler method only used from tests (Allison Karlitskaya)
- testlib: use setattr() to avoid warnings (Allison Karlitskaya)
- testlib: drop several old and unused APIs (Allison Karlitskaya)
- test: fix an incorrectly-named test (Allison Karlitskaya)
- test: fix a minor bug in our mock-bugzilla-server (Allison Karlitskaya)
- test: port pytest/test_samples.py to pytest style (Allison Karlitskaya)
- test: test method calls on the dbus channel (Allison Karlitskaya)
- client: use accessors instead of property on GApplication (Allison Karlitskaya)
- python: fix a ghosted local in cockpit-print (Allison Karlitskaya)
- python: white-space changes, limit to 118 columns (Allison Karlitskaya)
- test: add an assertion for mypy's sake (Allison Karlitskaya)
- python: factor-out a sub-condition for readability (Allison Karlitskaya)
- test: bring back test_host (Allison Karlitskaya)
- python: de-indent a function in samples.py (Allison Karlitskaya)
- test: avoid needlessly complicated path logic (Allison Karlitskaya)
- python: convert an embedded shellscript from a one-liner (Allison Karlitskaya)
- python: use pytest fixture style in test_packages (Allison Karlitskaya)
- test: factor out package-creation code (Allison Karlitskaya)
- python: introduce ruff as a linter (Allison Karlitskaya)
- pyproject.toml: require pytest-asyncio (Allison Karlitskaya)
- python: avoid an awkward destructuring assignment (Allison Karlitskaya)
- storaged: utilize Stack instead of Grid for vertical simple layout in details (Katerina Koukiou)
- storaged: hasGutter is not a property of Flex component (Katerina Koukiou)
- test: Disable preload to stabilize TestPages.testBasic (Martin Pitt)
- po: Update from Fedora Weblate (GitHub Workflow)
- firewall: allow custom ports when there is type mismatch (Omar Yusuf)
- test: Use dynamic pybridge detection instead of $TEST_SCENARIO (Martin Pitt)
- services: remove redundant spacing for the timer modal deletion alert (Katerina Koukiou)
- services: utilize stack layout to add spacer in service details (Katerina Koukiou)
- services: use stack instead of gallery for the service details layout (Katerina Koukiou)
- systemd: remove unused CSS (Katerina Koukiou)
- test: Handle pixel diffs when size has changed (Marius Vollmer)
- bridge: Drop unused "problem" initialization (Martin Pitt)
- metrics: fix broken alignment in expanded hour in metrics history (Katerina Koukiou)
- bridge, session: Drop changing umask (Martin Pitt)
- test: Drop TEST_SCENARIO check for expected pybridge messages (Martin Pitt)
- test: Enable pixel tests for pybridge scenario (Martin Pitt)
- test: Drop @todo support for flaky= (Martin Pitt)
- python: Make askpass "messages" vs. "error" consistent with C bridge (Martin Pitt)
- python: Handle ProcessLookupError when reading cgroup name (Martin Pitt)
- python: Fix FileNotFoundError crash if /sys/class/hwmon does not exist (Martin Pitt)
- test: Clean up test skips (Martin Pitt)
- test: Allow "vdo create" to take more time (Martin Pitt)
- test: Relax assumptions about Grafana DOM specifics (Marius Vollmer)
- Remove duplicate / from submodule url (Katerina Koukiou)
- storage: Don't crash when the VFO pool is missing (Marius Vollmer)
- test: Relax expected VDO sizes (Marius Vollmer)
- services: remove nested <Page> component from service details page (Katerina Koukiou)
- test: hide scrollbar in pixel testing (Katerina Koukiou)
- test: drop fmf_metadata experiment (Jelle van der Waa)
- test: document skip related test decorators (Jelle van der Waa)
- test: update TEST_OS values (Jelle van der Waa)
- .github: run CodeQL workflow on main as well (Jelle van der Waa)
- Revert "fmf: Force nodejs 18 on Rawhide" (Martin Pitt)
- systemd: Consistently use CardTitle's component attribute (Martin Pitt)
- metrics: Add per-cgroup disk IO usage (Tomas Matus)
- tests: Update test reference (Katerina Koukiou)
- firewall: Use <CardTitle component="h2"... for the card title (Katerina Koukiou)
- package.json: Update patternfly-* (Katerina Koukiou)
- test: Use real packages to test on-demand Stratis (Marius Vollmer)
- storage: Enable on-demand installation of Stratis on RHEL 9 (Marius Vollmer)
- all: Use <CardTitle component="h2"... for cards (Katerina Koukiou)
- test/image-prepare: change how --python works (Allison Karlitskaya)
- cockpit.spec: add support for the python bridge (Allison Karlitskaya)
- build: add ./configure --enable-pybridge flag (Allison Karlitskaya)
- build: include Python files in the "dist" tarball (Allison Karlitskaya)
- python: drop a superfluous assertion (Allison Karlitskaya)
- python: move some files to src/cockpit/misc (Allison Karlitskaya)
- python: switch to a dynamic version number (Allison Karlitskaya)
- python: migrate setuptools config to setup.cfg (Allison Karlitskaya)
- tools/make-dist: tweak "git" version number scheme (Allison Karlitskaya)
- build: drop PYTHON_BRIDGE_FILES= from Makefile (Allison Karlitskaya)
- python: add tox support (Allison Karlitskaya)
- test-server: stop using /tmp/dbus-tests as tmpdir (Allison Karlitskaya)
- build: make `make install` more selective about dist/ (Allison Karlitskaya)
- build: fix `make install` for relative `DESTDIR=` (Allison Karlitskaya)
- tools/fix-spec: use `mv -f` to avoid prompts (Allison Karlitskaya)
- debian: Add explicit `--buildsystem=autoconf` (Allison Karlitskaya)
- test: Support Debian/Ubuntu images with chronyd and no systemd-timesyncd (Marius Vollmer)
- storage: allow sidebar to grow full width in mobile mode (Katerina Koukiou)
- services: improve alignment of last (status) column (Katerina Koukiou)
- test: Wait for Stratis filesystems to be mounted before deleting (Marius Vollmer)
- test: update regressed pixel test (Katerina Koukiou)
- python: Close process stdin when closing SubprocessTransport (Martin Pitt)
- storage: only show 'Format' for primary button when empty filesystem is chosen (Mahmoud Hamdy)
- fmf: Force nodejs 18 on Rawhide (Martin Pitt)
- Update pixel tests (Katerina Koukiou)
- storage: fix overflowing content in overview page (Katerina Koukiou)
- lib: stop overriding the mobile breakpoint as for width < 768px the left nav is hidden (Katerina Koukiou)
- workflows: Move npm-update back to Ubuntu 20.04 (Martin Pitt)
- storage: Support stopped Stratis pools (Marius Vollmer)
- networkmanager: Recreate the D-Bus watch when the service restarts (Marius Vollmer)
- test: Drop unnecessary leave/enter page (Martin Pitt)
- package.json: remove unused eslint-flowtype-plugin dependency (Katerina Koukiou)
- test: drop pixel testing of popover for services using storage (Katerina Koukiou)
- storage: Improve error message when PackageKit is missing (Marius Vollmer)
- storage: When fixing NBDE, also recognize indirect root filesystems (Marius Vollmer)
- Update existing metrics tests and add new one for the metrics cards (Katerina Koukiou)
- lib: Rename patternfly-4-cockpit.scss file to patternfly-5-cockpit.scss (Katerina Koukiou)
- metrics: Fix broken styles on page (Katerina Koukiou)
- shell: add state for no matches in search in the language modal (Shubhit Dhiman)
- shell: About: Add Cockpit logo background screen (Garrett LeSage)
- test: Check cancel and logout with ongoing sudo authentication (Martin Pitt)
- test: Check SSH session cleanup in TestSuperuserDashboard (Martin Pitt)
- test: Use superuser helper methods in TestSuperuserDashboard (Martin Pitt)
- test: Link @todoPybridge to issues (Martin Pitt)
- packagekit: pass triggerRef to remove the div element the wraps the tooltip trigger (Katerina Koukiou)
- shell: remove background image in about modal (Katerina Koukiou)
- logs: services: fix filters alignment (Katerina Koukiou)
- shell: fix host edit/add buttons position (Katerina Koukiou)
- lib: show empty state footer only if actions are present (Katerina Koukiou)
- Correct the sizing of some icons (Katerina Koukiou)
- systemd: fix variant of motd dialog (Katerina Koukiou)
- metrics: port to new table implementation (Katerina Koukiou)
- lib: introduce new overrides and adjust existing custom CSS to match new DOM structure (Katerina Koukiou)
- Update to patternfly 5 alpha (Katerina Koukiou)
- workflows: Move reposchutz back to Ubuntu 20.04 (Martin Pitt)
- po: Update from Fedora Weblate (GitHub Workflow)
- shell: fix spacing in 'About Web Console' modal dialog (Katerina Koukiou)
- services: adjust service details header to use less custom CSS (Katerina Koukiou)
- storaged: Fix crash if block device lacks Encrypted interface (Martin Pitt)
- test: Increase VM memory for TestStorageHidden.testHiddenLuks (Martin Pitt)
- storage: Replace utils.array_find() with Array.find() (Martin Pitt)
- networkmanager: Replace array_find() with Array.find() (Martin Pitt)
- services: remove dropdown from CardActions as it inherits the fonts (Katerina Koukiou)
- lib: use flex to position and correctly align footer message in dialogs (Katerina Koukiou)
- lib: c-c-install-dialog: put back missing spinner (Katerina Koukiou)
- packagekit: use patternfly to put back missing spinner in restart services dialog (Katerina Koukiou)
- systemd/services: Use single source of truth for page location (Martin Pitt)
- apps: Use single source of truth for page location (Martin Pitt)
- firewall: remove the default top padding from the toolbar in 'add services' dialog (Katerina Koukiou)
- test: Fix polkit rule for Python bridge (Martin Pitt)
- test: Tighten pgrep again in TestConnection.testCockpitDesktop (Martin Pitt)
- test: Reduce cockpit-desktop invocation timeout in TestConnection.testCockpitDesktop (Martin Pitt)
- Adjust Breadcrumb usage on all affected pages to match PF5 guidelines (Katerina Koukiou)
- systemd: Remove custom styles from 'System time' dialog (Katerina Koukiou)
- storage: replace custom ct-text-align-right with pf-u-text-align-right class (Katerina Koukiou)
- terminal: remove redundant import (Katerina Koukiou)
- test: Mark TestStorageHidden.testHiddenSnap as nondestructive (Martin Pitt)
- test: Fix TestWsBastionContainer to actually be nondestructive (Martin Pitt)
- shell: fix minor CSS alignment of shell search menu independant to themes (Ragavendaran Puliyadi)
- static: rename login.css to login.scss to allow esbuild to flatten it properly (Ragavendaran Puliyadi)
- test: Reset insights-client after TestSystemInfo.testInsightsStatus (Martin Pitt)
- users: port shell selection to FormSelect (Katerina Koukiou)
- logs: Decode binary MESSAGEs (Samarjeet Kashyap)
- test: Make TestSelinux.testEnforcingToggle nondestructive (Martin Pitt)
- test: Make TestSystemInfo.testInsightsStatus nondestructive (Martin Pitt)
- test: Introduce @onlyImage decorator and apply to RHEL-only tests (Martin Pitt)
- selinux: Fix error reporting (Martin Pitt)
- shell: Disable "Add key" button while the file input box is empty (Martin Pitt)
- test: Fix Browser.set_file_autocomplete_val() and its usage (Martin Pitt)
- test: Drop obsolete OpenSSH < 7.8 code from check-shell-keys (Martin Pitt)
- test: Make check-loopback nondestructive (Martin Pitt)
- test: Make TestKeys.testPrivateKeys nondestructive (Martin Pitt)
- test: Make check-apps nondestructive (Martin Pitt)
- test: Consistently use f-strings in check-apps (Martin Pitt)
- test: Clean up leaked cockpit-ws process (Martin Pitt)
- test: Generalize /etc/cockpit restoration (Martin Pitt)
- test: Make most TestConnection tests nondestructive (Martin Pitt)
- test: Fix MachineCase.write_file()'s post_restore_action for nonexisting files (Martin Pitt)
- po: Update from Fedora Weblate (GitHub Workflow)
- workflows: Minimize permissions (Martin Pitt)
- workflows: Run on ubuntu-latest (Martin Pitt)
- tools/spec: Guard grep with test for checking PAM file (Luna)
- python: initial implementation of ssh support (Allison Karlitskaya)
- python: implement the /machines internal D-Bus endpoint (Allison Karlitskaya)
- python: remove mandatory message from CockpitProblem (Allison Karlitskaya)
- python: make sure the bridge has an SSH_AUTH_SOCK (Allison Karlitskaya)
- python: minor tweaks to bridge startup (Allison Karlitskaya)
- testlib: introduce @todoPybridgeRHEL8 decorator (Allison Karlitskaya)
- modules: update ferny (Allison Karlitskaya)
- build: fix source map generation (Katerina Koukiou)
- python: don't process kill messages on closing channels (Allison Karlitskaya)
- storage: fix alignment of 'Block devices' form element in 'Create stratis pool' dialog (Katerina Koukiou)
- static: allow 'auto' theme to be applied as default theme for login page (Ragavendaran Puliyadi)
- test: Reduce sleep times in nondestructive test cleanup (Martin Pitt)
- lib: remove PF override for svg's vertical-align (Simon Kobyda)
- ssh: Clean up libssh connection on terminating signals (Martin Pitt)
- Port to new way of using HelperText (Katerina Koukiou)
- lib: port context menu to patternfly component (Katerina Koukiou)
- test: Remove a race in TestStorageStratis.testAtBoot (Marius Vollmer)
- lib: Drop unnecessary optional chaining (Martin Pitt)
- lib: Clarify null check in handle_callback() (Martin Pitt)
- systemd: Avoid null-like value "other_props" (Martin Pitt)
- session: Assert that gss_display_name() succeeded (Martin Pitt)
- test: Ignore timedatex.service disconnection messages (Martin Pitt)
- test: discover machine_class dynamically from test classes (Jelle van der Waa)
- test: Don't ignore errors during coverage report generation (Marius Vollmer)
- test: Skip "medium" layout for basic networking test (Martin Pitt)
- Stop using pf-global--FontWeight--semi-bold as this is not existing in PF-v5 (Katerina Koukiou)
- test: Adapt coverage processing to new esbuild source maps (Marius Vollmer)
- packit: Re-add post-upstream-clone to copr_build (Martin Pitt)
- users: Retain authorized_keys file permissions (Martin Pitt)
- test: Simplify login in TestKeys.testAuthorizedKeys (Martin Pitt)
- systemd: set a different text color in the dark theme (Jelle van der Waa)
- login: add autocomplete tags (Marcus)
- po: Update from Fedora Weblate (GitHub Workflow)
- test: Update network overview pixel test for latest fedora-37 (Martin Pitt)
- package.json: Update @patternfly/react-core, @patternfly/react-styles, @patternfly/react-table (GitHub Workflow)
- metrics: add pixel tests for the graphs (Katerina Koukiou)
- run-tests: Fix test EXCLUDE to cover centos-8 (Katerina Koukiou)
- ws: Disallow direct URL logins with LoginTo=false (Martin Pitt)
- packagekit: Fix error display on update failures (Chandrashekhar Tripathi)
- Add pixel tests for Account create dialog (Simon Kobyda)
- passwords: Show validation errors as warnings with icons and outline (Simon Kobyda)
- accounts: Check if password and confirmation match after user finishes typing (Simon Kobyda)
- accounts: Rename 'Confirm' field to 'Confirm password' (Simon Kobyda)
- test: add test/image-prepare --env and --debug (Allison Karlitskaya)
- tools: Declare bundled NPM dependencies in spec file (Martin Pitt)
- lib: file-autocomplete: Fix descend into directory (Simon Kobyda)
- metrics: adjust graph colors and use gradient for marking end of graph area (Katerina Koukiou)
- po: Update from Fedora Weblate (GitHub Workflow)
- tests: temporarily disable stratis add block device dialog pixel test (Katerina Koukiou)
- lib: correct object check for dialog error object (Jelle van der Waa)
- storaged: drop unused state properties from OptionalPanel (Jelle van der Waa)
- storaged: don't set text state property which is never read (Jelle van der Waa)
- networkmanager: ===/!== bind more tightly then & (Jelle van der Waa)
- systemd: don't call delete on the delete value from a set (Jelle van der Waa)
- metrics: drop unused cpuTemperature state property (Jelle van der Waa)
- systemd: drop unused state properties (Jelle van der Waa)
- lib: cockpit-po-plugin: make source directory a configuration option (Katerina Koukiou)
- package.json: Move qunit to devDependencies (Martin Pitt)
- packit: Enable tests on aarch64 (Martin Pitt)
- apps: Fix progress bar and cancel button (Ahmed Abdelatty)
- test: Robustify sos tar reading (Martin Pitt)
- Revert "test: Try to open sos archive 3 times" (Martin Pitt)
- modules: update systemd_ctypes (Allison Karlitskaya)
- systemd: show multiple dialog errors correctly (Jelle van der Waa)
- workflows: Update differential-shellcheck workflow to version 4 (Jan Macku)
- test: metrics: grafana: wait to move away from loading screen (Katerina Koukiou)
- tests: update selector to match grafana from the new services image (Katerina Koukiou)
- tests: Introduce assertion for stratis private objects wrongly shown in block devices (Katerina Koukiou)
- systemd: Improve realmd label (Aazam Thakur)
- test: correct typing for browser.open() (Jelle van der Waa)
- test: drop unused and broken browser.title (Jelle van der Waa)
- test: extend our Python type hints coverage (Jelle van der Waa)
- test: drop unused host parameter from go() (Jelle van der Waa)
- pyproject.toml: enable pytest --strict-markers (Allison Karlitskaya)
- Makefile: Build dist/ and qunit tests for pytest (Martin Pitt)
- containers/unit-tests: Add missing python3-pytest-asyncio (Martin Pitt)
- test: Fix qunit test path (Martin Pitt)
- test: Stop hardcoding busybox container image name (Martin Pitt)
- kdump: Show ModalError as expandable (Jelle van der Waa)
- ssh: Drop call to sss_ssh_knownhostsproxy (Martin Pitt)
- various: replace mentions of IRC with Matrix (Allison Karlitskaya)
- po: Update from Fedora Weblate (GitHub Workflow)
- po: Drop 'zh_TW' language (GitHub Workflow)
- test: Drop check for sss_ssh_knownhostsproxy --pubkey (Martin Pitt)
- build.js: Drop obsolete --config option (Martin Pitt)
- packagekit: don't call formatPackageId on itself (Jelle van der Waa)
- kdump: wait till both cockpit.file's are complete before rendering (Jelle van der Waa)
- kdump: drop unneeded state variables (Jelle van der Waa)
- kdump: simplify and correct ModalError parameters (Jelle van der Waa)
- build: Move stylesheet processing into pkg/lib/build-common.js to enable reusing (Katerina Koukiou)
- accounts: Specifying custom shell during user creation (Simon Kobyda)
- accounts: Allow specifying home directory during account creation (Simon Kobyda)
- pkg: Use only full path imports as tree shaking is imperfect (Katerina Koukiou)
- build.js: apply hack with PF fix for failing pixel tests (Katerina Koukiou)
- pkg: No null loader is applied on page, toolbar and table components CSS anymore (Katerina Koukiou)
- build.js: Move our front end build tool from webpack to esbuild (Katerina Koukiou)
- lib/cockpit-po-plugin: Terminate cockpit.locale() call (Martin Pitt)
- HACKING: Explain container updating (Garrett LeSage)
- tests: add rhel-8-9 special cases (Katerina Koukiou)
- systemd: Drop loading of non-existing performance.js (Martin Pitt)
- lib/cockpit-rsync-plugin: Fix return value on failures (Martin Pitt)
- users: validate account expiry date onBlur (Mahmoud Hamdy)
- test: Skip three regressed tests on c8s/pybridge (Martin Pitt)
- test: Ignore frequent "Exception in callback None()" failure on c8s/pybridge (Martin Pitt)
- test: Add bug reference to "Task was destroyed but it is pending" pybridge error (Martin Pitt)
- test: Validate all Navigation menu page entries (Martin Pitt)
- lib: Actually render dialog static_error as alert (Marius Vollmer)
- lib: Add esbuild-cleanup-plugin.js (Martin Pitt)
- lib/esbuild-compress-plugin: Support subdirectories and filtering (Katerina Koukiou)
- lib/esbuild-eslint-plugin: Make filter an option (Katerina Koukiou)
- lib/esbuild-stylelint-plugin: cover the case when no matching files exist (Katerina Koukiou)
- selinux: Fix menu entry (Martin Pitt)
- Update pixel tests for the new modal footer spacing (Katerina Koukiou)
- patternfly-overrides: remove overrides whose issues have been resolved upstream in patternfly (Katerina Koukiou)
- patternfly-overrides: Remove override column gap for out modal footers (Katerina Koukiou)
- shell/scss: fix dark theme code background for new ssh host modal (Mahmoud Hamdy)
- test: Pixel test the full shell key dialog (Marius Vollmer)
- users: fix text misalignment issue in account overview menu (Caleb Durojaiye)
- lib: port the current manual NTP server dialog to PF (Jelle van der Waa)
- accounts: Allow specifying UID during account creation (Simon Kobyda)
- accounts: Rearange the order of Create account dialog (Simon Kobyda)
- Update documentation and comments to not be webpack specific (Martin Pitt)
- po: Update from Fedora Weblate (GitHub Workflow)
- tools: drop a function from git-utils.sh (Allison Karlitskaya)
- tools: drop webpack-jumpstart (Allison Karlitskaya)
- tools: remove jumpstart from make-dist (Allison Karlitskaya)
- containers: remove dead --submodule flag from script (Allison Karlitskaya)
- containers: remove stranded --wait flag from script (Allison Karlitskaya)
- Rename tools/webpack-make.js to ./build.js (Martin Pitt)
- pkg: Merge remaining pkg/build functionality into pkg/Makefile.am (Martin Pitt)
- tools: Teach webpack-make.js to get node_modules by itself (Martin Pitt)
- build: Move package-lock.json and FORCE rules to top-level Makefile (Martin Pitt)
- packit: Build web bundles without webpack-jumpstart (Martin Pitt)
- workflows: Avoid calling pkg/build in weblate-sync-pot.yml (Martin Pitt)
- pkg: Update dist/ install rule to avoid `find` in dependencies (Martin Pitt)
- systemd/services: Avoid time.clock_gettime_ns() (Martin Pitt)
- hacking: Improve used language (Garrett LeSage)
- modules: bump ferny version (Allison Karlitskaya)
- workflows: Build jumpstart tarball without pkg/build (Martin Pitt)
- build: simplify handling of systemd_ctypes and ferny (Allison Karlitskaya)
- tools: drop make-wheel script (Allison Karlitskaya)
- modules: update ferny to main version (Allison Karlitskaya)
- tools: Make webpack-make.js' directory argument optional (Martin Pitt)
- webpack.config.js: Don't require $ONLYDIR to end with / (Martin Pitt)
- build: Drop Makefile.deps mechanism and build dist/ in a single webpack run (Martin Pitt)
- webpack.config.js: Allow building all pages at once (Martin Pitt)
- build: Put webpacked unit tests into ./qunit/ (Martin Pitt)
- pkg: Pull QUnit test enumeration out of webpack-make.js (Martin Pitt)
- lib: Make cockpit-po-plugin work with multiple entry points (Martin Pitt)
- HACKING: Document webpack-make.js' --no-stylelint option (Martin Pitt)
- tools: Drop webpack-jumpstart partial mode (Martin Pitt)
- pkg: Move AppStream metadata files to src/appstream/ (Martin Pitt)
- lib: Update README (Martin Pitt)
- lib: Fix indentation in _fonts.scss (Martin Pitt)
- firewall: disable primary button in add services/port dialog when dialog is incomplete (Omar Yusuf)
- base1: Drop cockpit.dbus.publish() and .meta() (Martin Pitt)
- metrics: align minute graphs to the bottom so that incomplete hours minutes are connected to the hour before (Katerina Koukiou)
- metrics: fix minute borders in graphs (Katerina Koukiou)
- metrics: use polygon with clip path instead of svgs (Katerina Koukiou)
- metrics: remove unused CSS (Katerina Koukiou)
- lib: don't invoke the po plugin on failure (Jelle van der Waa)
- lib: don't run rsync when the build has errors (Jelle van der Waa)
- lib: support header selection for our table (Jelle van der Waa)
- lib: document and improve selection for ListingTable (Jelle van der Waa)
- kdump: add SSH key validation (Jelle van der Waa)
- kdump: add basic validation for required fields (Jelle van der Waa)
- kdump: show /var/crash as default value (Jelle van der Waa)
- kdump: refer to SSH as SSH when it's about the concept (Jelle van der Waa)
- kdump: set isRequired where required (Jelle van der Waa)
- kdump: move settings modal to a new class and decouple state (Jelle van der Waa)
- kdump: drop unrequired button handling (Jelle van der Waa)
- kdump: show a small helpertext for enabled/disabled (Jelle van der Waa)
- users: Show shell and home directory in user's details page (Simon Kobyda)
- Revert "python: use sockets instead of pipes in SubprocessTransport" (Allison Karlitskaya)
- python: major peer initialization overhaul (Allison Karlitskaya)
- python: clean up protocol error handling (Allison Karlitskaya)
- test: ensure everything is settled between pytest cases (Allison Karlitskaya)
- python: close all peers on router disconnect (Allison Karlitskaya)
- python: add ferny as a submodule (Allison Karlitskaya)
- python: Change approach to vendoring systemd_ctypes (Allison Karlitskaya)
- test: add an extra assertion for debugging (Allison Karlitskaya)
- test: split MockTransport into a separate file (Allison Karlitskaya)
- test: use pytest async support (Allison Karlitskaya)
- Bump sass to fix performance regression (Katerina Koukiou)
- pkg: Normalize entry point names (Martin Pitt)
- tuned: Merge into systemd (Martin Pitt)
- webpack.config.js: Simplify pkg path resolution (Martin Pitt)
- pkg: Avoid webpack-loader syntax (Martin Pitt)
- login.css: adjust order to avoid css warning (Katerina Koukiou)
- users: fix scss interpolation issue (Katerina Koukiou)
- metrics: reuse select-min class for limiting the graph visibility selector width (Katerina Koukiou)
- metrics: replace custom CSS for sticky metrics heading with component from patternfly (Katerina Koukiou)
- metrics: improve metrics page on mobile (Katerina Koukiou)
- metrics: pass how many graphs are visible from JS to SCSS in order to calculate the grid (Katerina Koukiou)
- metrics: Optimize popover; sheet mode for mobile (Garrett LeSage)
- metrics: fetch logs when we expand the hour view (Katerina Koukiou)
- metrics: redesign the page to show by default more details in a single page view (Katerina Koukiou)
- lib: limit css override for setting header font-size (Katerina Koukiou)
- metrics: fix typo when setting graph label font size (Katerina Koukiou)
- users: Parse content of /etc/shells (Simon Kobyda)
- users: Fetch useradd defaults when account creation dialog is opened (Simon Kobyda)
- users: Don't user hardcoded paths (Simon Kobyda)
- systemd/services: Lazily load timer information (Martin Pitt)
- HACKING: Clarify what "page" means and where to list them. (Martin Pitt)
- HACKING: Document node_modules checkout (Martin Pitt)
- HACKING: Emphasize webpack-watch based development process (Martin Pitt)
- HACKING: Recommend a cockpit/tasks based development environment (Martin Pitt)
- HACKING, test/README: Drop `$` prefixes (Martin Pitt)
- systemd: store terminal settings in local storage (Jelle van der Waa)
- users: introduce group renaming (Katerina Koukiou)
- users: always add class to make 'delete group' dropdown item red (Katerina Koukiou)
- tests: users: wait for the correct dialog to close (Katerina Koukiou)
- users: don't use hardcoded full path to commands in /usr/bin (Katerina Koukiou)
- test: Fix timer delete race condition in TestServices.testBasic (Martin Pitt)
- systemd/services: Fix initial loading of timers (Martin Pitt)
- po: Update from Fedora Weblate (GitHub Workflow)
- test: update pixel tests (Jelle van der Waa)
- test: Increase timeout for adding LUKS keys (Marius Vollmer)
- test: Fix CodeQL complaint (Marius Vollmer)
- storage: Reorder Format dialog fields (Marius Vollmer)
- storage: Control "nofail" and "_netdev" via a dropdown (Marius Vollmer)
- systemd/services: Parallelize Service updateProperties (Martin Pitt)
- systemd/services: Rewrite Service into a functional component (Martin Pitt)
- overview: fix 'cancel' button crash in the motd edit dialog (Katerina Koukiou)
- node_modules: update chrome-remote-interface for chromium 111 (Jelle van der Waa)
- test: Properly check Services page in unprivileged mode (Martin Pitt)
- systemd/services: Avoid duplicated unit type list (Martin Pitt)
- systemd/services: Read CLOCK_BOOTTIME with Python, fall back to /proc/timer_list (Martin Pitt)
- systemd/services: Clean up clock reading (Martin Pitt)
- pkg: Support more than one target in window.debugging (Martin Pitt)
- lib & users: use optional chaining when possible (Ahmed Abdelatty)
- users: Port SSH key reading/adding to standard Promise (Martin Pitt)
- networkmanager: Rewrite export_model() with standard Promise (Martin Pitt)
- packagekit: wire packagekit's backend name to autoupdates (Jelle van der Waa)
- packagekit: use packagekit for determining the backend name (Jelle van der Waa)
- all: Move from cockpit.{resolve,reject}() to standard Promise API (Martin Pitt)
- storaged: Port from cockpit.defer() to standard Promise (Martin Pitt)
- base1: Convert "publish object failure" D-Bus unit test to standard Promise (Martin Pitt)
- lib: Rewrite service.proxy.wait() with standard Promise (Martin Pitt)
- lib: Eliminate cockpit.defer() from dmi_info() (Martin Pitt)
- test: Update text of sudo warning message (Simon Kobyda)
- test: Disable preloads in TestLogin.testServer (Martin Pitt)
- test: Disable preloading for release builds as well (Martin Pitt)
- doc: drop host option from our documentation (Jelle van der Waa)
- test: add setup_provisioned_hosts helper for multi machine tests (Jelle van der Waa)
- systemd/services: Avoid excessive D-Bus calls and simplify state management (Martin Pitt)
- systemd/services: Unify unit details load error (Martin Pitt)
- systemd/services: Decouple service details from service list (Martin Pitt)
- systemd/services: Use cockpit.location.options as basis when changing options (Marius Vollmer)
- systemd/services: Don't clobber cockpit.location.options (Martin Pitt)
- systemd/services: Fix table layout for units without ActiveState (Martin Pitt)
- test: Add test for systemd units with Alias= (Martin Pitt)
- test: Fix flake in TestReauthorize.testBasic (Martin Pitt)
- test: Wait for systemd service memory to appear (Martin Pitt)
- lib: systemd: drop non-working host parameter for journalctl (Jelle van der Waa)
- lib: drop meaningless host option for cockpit.spawn (Jelle van der Waa)
- lib: drop always undefined address from machine info API (Jelle van der Waa)
- lib: Support custom time servers with chronyd (Marius Vollmer)
- test: Enable TestSystemInfo.testTime on Arch (Marius Vollmer)
- test: Install dnf-automatic into TMT images (Marius Vollmer)
- test: Post fewer coverage comments (Marius Vollmer)
- webpack: drop CSS entry points and include CSS in the JS entrypoints instead (Katerina Koukiou)
- overview: increase specificity of CSS to make sure import order does not matter (Katerina Koukiou)
- Don't use ~ prefix for node_modules imports (Katerina Koukiou)
- webpack: remove non-existent entrypoint for realmd (Katerina Koukiou)
- pkg/lib: fix stylelint issues (Katerina Koukiou)
- po: Update from Fedora Weblate (GitHub Workflow)
- test: Copy SELinux attributes when encrypting the rootfs (Marius Vollmer)
- storage: Correctly highlight dangerous menu items in red (Mahmoud Hamdy)
- Wrapped URLs in `<>` to make them linkable on the website (Garrett LeSage)
- test: Allow more time for insights results to appear (Marius Vollmer)
- test: Prevent insights-client from running during boot (Marius Vollmer)
- systemd/services: Fix event handler race leading to wrong page switch (Martin Pitt)
- systemd/services: Eliminate duplicate usePageLocation (Martin Pitt)
- systemd/services: Move D-Bus name constants into separate file (Martin Pitt)
- systemd/service: Stop marking ServiceDetails permitted property as required (Martin Pitt)
- test: Harmonize transient unit runtimes in TestServices.testTransientUnits (Martin Pitt)
- test: Fix race condition in TestServices.testServicesFiltersURLConsistency (Martin Pitt)
- package.json: Update @patternfly/patternfly, @patternfly/react-core, @patternfly/react-table (GitHub Workflow)
- test: Increase timeout for first Cockpit login (Martin Pitt)
- fmf: Enable ABRT tests on Fedora (Martin Pitt)
- test: Ensure that ABRT runs in TestJournal.testAbrt* (Martin Pitt)
- test: ABRT is not in CentOS 9 either (Martin Pitt)
- Update pixel tests (Katerina Koukiou)
- users: Add min width to the group and account create buttons (Katerina Koukiou)
- users: Give some more space to the # users column (Katerina Koukiou)
- users: create group action column only when administrative access is enabled (Katerina Koukiou)
- users: don't use hardcoded command paths in cockpit.spawn (Katerina Koukiou)
- test: Switch off SELinux for the first boot after encrypting root (Marius Vollmer)
- storage: Recognize new "systemctl is-enabled" output (Marius Vollmer)
- systemd/services: Initialize filters from first URL load (Martin Pitt)
- systemd/service: Track pinned units by unit name (ID), not object path (Martin Pitt)
- pkg/systemd: Deduplicate loading of pinned units (Martin Pitt)
- Bump eslint version (Katerina Koukiou)
- base1, lib: Avoid top-level await (Martin Pitt)
- lib: Add esbuild plugins for eslint, stylelint, and compression (Martin Pitt)
- systemd/services: Pull state update out of addTimerProperties() (Martin Pitt)
- systemd/services: Drop redundant `is_timer` property (Martin Pitt)
- systemd/services: Clean up tracking of seen load/active states (Martin Pitt)
- systemd/services: Clean up computed properties (Martin Pitt)
- systemd/services: Drop unnecessary binds (Martin Pitt)
- systemd/services: Fix setting isLoading property (Martin Pitt)
- configure: Fix check for xgettext (Martin Pitt)
- package.json: Update @patternfly/react-table (GitHub Workflow)
- Use whole path in patternfly imports (Katerina Koukiou)
- test: Fix cleanup of lingering user systemd managers (Martin Pitt)
- test: Fix cleanup of empty "Closing" logind sessions (Martin Pitt)
- users: take out comma out the href in the linked group members (Katerina Koukiou)
- users: Fix broken alignment of the first column in groups table (Katerina Koukiou)
- tests: users: remove redundant cleanup operations (Katerina Koukiou)
- fmf: Skip TestAccounts.testUserPasswords (Martin Pitt)
- test: Skip TestStorageStratis.testEncrypted on RHEL 8 with pybridge (Martin Pitt)
- python: Retry sd_bus_add_match() on EINTR (Martin Pitt)
- python: Add socket.{send,recv}_fds() backports for older Python versions (Martin Pitt)
- python: Make askpass compatible with Python 3.6 (Martin Pitt)
- po: Update from Fedora Weblate (GitHub Workflow)
- pkg: fix all potentially inconsistent setState calls (Jelle van der Waa)
- testlib: bring back "task destroyed but pending" messages (Martin Pitt)
- test: Prevent grub2-mkconfig from clobbering BLS entries (Marius Vollmer)
- tools: add po plugin as input for webpack-make (Jelle van der Waa)
- po: Update from Fedora Weblate (GitHub Workflow)
- Fix cpu temperature sensors detection (Tomas Matus)
- test: use Machine.ostree_image where possible (Jelle van der Waa)
- test: Use skipImage globs in check-packagekit (Martin Pitt)
- test: Restore /etc/default/useradd in check-users (Martin Pitt)
- users: append's dropdown's menu to document body (Katerina Koukiou)
- fmf: Use node.js 16 for RHEL 8 tests (Martin Pitt)
- lib: Make PO and rsync bundler plugins work for webpack and esbuild (Martin Pitt)
- webpack.config.js: Drop reference_patterns po plugin option (Martin Pitt)
- modules: update systemd_ctypes (Martin Pitt)
- build: Move to a webpack module (Martin Pitt)
- lib, tools: Rename JS tool executables to *.js (Martin Pitt)
- Make imports ES6 friendly (Martin Pitt)
- build: Drop usage of __dirname (Martin Pitt)
- webpack.config.js: Fix two trivial ESLint errors (Martin Pitt)
- lib: qunit-tests.js cleanups (Martin Pitt)
- lib: Merge qunit-config.js into qunit-tests.js (Martin Pitt)
- lib: Replace qunit CSS require() with import (Martin Pitt)
- lib: Drop dead code from qunit-config.js (Martin Pitt)
- python: don't signal already-exited processes (Allison Karlitskaya)
- python: catch BusError on Properties.Get (Allison Karlitskaya)
- test: Refactor accounts test (Simon Kobyda)
- test: Shrink the memory hog in TestSystemInfo.testOverview (Martin Pitt)
- test: Add /usr/local/bin to sudo's secure path on RHEL (Martin Pitt)
- python: simplify "kill" logic in router (Allison Karlitskaya)
- python: on ProtocolChannel close, close the transport (Allison Karlitskaya)
- python: kill subprocess on closing its transport (Allison Karlitskaya)
- python: fix signals on SubprocessTransport (Allison Karlitskaya)
- test: Put all overrides into /etc/ (Martin Pitt)
- test: Clean up preload disabling/enabling (Martin Pitt)
- testlib: remove special cases for python bridge (Allison Karlitskaya)
- python: close all channels on EOF and wait for them (Allison Karlitskaya)
- python: add task management to Channel class (Allison Karlitskaya)
- python: clean up channel closing logic (Allison Karlitskaya)
- python: stop sending "close" transport control message (Allison Karlitskaya)
- metrics: fix error message about missing data from PCP (Katerina Koukiou)
- tests: users: use ostree_image helper instead of hardcoded images list (Katerina Koukiou)
- tests: Restart systemd-user-sessions.service after each test (Katerina Koukiou)
- tests: users: replace navigation bty URL modification with clicking on href link (Katerina Koukiou)
- tests: ensure we are on the main accounts page before continuing with the test (Katerina Koukiou)
- test: Use username with capital letter (Matej Marusak)
- test: Drop obsolete sssd hack (Martin Pitt)
- python: improve static typing in cockpit.channels.metrics (Allison Karlitskaya)
- Add *.swp pattern into .gitignore (Simon Kobyda)
- Remove swap file from repo (Simon Kobyda)
- metrics: pass INTERVAL value when creating the metrics1 channel (Katerina Koukiou)
- packit: add Fedora 38 testing and release, drop Fedora 36 (Jelle van der Waa)
- po: Update from Fedora Weblate (GitHub Workflow)
- python: Connecting to specific D-Bus addresses (Marius Vollmer)
- test: Factorize OS specific test skips (Martin Pitt)
- tls: Make test failures more useful (Martin Pitt)
- test: Get along with /usr/local/bin/cockpit-bridge (Martin Pitt)
- test: Avoid unnecessary hardcoded cockpit-bridge paths (Martin Pitt)
- containers: Move ws to Fedora 37 (Martin Pitt)
- packagekit: Add manifest condition (Martin Pitt)
- python: Support manifest conditions (Martin Pitt)
- lib: Add development support for remote hosts (shawly)
- test: update pixel tests for new tasks container (Jelle van der Waa)
- python: Defer asyncio.Lock() creation for D-Bus (Martin Pitt)
- test: add error handling for when there are no pixels found (Jelle van der Waa)
- test: drop log.html if provided for fetching pixels (Jelle van der Waa)
- python: Drop duplicate set_event_loop_policy() (Martin Pitt)
- python: Avoid get_event_loop() in http channel (Martin Pitt)
- python: Fix exception formatting to be compatible with Python 3.6 (Martin Pitt)
- pytest: Work around mypy caching bug (Martin Pitt)
- pytest: Fix TestPackages for environments with ~/.local/share/cockpit/ (Martin Pitt)
- networkmanager: use NetworkManager's Capabilities (Jelle van der Waa)
- metrics: introduce graph visibility selector (Katerina Koukiou)
- metrics: allow graph columns to stretch if there is enough space (Katerina Koukiou)
- python: freeze channels until they send "ready" (Allison Karlitskaya)
- python: ensure basic behaviour of all channel types (Allison Karlitskaya)
- users: don't propagate the event when clicking on the close button on groups (Katerina Koukiou)
- tests: users: ensure that the group selector is closed before attempting to expand it (Katerina Koukiou)
- test: users: update the group selection UI only when the configuration get's propagated from the backend (Katerina Koukiou)
- tests: users: improve test documentation (Katerina Koukiou)
- python: more ${libexecdir} hackery (Allison Karlitskaya)
- python: add cockpit-askpass in python (Allison Karlitskaya)
- python: Fix KeyError on overriding nonexisting manifest keys (Martin Pitt)
- pytest: Add unit tests for manifest loading (Martin Pitt)
- test: Use .ssh/authorized_keys instead of .ssh/authorized_keys.d (Matej Marusak)
- test: Use correct cockpit.conf on ostree images (Matej Marusak)
- test: Drop unnecessary editing of certificate chain (Matej Marusak)
- test: Wait until mock-insights is running (Matej Marusak)
- test: Support rhel4edge (Matej Marusak)
- workflows: Add smoketest for pybridge on CentOS Stream 8 (Martin Pitt)
- python: Use systemd_ctype's asyncio.run() shim (Martin Pitt)
- python: Avoid str.removesuffix() (Martin Pitt)
- python: Fix type annotations to be compatible with Python 3.6 (Martin Pitt)
- python: Drop walruses (Martin Pitt)
- .github: fix extranous 'd' before commit message (Jelle van der Waa)
- .github: update release action workflow (Jelle van der Waa)
- pytest: Add mypy for the Python bridge (Martin Pitt)
- python: Ignore remaining 7 mypy errors (Martin Pitt)
- python: Check option types in channels (Martin Pitt)
- python: Fix typing in superuser.py (Martin Pitt)
- python: Relax Samples type (Martin Pitt)
- python: Assert valid transport in Channel.close_on_eof() (Martin Pitt)
- cockpit.print: Fix type annotations for mypy (Martin Pitt)
- python: Restrict mypy to src/cockpit (Martin Pitt)
- login: Change key verify command background (Garrett LeSage)
- containers: Drop obsolete sassc from unit-tests (Martin Pitt)
- containers: Add mypy to unit-tests (Martin Pitt)
- po: Update from Fedora Weblate (GitHub Workflow)
- python: Update libexecdir detection to look for a cockpit-bridge package program (Martin Pitt)
- test: enable TestAccounts.testBasic on Python bridge (Jelle van der Waa)
- python: Drop SocketTransport (Martin Pitt)
- python: Implement TCP stream channel (Martin Pitt)
- python: Make ProtocolChannel.create_transport() async (Martin Pitt)
- base1: Document and test TCP stream channels (Martin Pitt)
- lib: cockpit-po-plugin: allow also msgids from 'src/' directory (Katerina Koukiou)
- tests: fix race condition where new user was added while the page was loaded (Katerina Koukiou)
- tests: users: fix leaking watches when parsing utmp (Katerina Koukiou)
- lib: c-c-dialog: Expect also objects as error messages in dialogs (Katerina Koukiou)
- tests: clean up user session processes at the end of the tests (Katerina Koukiou)
- users: Add filter for the groups table (Katerina Koukiou)
- python: Fix fslist1 FileNotFoundError crash (Martin Pitt)
- python: Report detailed error message when opening fsread1 channel fails (Martin Pitt)
- python: Make test_bridge check_open() more flexible for testing reply details (Martin Pitt)
- python: Properly report HTTPExceptions (Martin Pitt)
- selinux: Allow cockpit-session to run gnome-keyring (Martin Pitt)
- overview: Simplify card flow breakpoints (Garrett LeSage)
- tests: Increase timeout for picking up changes in user groups (Katerina Koukiou)
- users: use useMemo for optimizing the re-rendering of the accounts page (Katerina Koukiou)
- tests: rename 'anton' user in TestAccounts.testUnprivileged (Katerina Koukiou)
- tests: users: robustify check by waiting for the UI to update groups before continuing (Katerina Koukiou)
- users: show loading page while data are still parsed (Katerina Koukiou)
- users: Introduce group create dialog (Katerina Koukiou)
- test: add tests for the internal metrics channel (Jelle van der Waa)
- cockpit.print: add readline support (Allison Karlitskaya)
- cockpit.print: add support for '-' as a command (Allison Karlitskaya)
- cockpit.print: add spawn command for stream channel (Allison Karlitskaya)
- cockpit.print: change default channel naming (Allison Karlitskaya)
- cockpit.print: Fix kwargs parsing (Allison Karlitskaya)
- python: Close unix stream channels on EOF (Martin Pitt)
- testlib: remove many excepted journal messages for pybridge (Allison Karlitskaya)
- modules: update systemd_ctypes (Allison Karlitskaya)
- python: fix check for EIO in Transports classes (Allison Karlitskaya)
- lib: cockpit-components-file-autocomplete: fix moving back to previous path (Katerina Koukiou)
- python: Get values of invalidated D-Bus properties (Marius Vollmer)
- test: Allow switching to superuser with passwordless sudo (Matej Marusak)
- lib: FileAutoComplete: when clearing out the input inform the component's user (Katerina Koukiou)
- python: port fsread1 to GeneratorChannel (Allison Karlitskaya)
- python: add a GeneratorChannel subtype (Allison Karlitskaya)
- python: move send-side flow control to Channel (Allison Karlitskaya)
- cockpit.print: allow dashes in kwarg keys (Allison Karlitskaya)
- cockpit.print: fix positional arguments with '=' (Allison Karlitskaya)
- test/image-prepare: slight re-org (Allison Karlitskaya)
- build: add tools/make-wheel (Allison Karlitskaya)
- package.json: Update @patternfly/react-core, @patternfly/react-icons, @patternfly/react-styles, @patternfly/react-table (GitHub Workflow)
- systemd: show Default policy as recommended (Jelle van der Waa)
- systemd: show FUTURE crypto policy as last (Jelle van der Waa)
- systemd: support a subset of crypto subpolicies (Jelle van der Waa)
- test: Robustify encrypt_root() (Martin Pitt)
- selinux: Fix error message formatting (Martin Pitt)
- test: Restart logind to clean up "closing" sessions (Martin Pitt)
- test: Allow loginctl kill-session to fail in cleanup handler (Martin Pitt)
- test: loosen pgrep on ^/usr/bin/cockpit-bridge (Allison Karlitskaya)
- python: add support for /manifests.json to Packages (Allison Karlitskaya)
- python: handle KeyError when package doesn't exist (Allison Karlitskaya)
- python: send html error page on Packages errors (Allison Karlitskaya)
- test: Filter out "dark" layout after reading custom layouts (Marius Vollmer)
- ws: Fix rpm debug symbol extraction for mock-pam-conv-mod.so (Martin Pitt)
- python: add routing for bridges from manifests (Allison Karlitskaya)
- python: rename "bridge rules" to "bridge configs" (Allison Karlitskaya)
- python: improve logging in the Router (Allison Karlitskaya)
- python: add kwargs to RoutingError (Allison Karlitskaya)
- python: tweak argument types to Peer.spawn() (Allison Karlitskaya)
- python: send version=1 to peers, not "1" (Allison Karlitskaya)
- python: reduce use of Any in typing hints (Allison Karlitskaya)
- test: Use node readline API in firefox-cdp-driver.js (Martin Pitt)
- test: Rewrite chromium-cdp-driver.js using async/await (Martin Pitt)
- test: Add bug reference to hack in firefox-cdp-driver.js (Martin Pitt)
- Revert "test: Skip problematic exception in Firefox" (Martin Pitt)
- test: Put back another pybridge crash message (Martin Pitt)
- bridge: Robustify temperature sensor scanning (Martin Pitt)
- package.json: Update xterm-addon-canvas (GitHub Workflow)
- networkmanager: ship appstream xml file (Jelle van der Waa)
- test: Restore expected ConnectionResetError message for pybridge scenario (Martin Pitt)
- python: Send null owner D-Bus signal for absent services (Martin Pitt)
- base1: Enable "owned messages" D-Bus unit test for pybridge (Martin Pitt)
- networkmanager: Fix two jQuery promise leftovers (Martin Pitt)
- po: Update from Fedora Weblate (GitHub Workflow)
- Adjust for onChange parameters order change in the Datepicker and TimePicker components (Katerina Koukiou)
- Adapt to property order changes of the SearchInput component (Katerina Koukiou)
- package.json: Update @patternfly/patternfly, @patternfly/react-core, @patternfly/react-icons, @patternfly/react-styles, @patternfly/react-table (GitHub Workflow)
- shell: unset 'active' state also when closing the menu by clicking on the same iframe (Katerina Koukiou)
- python: correctly log possible None value (Jelle van der Waa)
- test: Drop obsolete pybridge expected log messages (Martin Pitt)
- tests: pixel tests: set language direction directly before taking the screenshot (Katerina Koukiou)
- test: Fix TestSuperuser.testRemoveBridgeConfig (Martin Pitt)
- python: patch ${libexecdir} after parsing and overrides (Allison Karlitskaya)
- python: read superuser rules from manifests (Allison Karlitskaya)
- shell: Tolerate empty Superuser Methods property (Martin Pitt)
- python: simplify a field initialization (Allison Karlitskaya)
- test: bump reference-image to fedora-37 (Jelle van der Waa)
- test: enable TestTimers.testCreate on the Python bridge (Jelle van der Waa)
- python: serve */po.js with manifests.js (Allison Karlitskaya)
- python: tell the browser not to cache /manifests.js (Allison Karlitskaya)
- python: rework packages serving logic (Allison Karlitskaya)
- python: drop search for *.min.* in packages (Allison Karlitskaya)
- python: shift file list set building to walk() (Allison Karlitskaya)
- python: split out Packages file checksum code (Allison Karlitskaya)
- python: fix packages checksum calculation for subdirs (Allison Karlitskaya)
- python: remove default path from Package.walk (Allison Karlitskaya)
- cockpit-po-plugin: remove reference_patterns option (Allison Karlitskaya)
- webpack.config.js: exclude manifests from shell/po.js (Allison Karlitskaya)
- webpack.config.js: drop src/ws from static/po.js (Allison Karlitskaya)
- terminal: update xterm dependency and start using an add on for the canvas (Katerina Koukiou)
- nav: fix toggling of the system dropdown (Katerina Koukiou)
- kpatch: Tolerate missing /etc/os-release (Marius Vollmer)
- python: add cockpit.print helper module (Allison Karlitskaya)
- selinux: Fix React crash on API/CLI errors (Martin Pitt)
- Show service logs for user services (Timothy Johnson)
- test: Robustify test.service in check-system-services (Martin Pitt)
- python: correctly parse Accept-Language header (Jelle van der Waa)
- python: don't yield f'{base}.{ext}' twice (Jelle van der Waa)
- base1: Port test-file.js QUnit tests to async functions (Martin Pitt)
- Move to gnu18 C standard, fail on old C constructs (Martin Pitt)
- test: Fix testPmProxySettings on arch (Martin Pitt)
- test: Disable partial webpack jumpstart for devel scenario (Martin Pitt)
- test: Drop obsolete udevadm trigger hacks (Martin Pitt)
- python: Respect umask in fsreplace1 (Martin Pitt)
- systemd: Always use reportd on the system bus (Marius Vollmer)
- lib: Don't use "undefined" as column key with ListingTable (Marius Vollmer)
- test: update references to Fedora-36 to 37 (Jelle van der Waa)
- test: Accept "closed" for disabled VDO deduplication state (Martin Pitt)
- test: Increase VM RAM for VDO (Martin Pitt)
- python: Avoid waiting for the child in SubprocessStreamChannel.do_close() (Martin Pitt)
- python: Log spawned pid in SubprocessTransport (Martin Pitt)
- users: Fix calling `last` in endless loop (Martin Pitt)
- users: Fix crash when lastlog fails (Martin Pitt)
- systemd: consider uint64(-1) as invalid for memory (Jelle van der Waa)
- nav: Force long usernames and hostnames to wrap (Garrett LeSage)
- python: apply user provided env variables (Jelle van der Waa)
- storage: Don't accidentally leave the filesystem unmounted (Marius Vollmer)
- storage: Normalize "defaults" fstab options in one place (Marius Vollmer)
- storage: Only mount after undo if filesystem was mounted before (Marius Vollmer)
- storage: Correctly ignore errors during undoing fstab changes (Marius Vollmer)
- test: Do not try to change layout when TEST_SHOW_BROWSER=1 (Matej Marusak)
- firewall: Show additional ports even when no service is defined (Matej Marusak)
- test: Don't swallow duplicate Browser messages by default (Marius Vollmer)
- python: allow filtering of log messages on module names (Jelle van der Waa)
- python: use logger everywhere so we can filter log messages (Jelle van der Waa)
- po: Update from Fedora Weblate (GitHub Workflow)
- packagekit: Add alternative error for "PackageKit is not installed" (Martin Pitt)
- python: Clean up children of spawned processes (Martin Pitt)
- test: Mark TestJournal.testAbrtReportCancel as stable (Marius Vollmer)
- webpack.config.js: don't gzip .html pages (Allison Karlitskaya)
- webpack-make: include static depends in Makefile (Allison Karlitskaya)
- python: Implement closing of spawn channels (Martin Pitt)
- base1: Add test case for terminating spawned process (Martin Pitt)
- base1: Use await for most test-spawn-proc.js tests (Martin Pitt)
- python: Fully implement fswatch1 channel (Martin Pitt)
- base1: Add browser unit test for directory watching with fswatch1 (Martin Pitt)
- python: Properly fail fslist1 channel with watch=True (Martin Pitt)
- doc: fslist1 "watch" option is true by default (Martin Pitt)
- sosreport, lib: Use fswatch1 channel to monitor directory changes (Martin Pitt)
- lib: Disable file watching in FileAutoComplete (Martin Pitt)
- python: metrics: fix rate calculation with 0 values (Allison Karlitskaya)
- python: freeze Peer until we see 'init' (Allison Karlitskaya)
- python: add support for freezing endpoints (Allison Karlitskaya)
- storaged: Fix writing fstab when modifying NFS mounts (Martin Pitt)
- python: correctly handle certain AMD series CPU's (Jelle van der Waa)
- selinux: Allow cockpit-session to write user's home (Martin Pitt)
- lib: Drop obsolete jQuery shim from cockpit.js (Martin Pitt)
- python: Add temporary ${libexecdir} expansion in manifests (Martin Pitt)
- .gitignore: Drop cockpit-bridge.pyz (Martin Pitt)
- systemd: Log failure to run cockpit-certificate-helper (Martin Pitt)
- storage: Checking and fixing system config for NBDE (Marius Vollmer)
- containers: Make webpack-jumpstart --partial in unit test opportunistic (Martin Pitt)
- python: Fix D-Bus timeout (Martin Pitt)
- packagekit: Avoid redundant property GetAll() call on update transaction (Martin Pitt)
- lib: Simplify packagekit.watchTransaction notify handler (Martin Pitt)
- lib: Rewrite packagekit.transaction() using promise chaining (Martin Pitt)
- test: Check expected package name/version in progress bar in TestUpdates.testBasic (Martin Pitt)
- pybridge: Don't timeout D-Bus method calls by default (Marius Vollmer)
- testlib: drop sudo-related messages for /pybridge (Allison Karlitskaya)
- python: implement send-stderr scheme for peers (Allison Karlitskaya)
- python: collect stderr messages from sudo (Allison Karlitskaya)
- python: add reset= kwarg to stderr getters (Allison Karlitskaya)
- python: have SubprocessTransport.get_stderr() return str (Allison Karlitskaya)
- python: pass transport to do_closed() on Protocol (Allison Karlitskaya)
- python: wrap peer connection errors in BusError (Allison Karlitskaya)
- python: also ignore top-level ConnectionResetError (Allison Karlitskaya)
- python: Implement /config and /environment internal bus objects (Martin Pitt)
- python: Clean up logger names (Martin Pitt)
- base1: Test more cockpit.Config errors (Martin Pitt)
- base1: Rewrite cockpit.Config unit test async style (Martin Pitt)
- python: Run HTML unit tests with bridge debug logging (Martin Pitt)
- workflows: Pacify git's permission check in release workflow (Katerina Koukiou)
- systemd: ignore subpolicy for FIPS crypto policies (Jelle van der Waa)
- python: drop zipfile support in cockpit.packages (Jelle van der Waa)
- po: Update from Fedora Weblate (GitHub Workflow)
- pf4: Unslash tabular zeros via subset & range (Garrett LeSage)
- python: Fix signature of internal cockpit.Config.GetUInt stub (Martin Pitt)
- python: Usefully log do_call() generic exceptions (Martin Pitt)
- tests: pixel-testing: introduce a scenario for RTL (Katerina Koukiou)
- testlib: adjust set_attr helper to not convert all values to bool (Katerina Koukiou)
- systemd: Fix ObjectManager path for realmd (Martin Pitt)
- python: Debug-log watch errors (Martin Pitt)
- test: add --python option to image-prepare (Allison Karlitskaya)
- test: Restore /var/log/wtmp for nondestructive tests (Martin Pitt)
- build: Drop autom4te.cache from release tarballs (Martin Pitt)
- tools: Fix motd/issue symlinks on upgrade from Debian stable (Martin Pitt)
- package.json: Update @patternfly/react-core, @patternfly/react-table (GitHub Workflow)
- shell: fix proptypes warning in CockpitNav component (Katerina Koukiou)
- test: Update expected pybridge messages for fedora-37 (Martin Pitt)
- test: mark testPackageKitCrash flaky on pybridge (Jelle van der Waa)
- systemd: add minutely option to create timer modal (Dphaas2004)
- lib: patternfly-overrides: these are wrong - patternlfy handles it correct (Katerina Koukiou)
- lib: patternfly-overrides: add missing patternfly issues for CSS overrides (Katerina Koukiou)
- lib: patternfly-overrides: remove workaround which was fixed upstream (Katerina Koukiou)
- python: D-Bus signal matching improvements (Marius Vollmer)
- python: import unittest.mock in test_bridge.py (Marius Vollmer)
- python: More robust DBus message dispatching (Marius Vollmer)
- tests: verify clearing the text filter in services page (Katerina Koukiou)
- test: Run lintian on Debian/Ubuntu packages (Martin Pitt)
- tools: Add lintian override for stub pam_cockpit_cert.so (Martin Pitt)
- tools: Fix up lintian overrides for Debian stable (Martin Pitt)
- tools: Move Debian to debhelper compat level 13 (Martin Pitt)
- tools: Bump Debian Standards-Version to 4.6.2 (Martin Pitt)
- services: reflect filters also in the URL (Katerina Koukiou)
- test: TestJournal.testAbrtReport is flaky with Python (Marius Vollmer)
- systemd: install units for /run/cockpit/session (Allison Karlitskaya)
- ws: add support for connecting to unix sockets (Allison Karlitskaya)
- ws: rearrange an error check in cockpitauth (Allison Karlitskaya)
- ws: open-code default ssh hostname handling (Allison Karlitskaya)
- ws: change handling of default auth program (Allison Karlitskaya)
- ws: assume type is non-%NULL (Allison Karlitskaya)
- ws: Use g_autoptr() in cockpit_session_launch() (Allison Karlitskaya)
- ws: g_autoptr(CockpitCreds) (Allison Karlitskaya)
- test: Use 'python bridge' when skipping tests (Matej Marusak)
- test: Warn when static-code skips a test (Marius Vollmer)
- test: add pixel tests for accounts page (Katerina Koukiou)
- users: delete group dialog: follow patternfly guidelines for modal titles (Katerina Koukiou)
- tools: Bring back missing files check in Debian packaging (Martin Pitt)
- test: Increase kdump wait timeout (Martin Pitt)
- python: cockpit.Packages D-Bus API (Marius Vollmer)
- po: Update from Fedora Weblate (GitHub Workflow)
- python: add support for manifest overrides (Allison Karlitskaya)
- python: stop using pkg_resources (Allison Karlitskaya)
- hwinfo: add missing cockpit-dark-theme import (Katerina Koukiou)
- package.json: Update @patternfly/react-core, @patternfly/react-table (GitHub Workflow)
- test: Accept insights_client_t SELinux policy (Martin Pitt)
- cc-table: fix infinite call of useEffect hook (Katerina Koukiou)
- test: Clean up decorator implementation (Martin Pitt)
- test: Sort functions in testlib.py (Martin Pitt)
- tools: Migrate spec to SPDX license (Miroslav Suchý)
- po: Update from Fedora Weblate (GitHub Workflow)
- networkmanager: fix network interface members actions (Katerina Koukiou)
- Fix 'edit' mode for hosts (Katerina Koukiou)
- Update pixel tests to expect afp firewall service (Katerina Koukiou)
- lib: fix tables in modals in dark mode (Katerina Koukiou)
- test: Show lines starting with "WARNING:" for successful tests (Marius Vollmer)
- python: Track name owner for dbus channel (Marius Vollmer)
- shell: make middle click work for nav items (Jelle van der Waa)
- Move dark theme handling to pkg/lib/cockpit-dark-theme.js out of the shell (Katerina Koukiou)
- test: make testPmProxySettings work on Arch Linux (Jelle van der Waa)
- all: eliminate ct-pagesection-mobile class (Katerina Koukiou)
- test: Mark TestAccounts.testBasic as flaky in pybridge (Martin Pitt)
- test: Adjust expected pybridge messages for a similar crash (Martin Pitt)
- test: Ignore another non-fatal pybridge crash (Martin Pitt)
- systemd: Avoid path_namespace watches with org.freedesktop.problems (Marius Vollmer)
- packagekit: format changelog description (Katerina Koukiou)
- metrics: use standard patternfly component for the metrics page heading labels (Katerina Koukiou)
- users: when the accounts list is empty because of filtering show the empty state in the table (Katerina Koukiou)
- users: don't show loading indicated when filtered accounts list is empty (Katerina Koukiou)
- lib: table: keys can be '0' which is falsy but still a valid key (Katerina Koukiou)
- test/run: Re-enable flake auto-retries for pybridge scenario (Martin Pitt)
- test: Mark expected failing tests for pybridge scenario (Martin Pitt)
- testlib: add a @todo decorator (Allison Karlitskaya)
- run-tests: simplify tap line printing (Allison Karlitskaya)
- run-tests: simplify skip logic (Allison Karlitskaya)
- tools: Use GitHub API in debian/watch (Martin Pitt)
- package.json: Update @patternfly/react-core, @patternfly/react-table (GitHub Workflow)
- test: Increase timeout for two TestIPA test (Martin Pitt)
- test: Add another possible sudo error message to TestLogin.testSELinuxRestrictedUser (Martin Pitt)
- test: Fix race condition in TestUpdates.testInfoSecurity (Martin Pitt)
- python: Fix crash on absent os-release files (Martin Pitt)
- python: Ignore packages with broken or empty manifest.json (Martin Pitt)
- metrics: fix pod lookup in top 5 memory users (Jelle van der Waa)
- selinux: Use createRoot as mandated by React 18 (Marius Vollmer)
- shell: Use createRoot as mandated by React 18 (Marius Vollmer)
- test: Warn about waits that get close to their timeout (Marius Vollmer)
- fmf: Drop $TEST_OS rawhide hack (Martin Pitt)
- fmf: Skip TestLogin.testSELinuxRestrictedUser on RHEL 8 (Martin Pitt)
- test: Fix TestNetworkingBasic.testBasic for missing pcp (Martin Pitt)
- test: Relax sudo permission error message (Martin Pitt)
- test: Fix unexpected messages in check-superuser on failures (Martin Pitt)
- test: Fix package version in TestMetricsPackages.testBasic (Martin Pitt)
- systemd: Fix crash on missing ABRT problem (Martin Pitt)
- systemd: Fix error handling in ABRT retrieval (Martin Pitt)
- python: better exception handling in Transport code (Allison Karlitskaya)
- test: Fix unexpected messages in TestUpdates.testPackageKitCrash (Martin Pitt)
- test: Clean up temporary fifo in TestUpdates.testBasic (Martin Pitt)
- test: Add expected sudo: PERM_SUDOERS message to TestLogin.testSELinuxRestrictedUser (Martin Pitt)
- systemd/services: Fix and simplify timer unit elapse calculation (Martin Pitt)
- tools: Don't let webpack-jumpstart --partial go beyond a node_modules/ update (Martin Pitt)
- test: Speed up CI runs with our jumpstart cache (Martin Pitt)
- overview: Fix RTL (Garrett LeSage)
- pf: Override PF widgets to "support" RTL (Garrett LeSage)
- tests: users: use gpasswd in the tests (Katerina Koukiou)
- users: only use gpasswd for editing groups (Katerina Koukiou)
- users: added undo button for groups changes (Katerina Koukiou)
- user: add support for group editing in the user details (Katerina Koukiou)
- test: Don't fail tests when using TEST_SHOW_BROWSER (Matej Marusak)
- users: Drop unused css styles (Matej Marusak)
- users: Use standard components for 'Authorized public SSH keys' (Matej Marusak)
- users: Highlight newly added groups (Matej Marusak)
- python: Handle dbus "meta" requests (Marius Vollmer)
- python: Return specific error when introspection fails for method call (Marius Vollmer)
- python: Return type in method reply (Marius Vollmer)
- test: Allow NoReply errors for timeouts (Marius Vollmer)
- test: Fix TestNetworkingBasic.testBasic for stopped pcp (Martin Pitt)
- po: Update from Fedora Weblate (GitHub Workflow)
- users: fix display of the groups view (Katerina Koukiou)
- css: Move some CSS imports that 're happening inside JS to SCSS files (Garrett LeSage)
- lib: fix missing updates on useEvent with with react-18 (Katerina Koukiou)
- lib: Rewrite context menu to functional component (Katerina Koukiou)
- Do some followup porting to react-18 react-dom client API (Katerina Koukiou)
- test: Update pixels for changed Fedora 36 IPv6 address generation (Martin Pitt)
- users: Show loading state (Matej Marusak)
- test: Wait for checkbox to be correctly initialized before trying to change it (Matej Marusak)
- users: Spell correctly autocomplete prop (Matej Marusak)
- users: Always use strings in inputs (Matej Marusak)
- users: drop superfluous trailing arguments (Jelle van der Waa)
- systemd: drop unused mitigationsAvailable state property (Jelle van der Waa)
- users: directly invoke show_modal_dailog (Jelle van der Waa)
- containers: pkg: drop superfluous trailing argument (Jelle van der Waa)
- metrics: drop unused minutes in MetricsHour (Jelle van der Waa)
- test: remove unused variable bounding_rect (Jelle van der Waa)
- base1: remove useless conditionals (Jelle van der Waa)
- systemd: correct copy to 'keyboard' to 'clipboard' (Jelle van der Waa)
- tuned: fixed typo in exception (Katerina Koukiou)
- selinux: avoid AT_SECURE on exec from cockpit-session (Allison Karlitskaya)
- package.json: Update @patternfly/patternfly, @patternfly/react-core, @patternfly/react-icons, @patternfly/react-styles, @patternfly/react-table (GitHub Workflow)
- fonts: enable opt-in updated, monospace and tabular PF fonts (Katerina Koukiou)
- users: right align kebab menu on the groups list (Katerina Koukiou)
- users: on initial load sort groups by members count (Katerina Koukiou)
- users: remove CardBody to fix spacing on the groups card (Katerina Koukiou)
- .github: run protection checks on Ubuntu 20.04 (Jelle van der Waa)
- test: Lint fix (Matej Marusak)
- users: Use built-in empty state for tables (Matej Marusak)
- users: Highlight newly added users (Matej Marusak)
- shell: setDarkMode also when updating existing frames (Katerina Koukiou)
- shell: make setDarkMode function a helper and use it where possible (Katerina Koukiou)
- users: don't use localCompare for sorting numeric items (Katerina Koukiou)
- users: add design dot detail before the group names (Katerina Koukiou)
- users: implement group delete action (Katerina Koukiou)
- users: show information about groups (Katerina Koukiou)
- users: add some explanatory comment (Katerina Koukiou)
- systemd: disable create timer button on unit load (Jelle van der Waa)
- services: Better handle empty state (Matej Marusak)
- c-c-table: Clear out new items after animation is done (Matej Marusak)
- c-c-table: Keep list of all known keys (Matej Marusak)
- shell: Add basic language RTL support (Matej Marusak)
- test: Adjust testSELinuxRestrictedUser for fixed SELinux in RHEL 9.2 (Martin Pitt)
- tools: Update Debian's policykit-1 dependency for package split (Martin Pitt)
- po: Update from Fedora Weblate (GitHub Workflow)
- test: Add dark theme switcher tests (Jelle van der Waa)
- systemd: Serialize reload and unit start/stop on Service details page (Martin Pitt)
- shell: fix white flash regression by dark theme switcher (Jelle van der Waa)
- run-tests: using typing.List[] instead of list[] (Allison Karlitskaya)
- systemd_ctypes: sync with main (Allison Karlitskaya)
- test: only capture failed services header (Jelle van der Waa)
- python: improve exception handling in superuser startup (Allison Karlitskaya)
- python: add pkexec as a superuser bridge (Allison Karlitskaya)
- run-tests: add --no-retry-fail commandline option (Allison Karlitskaya)
- run-tests: pass argparse Namespace to finish() (Allison Karlitskaya)
- python: add support for login messages memfd (Allison Karlitskaya)
- all: Show ModalError on top of dialogs (Martin Pitt)
- lib: Put Dialog errors at the top (Martin Pitt)
- lib: Move Dialog static_error before the body (Martin Pitt)
- lib: Drop Dialog and DialogFooter public APIs (Martin Pitt)
- python: add support for superuser bridge (Allison Karlitskaya)
- python: flesh out the implementation of Peer (Allison Karlitskaya)
- python: add higher-level API to MockTransport (Allison Karlitskaya)
- python: implement `kill` transport control message (Allison Karlitskaya)
- test: reset failed units at the start of testMenuSearch (Jelle van der Waa)
- doc: Fix factor default in cockpit.format_*() (Martin Pitt)
- python: don't write to transport after disconnect (Allison Karlitskaya)
- python: minor logging improvements (Allison Karlitskaya)
- python: move internal dbus to the Bridge (Allison Karlitskaya)
- python: disable asyncio debugging by default (Allison Karlitskaya)
- users: Reflect changes from redesign on the account details page (Tomas Matus)
- users: Introduce lock and logout dialogs (Tomas Matus)
- users: Implement accounts page redesign (Tomas Matus)
- lib: cockpit-components-table.jsx (Tomas Matus)
- shell: Use correct default lang attribute (Matej Marusak)
- nav: Fix host switcher background split bug (Garrett LeSage)
- Dark theme switcher support (Jelle van der Waa)
- Update a list of distros which don't support realmd auto-detection (Simon Kobyda)
- Allow root login on RHEL 8 (Jelle van der Waa)
- test: Skip many D-Bus unit tests with the python bridge (Marius Vollmer)
- python: ObjectManager support for the dbus payload (Marius Vollmer)
- test: Use ObjectManager in the D-Bus "proxies" test (Marius Vollmer)
- test: Remove duplicate "bad variants" test (Marius Vollmer)
- python: Don't assume strings are always 's' in D-Bus method calls (Marius Vollmer)
- python: Support D-Bus introspection without a service name (Marius Vollmer)
- python: use sockets instead of pipes in SubprocessTransport (Allison Karlitskaya)
- python: don't call process_exited() on closed protocol (Allison Karlitskaya)
- python: remove 'watcher' global state (Allison Karlitskaya)
- python: don't try to writev more than 1024 buffers (Allison Karlitskaya)
- python: fix an f-string typo (Allison Karlitskaya)
- overview: Stretch menu selector to modal body (Garrett LeSage)
- shell: Use PF's scrollbable, plain menus (Garrett LeSage)
- storage: Translate graphs' labels (Matej Marusak)
- pkg: fix document class checking (Jelle van der Waa)
- test: apply the same workaround for centos-9-stream (Jelle van der Waa)
- storaged: handle zswap/swap blocks without signatures better (Jelle van der Waa)
- services: translate the filter help string in the services page (Katerina Koukiou)
- po: Update from Fedora Weblate (GitHub Workflow)
- python: replace `'''` with `"""`, throughout (Allison Karlitskaya)
- python: disable debugging output by default (Allison Karlitskaya)
- shell: fix open state toggling of the dropdowns on the shell (Katerina Koukiou)
- package.json: Update @patternfly/patternfly (GitHub Workflow)
- test: check-users: expect disabled 'Terminate session' button for non logged in users and root account (Katerina Koukiou)
- HACKING: document required pytest version (Jelle van der Waa)
- python: remove routing rule logic from the router (Allison Karlitskaya)
- python: pass channel to Endpoint.do_channel_control() (Allison Karlitskaya)
- python: rename Protocol send/receive methods (Allison Karlitskaya)
- python: major rework of core class relationships (Allison Karlitskaya)
- python: simplify check for already-open channels (Allison Karlitskaya)
- python: drop Channel and Peer from core routing (Allison Karlitskaya)
- python: clean up channel match rule creation (Allison Karlitskaya)
- python: minor tweak for mypy happiness (Allison Karlitskaya)
- python: move init checking to ProtocolServer class (Allison Karlitskaya)
- python: fix typo on exception path (Allison Karlitskaya)
- python: don't raise exception on EPIPE on stdout (Allison Karlitskaya)
- python: add unit tests for Bridge (Allison Karlitskaya)
- python: port to new systemd_ctypes dbus interface (Allison Karlitskaya)
- python: send ready when opening null channel (Allison Karlitskaya)
- codeql-config: mask py/redundant-else warnings (Allison Karlitskaya)
- upgrade to react 18 and enable the new concurrent renderer (Katerina Koukiou)
- users: Validate that real account name does not contain colons (Ian Brown)
- networkmanager: Improve firewall permission check (Ladislav Slezák)
- containers/ws: Enable mounting of /etc/cockpit as volume (realk1ko)
- ssh: Rewrite mock-sshd based on new example code (Marius Vollmer)
- ssh: Also disconnect on pipe close (Marius Vollmer)
- pf, dark: Fix disabled buttons in modals (Garrett LeSage)
- test: exclude Kpatch on tmt (Jelle van der Waa)
- Update redirected urls (Matej Marusak)
- package.json: Update @patternfly/patternfly, @patternfly/react-core, @patternfly/react-icons, @patternfly/react-styles, @patternfly/react-table (GitHub Workflow)
- storaged: explictly set a key for eslint (Jelle van der Waa)
- po: Update from Fedora Weblate (GitHub Workflow)
- Drop obsolete versioned dependencies (Martin Pitt)
- test: only sed /etc/cockpit/disallowed-users if it exists (Jelle van der Waa)
- test: add helper function to check if remote file exists (Jelle van der Waa)
- autogen: Copy automake tools (Martin Pitt)
- pkg: correct indexOf function call in cockpit.location.encoding (Jelle van der Waa)
- test: build a wheel for the pybridge scenario (Allison Karlitskaya)
- test: Update pixel references to current Chromium (Martin Pitt)
- Move from LGTM to GitHub code scanning (Martin Pitt)
- test: Drop hardcoded permissions in check-testlib (Martin Pitt)
- apps: Fix exception handling in watch-appstream.py (Martin Pitt)
- test: Rewrite disabling of test machine (Martin Pitt)
- test: Drop obsolete commented out code (Martin Pitt)
- test: Drop unused reassignment in TestSelinux (Martin Pitt)
- test: Fix undefined variable (Martin Pitt)
- Always close files in Python code (Martin Pitt)
- tools: Drop unused variable from tools/make-compile-commands (Martin Pitt)
- Explicitly return None for value-returning functions (Martin Pitt)
- Consistently use "cls" for first argument of Python class methods (Martin Pitt)
- test: Add missing semicolon in pixeldiff.html (Martin Pitt)
- test: Use verbose assertions (Martin Pitt)
- test: Drop unnecessary "else" clauses from for loops (Martin Pitt)
- test: Drop duplicate `args` definition in check-shell-host-switching (Martin Pitt)
- Fix incomplete string replacements (Martin Pitt)
- tools: More careful hostname check (Martin Pitt)
- test: Port mock-insights to current Python SSL API (Martin Pitt)
- po: Update from Fedora Weblate (GitHub Workflow)
- tools: disallow root login by default (Jelle van der Waa)
- test: erase rpms before installing on rhel8 (Jelle van der Waa)
- python: drop cockpit-bridge.pyz target (Allison Karlitskaya)
- python: merge `make pycheck` into pytest (Allison Karlitskaya)
- python: stop running `make pycheck` against the .pyz (Allison Karlitskaya)
- test-server: Change python bridge detection logic (Allison Karlitskaya)
- webpack-jumpstart: tweak partial mode (Allison Karlitskaya)
- webpack-jumpstart: take some ShellCheck suggestions (Allison Karlitskaya)
- python: add pytest-timeout, set PYTEST_TIMEOUT=120 (Allison Karlitskaya)
- webpack-make: include $(SRCDIR) in stampfile name (Allison Karlitskaya)
- test: enable stratis tests on Arch Linux (Jelle van der Waa)
- package.json: Update @patternfly/patternfly (GitHub Workflow)
- fmf: Skip NFS tests on RHEL (Martin Pitt)
- fmf: Move storage test exclusions into correct section (Martin Pitt)
- fmf: Install kpatch test dependency for RHEL (Martin Pitt)
- flatpak: preserve xml declaration in installed metainfo (Allison Karlitskaya)
- pkg: make JavaScript keyspacing consistent (Jelle van der Waa)
- test: extend timeout for CPU usage going back to idle (Jelle van der Waa)
- workflows: Fix date format for Flathub release (Martin Pitt)
- test: stop parsing curl error output (Jelle van der Waa)
- pkg: enable object property newline rule (Jelle van der Waa)
- po: Update from Fedora Weblate (GitHub Workflow)
- fmf: Factorize and merge plan files (Martin Pitt)
- pf4: Comment select menu overrides (Garrett LeSage)
- pf4: Don't set max-width for Patternfly's select (Simon Kobyda)
- containers: fix unit-tests/start --submodule option (Allison Karlitskaya)
- python: drop tox section from pyproject.toml (Allison Karlitskaya)
- tests: fix periodic test-chan.html failure (Allison Karlitskaya)
- containers: fix unit-tests with no submodules (Allison Karlitskaya)
- python: complete test coverage of transport.py (Allison Karlitskaya)
- python: remove pointless typing hints (Allison Karlitskaya)
- python: return empty stderr on stream channel (Allison Karlitskaya)
- python: pass BrokenPipeError to connection_lost() (Allison Karlitskaya)
- python: coverage tweaks (Allison Karlitskaya)
- python: add tests for the Spooler class (Allison Karlitskaya)
- python: fix SubprocessTransport construction order (Allison Karlitskaya)
- python: add test cases for SubprocessTransport (Allison Karlitskaya)
- python: enable direct invocation of pytest (Allison Karlitskaya)
- workflows: run pytest on pull requests (Allison Karlitskaya)
- git: Add systemd_ctypes as submodule (Allison Karlitskaya)
- containers: add pytest-cov to unit-tests (Allison Karlitskaya)
- python: conditionally xfail on some samplers (Allison Karlitskaya)
- python: add some initial tests for the samplers (Allison Karlitskaya)
- python: fix device-mapper ignore in disk sampler (Allison Karlitskaya)
- python: tighten up typing in samples.py (Allison Karlitskaya)
- python: add a framework for unit testing (Allison Karlitskaya)
- python: using non-blocking IO in Transport classes (Allison Karlitskaya)
- python: add Transport._close() method (Allison Karlitskaya)
- python: fix two obvious bugs in Transport class (Allison Karlitskaya)
- python: fix type annotations in transports.py (Allison Karlitskaya)
- pf4: Fix dark mode dropmarker in form controls (Garrett LeSage)
- fmf: Split out networking tests (Martin Pitt)
- fmf: Trim test dependencies (Martin Pitt)
- fmf: Run basic and optional tests in separate test plans (Martin Pitt)
- test: Skip TestUpdates.testKPatch on CentOS 9 stream (Martin Pitt)
- fmf: Add missing subscription-manager test dependency (Martin Pitt)
- fmf: Run Fedora 37 tests with proper $TEST_OS (Martin Pitt)
- fmf: Re-enable TestSOS.testBasic on Fedora 36 (Martin Pitt)
- Revert "test: Skip TestSOS.testBasic with old Firefoxes in the Testing Farm" (Martin Pitt)
- Revert "tf: Add hack for sos missing python magic" (Martin Pitt)
- test: enable dark theme pixel tests (Jelle van der Waa)
- page: Add dark version of new fade color (Garrett LeSage)
- pf: Fix dark mode in multiple PatternFly components (Garrett LeSage)
- metrics: Dark mode fixes (Garrett LeSage)
- logs: Increase contrast of headings in dark mode (Garrett LeSage)
- css: Fix critical list items in dark mode (Garrett LeSage)
- shell, nav: Improve dark mode style (Garrett LeSage)
- lib: Add dark theme compatibility for graphs (Jelle van der Waa)
- shell: Set iframe body background to PF's dark theme (Jelle van der Waa)
- pkg: Enable dark theme by default with PF class (Jelle van der Waa)
- pkg: Enable dark mode through JavaScript on load (Jelle van der Waa)
- pkg: Load PF dark theme css (Jelle van der Waa)
- test-channelresponse: handle missing pidfd support (Jelle van der Waa)
- test: run unit tests also on RHEL-8 (Jelle van der Waa)
- workflows: Refresh cockpit/ws container every Monday (Martin Pitt)
- containers/ws: Change tagging schema from date to cockpit version (Martin Pitt)
- containers/ws: Make release.sh friendlier for local runs (Martin Pitt)
- containers/ws: Move release steps into a shell script (Martin Pitt)
- containers/ws: Drop installation from preview COPR (Martin Pitt)
- containers/ws: Drop obsolete hack (Martin Pitt)
- po: Update from Fedora Weblate (GitHub Workflow)
- package.json: Update @patternfly/patternfly, @patternfly/react-core, @patternfly/react-icons, @patternfly/react-styles, @patternfly/react-table (GitHub Workflow)
- test: enable clevs tang test on Arch Linux (Jelle van der Waa)
- overview: Fix split button variant (Garrett LeSage)
- storage: Change default to "Passphrase" when adding a crypto key (Marius Vollmer)
- python: abort() the Transport on EPIPE (Allison Karlitskaya)
- python: annotate CockpitProtocol.transport (Allison Karlitskaya)
- python: pass router to Endpoints on construction (Allison Karlitskaya)
- package.json: Update @patternfly/patternfly, @patternfly/react-core, @patternfly/react-icons, @patternfly/react-styles, @patternfly/react-table (GitHub Workflow)
- .github: update webpack-jumpstart actions (Jelle van der Waa)
- test: allowed systemd user journal corruption messages (Jelle van der Waa)
- test: Avoid multi-arch conflict on mock-pam-conv-mod.so (Martin Pitt)
- test: Fall back to package.json during coverage processing (Marius Vollmer)
- flatpak: Use GNOME 43 runtime (Allison Karlitskaya)
- test: Relax test skip expected output (Martin Pitt)
- release workflow: update flathub ChangeLog (Allison Karlitskaya)
- build: patch <releases> in metainfo on install (Allison Karlitskaya)
- po: Update from Fedora Weblate (GitHub Workflow)
- login: Allow bypass with "soft" requirements (Garrett LeSage)
- test: Fix abrt selectors (Matej Marusak)
- updates: Wrap Tooltip body into one element (Matej Marusak)
- Add workaround around PF inconsistent headers (Matej Marusak)
- package.json: Update @patternfly/patternfly, @patternfly/react-core, @patternfly/react-icons, @patternfly/react-styles, @patternfly/react-table (GitHub Workflow)
- python: add support for pty subprocesses (Allison Karlitskaya)
- python: clean up exit handling on SubprocessTransport (Allison Karlitskaya)
- python: handle connection errors in dbus channel (Allison Karlitskaya)
- python: port stream channel to ProtocolChannel (Allison Karlitskaya)
- python: add a ProtocolChannel subclass (Allison Karlitskaya)
- python: replace AsyncStdio helper with StdioTransport (Allison Karlitskaya)
- ssh: Copy session before using it to check known hosts (Marius Vollmer)
- selinux: Allow fowner capability to cockpit-session (Martin Pitt)
- python: add options control command (Jelle van der Waa)
- test: enable more NetworkManager tests on Arch Linux (Jelle van der Waa)
- test: enable NetworkManager firewall tests for Arch (Jelle van der Waa)
- test: Drop mentions of Fedora 35 (Matej Marusak)
- lib: append Datepicker to document.body (Jelle van der Waa)
- systemd: append Datepicker to document.body (Jelle van der Waa)
- test: Don't use "journalctl -n -u" (Marius Vollmer)
- test: Prevent bash TCO when keeping a mount point busy (Marius Vollmer)
- po: Update from Fedora Weblate (GitHub Workflow)
- users: append Datepicker to document.body (Jelle van der Waa)
- doc: firewalld-cmd no longer exists (Jelle van der Waa)
- bridge: python: drop disk.all.ops (Jelle van der Waa)
- test: drop removed Dbus port workaround (Jelle van der Waa)
- packagekit: instantiate remarkable once (Jelle van der Waa)
- packagekit: apply our link attributes to markdown (Jelle van der Waa)
- .github: update github-script action to v6 (Jelle van der Waa)
- .github: update checkout action to v3 (Jelle van der Waa)
- python: support 'disk.dev.{read,written}' metrics (Jelle van der Waa)
- test: drop Debian networkmanager hack (Jelle van der Waa)
- test: enable more networkmanager tests on Arch Linux (Jelle van der Waa)
- test: enable checkpoint tests on Arch Linux (Jelle van der Waa)
- test: Run partprobe on new loop devices (Marius Vollmer)
- test: Run TestStorageLuks.testLuks1Slots also on Arch (Marius Vollmer)
- fmf: Add lvm2 test dependencies (Martin Pitt)
- python: add CGroups v1 support (Jelle van der Waa)
- base1: expand metrics1 tests with error handling (Jelle van der Waa)
- python: make metrics errors compatible with old bridge (Jelle van der Waa)
- workflows: Add differential-shellcheck action (Jan Macku)
- gitleaks: Ignore mock SSH keys (Martin Pitt)
- packit: Drop targets list from COPR build (Martin Pitt)
- containers: add mypy to the unit-test container (Jelle van der Waa)
- workflows: Apply clang valgrind workaround to unit-tests-refresh (Martin Pitt)
- containers: Update unit-tests README to current reality (Martin Pitt)
- test: Fix check-networkmanager-other to clean up after itself (Martin Pitt)
- python: use dir_fd for fetching cgroups (Jelle van der Waa)
- storage: Don't rely on metrics compression to avoid pointless renders (Marius Vollmer)
- po: Update from Fedora Weblate (GitHub Workflow)
- Metrics: Add read/write usage per disk (Tomas Matus)
- css: don't use data-lable in selectors (Tomas Matus)
- Bridge: ignore partitions on nvme when sampling IO (Tomas Matus)
- metrics: ignore flatpak revokefs-fuse (Jelle van der Waa)
- ssh: Use ssh_userauth_publickey_auto (Marius Vollmer)
- tools: Recommend cockpit-ostree on OSTree systems (Martin Pitt)
- build: add `pcc` (Python Cockpit Client) rule (Allison Karlitskaya)
- storage: Test and fix teardown of LVM2 and RAID members (Marius Vollmer)
- test: Wait for partition to be recognized as mounted before deletion (Marius Vollmer)
- storage: Reload systemd after removing entries from fstab (Marius Vollmer)
- test: Consider browser's time zone when checking service's next run (Simon Kobyda)
- python: implement internal source metrics1 (Jelle van der Waa)
- python: add samples.py as make dependency (Jelle van der Waa)
- python: Handle early errors during cockpit.spawn (Marius Vollmer)
- build: rip out automated version history (Allison Karlitskaya)
- python: Send expected 'ping' during flow control (Marius Vollmer)
- python: support ChannelError from AsyncChannel.run() (Allison Karlitskaya)
- test-channelresponse: use pidfd to watch for child exit (Allison Karlitskaya)
- python: use ChannelError from the filesystem channel (Allison Karlitskaya)
- python: introduce a ChannelError type (Allison Karlitskaya)
- python: update systemd_ctypes dependency (Allison Karlitskaya)
- po: Update from Fedora Weblate (GitHub Workflow)
- test/run: Add scenario for running integration tests with the Python bridge (Martin Pitt)
- build: Fix permissions of cockpit-bridge.pyz (Martin Pitt)
- login: Fix username/password autofill (Jacek Tomasiak)
- po: Update from Fedora Weblate (GitHub Workflow)
- test: Use change_ssh_port in one more place (Marius Vollmer)
- test: Also apply pam-sss workaround on ubuntu-stable (Marius Vollmer)
- test: Change SSH port via socket unit on ubuntu-stable (Marius Vollmer)
- test: Prevent bash from eliminating a tail call (Marius Vollmer)
- test: ubuntu-stable no longer has old PAM (Marius Vollmer)
- ws: Go back to assuming GChildWatch on mips in test-channelresponse (Martin Pitt)
- login: Use valid selectors when testing for :is() / :where() support. (Emilio Cobos Álvarez)
- tools: replace usage of deprecated egrep (Jelle van der Waa)
- python: remove "dbus_internal" hack (Allison Karlitskaya)
- shell: Don't use data-label in CSS (Garrett LeSage)
- network: Don't use data-label in CSS (Garrett LeSage)
- test: Add rhel-9-2 and rhel-8-8 to lists of images, as appropriate (Marius Vollmer)
- storage: Direct mounting and unmounting (Marius Vollmer)
- Revert "networking: Update rhel docs" (Matej Marusak)
- po: Update from Fedora Weblate (GitHub Workflow)
- test: Replace deprecated DSA key with ED25519 (Martin Pitt)
- test: Drop obsolete MD5 fingerprint fallback (Martin Pitt)
- ssh: Replace deprecated DSA key with ECDSA in unit test (Martin Pitt)
- ssh: Drop DSA host key from mock-sshd (Martin Pitt)
- ssh: Drop ssh-dss key from default mock_known_hosts (Martin Pitt)
- ssh: Drop unused mock_known_hosts_2 (Martin Pitt)
- metrics: Disable on-demand install without PackageKit in PCP config dialog (Martin Pitt)
- pybridge: Add http-stream2 channel (Martin Pitt)
- base1: Factorize /mock/info test-server query (Martin Pitt)
- po: Update from Fedora Weblate (GitHub Workflow)
- workflows: workaround Clang vs. Valgrind breakage (Allison Karlitskaya)
- unit-tests: explicitly create the home directory (Allison Karlitskaya)
- test: Don't let our dnsmasq instances read /etc/resolv.conf (Marius Vollmer)
- networkmanager: show Wireguard device type (Jelle van der Waa)
- networkmanager: Watch the D-Bus ObjectManager (Marius Vollmer)
- python: correctly log notify events (Jelle van der Waa)
- python: return after send_message (Jelle van der Waa)
- webpack: Fix regexp for unit test files (Martin Pitt)
- tools: Make path tests independent from contained directory (Martin Pitt)
- kdump: Add SUSE kdump config support (Jacek Tomasiak)
- base1: Add parallel stress test for http-stream2 (Martin Pitt)
- base1: Re-enable echo barrier test for C bridge (Martin Pitt)
- ws: Add /mock/info path (Martin Pitt)
- doc: http-stream2 method field is mandatory (Martin Pitt)
- python: Really skip introspection when possible (Marius Vollmer)
- test: Drop obsolete mkdir -p calls (Martin Pitt)
- lib: Allow setting initial password for PasswordFormFields (Simon Kobyda)
- lib: Remove unused arrow function parameter in PasswordFormFields (Simon Kobyda)
- python: send EOF on AsyncChannel close (Allison Karlitskaya)
- test: Robustify executed commands (Martin Pitt)
- test: Ignore corrupted journal message in TestSystemInfo.testTime (Martin Pitt)
- test: Adjust special cases for Fedora 37 (Martin Pitt)
- packit: Drop Fedora 35, add Fedora 37 (Martin Pitt)
- po: Update from Fedora Weblate (GitHub Workflow)
- HACKING.md fix formatting (Tomáš Matuš)
- test: Move domain specific libraries to test/common/ (Martin Pitt)
- storage: Show block label in filesystem panel (Marius Vollmer)
- test: assume motd permissions work on debian-testing (Allison Karlitskaya)
- storage: Refactor mount user handling (Marius Vollmer)
- test: Wait a bit longer for Candlepin to start (Marius Vollmer)
- workflows: Update pot every morning (Matej Marusak)
- networking: Update rhel docs (Matej Marusak)
- test: allow root user to be named "Super User" (Allison Karlitskaya)
- python: fix loading pages from /usr (Jelle van der Waa)
- Fix typo in http-stream2 (Josh Boudreau)
- kdump: use correct base for translations (Jelle van der Waa)
- test: change minimum filesystem sizes to 320MB (Allison Karlitskaya)
- tools: Drop SUSE section for removing 3rd party branding (Adam Majer)
- tf: Add hack for sos missing python magic (Matej Marusak)
- test: make Fedora-37 Fedora-36 (Jelle van der Waa)
- po: Update from Fedora Weblate (GitHub Workflow)
- test: rawhide is now Fedora-38 (Jelle van der Waa)
- test: disable NetworkManager pixel test on mobile (Allison Karlitskaya)
- css, stylelint: Set indentation to 2; reindent everything (Garrett LeSage)
- shell: Ask for admin access method if there are multiple (Marius Vollmer)
- shell: Ignore cached sudo credentials when starting the privileged bridge (Marius Vollmer)
- session: Use the regular Arch PATH value on Arch (Marius Vollmer)
- bridge: Fix polkit agent registration (Marius Vollmer)
- cockpit.js: Support different URL root for the websocket (Martin Pitt)
- doc: Fix broken indentation in cockpit.conf.xml (Martin Pitt)
- test: Factorize calling curl through nginx in TestReverseProxy (Martin Pitt)
- po: Update from Fedora Weblate (GitHub Workflow)
- pf: Fix breadcrumb link cursor (Garrett LeSage)
- test: Fix TestAutoUpdates setup for non-dnf systems (Martin Pitt)
- test: Accept unloaded pmlogger.service in TestGrafanaClient (Martin Pitt)
- test: Fix cleanup in TestPages.testBasic (Martin Pitt)
- kdump: Use close with cockpit.file, not remove (Marius Vollmer)
- storage: Remove some pixel tests for complex tables (Marius Vollmer)
- test: Allow opportunistic cleanup commands to fail (Martin Pitt)
- test: Fix pkill command in TestSystemInfo.testOverview (Martin Pitt)
- test: Fix ws cleanup in TestConnection.testLocalSession (Martin Pitt)
- test: Simplify TestConnection.testLocalSession (Martin Pitt)
- client: Support WebKit 4.1 API (Martin Pitt)
- Revert "package.json: Update @patternfly/patternfly, @patternfly/react-core, @patternfly/react-icons, @patternfly/react-styles, @patternfly/react-table" (Martin Pitt)
- Revert "test: Speed up CI runs with our jumpstart cache" (Martin Pitt)
- base1: Add http-stream2 unit test for non-default method (Martin Pitt)
- doc: Document missing http-stream2 options (Martin Pitt)
- base1: Add http-stream2 unit test for invalid channel options (Martin Pitt)
- base1: Make "streaming" test-http test more strict (Martin Pitt)
- base1: Rewrite test-http using ES6 (Martin Pitt)
- package.json: Update @patternfly/patternfly, @patternfly/react-core, @patternfly/react-icons, @patternfly/react-styles, @patternfly/react-table (GitHub Workflow)
- lib: allow setting initial value in FileAutoComplete (Tomas Matus)
- css: Remove unused PF component imports (Garrett LeSage)
- common: Initialize message in cockpit_web_request_on_socket_input() (Martin Pitt)
- test: Add delay to firewall zone services dialog pixel test (Martin Pitt)
- test: Update pixel reference for TestStorageUsed.testUsed (Martin Pitt)
- firewall: Services needs a border & fixed height (Garrett LeSage)
- firewall: Fix missing CSS for add services (Garrett LeSage)
- po: Update from Fedora Weblate (GitHub Workflow)
- test: Fix run-tests scheduling with little or no parallelism (Martin Pitt)
- networking: Remove redundant imports (Garrett LeSage)
- package.json: Update @patternfly/patternfly, @patternfly/react-core, @patternfly/react-icons, @patternfly/react-styles, @patternfly/react-table (GitHub Workflow)
- test: Adjust pixel tests for changed NM IPv6 behaviour (Martin Pitt)
- lib: drop duplicate patternfly-variables include (Jelle van der Waa)
- Improve CPU temperature sensors detection (Tomas Matus)
- services: Swap timer order: specific & after boot (Garrett LeSage)
- systemd: Create deep copy when updating state of timers (Matej Marusak)
- systemd: Control isOpen in TimePicker (Matej Marusak)
- test: Speed up CI runs with our jumpstart cache (Martin Pitt)
- test: Increase scheduling cost of provisioned VMs (Martin Pitt)
- cmmon: Fix memory allocation in cockpit_hex_decode() (kklionz)
- tasks: Update README for default OS change to Fedora 36 (Martin Pitt)
- nav: Change "Title Case" to "Sentence case" (Garrett LeSage)
- bridge: Assert valid user in cockpit_peer_handle() (Martin Pitt)
- package.json: Update @patternfly/patternfly, @patternfly/react-core, @patternfly/react-icons, @patternfly/react-styles, @patternfly/react-table (GitHub Workflow)
- tools: Adjust Debian lintian overrides for source (Martin Pitt)
- tools: Adjust Debian copyright file to current version (Martin Pitt)
- tools: Add missing Python dependency to cockpit-packagekit Debian packaging (Martin Pitt)
- test: Show overall coverage status (Matej Marusak)
- test: Adjust for ubuntu-stable moving to 22.10 "kinetic" (Martin Pitt)
- systemd: Don't call updateTime() for every property change ever (Marius Vollmer)
- packit: Drop obsolete FMF plan bumping (Martin Pitt)
- test: Improve run-tests scheduling of multi-provision tests (Martin Pitt)
- test: drop inotify exclusions (Jelle van der Waa)
- test: move flake8 excludes/ line limit to a config file (Jelle van der Waa)
- test: call flake8 directly (Jelle van der Waa)
- test: use noqa so we can skip our custom filter (Jelle van der Waa)
- test: enable testWithAvailableUpdates on the Arch image (Jelle van der Waa)
- test: clean up build files after building on Arch Linux (Jelle van der Waa)
- test: force install packages on Arch Linux (Jelle van der Waa)
- test: Add assert_pixels() API for disabling animation waiting (Martin Pitt)
- .github: always try to jumpstart node_modules (Jelle van der Waa)
- sosreport: Use "-v" instead of "-vvv" for verbose logging (Marius Vollmer)
- lib: Set id of PasswordFormFields FormGroup (Simon Kobyda)
- po: Update from Fedora Weblate (GitHub Workflow)
- kdump: Refactor config handling (Jacek Tomasiak)
- test: stop using deprecated machine_core import (Jelle van der Waa)
- test: Make venvs happy (Jacek Tomasiak)
- workflows: Add build-ws-container (Martin Pitt)
- networking: ipv4 helper for interface configuration (Gil Obradors)
- test: Avoid uploading to ~user directories (Martin Pitt)
- test: Don't write successful test output in run-tests (Martin Pitt)
- ws: Add alternative "disconnected" error message when killing the bridge (Martin Pitt)
- ws: Fix test-channelresponse for glib dropping global child watch (Martin Pitt)
- package.json: Update @patternfly/patternfly, @patternfly/react-core, @patternfly/react-icons, @patternfly/react-styles, @patternfly/react-table (GitHub Workflow)
- packit.yaml: drop deprecated metadata key (Jelle van der Waa)
- lib: document why box-shadow is imported (Jelle van der Waa)
- systemd: drop numberinput workaround (Jelle van der Waa)
- storaged: drop helper-text.css (Jelle van der Waa)
- test: add pixel tests for our custom progress implementation (Jelle van der Waa)
- test: Robustify testPackageKitCrash expected messages (Martin Pitt)
- packagekit: Add "Reboot after completion" switch to update progress page (Martin Pitt)
- test: Check cancelling of package updates (Martin Pitt)
- client: Fix crash on absent Handy.StyleManager (Martin Pitt)
- test: replace pycodestyle and pyflakes with flake8 (Jelle van der Waa)
- build: Fix valgrind invocation for HTML tests (Martin Pitt)
- ws: Fix memory leak in test-server (Martin Pitt)
- workflows: Stricter timeouts in unit-tests-refresh (Martin Pitt)
- workflows: Run unit tests on Ubuntu 22.04 (Martin Pitt)
- test: drop PackageKit state on Arch Linux (Jelle van der Waa)
- test: fix removing packages on Arch Linux (Jelle van der Waa)
- storaged: add Arch Linux nfs-utils/stratisd packages (Jelle van der Waa)
- po: Update from Fedora Weblate (GitHub Workflow)
- fmf: Force checking out node_modules/ (Martin Pitt)
- metrics: Add CPU temperature to metrics page (Tomas Matus)
- fmf: Fix syntax error in node_modules checkout (Martin Pitt)
- shell: update PF link to link to it's redirect (Jelle van der Waa)
- test: fix line length issue introduced by static typing (Jelle van der Waa)
- test: remove star imports (Jelle van der Waa)
- test: ignore 'parent' imported but unused warning (Jelle van der Waa)
- test: don't initialize self.machine to None (Jelle van der Waa)
- test: drop self.machine conditional (Jelle van der Waa)
- test: add optional type hints (Jelle van der Waa)
- test: tell vulture to ignore ignore_errors (Jelle van der Waa)
- test: fix Python linter issues in lcov.py (Jelle van der Waa)
- .github: run static code checks (Jelle van der Waa)
- containers/ws: Support all OpenSSH key types (Martin Pitt)
- package.json: Update @patternfly/patternfly, @patternfly/react-core, @patternfly/react-icons, @patternfly/react-styles, @patternfly/react-table (GitHub Workflow)
- packagekit: Show current package when reattaching to running update (Martin Pitt)
- packagekit: Promise and D-Bus call result code cleanup (Martin Pitt)
- packagekit: Rewrite ApplyUpdates component to use hooks (Martin Pitt)
- HACKING.md: mention the Python bridge (Allison Karlitskaya)
- workflows: add pycheck to unit-tests (Allison Karlitskaya)
- python: set $USER and friends at bridge startup (Allison Karlitskaya)
- python: implement fswatch1 (Allison Karlitskaya)
- python: clean up error reporting in fsread1 (Allison Karlitskaya)
- python: implement tags on the filesystem streams (Allison Karlitskaya)
- python: default to stderr='message' on streams (Allison Karlitskaya)
- python: move http test from hanging to failing (Allison Karlitskaya)
- python: turn some protocol errors into soft errors (Allison Karlitskaya)
- python: reorganize channel types (Allison Karlitskaya)
- python: split fsread1 to its own file (Allison Karlitskaya)
- python: implement minimal fsreplace1 payload (Allison Karlitskaya)
- python: implement minimal fslist1 payload (Allison Karlitskaya)
- base1: Remove fence test from test-echo.js (Allison Karlitskaya)
- python: send 'done' on echo channel (Allison Karlitskaya)
- python: Add build system integration (Allison Karlitskaya)
- python: set type fields on dbus-internal variants (Allison Karlitskaya)
- python: add dbus channel based on systemd_ctypes (Allison Karlitskaya)
- python: split out the stream channel (Allison Karlitskaya)
- python: use pkg_resources instead of packaging (Allison Karlitskaya)
- python: add a stub dbus-json3 session channel (Allison Karlitskaya)
- python: split router from bridge (Allison Karlitskaya)
- python: Use package-relative imports (Allison Karlitskaya)
- python: add --bridges commandline argument (Allison Karlitskaya)
- python: stop hardcoding logging path (Allison Karlitskaya)
- python: add bridges to packages (Allison Karlitskaya)
- python: add zipfile support to packages webserver (Allison Karlitskaya)
- python: port packages.py to Pathlib (Allison Karlitskaya)
- python: read os-release in utf-8 (Allison Karlitskaya)
- python: Make sure main() is not async (Allison Karlitskaya)
- python: Add a WIP "samples" implementation (Allison Karlitskaya)
- python: major refactors (Allison Karlitskaya)
- python: something like real packages (Allison Karlitskaya)
- python: more bridge.py implementation (Allison Karlitskaya)
- python: buffered.pyfragment: add some more old code (Allison Karlitskaya)
- python: async! (Allison Karlitskaya)
- python: implement more things (Allison Karlitskaya)
- python: more hacking (Allison Karlitskaya)
- python: start a cockpit-bridge equivalent, in Python (Allison Karlitskaya)
- build: move C flags to src/Makefile.am (Allison Karlitskaya)
- test-server: use cockpit-bridge only by default (Allison Karlitskaya)
- po: Update from Fedora Weblate (GitHub Workflow)
- packagekit: Fix "Restart services" button priority (Martin Pitt)
- test: Post review comments for uncovered code additions (Marius Vollmer)
- test: update pixel tests (Jelle van der Waa)
- pkg: test: adjust search input classes/colours (Jelle van der Waa)
- lib: Patternfly Panel mistakenly uses position relative (Jelle van der Waa)
- package.json: Update @patternfly/patternfly, @patternfly/react-core, @patternfly/react-icons, @patternfly/react-styles, @patternfly/react-table (GitHub Workflow)
- firewall: Update docs link (Matej Marusak)
- test: document more testlib functions (Jelle van der Waa)
- stylelint: Remove some unnecessary CSS (Garrett LeSage)
- stylelint: Adjust ruleset (Garrett LeSage)
- stylelint: Custom properties should come first (Garrett LeSage)
- stylelint: Remove vendor prefixes (Garrett LeSage)
- stylelint: Rewrite colors (Garrett LeSage)
- stylelint: Add/remove empty line space (Garrett LeSage)
- stylelint: Adjust spacing after : and before ! (Garrett LeSage)
- stylelint: function-parentheses-newline-inside (Garrett LeSage)
- stylelint: value-keyword-case (Garrett LeSage)
- stylelint: selector-pseudo-element-colon-notation (Garrett LeSage)
- stylelint: shorthand-property-no-redundant-values (Garrett LeSage)
- stylelint: length-zero-no-unit (Garrett LeSage)
- stylelint: declaration-block-trailing-semicolon (Garrett LeSage)
- stylelint: string-quotes (Garrett LeSage)
- test: Python 3.11 compatibility (Jelle van der Waa)
- po: Update from Fedora Weblate (GitHub Workflow)
- base1: Drop legacy PF3 and cockpit.css (Martin Pitt)
- ws: Drop OpenSans fonts (Martin Pitt)
- examples: Drop PatternFly 3 and patternfly.css (Martin Pitt)
- examples: Drop ocserv (Martin Pitt)
- examples: Drop package-simple (Martin Pitt)
- test: Mark TestPinger as nondestructive (Martin Pitt)
- containers/ws: Accept $container == podman (Martin Pitt)
- test: Check cockpit/ws container's installed service (Martin Pitt)
- test: Fix pycodestyle errors (Martin Pitt)
- containers/ws: Fix pulling in packages from COPR (Martin Pitt)
- containers/ws: Install openssh-clients (Martin Pitt)
- containers/ws: Use a builder container to reduce size (Martin Pitt)
- containers/ws: Factorize install command in install.sh (Martin Pitt)
- containers/ws: Drop unnecessary chmod from install.sh (Martin Pitt)
- containers/ws: Eliminate /container/target-namespace link (Martin Pitt)
- containers/ws: Move COPR setup into install.sh (Martin Pitt)
- tls: Drop COCKPIT_GROUP in cockpit-certificate-helper (Martin Pitt)
- tls: Make organization name optional in cockpit-certificate-helper (Martin Pitt)
- tls: Add missing line break in "Would use..." certificate check message (Martin Pitt)
- ssh: Re-drop comment from test RSA key (Martin Pitt)
- test: make the 'reference-image' file optional (Pino Toscano)
- test: Stop resizing the browser by default with TEST_SHOW_BROWSER (Martin Pitt)
- test: Drop brittle sysconfig name check in NetworkManager tests (Martin Pitt)
- ssh: Show libssh error message when importing the private key fails (Martin Pitt)
- ssh: Regenerate password protected RSA test key (Martin Pitt)
- ssh: Drop duplicated SSH keys from unit test (Martin Pitt)
- doc: Update cockpit-auth-ssh-key URL (Martin Pitt)
- Fix typo in container name (Christian Heimes)
- stylelint: string-quotes (Jelle van der Waa)
- stylelint: unit-case (Jelle van der Waa)
- stylelint: media-query-list-comma-space-{after,before} (Jelle van der Waa)
- stylelint: media-query-list-comma-newline-after (Jelle van der Waa)
- stylelint: media-feature-name-no-vendor-prefix (Jelle van der Waa)
- stylelint: media-feature-name-case (Jelle van der Waa)
- stylelint: media-feature-range-operator-space-{after,before} (Jelle van der Waa)
- stylelint: media-feature-parentheses-space-inside (Jelle van der Waa)
- stylelint: media-feature-colon-space-{after,before} (Jelle van der Waa)
- stylelint: number-leading-zero (Jelle van der Waa)
- stylelint: number-no-trailing-zeros (Jelle van der Waa)
- stylelint: no-eol-whitespace (Jelle van der Waa)
- stylelint: no-extra-semicolons (Jelle van der Waa)
- ws: Pass UrlRoot to cockpit.js (Martin Pitt)
- test: Check reverse proxy with login page/UrlRoot combinations (Martin Pitt)
- test: Run fresh browser for each TestReverseProxy scenario (Martin Pitt)
- lib/page: Simplify new row animation (Garrett LeSage)
- containers/ws: Simplify openssl invocation (Martin Pitt)
- containers/ws: Fix frame decoding (Martin Pitt)
- containers/ws: cockpit-auth-ssh-key code cleanup (Martin Pitt)
- stylelint: block-opening-brace-newline-{before,after} (Jelle van der Waa)
- stylelint: block-opening-brace-space-before (Jelle van der Waa)
- stylelint: block-opening-brace-space-after (Jelle van der Waa)
- stylelint: block-closing-brace-space-before (Jelle van der Waa)
- stylelint: enable block-closing-newline-before (Jelle van der Waa)
- stylelint: block-closing-brace-empty-line-{after,before} (Jelle van der Waa)
- stylelint: enable function-comma-space-{before,after} (Jelle van der Waa)
- fmf: Fix node_modules/ handling for tarballs (Martin Pitt)
- base1: fix some test-http asserts (Allison Karlitskaya)
- tap-cdp: return non-zero if we see 'not ok' lines (Allison Karlitskaya)
- lib: packagekit: simplifiy assigning (Jelle van der Waa)
- shell: drop unused run_error from AddMachine (Jelle van der Waa)
- systemd: drop unused running from JournalBox (Jelle van der Waa)
- kdump: drop dialogTarget which is set but never used (Jelle van der Waa)
- lib: correct dateObj to dateObject in state (Jelle van der Waa)
- systemd: drop unused error state in Service (Jelle van der Waa)
- systemd: drop unused state variables in ServicesPageBody (Jelle van der Waa)
- storaged: drop identical if conditions (Jelle van der Waa)
- storaged: drop unused function arguments (Jelle van der Waa)
- shell: simplify showing troubleshooting condition (Jelle van der Waa)
- shell: drop unused credentialsDialogOpened (Jelle van der Waa)
- test: Move git hook scripts to tools/ (Martin Pitt)
- test: Eliminate check-dist script (Martin Pitt)
- tools: Eliminate check-dist (Martin Pitt)
- tools: Drop unused patternfly.sed (Martin Pitt)
- webpack.config.js: Fix indentation (Martin Pitt)
- login: Add dark mode (Garrett LeSage)
- test: Disable FreeIPA tests on debian-testing (Matej Marusak)
- services: Add pinning services (Tomas Matus)
- po: Update from Fedora Weblate (GitHub Workflow)
- test: Drop obsolete container test documentation and scenario (Martin Pitt)
- lgtm.yml: disable documentation building (Jelle van der Waa)
- shell: Fix rendering of access level indicator (Marius Vollmer)
- lib: Drop empty css file (Jelle van der Waa)
- Enable CSS linting through stylelint (Jelle van der Waa)
- test: Use a "patience" diff for the coverage report (Marius Vollmer)
- test: mark key_press_chromium/firefox "private" (Jelle van der Waa)
- test: document a few testlib functions (Jelle van der Waa)
- test: one-line docstring should fit on one line with quotes (Jelle van der Waa)
- test: change docstrings to """ (Jelle van der Waa)
- static: drop Internet Explorer workaround for baseUri (Jelle van der Waa)
- workflows: Adjust unit-tests-refresh to recent container changes (Martin Pitt)
- containers: Drop obsolete/broken docker support (Martin Pitt)
- test: Fix coverage DiffMap generation for removed files (Martin Pitt)
- test: Force diff prefixes in coverage diff generation (Martin Pitt)
- containers: Drop bastion (Martin Pitt)
- containers: Add SSH key login support to ws (Martin Pitt)
- containers: Document and check SSH known host file for ws container (Martin Pitt)
- test: `content_tab_wait_in_info` takes only one alternative value (Matej Marusak)
- storage: Listen on changed fs sizes (Matej Marusak)
- updates: Do not oops on non found update (Matej Marusak)
- static: actually use the method parameter (Jelle van der Waa)
- static: make the "Try again" link a mouse pointer (Jelle van der Waa)
- test: always pull latest node_modules (Jelle van der Waa)
- package.json: Update chrome-remote-interface (Jelle van der Waa)
- login: Fix overlapped "Connect to:" & alert (Garrett LeSage)
- tools: Drop templating for Arch and Debian packaging (Martin Pitt)
- tools: Drop create-spec (Martin Pitt)
- tools: Eliminate BUILD_ALL spec template variable (Martin Pitt)
- tools: Eliminate required_base computation from spec file (Martin Pitt)
- tools: Eliminate xstatic-patternfly-common from spec (Martin Pitt)
- tools: Eliminate RELEASE spec template variable (Martin Pitt)
- tools: Use %{version} in spec Source0 URL (Martin Pitt)
- packit: Add bug link for hardcoded COPR targets (Martin Pitt)
- kdump: show tooltip when crashkernel is not configured (Jelle van der Waa)
- po: Update from Fedora Weblate (GitHub Workflow)
- containers/unit-tests: replace start script (Allison Karlitskaya)
- containers/unit-tests/exec: drop a script (Allison Karlitskaya)
- build: pass --nonet to appstream-util validate (Allison Karlitskaya)
- build: fix `make dist` out-of-tree (Allison Karlitskaya)
- build: fix valgrind --suppressions= logic (Allison Karlitskaya)
- firewall: Allow editing custom services (Matej Marusak)
- build: only run add-metainfo-releases if we have it (Allison Karlitskaya)
- client: fix dist in presence of unannotated tags (Allison Karlitskaya)
- fmf: Move plan and scripts to test/browser/ (Martin Pitt)
- build: Include top-level FMF plan into dist tarballs (Martin Pitt)
- test: Update pixel ref for changed QEMU (Martin Pitt)
- HACKING: Reduce integration test dependencies (Martin Pitt)
- HACKING: Clean up apt command (Martin Pitt)
- containers/ws: Support running as unprivileged user (Martin Pitt)
- containers/ws: Move --local-ssh option to run script (Martin Pitt)
- test: Do pixel testing on fedora-36 (Marius Vollmer)
- static: lib: drop MozWebSocket fallback (Jelle van der Waa)
- systemd: Fix link in BreadcrumbItem (Tomas Matus)
- storaged: Set cockpit.format_bytes() precision instead of string hacking (Martin Pitt)
- firewall: Prefer zone name when given (Matej Marusak)
- metrics: lookup podman container names (Jelle van der Waa)
- po: Update from Fedora Weblate (GitHub Workflow)
- .gitignore: add version.m4 (Jelle van der Waa)
- containers: Bump bastion and ws containers to Fedora 36 (Matej Marusak)
- tools: Adjust RHEL dependencies (Martin Pitt)
- test: Quiesce rare unexpected message in TestAccounts (Martin Pitt)
- test: Wait for CDP targets during browser/CDP startup (Martin Pitt)
- test: Code coverage for the PR diff (Marius Vollmer)
- test: Normalize source filenames earlier in lcov.py (Marius Vollmer)
- systemd: Use WithDialogs protocol for mitigations dialog (Marius Vollmer)
- firewall: Delete and activate zones more efficiently (Matej Marusak)
- firewall: Use new firewalld methods (Matej Marusak)
- test: Add "pixel-tests help" (Marius Vollmer)
- test: Add "pixel-tests fetch" (Marius Vollmer)
- test: Add "pixel-tests reset" (Marius Vollmer)
- test: Explain next step after "pixel-tests push" (Marius Vollmer)
- test: Run "pixel-tests pull" before status and push commands (Marius Vollmer)
- test: Use --track-naughties also for container scenarios (Marius Vollmer)
- build: change approach to versioning (Allison Karlitskaya)
- build: turn packaging files into proper rules (Allison Karlitskaya)
- .gitignore: fix sort order (Allison Karlitskaya)
- .gitignore: add doc output (Allison Karlitskaya)
- po: Update from Fedora Weblate (GitHub Workflow)
- tools: Bump Debian Standards-Version to 4.6.1 (Martin Pitt)
- tools: Drop unused debian/adjust-for-release (Martin Pitt)
- workflow: Move release to centralized action (Martin Pitt)
- git-utils.sh: pre-init the cache directory for untar (Allison Karlitskaya)
- shell: drop privileged state (Jelle van der Waa)
- packagekit: Use WithDialogs for AutoUpdate dialog (Marius Vollmer)
- containers/ws: Move os-release symlinking into run script (Martin Pitt)
- login: Make fonts path relative, so prefixes work (Garrett LeSage)
- test: Get rid of test/containers/run-test (Marius Vollmer)
- test: enable podman cpu metric tests for coreos (Jelle van der Waa)
- test: Only assert type of cancelled shutdown (Marius Vollmer)
- test: Give coverage reports a title (Marius Vollmer)
- test: output full path to coverage html (Jelle van der Waa)
- test: Generalize TestStorageResize.testResizeNtfs skips (Martin Pitt)
- test: Drop obsolete rhel-8-6 and rhel-9-0 special cases (Martin Pitt)
- test: Update default $TEST_OS (Martin Pitt)
- tuned: Use WithDialogs protocol (Marius Vollmer)
- po: Update from Fedora Weblate (GitHub Workflow)
- packit: Bump FMF test plan ref on release (Martin Pitt)
- test: Clean up rhel-8-6 and rhel-8-7-distropkg for storage tests (Marius Vollmer)
- storaged: storaged: remove please from dialogs (Jelle van der Waa)
- packit: Create spec file with correct version (Martin Pitt)
- packit: Work around dangling symlinks (Martin Pitt)
- Revert "Ignore sizzle.js in ESLint" (Allison Karlitskaya)
- test: drop sizzle.js symlink (Allison Karlitskaya)
- git-hook-pre-push: bring back realpath -m (Allison Karlitskaya)
- containers/ws: Drop hardcoded docker path (Martin Pitt)
- containers/ws: Merge install scripts (Martin Pitt)
- containers/ws: Rename atomic-* scripts to label-* (Martin Pitt)
- containers/ws: Drop obsolete metadata (Martin Pitt)
- containers: Update README (Martin Pitt)
- containers: Drop obsolete kubernetes resources (Martin Pitt)
- workflows: New release process (Allison Karlitskaya)
- flatpak: significantly simplify scripts (Allison Karlitskaya)
- guide: stop building into dist/ (Allison Karlitskaya)
- scripts: stop abusing `realpath -m` (Allison Karlitskaya)
- tools/git-utils.sh: always init the cache (Allison Karlitskaya)
- doc: Fix getcert invocation in cockpit-tls manpage (Martin Pitt)
- packit: Use upstream tarball for release COPR build (Martin Pitt)
- package.json: Update @patternfly/react-core, @patternfly/react-icons, @patternfly/react-styles, @patternfly/react-table (GitHub Workflow)
- workflows: Use deploy key for release website update (Martin Pitt)
- cockpituous: Disable release-dockerhub (Martin Pitt)
- packit: Take over Fedora koji/bodhi releases (Martin Pitt)
- workflows: Restrict GitHub token permission in release workflow (Martin Pitt)
- sosreport: List existing reports, ask for options when creating (Marius Vollmer)
- test: Skip TestSOS.testBasic with old Firefoxes in the Testing Farm (Marius Vollmer)
- test: Relax expected D-Bus error message (Martin Pitt)
- networking: Wait for state to be loaded before showing firewall page (Marius Vollmer)
- networking: Rewire dialogs to use the WithDialogs protocol (Marius Vollmer)
- pf4: Wrap tabs when there's not enough space (Garrett LeSage)
- po: Update from Fedora Weblate (GitHub Workflow)
- systemd: allow removal of cockpit created timers (Jelle van der Waa)
- test: create directory for write_file (Jelle van der Waa)
- shell: Immediately close superuser dialog when cancelling (Marius Vollmer)
- test: Adjust for rhel-8-7 (Martin Pitt)
- storaged: Fix VDO for RHEL 9 (Martin Pitt)
- storaged: Rename vdo_overlay to legacy_* (Martin Pitt)
- test: Clean up skips in check-storage-vdo (Martin Pitt)
- metrics: Refactor PCPConfig dialog (Marius Vollmer)
- shell: Rewrite superuser dialogs (Marius Vollmer)
- package.json: Update @patternfly/patternfly, @patternfly/react-core, @patternfly/react-icons, @patternfly/react-styles, @patternfly/react-table (GitHub Workflow)
- metrics: show podman container cpu usage (Jelle van der Waa)
- test: clean up /home/admin when required (Jelle van der Waa)
- containers: Simplify package installation for bastion container (Martin Pitt)
- packit: Fix copr owner (Martin Pitt)
- metrics: Add some space around "No logs found" in event details (Martin Pitt)
- metrics: Show logs link for events without journal messages (Martin Pitt)
- po: Update from Fedora Weblate (GitHub Workflow)
- test: Ensure tests don't trigger Oops (Martin Pitt)
- test: Factorize @nondestructive decorator in TestTestlib (Martin Pitt)
- lib: More dialog documentation (Marius Vollmer)
- systemd: Use new protocol for dialogs (Marius Vollmer)
- make-compile-commands: avoid including makefiles (Allison Karlitskaya)
- sass: Reduce duplication in variables import (Garrett LeSage)
- systemd: Only reset units that have actually failed (Marius Vollmer)
- systemd: Cancel shutdown as root (Martin Pitt)
- packit: Enable tests on Fedora Rawhide (Martin Pitt)
- shell: Translate documentation links (Matej Marusak)
- client: enable dark mode if libhandy is available (Allison Karlitskaya)
- package.json: Update @patternfly/patternfly, @patternfly/react-core, @patternfly/react-icons, @patternfly/react-styles, @patternfly/react-table (GitHub Workflow)
- cockpit.spec: drop RHEL build hanging workarounds (Allison Karlitskaya)
- cockpit.spec: stop redirecting test stderr to stdout (Allison Karlitskaya)
- po: stop translating .c code (Allison Karlitskaya)
- tests: remove mock-locale (Allison Karlitskaya)
- bridge: Don't 404 on "po.js" (Allison Karlitskaya)
- systemd: inform why no memory information is shown (Jelle van der Waa)
- systemd: show not detected cpu model as unknown (Jelle van der Waa)
- tls: avoid static port in test-tls-server (Allison Karlitskaya)
- dialogs: Fix example (Marius Vollmer)
- build: remove our custom tap-driver (Allison Karlitskaya)
- build: set VERBOSE=1 on `make check` (Allison Karlitskaya)
- test-stream: don't rely on stderr being pollable (Allison Karlitskaya)
- shell: Use new protocol for TopNav dialogs (Marius Vollmer)
- po: Update from Fedora Weblate (GitHub Workflow)
- test: Assume that fstab and crypttab updates are synchronous now (Marius Vollmer)
- packit: Release to COPR (Martin Pitt)
- overview: Right alight reboot dropdown (Matej Marusak)
- workflows: Prefix node-cache tags with project name (Martin Pitt)
- package.json: Update @patternfly/patternfly, @patternfly/react-core, @patternfly/react-icons, @patternfly/react-styles, @patternfly/react-table (GitHub Workflow)
- packagekit: order kpatches before security updates (Jelle van der Waa)
- shell: Don't show "Oops" for silent errors (Marius Vollmer)
- .github: drop deploy-keys.sh (Allison Karlitskaya)
- metrics: Drop metrics closing error message (Martin Pitt)
- metrics: Avoid multiple renders for event logs (Martin Pitt)
- logs: Use utility for toolbar wrapping (Matej Marusak)
- test: Lower default CDP timeout to 15s (Martin Pitt)
- test: Robustify root session check in TestLogin.testPamAccess (Martin Pitt)
- test: Fix race condition in TestAutoUpdates.testBasic (Martin Pitt)
- test: Factorize PCP settings dialog closing (Martin Pitt)
- test: Wait for dialog to close in TestAutoUpdates.testBasic (Martin Pitt)
- test: drop ubuntu-2004 (Jelle van der Waa)
- po: Update from Fedora Weblate (GitHub Workflow)
- firewall: filter net devices using a bitmask & (Jelle van der Waa)
- test: Restore grub's default kernel in testCPUSecurityMitigationsEnable (Martin Pitt)
- test: Clarify BLS boot options cases (Martin Pitt)
- systemd: Drop kernelopt.sh hack for pre-release RHEL 8.0 (Martin Pitt)
- test: Drop obsolete RHEL 7 compat code from testCPUSecurityMitigationsEnable (Martin Pitt)
- packagekit: add option to only install kpatches (Jelle van der Waa)
- packagekit: don't stretch the kpatches badge (Jelle van der Waa)
- packagekit: ensure spacing between error and form (Jelle van der Waa)
- packagekit: every unique element should have a key (Jelle van der Waa)
- package.json: Update @patternfly/patternfly, @patternfly/react-core, @patternfly/react-icons, @patternfly/react-styles, @patternfly/react-table (GitHub Workflow)
- configure.ac: use AC_CHECK_TOOL to find ar (Allison Karlitskaya)
- systemd: Updates for the Insights status (Marius Vollmer)
- reposchutz: use fetch-depth: 0 (Allison Karlitskaya)
- workflows/npm-update{,-pf}.yml: don't install npm (Allison Karlitskaya)
- tools/node-modules: use bots/npm install (Allison Karlitskaya)
- workflows/npm-update{,-pf}.yml: don't force push main (Allison Karlitskaya)
- test: Reduce maximum line length to 200 (Martin Pitt)
- test: Drop redundant TestMultiMachine.testFIPS (Martin Pitt)
- test: Adjust special cases for rhel-9-1 (Martin Pitt)
- tools: Simplify unpackaged modules removal in Debian packaging (Martin Pitt)
- tools: Drop PatternFly API symlink from Debian packaging (Martin Pitt)
- test/common/cdp.py: small clean ups (Allison Karlitskaya)
- tools/urls-check: some cleanups (Allison Karlitskaya)
- test/static-code: reduce Python line limit to 300 (Allison Karlitskaya)
- tests: replace an RSA key with an Ed25519 one (Allison Karlitskaya)
- verify: reformat a shellscript fragment (Allison Karlitskaya)
- po: Update from Fedora Weblate (GitHub Workflow)
- build: Ship correct patternfly.css symlink also for development builds (Marius Vollmer)
- storage: Don't complain about missing fstab entry for "/" (Marius Vollmer)
- storage: Don't clear dialog errors when setting options etc (Marius Vollmer)
- package.json: Update @patternfly/patternfly, @patternfly/react-core, @patternfly/react-icons, @patternfly/react-styles, @patternfly/react-table (GitHub Workflow)
- package.json: Update qunit (GitHub Workflow)
- test: make testNfsClient clean up properly (Jelle van der Waa)
- workflows/npm-update{,-pf}.yml: force push via SSH (Allison Karlitskaya)
- .github/deploy-keys: add a SECRET_NAME third option (Allison Karlitskaya)
- .github/deploy-keys: require project name (Allison Karlitskaya)
- .github/deploy-keys.sh: add another hint (Allison Karlitskaya)
- reposchutz: try again with fixing the permissions (Allison Karlitskaya)
- storaged: handle nfs flake due to switching elements (Jelle van der Waa)
- storaged: initialize initial value for nfs edit form (Jelle van der Waa)
- workflows: Restore issues write permissions to reposchutz (Martin Pitt)
- po: Update from Fedora Weblate (GitHub Workflow)
- workflows/npm-update(-pf).yml: change the environment (Allison Karlitskaya)
- .github/deploy-keys: remove npm-install.yml ref (Allison Karlitskaya)
- workflows: drop npm-install.yml (Allison Karlitskaya)
- reposchutz, tools/node-modules: a new security approach (Allison Karlitskaya)
- tools/node-modules: add a 'verify' command (Allison Karlitskaya)
- tools/node-modules install: a new approach (Allison Karlitskaya)
- tools/node-modules: add support for commands with '-' (Allison Karlitskaya)
- tools/node-modules: rename `rebuild` to `install` (Allison Karlitskaya)
- tools/git-utils.sh: add trivial `git` subcommand (Allison Karlitskaya)
- tools/git-utils.sh: new tar_to_cache() function (Allison Karlitskaya)
- tools/git-utils.sh: hide some stderr output (Allison Karlitskaya)
- workflows: Split npm-update to PF and non PF tasks (Matej Marusak)
- packagekit: handle timeSinceRefresh unitialized (Jelle van der Waa)
- shell: Add entry for Georgian (Matej Marusak)
- package.json: Update @patternfly/patternfly, @patternfly/react-core, @patternfly/react-icons, @patternfly/react-styles, @patternfly/react-table (GitHub Workflow)
- test: Check pam_access denied logins (Martin Pitt)
- test: Robustify TestLogin.testBasic (Martin Pitt)
- test: Update pixel tests for PF prerelease (Matej Marusak)
- nav, pf4: Adapt to PF's new header select style (Garrett LeSage)
- package.json: Update PF to prerelease (Matej Marusak)
- nav: Fix dropdown left padding, using a spacer (Garrett LeSage)
- nav: Re-add separator between dropdown & nav (Garrett LeSage)
- nav: Use padding instead of margin; adjust padding (Garrett LeSage)
- shell: Hide borders from top menu items (Matej Marusak)
- shell: Remove trailing spaces from keys (Matej Marusak)
- overview: Also recalculate on date change (Matej Marusak)
- serverTime: Assume default time is valid (Matej Marusak)
- serverTime: TimePicker now also contains seconds (Matej Marusak)
- storaged: add spacing between smart data (Jelle van der Waa)
- test: Enable grafana pcp plugin manually (Matej Marusak)
- kdump: Show current journal when (re)starting service fails (Martin Pitt)
- lib: Add service.proxy.getRunJournal() (Martin Pitt)
- lib: Support error details in cockpit Dialog (Martin Pitt)
- kdump: Drop useless Promise wrapper (Martin Pitt)
- kdump: Use cockpit.js as ES6 module (Martin Pitt)
- lib: Provide cockpit.js as ES6 module (Martin Pitt)
- test: add --track-naughties option for run-tests (Pino Toscano)
- po: Update from Fedora Weblate (GitHub Workflow)
- systemd: add FIPS as crypto policy (Jelle van der Waa)
- webpack.config.js: use Red Hat fonts from PatternFly (Allison Karlitskaya)
- systemd: Show timer creation errors (Martin Pitt)
- tests: allow having the test/reference directory in another subdir (Katerina Koukiou)
- HACKING: Document ./configure paths for cockpit-bridge (Jelle van der Waa)
- test: Don't expect lecture on debian-testing (Matej Marusak)
- test: Add --coverage option (Marius Vollmer)
- package.json: Update qunit (GitHub Workflow)
- test: remove already handled restart messages (Jelle van der Waa)
- test: Fix pam_faillock configuration in Debian/Ubuntu (Martin Pitt)
- client: install metainfo file (Allison Karlitskaya)
- lib: shell: remove unused variables.scss (Jelle van der Waa)
- metrics: Consistent page title and Overview link (Martin Pitt)
- test: add firefox-developer to firefox binaries (Jelle van der Waa)
- test: Enable 2FA auth tests on Debian/Ubuntu (Martin Pitt)
- bridge: Default "init-superuser" to "none" (Marius Vollmer)
- .github: drop livetest.yml (Allison Karlitskaya)
- systemd: Parse /proc/cpuinfo on s390x (Martin Pitt)
- test: Check expected number of CPUs on Overview page as well (Martin Pitt)
- test/static-code: run eslint (Allison Karlitskaya)
- javascript: many eslint fixes (Allison Karlitskaya)
- src: tweak a mock javascript file (Allison Karlitskaya)
- eslintrc: allow 3 chained calls on one line (Allison Karlitskaya)
- eslintignore: ignore cockpit/ and dist/ (Allison Karlitskaya)
- flatpak/test: do a global var differently (Allison Karlitskaya)
- flatpak: tweak `true` hack in testcases (Allison Karlitskaya)
- examples: fix xhr-proxy example (Allison Karlitskaya)
- webpack: disable eslint in production builds (Allison Karlitskaya)
- storage: Ignore anything mounted like a Canonical "snap" (Marius Vollmer)
- eslintrc: reenable array callback return rule and fix all related errors (Katerina Koukiou)
- package.json: remove unused expose-loader and update eslint-config-standard (Katerina Koukiou)
- eslintrc: remove jsx-a11y from the plugins section (Katerina Koukiou)
- eslintrc: extend recommended configuration of flowtype plugin (Katerina Koukiou)
- metrics: History metrics react to visibility changes (Martin Pitt)
- test: Be more thorough when recognizing affected tests (Matej Marusak)
- pkg/lib: fix some whitespace (Allison Karlitskaya)
- networking: Clarify return values of call_object_method (Marius Vollmer)
- storaged: Swap decimal/binary unit in fmt_size_long() (Martin Pitt)
- base1: Default to base-10 units in cockpit.format_bytes*() (Martin Pitt)
- base1: Clean up and strenghten format_bytes_per_sec test (Martin Pitt)
- systemd: Format RAM device size with base-2 unit (Martin Pitt)
- test: Rename testTally to testFaillock (Martin Pitt)
- test: Add special cases for ubuntu-2204 (Martin Pitt)
- test: Enable recorded journal test on Ubuntu 21.10 and Debian testing (Martin Pitt)
- test: Fix teslib test (Matej Marusak)
- test: Do not retry tests where only css was affected (Matej Marusak)
- containers: Update flatpak to GNOME runtime version 42 (Martin Pitt)
- systemd: check if command exists in timer creation dialog (Jelle van der Waa)
- systemd: fix missing key warning in systemd timer details (Jelle van der Waa)
- test: Enable FreeIPA tests on debian-testing (Martin Pitt)
- test: Skip 2FA auth check on Debian/Ubuntu (Martin Pitt)
- test: Clean up and factorize chrony hack in check-system-realms (Martin Pitt)
- test: Simplify ABRT tests to only use the API key (Martin Pitt)
- metrics: fix missing aria-label on progress element (Jelle van der Waa)
- build-debian-copyright: output relative pathnames (Allison Karlitskaya)
- build-debian-copyright: support non-gziped licenses (Allison Karlitskaya)
- test: test Arch Linux offline (Jelle van der Waa)
- pf4: Properly handled nested PF Flex (Garrett LeSage)
- systemd: Use format_bytes() API for current memory usage (Martin Pitt)
- base1: Support custom precision for cockpit.format_bytes*() (Martin Pitt)
- base1: Support base-10 units in cockpit.format_bytes_per_sec() (Martin Pitt)
- base1: Turn format_bytes*() "separate" flag into an object option (Martin Pitt)
- base1: Add optional precision argument to format_number() (Martin Pitt)
- base1: Add unit test for format_number() for very small values (Martin Pitt)
- doc: Move cockpit.format_number docs up (Martin Pitt)
- doc: Fix cockpit.format_bytes() precision documentation (Martin Pitt)
- test: lax the sudo incident message (Jelle van der Waa)
- po: Translate messages from our extension AppStream metadata (Martin Pitt)
- test: Drop redundant user process killing (Martin Pitt)
- test: Retry unmounting user runtime directory (Martin Pitt)
- metrics: Use cockpit.format_bytes() for RAM/Swap sizes (Martin Pitt)
- metrics: Clarify units from PCP (Martin Pitt)
- storaged, services: Use default format_bytes() unit (Martin Pitt)
- kdump: Clarify unit of reserved memory (Martin Pitt)
- kdump: Read kexec_crash_size with file API (Martin Pitt)
- test: Replace remaining custom reboot commands with proper API (Martin Pitt)
- test: Refresh pixel tests for stratis (Matej Marusak)
- lib: Fix animation and use ct as a prefix (Garrett LeSage)
- storage: Highlight side panel new items (Matej Marusak)
- storage: Refactor usage of SidePanel rows (Matej Marusak)
- all: Rename occurances of "Apply" to "Save" (Garrett LeSage)
- test: Simplify and robustify pixel test (Martin Pitt)
- test: Clean up leftover user XDG_RUNTIME_DIRs (Martin Pitt)
- test: Show if cleaning up home directories fails (Martin Pitt)
- test: Kill user processes more strongly (Martin Pitt)
- workflows: Fix race between flatpak tests (Martin Pitt)
- containers: Fix test-ssh to clean up after itself (Martin Pitt)
- test: Robustify cleanup in TestStorageNfs.testNfsClient (Martin Pitt)
- test: Generalize faillock cleanup on arch (Martin Pitt)
- test: Clean up all user processes, not just admin's (Martin Pitt)
- test: Call super().tearDown() as appropriate (Marius Vollmer)
- shell: Re-include cross-package translations (Martin Pitt)
- test: fips-mode-setup is be available everywhere (#17146) (Jelle van der Waa)
- test: add nfs-server as fmf test dependency (Jelle van der Waa)
- test: make TestStorageNfs tests non destructive (Jelle van der Waa)
- selinux: Fix policy for pam_faillock (Martin Pitt)
- firewall: show enable/disable text for firewall switch (Jelle van der Waa)
- firewall: add message about incoming/outgoing traffic (Jelle van der Waa)
- firewall: align header and firewall rules on mobile (Jelle van der Waa)
- firewall: rename 'Add zone' to 'Add new zone' (Jelle van der Waa)
- firewall: always show allowed addresses (Jelle van der Waa)
- firewall: translate interface/interfaces conditionally (Jelle van der Waa)
- firewall: move delete button into a kekab menu (Jelle van der Waa)
- tools/release-guide: adjust to build system changes (Allison Karlitskaya)
- po: Update from Fedora Weblate (GitHub Workflow)
- test: Refresh stratis pixel tests (Matej Marusak)
- lib: Animate new items in ListingTable (Matej Marusak)
- build: create compile_commands.json (Allison Karlitskaya)
- tools: add tool to create compile_commands.json (Allison Karlitskaya)
- tuned: make TunedDialogBody a re-usable component (Jelle van der Waa)
- systemd: Implement crypto policies support (Jelle van der Waa)
- tuned: change recommended color to green (Jelle van der Waa)
- lib: make privileged button use superuser (Jelle van der Waa)
- test: update pixel tests for tasks container refresh (Jelle van der Waa)
- test: Allow translated "signal 13" message in TestPages.testPtBRLocale (Martin Pitt)
- kdump: Fix crash on undefined config (Martin Pitt)
- test: Increase timeout for rpm-ostree install (Martin Pitt)
- test: Re-Increase VM memory in TestMultiMachine (Martin Pitt)
- fmf: Limit test to one hour (Martin Pitt)
- fmf: Trim tests to only exercise external APIs and be faster (Martin Pitt)
- fmf: Move TestUpdate exclusions to the correct place (Martin Pitt)
- doc: Clarify unit of cockpit.file's max_read_size option (Martin Pitt)
- HACKING: Drop obsolete Edge documentation (Martin Pitt)
- test: Clean up sudo privileges for test user in TestLogin.testNoAdminGroup (Martin Pitt)
- Revert "test: Robustify TestReauthorize.testSudo" (Martin Pitt)
- test: Drop alternative truths on user creation (Martin Pitt)
- test: Reduce multi-VM test memory (Martin Pitt)
- test: Make testNoAdminGroup nondestructive and move it to TestLogin (Martin Pitt)
- test: Robustify TestReauthorize.testSudo (Martin Pitt)
- build: remove custom `install` rules for webpack (Allison Karlitskaya)
- webpack: replace our gzip tricks with compression-webpack-plugin (Allison Karlitskaya)
- test: stop assuming that assets are compressed (Allison Karlitskaya)
- cockpitwebresponse: add gzip support (Allison Karlitskaya)
- cockpitwebresponse: clean up web_response_file() (Allison Karlitskaya)
- cockpitwebresponse: clean up web_response_file() (Allison Karlitskaya)
- webserver: add an accepts_encoding() helper (Allison Karlitskaya)
- cockpitpackages: minor cleanup to globbing code (Allison Karlitskaya)
- pkg: stop including cross-package translations (Allison Karlitskaya)
- updates: Use better key (Matej Marusak)
- selinux: Don't re-render after each item (Matej Marusak)
- cockpit-po-plugin: stop including base1/ in all packages (Allison Karlitskaya)
- webpack-jumpstart: remove a redundant message (Allison Karlitskaya)
- make-dist: add a bit more 'pretty' output (Allison Karlitskaya)
- cockpit.spec: fix RHEL 8 check (Allison Karlitskaya)
- ws: Don't cache po.js files forever (Martin Pitt)
- common: More specific output parameters in cockpit_web_response_negotiation() (Martin Pitt)
- test: drop DEFAULT_TEST_OS from locale tests (Jelle van der Waa)
- test/run: remove unused variable (Allison Karlitskaya)
- test: Drop obsolete special cases for rhel-8-{4,5} and fedora-34 (Martin Pitt)
- Revert "tools: Make unit tests non-fatal on Fedora s390x" (Martin Pitt)
- tools: Stop hardcoding make parallelism in spec file (Martin Pitt)
- users: Add Force password change on first login (Tomas Matus)
- ws: Eliminate eternal caching (Martin Pitt)
- test: Stop hardcoded Arch repository/mirror (Martin Pitt)
- test: drop 9 minute timeout for sos-report (Jelle van der Waa)
- test: drop mkdir /etc/sos (Jelle van der Waa)
- test: Drop rhel-8-5 from documented supported OSes (Martin Pitt)
- autogen.sh: drop ./autogen.sh mock (Allison Karlitskaya)
- flatpak: prepare using make-dist (Allison Karlitskaya)
- image-prepare: use make-dist instead of make_dist.py (Allison Karlitskaya)
- misc: move make_dist.py users to make-dist (Allison Karlitskaya)
- tools/make-dist: new script to make a tarball (Allison Karlitskaya)
- build: fix out-of-tree `make dist` (Allison Karlitskaya)
- build: fix webpack build for out-of-tree (Allison Karlitskaya)
- build: drop tar tricks in dist-hook (Allison Karlitskaya)
- Makefile.am: group all dist-related stuff (Allison Karlitskaya)
- build: drop ACLOCAL_AMFLAGS (Allison Karlitskaya)
- build: reduce DISTCHECK_CONFIGURE_FLAGS (Allison Karlitskaya)
- build: move EXTRA_DIST of package.json to pkg/ (Allison Karlitskaya)
- build: build debian copyright as part of dist-hook (Allison Karlitskaya)
- build: use EXTRA_DIST for testing node_modules (Allison Karlitskaya)
- build-debian-copyright: look for files in srcdir (Allison Karlitskaya)
- create-spec: look for json files in srcdir (Allison Karlitskaya)
- branding: reduce EXTRA_DIST use (Allison Karlitskaya)
- selinux: remove another mid-body conditional (Allison Karlitskaya)
- build: move the webpack install rules to pkg/ (Allison Karlitskaya)
- build: tidy up cockpit-client symlink install (Allison Karlitskaya)
- build: lift docs rules out of toplevel Makefile (Allison Karlitskaya)
- fmf: Drop cockpit packages from test dependencies (Martin Pitt)
- build: massive overhaul of build system (Allison Karlitskaya)
- common: move testing .c files to src/testlib/ (Allison Karlitskaya)
- ws: drop old copies of unit files (Allison Karlitskaya)
- test: Use SSHConnection.reboot() API (Martin Pitt)
- po: Update from Fedora Weblate (GitHub Workflow)
- packit.yaml: reduce the srpm depends (Allison Karlitskaya)
- packit: build SRPM in COPR (Tomas Tomecek)
- Drop some unused css rules (Matej Marusak)
- overview: Use standard PF list (Matej Marusak)
- systemd: use udev memory information (Jelle van der Waa)
- systemd: Fix Service details crash on disappearing units (Martin Pitt)
- test: Increase timeout for load to drop (Martin Pitt)
- autogen.sh: --disable-doc for `./autogen.sh mock` (Allison Karlitskaya)
- build: don't require ENABLE_DOC for make dist (Allison Karlitskaya)
- ssh: drop unused #include "common/cockpittest.h" (Allison Karlitskaya)
- bridge: compile common metrics code once (Allison Karlitskaya)
- common: stop building libcockpit-common -fPIC (Allison Karlitskaya)
- pam-ssh-add: change #include "pwd.h" to <pwd.h> (Allison Karlitskaya)
- pam-ssh-add: stop linking against cockpitmemory (Allison Karlitskaya)
- pam-ssh-add: stop using our closefrom() hacks (Allison Karlitskaya)
- test: Set browser window size when first loading a page (Marius Vollmer)
- package.json: Update xterm (GitHub Workflow)
- test: Kill admin sessions after nondestructive tests (Martin Pitt)
- test: Make load-hog.service heavier (Martin Pitt)
- metrics: Space by 1px for sandwiched usage bars (Garrett LeSage)
- metrics: Slim usage bars further to xs (Garrett LeSage)
- metrics: Compress space a bit (Garrett LeSage)
- test: make TestConnection.testCaCert @nd (Jelle van der Waa)
- test: make TestNetworkingOther nondestructive (Jelle van der Waa)
- test: make TestReauthorize nondestructive (Jelle van der Waa)
- test: make TestSuperuser nondestructive (Jelle van der Waa)
- metrics: Fix link construction for user services (Tomas Matus)
- test: Create memhog script in TestCurrentMetrics.testMemory (Martin Pitt)
- Reformat code to work with current ESLint (Martin Pitt)
- package.json: Cover test/common in eslint checks (Martin Pitt)
- test: Minimize scope of "seq" in firefox-cdp-driver.js (Marius Vollmer)
- pf: Add xs to flex gap override (Garrett LeSage)
- login: Translate error message (herengui)
- test: Drop Machine.execute() calls with script= (Martin Pitt)
- metrics: Convert "all CPUs" tooltip into a popover (Martin Pitt)
- metrics: Show top CPU core usage (Martin Pitt)
- Ignore sizzle.js in ESLint (Martin Pitt)
- test: Fix ESLint errors in test-functions.js (Martin Pitt)
- test: Auto-fix JS code style in test-functions.js (Martin Pitt)
- test: Quiesce no-eval ESLint rule in firefox/chromium CDP driver (Martin Pitt)
- test: Declare constants in firefox/chromium CDP driver (Martin Pitt)
- test: Fix no-unused-vars ESLint errors in firefox/chromium CDP driver (Martin Pitt)
- test: Introduce wrapper function for setting SSL bad certificate action (Martin Pitt)
- test: Fix JS code style in firefox/chromium CDP driver (Martin Pitt)
- test: Fix TypeError crash with --trace (Martin Pitt)
- test: Ignore "ext2 filesystem" label in TestStorageBasic pixel test (Martin Pitt)
- test: TestMenu.testSessionTimeout tweaks (Martin Pitt)
- test: Split off TestMenu.testSessionTimeout (Martin Pitt)
- test: Avoid override files in /usr where possible (Martin Pitt)
- test: Be verbose when a test times out (Marius Vollmer)
- bridge: Support manifest overrides in system and user config dirs (Martin Pitt)
- bridge: Fix call to package_walk_directory() (Martin Pitt)
- bridge: Warn about unreadable manifests and overrides (Martin Pitt)
- bridge: Change read_json_file() to take a single path (Martin Pitt)
- configure.ac: remove GLib deprecations workaround (Allison Karlitskaya)
- src: modernise three GObject subclasses (Allison Karlitskaya)
- ws: port cockpit_auth_login_async() to GTask (Allison Karlitskaya)
- ws: fix a bug in cockpit_auth_login_async() (Allison Karlitskaya)
- test: Don't compare systemd version (Matej Marusak)
- test: New libreport uses bugzilla API key (Matej Marusak)
- configure.ac: improve --help text for selinux policy (Allison Karlitskaya)
- build: remove clean-local rule for dist/ (Allison Karlitskaya)
- build: convert last implicit rule to explicit (Allison Karlitskaya)
- build: drop --as-needed (Allison Karlitskaya)
- build: drop unnecessary CFLAGS (Allison Karlitskaya)
- autogen.sh: fix ./autogen.sh mock loop (Allison Karlitskaya)
- build: stop generating valgrind-suppressions (Allison Karlitskaya)
- .gitignore: more cleanup (Allison Karlitskaya)
- fmf: Skip TestPages.testBasic on RHEL 9.0 (Martin Pitt)
- test: Update more pixel references for Chromium 96 (Marius Vollmer)
- test: Put back image-prepare --overlay (Martin Pitt)
- overview: Change health card alignment (Garrett LeSage)
- PF: Work around flex; make it use gap (Garrett LeSage)
- test: networkmanager dropped legacy cfg support (Jelle van der Waa)
- test: handle rpm to usr migration (Jelle van der Waa)
- test: allow failed to connect to coredump (Jelle van der Waa)
- test: adjust exepcted journalctl output for 250 (Jelle van der Waa)
- test: whitelist new detailed systemd-coredump output (Jelle van der Waa)
- test: add Fedora-36 (Jelle van der Waa)
- tmt: Put back absolute log path for older tmt versions (Martin Pitt)
- webserver: add support for X-Forwarded-For (Allison Karlitskaya)
- man: change the language= tag of config examples (Allison Karlitskaya)
- webserver: simplify _get_remote_address() logic (Allison Karlitskaya)
- test-webserver: add X-Forwarded-Proto tests (Allison Karlitskaya)
- test-webserver: check protocol and remote of the request (Allison Karlitskaya)
- test-webserver: use cockpit_test_add() (Allison Karlitskaya)
- cockpittest: add a new g_test_add()-like macro (Allison Karlitskaya)
- test-webserver: fix Fixture vs TestCase confusion (Allison Karlitskaya)
- networking: Fix IP Settings dialog (Marius Vollmer)
- tools: Suggest udisks2-lvm2 for Debian/Ubuntu (Martin Pitt)
- lib/page: Keep breadcrumb height for added buttons (Garrett LeSage)
- metrics: Use breadcrumb type of PageSection (Garrett LeSage)
- metrics: Reduce historical metrics heading gap (Garrett LeSage)
- metrics: Remove extra space (Garrett LeSage)
- metrics: Current cards must be <=50% page height (Garrett LeSage)
- metrics: Remove doubled-up main section padding (Garrett LeSage)
- metrics: Unstick top header (Garrett LeSage)
- networking: Fix return value of CheckpointCreate method (Marius Vollmer)
- abrt: Fix displaying of open file descriptors (Matej Marusak)
- abrt: Only navigate once problem is deleted (Matej Marusak)
- cockpituous: Enable bodhi for Fedora 36 (Martin Pitt)
- test: Don't edit selinux mapping for admin user (Matej Marusak)
- Revert "test: Increase timeout for loading Services page" (Matej Marusak)
- services: Wait for dbus before subscribing (Matej Marusak)
- services: Show current status while loading (Matej Marusak)
- test: Just wait until default.target is active (Matej Marusak)
- test: Unify systemctl calls (Matej Marusak)
- services: Display error instead of being stuck on loading page (Matej Marusak)
- users: Move password quality checks into `PasswordFormFields` (Matej Marusak)
- users: `PasswordFormFields` also keeps passwords (Matej Marusak)
- po: Update from Fedora Weblate (GitHub Workflow)
- po: Add 'ka' language (GitHub Workflow)
- test: Reinstate offline builds for rpms/debs (Martin Pitt)
- test: Avoid repository update in fedora-coreos preparation (Martin Pitt)
- test: Skip TestStoragePackagesNFS.testNfsMissingPackages on arch (Martin Pitt)
- users: Call `date` instead of using Date() to parse `lastlog` output (Martin Pitt)
- test: Improve TestGrafanaClient (Marius Vollmer)
- test: Fixes for language testing (Marius Vollmer)
- test: Allow exceptions while waiting (Marius Vollmer)
- services: Add link to 'Unit not found' page (Matej Marusak)
- tools: Drop make-srpm from make-rpms (Martin Pitt)
- test: Move RHEL 8 install-time crypttab hack to tests (Martin Pitt)
- test: Rewrite image-prepare using image-customize (Martin Pitt)
- fmf: Skip TestSOS on Fedora 36 for now (Martin Pitt)
- packit: Start testing on Fedora 36 (Martin Pitt)
- test: Add special cases for Fedora 36 (Martin Pitt)
- package.json: Update qunit (GitHub Workflow)
- login: Check selector support & :is/:where (Garrett LeSage)
- test: Fix Firefox CDP driver (Matej Marusak)
- test: workaround purge not cleaning up pmlogger requires (Jelle van der Waa)
- test: Do not create kmod-kvdo package (Matej Marusak)
- packit: Stop testing on Fedora 34 (Martin Pitt)
- fmf: Skip TestUpdates.testFailServiceRestart (Martin Pitt)
- fmf: Fix artifacts on Testing Farm (Martin Pitt)
- containers: Update ws-container* make rules (Martin Pitt)
- containers: Explicitly install util-linux-core into cockpit/ws (Martin Pitt)
- users: Add override button to confirm weak password (Tomas Matus)
- Revert "cockpit-client: disable and hide forward/back" (Garrett LeSage)
- test: Update pixel references for Chromium 96 (Martin Pitt)
- po: Update from Fedora Weblate (GitHub Workflow)
- test: Check for unexpected messages on failures as well (Martin Pitt)
- Use mobile side optimization in every PageSection (Garrett LeSage)
- overview: Drop custom overrides (Garrett LeSage)
- test: Increase session cleanup hammer size on Fedora 34 (Martin Pitt)
- users: Move tooltip out of label (Tomas Matus)
- users: Move popover behind checkbox, edit popover message (Tomas Matus)
- users: Rename locking in create new account (Tomas Matus)
- test: Fix race condition in TestFirewall.testNetworkingPage (Martin Pitt)
- cockpituous: Add Fedora 36, drop 34 (Martin Pitt)
- fmf: Skip TestPages.testHistory (Martin Pitt)
- test: Restart reportd after installing custom configuration (Martin Pitt)
- test: Factorize and strengthen disabling of virbr0 (Martin Pitt)
- test: Debug hanging logind sessions (Martin Pitt)
- test: Make sure errors are cleared when editing passwords (Matej Marusak)
- users: Don't use global objects in chained promises (Matej Marusak)
- test: Ignore message on missing /run/systemd/coredump (Martin Pitt)
- HACKING: Fix typo in git hook installation (Martin Pitt)
- shell: Avoid duplicate browser history entries (Marius Vollmer)
- all: Avoid links with both href and click handlers (Marius Vollmer)
- all: Fix breadcrumb navigation (Marius Vollmer)
- test: Wait until all processes terminate on OSTree (Matej Marusak)
- test: Add missing space between `/dev/null` and `||` (Matej Marusak)
- test: Allow realmd messages upon killing NM (Matej Marusak)
- test: Use `relogin()` function (Matej Marusak)
- tools: add git-hook-pre-rebase (Allison Karlitskaya)
- storage: Change all capitals string (Matej Marusak)
- packagekit: Do not concat translated strings (Matej Marusak)
- Fix some title case strings (Matej Marusak)
- tools: Drop title2sentence script (Matej Marusak)
- users: Add hidden input with username when changing current user password (Matej Marusak)
- users: Use `autocomplete` property for password inputs (Matej Marusak)
- test: Fix NM startup TestHistoryMetrics.testPmProxySettings (Martin Pitt)
- test: Require pmlogger to actually start in TestHistoryMetrics (Martin Pitt)
- test: Fix use of f-string (Matej Marusak)
- test: Fix race condition with checking out pixel tests (Martin Pitt)
- test: Fix TestLogin.testTally for disappearing log files (Martin Pitt)
- test: Properly clean up dangling sessions (Martin Pitt)
- test: Drop obsolete comment in TestSession (Martin Pitt)
- tests: Unify usage of `allow_restart_journal_messages()` (Matej Marusak)
- test: Work around pmlogger.service breakage in debian-stable (Martin Pitt)
- test: Fix unexpected messages in TestMultiMachine.testSshKeySetup (Martin Pitt)
- test: Eliminate run-tests --batches option (Martin Pitt)
- test: Show number of parallel tests in run-tests (Martin Pitt)
- test: run-tests dynamic serial test scheduling (Martin Pitt)
- fmf: Ignore runtime dir error message on centos-8-stream (Martin Pitt)
- test/verify/check-connection: use machine.curl() (Allison Karlitskaya)
- test: Implement terminate_session() for OSTree (Martin Pitt)
- test: Fix TestSession (Martin Pitt)
- test: Simplify TestNetworkingBasic.testBasic test setup (Martin Pitt)
- test: Increase timeout for loading Services page (Martin Pitt)
- test: Fix typo in check-system-services comment (Martin Pitt)
- test: Allow restart messages in testClientCertAuthentication (Matej Marusak)
- test: Remove duplicate allowed message (Matej Marusak)
- test: make TestKeys.testAuthorizedKeys non destructive (Jelle van der Waa)
- test: mark tests in TestConnection as nondestructive (Jelle van der Waa)
- test: cleanup and remove test user after TestRoles.testBasic (Jelle van der Waa)
- test: testDynamic can be made @nondestructive (Jelle van der Waa)
- test: make TestSession nondestructive (Jelle van der Waa)
- test: convert system-info tests to nondestructive (Jelle van der Waa)
- Removed deprecated `ProgressVariant.info` property (Matej Marusak)
- container: Fix cockpit/ws registry (Martin Pitt)
- containers: Move cockpit/ws to Fedora 35 (Martin Pitt)
- test: Drop TestFirewall.testAddServices medium pixel test (Martin Pitt)
- test: Fix TestServices.testBasic pixel test (Martin Pitt)
- test: Fix virbr0/firewalld inconsistencies in network pixel tests (Martin Pitt)
- test: Ensure correct serial test bookkeeping in run-tests (Martin Pitt)
- test: Require run-tests --browser option together with --machine (Martin Pitt)
- test: Make run-tests Test class self-printable (Martin Pitt)
- test: Generalize pattern for unexpected PCP message (Martin Pitt)
- test: Robustify TestRunTest.testRetry (Martin Pitt)
- test: Don't leave mock FAF/bugzilla servers behind (Martin Pitt)
- test: Robustify TestHistoryMetrics.testPmProxySettings (Martin Pitt)
- po: Update from Fedora Weblate (GitHub Workflow)
- logs: Don't navigate to log details when selecting details (Matej Marusak)
- tools: Build valid arch PKGBUILD and Debian changelog in dist tarballs (Martin Pitt)
- build: add `make rsync` target (Allison Karlitskaya)
- build: don't recompress existing files on install (Allison Karlitskaya)
- build: get the unit tests out of the main build (Allison Karlitskaya)
- build: remove a redundant use of noinst_SCRIPTS (Allison Karlitskaya)
- pkg/build: use noinst_DATA instead of _SCRIPTS (Allison Karlitskaya)
- build: clean up building of .so files (Allison Karlitskaya)
- test: Move run-tests serial machine assignment into Test method (Martin Pitt)
- test: Move run-test finishing into Test class (Martin Pitt)
- test: Move run-test test title into Test class (Martin Pitt)
- test: Move run-test process handling into Test class (Martin Pitt)
- test: Split out test detection in run-tests (Martin Pitt)
- test: Move run-tests' GlobalMachine further up (Martin Pitt)
- test: Fix run-tests --batches default value (Martin Pitt)
- build: don't "clean" man_MANS (Allison Karlitskaya)
- build: use explicit patterns for xml manpages (Allison Karlitskaya)
- metrics: Use `setUTC*` functions to work across all timezones (Matej Marusak)
- package.json: Update xterm (GitHub Workflow)
- git-hook-post-commit: add some colour (Allison Karlitskaya)
- tools: Add missing copyrights for shipped node_modules/ (Martin Pitt)
- fmf: Run journal, packages, and pages tests (Martin Pitt)
- test: Stop marking rebooting TestUpdates tests as nondestructive (Martin Pitt)
- fmf: Drop obsolete test exclusions (Martin Pitt)
- testlib: allow tests with custom `machine_class` to run also when specific address is specified (Katerina Koukiou)
- test: Fold remaining relevant piece of check-system-s4u into TestIPA.testClientCertAuthentication() (Martin Pitt)
- test: Reduce packagekit.service stop time (Martin Pitt)
- github: Change our issue forms to YAML (Garrett LeSage)
- fmf: Don't install weak firefox dependencies (Martin Pitt)
- test: Documentation updates (Martin Pitt)
- test: Allow 5 differences before failing a pixel test (Marius Vollmer)
- services: Fix user relationships (Tomas Matus)
- metrics: Improve load average splitting for narrow layouts (Martin Pitt)
- firewall: add helpertext to custom port ID (Jelle van der Waa)
- firewall: show ID before description (Jelle van der Waa)
- test: test if custom service is applied in firewalld (Jelle van der Waa)
- firewall: drop unrequired event checks (Jelle van der Waa)
- firewall: move to non-deprecated getServiceSettings2 method (Jelle van der Waa)
- overview: Fix spinner size (Garrett LeSage)
- overview: Use correct warning icon (Garrett LeSage)
- systemd: style the shutdown/reboot icon grey (Jelle van der Waa)
- po: Update from Fedora Weblate (GitHub Workflow)
- systemd: use the secondary color for bug fixes (Jelle van der Waa)
- systemd: add more spacing between healthcard items (Jelle van der Waa)
- systemd: drop spacing between login history link and text (Jelle van der Waa)
- systemd: display the scheduled reboot/shutdown time (Jelle van der Waa)
- storage: Document interface revision policy of Stratis (Marius Vollmer)
- test: Add 1280x768 "medium" layout for pixel tests (Marius Vollmer)
- test: Properly clean up old admin user in check-system-realm (Martin Pitt)
- test: Put test package into /usr/local/ in TestPackages (Martin Pitt)
- test: Factorize TestPackages (Martin Pitt)
- lib: Let webpack rsync plugin rsync to /usr/local/share/cockpit/ (Martin Pitt)
- hwinfo: Fix memory information on multi-channel memory platforms (Jonathan Wang)
- test: Don't allow unused pixel test references (Marius Vollmer)
- test: Remove support for the */mobile test scenario (Marius Vollmer)
- test: No need to ignore flaky triangles anymore (Marius Vollmer)
- test: Rework pixel testing and mobile layout logic (Marius Vollmer)
- workflows: use ./autogen.sh mock from flatpak test (Allison Karlitskaya)
- packit.yaml: use ./autogen.sh mock (Allison Karlitskaya)
- autogen.sh: add a 'mock' option (Allison Karlitskaya)
- autogen.sh: add 'rpm' option (Allison Karlitskaya)
- firewall: make custom service id really optional (Jelle van der Waa)
- firewall: drop useless placeholder (Jelle van der Waa)
- firewall: rename aliases to services (Jelle van der Waa)
- firewall: set a custom service descrtipion (Jelle van der Waa)
- test: add tests for working branding (Allison Karlitskaya)
- test: Improve TestTerminal.testBasic pixel test (Marius Vollmer)
- system: Group terminal toolbar items (Marius Vollmer)
- HACKING: update to use tools/create-spec (leomoty)
- session: Robustify argv parsing (Martin Pitt)
- session: Ensure user has a defined shell (Martin Pitt)
- bridge: Add start_helper_process() assertion for valid argv (Martin Pitt)
- bridge: Reject empty spawn arrays (Martin Pitt)
- Fix certificate filenames for debug calls (leomoty)
- build: build selinux policy "upstream" (Allison Karlitskaya)
- configure.ac: remove some dead stuff (Allison Karlitskaya)
- cockpit.spec: use %make_build (Allison Karlitskaya)
- src: Add coverity annotation to false-positive leaked storage (Matej Marusak)
- test: Give starting kdump.service more time in TestKDumpNFS (Martin Pitt)
- packit: Run package build and unit tests on i386 and s390x (Martin Pitt)
- bridge: Fix time_t format string in test_metrics_archive_timestamp_now() (Martin Pitt)
- Revert "build: add -ffile-prefix-map to CFLAGS" (Martin Pitt)
- test: In the year 2037... (Matej Marusak)
- unit-tests: add a check for reproducible builds (Allison Karlitskaya)
- build: add -ffile-prefix-map to CFLAGS (Allison Karlitskaya)
- common: drop stack trace printing code (Allison Karlitskaya)
- test: Adjust expected Fedora documentation name for fedora-testing (Martin Pitt)
- build: Fix copy&paste typo in configure.ac's --enable-cockpit-client (Martin Pitt)
- test: sudo and socketpair() now work properly on fedora-35 (Martin Pitt)
- branding: fix symlink installation (Allison Karlitskaya)
- test: Add special cases for rhel-8-6-distropkg (Matej Marusak)
- test: Update lists of supported OSes (Matej Marusak)
- packagekit: Show a spinner while checking for kpatch support on RHEL (Martin Pitt)
- packit.yaml: move jumpstart after autogen (Allison Karlitskaya)
- packit.yaml: stop clobbering git config (Allison Karlitskaya)
- tools/webpack-jumpstart: set default email to <> (Allison Karlitskaya)
- packit.yaml: use --enable-prefix-only (Allison Karlitskaya)
- tools/make-srpm: build direct from .tar.xz (Allison Karlitskaya)
- build: produce static cockpit.spec for release (Allison Karlitskaya)
- shell: Disable no-autofocus rule (Matej Marusak)
- Use buttons instead of anchor elements (Matej Marusak)
- static: Stop setting window.localStorage["os-release"] (Martin Pitt)
- apps, shell: Read the correct /etc/os-release (Martin Pitt)
- lib: Factor out /etc/os-release parsing (Martin Pitt)
- git-hook-post-commit: deal with deleted files (Allison Karlitskaya)
- debian/control: pin pages to the same bridge version (Allison Karlitskaya)
- debian/control: drop Break: from missing jquery (Allison Karlitskaya)
- po: Update from Fedora Weblate (GitHub Workflow)
- test-jsonfds: squelch a GCC false positive (Allison Karlitskaya)
- build: install relative symlinks (Allison Karlitskaya)
- selinux: fix a deprecation warning (Allison Karlitskaya)
- cockpit.spec: undo stderr redirection during build (Allison Karlitskaya)
- make-rpms: define _topdir (Allison Karlitskaya)
- make-rpms: replace --rebuild with -rb (Allison Karlitskaya)
- tools/make-rpms: fix indentation (Allison Karlitskaya)
- .gitignore: add some package building stuff (Allison Karlitskaya)
- .gitignore: try again with the sorting thing (Allison Karlitskaya)
- cockpit.spec: clean up list file creation (Allison Karlitskaya)
- cockpit.spec: rm -f cockpit.pp.bz2 before creating (Allison Karlitskaya)
- cockpit.spec: don't hardcode -j4 (Allison Karlitskaya)
- pkg/lib: add required property rowIndex (Jelle van der Waa)
- .gitignore: ignore test-*.log and test-*.trs (Allison Karlitskaya)
- test: Don't expect only one item on dashboard (Matej Marusak)
- unit-tests: add vulture to the container (Allison Karlitskaya)
- test/static-code: add Vulture for python code (Allison Karlitskaya)
- storagelib: clean up unused stuff (Allison Karlitskaya)
- check-storage-mdraid: drop unused arg from info_field() (Allison Karlitskaya)
- check-shell-keys: drop unused args from two helpers (Allison Karlitskaya)
- testlib.py: make a tweak in login_and_go() (Allison Karlitskaya)
- python code: remove some unused variables (Allison Karlitskaya)
- python code: prefix unused variables with _ (Allison Karlitskaya)
- min-base-version: look in the source tree (Allison Karlitskaya)
- test/static-code: drop duplicate check (Allison Karlitskaya)
- flatpak: Wait for application to stop during test (Martin Pitt)
- test: Use MOZ_HEADLESS_WIDTH et al to control Firefox window size (Marius Vollmer)
- test: Ignore hostname in terminal heading (Matej Marusak)
- test: Clean up failed services for pixel tests (Matej Marusak)
- test: Don't expect failed service on overview page (Matej Marusak)
- git-hook-pre-push: several improvements (Allison Karlitskaya)
- git-hook-post-commit: remove tmp directory (Allison Karlitskaya)
- git-hook-post-commit: change environment handling (Allison Karlitskaya)
- git-hook-post-commit: split out from pre-push hook (Allison Karlitskaya)
- static-code: add warning about disabled `set -e` (Allison Karlitskaya)
- test: add separate check for font paths (Allison Karlitskaya)
- test/static-code: parse --tap option (Allison Karlitskaya)
- test: Ignore realmd disconnect message on idle timeout for property updates (Martin Pitt)
- packagekit: Rename "Kernel patch" to "Kernel live patch" (Martin Pitt)
- test: introduce a proper git pre-push hook (Allison Karlitskaya)
- tools/test-static-code: clean up some comments (Allison Karlitskaya)
- test-static-code: clean up python checks (Allison Karlitskaya)
- storage: clean up vdo python imports (Allison Karlitskaya)
- check-bastion test: don't 'import *' (Allison Karlitskaya)
- tools/escape-to-c: drop a superfluous f-string (Allison Karlitskaya)
- pkg/lib: add 'import sys' to inotify.py (Allison Karlitskaya)
- tools/test-static-code: major overhaul (Allison Karlitskaya)
- test: Don't retry failed pixel tests (Marius Vollmer)
- test: Fix TestConnection.testCockpitDesktop on arch (Martin Pitt)
- test: Fix pgrep for privileged bridge in TestConnection.testCockpitDesktop (Martin Pitt)
- test: sudo and socketpair() now work properly on fedora-34 (Martin Pitt)
- shell: Don't try to render empty dialog (Matej Marusak)
- cockpit.js: Don't `console.warn` when handling `message` (Matej Marusak)
- shell: Fix changing of an uncontrolled input to controlled (Matej Marusak)
- updates: Fix DOM nesting (Matej Marusak)
- po: Update from Fedora Weblate (GitHub Workflow)
- webserver: move some code out of cockpitauth (Allison Karlitskaya)
- cockpitwebresponse: clean up protocol handling (Allison Karlitskaya)
- cockpitwebrequest: add host accessor (Allison Karlitskaya)
- ws: plumb CockpitWebRequest into websocket APIs (Allison Karlitskaya)
- cockpitwebservice: remove some hacks for testing (Allison Karlitskaya)
- test-webservice: substantial restructure (Allison Karlitskaya)
- ws: plumb CockpitWebRequest into CockpitChannelResponse (Allison Karlitskaya)
- cockpitwebserver: add an accessor for protocol (Allison Karlitskaya)
- cockpitwebserver: add cockpit_web_request_respond() (Allison Karlitskaya)
- webresponse: clean up query string handling (Allison Karlitskaya)
- webserver: clean up detail-calculation code (Allison Karlitskaya)
- ws: rebase CockpitAuth API on CockpitWebRequest (Allison Karlitskaya)
- webserver: add two webrequest accessors for headers (Allison Karlitskaya)
- webserver: expose and emit CockpitWebRequest (Allison Karlitskaya)
- webserver: rename WebRequest to CockpitWebRequest (Allison Karlitskaya)
- cockpitwebserver: move some methods (Allison Karlitskaya)
- cockpit.spec: drop --with-selinux-config-type (Allison Karlitskaya)
- test: sudo and socketpair() now work properly on fedora-testing (Simon Kobyda)
- common: Fix unused assignment in test_memfd_json_error_cases() (Martin Pitt)
- build: drop two unused substitutions (Allison Karlitskaya)
- build: move systemd-specific bits to src/systemd (Allison Karlitskaya)
- build: remove ridiculous definition of MV= (Allison Karlitskaya)
- build: have autoconf generate cockpit-desktop (Allison Karlitskaya)
- src/systemd: new directory (Allison Karlitskaya)
- Makefile.am: sort inclusions (Allison Karlitskaya)
- configure.ac: drop selinux type option (Allison Karlitskaya)
- ssh: Drop unused variable in on_channel_data() (Martin Pitt)
- storage: Move table button actions into menu in narrow layouts (Marius Vollmer)
- .gitignore: clean up (Allison Karlitskaya)
- common: start using closefrom(), keeping our hack (Allison Karlitskaya)
- webpack-jumpstart: don't touch unrelated files (Allison Karlitskaya)
- webpack-jumpstart: add --force option (Allison Karlitskaya)
- package.json: Update prop-types (GitHub Workflow)
- test: Allow more variations of "Unknown metric name" messages (Martin Pitt)
- test: Ignore unexpected certificate message in TestIPA.testQualifiedUsers (Martin Pitt)
- shell: Always use unique key identifier (Matej Marusak)
- ssh: Always show name of key (Matej Marusak)
- shell: Allow adding ssh keys with passphrase (Matej Marusak)
- storage: Improve tear down actions (Marius Vollmer)
- test: Allow assert_pixels ignore selectors to match multiple elements (Marius Vollmer)
- storage: Say just "in use" instead of "in active use" (Marius Vollmer)
- storage: use "systemctl" to stop units, not D-Bus (Marius Vollmer)
- ws: Use correct free functions in cockpitcompat.c (Martin Pitt)
- bridge, ws: Use correct free() function for cockpit_hex_{de,en}code() (Martin Pitt)
- bridge: Fix fd and file leak in test-connect.c (Martin Pitt)
- pam-ssh: Fix theoretical data leak in stash_password_for_session() (Martin Pitt)
- ws: Fix (theoretical) memory leak in build_authorize_challenge() (Martin Pitt)
- ws: Drop unnecessary headers condition (Martin Pitt)
- test: Adjust expected sssd error message for missing CA (Martin Pitt)
- Revert last PatternFly update (Martin Pitt)
- flatpak workflow: validate the generated metainfo (Allison Karlitskaya)
- tools: Fix comment for config.h check (Martin Pitt)
- test: Give content iframes a fixed size when pixel testing (Marius Vollmer)
- build: Enable AC_SYS_LARGEFILE (Martin Pitt)
- build: Consistently include config.h (Martin Pitt)
- build: Consistently use AM_CPPFLAGS (Martin Pitt)
- bridge: Fix build failure with --enable-debug (Martin Pitt)
- flatpak: stop suggesting to install cockpit-bridge (Allison Karlitskaya)
- bridge: give hints for missing cockpit-system package (Allison Karlitskaya)
- shell: Fix locale provided to DatePicker (Matej Marusak)
- po: Update from Fedora Weblate (GitHub Workflow)
- storage: Also show "other devices" in plots (Martin Pitt)
- Add a cockpit rsync webpack plugin for cockpit plugins (Jelle van der Waa)
- test: Pixel check menu searching and statuses (Matej Marusak)
- urls-check: Ignore patternfly redirects (Matej Marusak)
- test: Allow restarting messages in TestKdumpNFS (Martin Pitt)
- test: Fix unexpected glib messages for cockpit-ws (Martin Pitt)
- ws: Avoid regular json_object_get_string_member assertion (Martin Pitt)
- test: Allow restarting messages in TestStorage{Luks,Stratis}.testReboot (Martin Pitt)
- test: Fix TestIPA.testUnqualifiedUsers 2FA race condition (Martin Pitt)
- test: Clean up 2FA check in TestIPA.testUnqualifiedUsers (Martin Pitt)
- test: Relax expected memory plateau in TestPages.testPlots (Martin Pitt)
- package.json: Update xterm (GitHub Workflow)
- po: Update from Fedora Weblate (GitHub Workflow)
- webpack-jumpstart: add --partial mode (Allison Karlitskaya)
- webpack-jumpstart: rework consistency check logic (Allison Karlitskaya)
- webpack-jumpstart: stop using git-fsck (Allison Karlitskaya)
- webpack-jumpstart: add a big comment (Allison Karlitskaya)
- webpack-jumpstart: undo merge commits for rebase (Allison Karlitskaya)
- webpack-jumpstart: don't accept trivial changes (Allison Karlitskaya)
- package.json: Update prop-types (GitHub Workflow)
- lib: setting the time does not re-calculate (Jelle van der Waa)
- lib: do not show non-valid dates as option for reboot/shutdown (Jelle van der Waa)
- lib: Use en-us locale for formatting the date passed to date (Jelle van der Waa)
- lib: set the error string message to state instead of an object (Jelle van der Waa)
- po: Update from Fedora Weblate (GitHub Workflow)
- unit-tests: set the workdir to ~ (Allison Karlitskaya)
- unit-tests: move scenarios to a subdirectory (Allison Karlitskaya)
- unit-tests: stop using TEST_SCENARIO (Allison Karlitskaya)
- unit-tests: split entrypoint into a separate script (Allison Karlitskaya)
- unit-tests: remove /results volume support (Allison Karlitskaya)
- unit-tests: drop vestigial NO_NPM mode (Allison Karlitskaya)
- tools: stop using git-fsck in git-utils (Allison Karlitskaya)
- tools: print git-utils messages to stderr (Allison Karlitskaya)
- tools/termschutz: remove unused import (Allison Karlitskaya)
- common: fix a shadowed parameter (Allison Karlitskaya)
- cockpit-client-ssh: remove unused variable (Allison Karlitskaya)
- test: change browser locale to C.UTF-8 (Allison Karlitskaya)
- test: Add pixel tests for top navigation bar (Martin Pitt)
- test: Add pixel tests for system menu and host switching (Martin Pitt)
- containers: Stop using deprecated imp module (Jelle van der Waa)
- build: fix `make dist` from tarball (Allison Karlitskaya)
- flatpak: remove $(BUILT_SOURCES) hack (Allison Karlitskaya)
- src: remove use of glib-compile-resources (Allison Karlitskaya)
- ws: remove old hack from test-channelresponse (Allison Karlitskaya)
- flatpak: Create screenshots after tests if imagemagick is installed (Martin Pitt)
- c-client: Remember cookies (Matej Marusak)
- client: Fix clear × on connect-to input for WebKit (Garrett LeSage)
- branding: Always use the same background (Matej Marusak)
- c-client: Show proper title for "Connect to" card (Matej Marusak)
- c-client: Show recent hosts (Matej Marusak)
- c-client: Keep localstorage (Matej Marusak)
- build: hardcode user/group to root:root in tarball (Allison Karlitskaya)
- flatpak: remove --disable-cache (Allison Karlitskaya)
- build: change timestamp mangling approach (Allison Karlitskaya)
- build: combine dist hooks into one (Allison Karlitskaya)
- build: create deterministic tarballs (Allison Karlitskaya)
- session: Close shell's stdin in user_has_valid_login_shell() (Martin Pitt)
- test: Avoid alternative truth in TestLogin.testSessionRecordingShell (Martin Pitt)
- test: sudo with cert auth now works on RHEL 8.6/C8S (Martin Pitt)
- test: Fix Firefox CDP driver for version 97 nightlies (Martin Pitt)
- tls: Fix potential out-of-bounds buffer access (Martin Pitt)
- metrics: Tighten up spacing in progress stacks (Garrett LeSage)
- metrics: Don't negate gap in description list (Garrett LeSage)
- test: Better handle selinux alerts produced during login (Marius Vollmer)
- workflows: Add missing apt update to flatpak-test (Martin Pitt)
- package.json: Update @patternfly/patternfly, @patternfly/react-core, @patternfly/react-icons, @patternfly/react-styles, @patternfly/react-table (GitHub Workflow)
- fmf: Go back to firefox distro version (Martin Pitt)
- po: Update from Fedora Weblate (GitHub Workflow)
- unit-tests: Enable -fanalyzer for gcc (Martin Pitt)
- tests: return true (not undefined) from a filter (Allison Karlitskaya)
- Fix typos and spelling issues found by codespell (Garrett LeSage)
- networking: Fix typo perserve -> preserve (Matej Marusak)
- test/README.md: update ssh config suggestions (Allison Karlitskaya)
- cockpit-client: add support for :port (Allison Karlitskaya)
- test: Update pixel test references (Marius Vollmer)
- test: Blur the focused input element before pixel texting (Marius Vollmer)
- test: Wait for animations to finish before pixel testing (Marius Vollmer)
- base1: move done() in "path signal" dbus test (Allison Karlitskaya)
- unit-tests: adjust timeout to 30 minutes (Allison Karlitskaya)
- unit-tests: remove amd64 arch from i386 container (Allison Karlitskaya)
- test: Enable pam_ssh_add for Arch Linux tests (Jelle van der Waa)
- test: add Arch Linux compatiblity for testLogging (Jelle van der Waa)
- test: enable testTally on Arch Linux (Jelle van der Waa)
- pixel tests: add explicit 'reference-image' file (Allison Karlitskaya)
- test: Update pixel test references for Fedora 35 (Marius Vollmer)
- test: Skip TestUpdatesSubscriptions on fedora-35 (Marius Vollmer)
- tests: remove valgrind memfd hack (Allison Karlitskaya)
- unit-tests: move to Debian testing (Allison Karlitskaya)
- ws: Handle favicon.ico in test-server (Martin Pitt)
- ws: remove a stray pam_appl.h user (Allison Karlitskaya)
- configure.ac: remove detection of chcon (Allison Karlitskaya)
- configure.ac: remove users tools detection (Allison Karlitskaya)
- build: remove conditional use of AM_SILENT_RULES (Allison Karlitskaya)
- build: remove GHashTable valgrind hacks (Allison Karlitskaya)
- configure.ac: remove two useless macros (Allison Karlitskaya)
- build: stop $(MKDIR_P) nonsense (Allison Karlitskaya)
- build: stop $(LN_S) nonsense (Allison Karlitskaya)
- test: Fix check-static-login for Arch (Martin Pitt)
- session: Validate client certificates against sssd's trusted CA (Martin Pitt)
- test: Work around Debian testing pam-sss log permission bug (Martin Pitt)
- guide: Don't suggest specifying PKCS12 transfer password on command line (Martin Pitt)
- guide: Encrypt generated private key and suggest to clean it up (Martin Pitt)
- guide: Document how to sign user certificates for authentication (Martin Pitt)
- test: Use FreeIPA signed user cert in TestIPA.testClientCertAuthentication (Martin Pitt)
- test: Fix up DNS for validating certificates (Martin Pitt)
- ws: remove "proxy redirect" code (Allison Karlitskaya)
- tls: add internal https redirect handling (Allison Karlitskaya)
- tls: tweak redirect testing (Allison Karlitskaya)
- test: Add Arch Linux compatibility for `About Web Console` (Jelle van der Waa)
- fmf: Fix $TEST_OS for centos-9-stream (Martin Pitt)
- package.json: Update xterm (GitHub Workflow)
- test: Check before umount'ing an umounted device (Jelle van der Waa)
- test: Skip all Arch Linux test issues (Jelle van der Waa)
- test: Order PAM rules correctly for Arch Linux (Jelle van der Waa)
- test: Add Arch Linux PAM compatibility (Jelle van der Waa)
- test: Add Arch PAM compatibility for testRaw (Jelle van der Waa)
- test: Add arch compatibility for testBasic (Jelle van der Waa)
- test: Arch Linux uses systemd-timesyncd (Jelle van der Waa)
- test: Skip checking if arch is listed in help => about (Jelle van der Waa)
- test: Add locale generation for Arch Linux (Jelle van der Waa)
- test: Set libexecdir for Arch Linux (Jelle van der Waa)
- test: Skip all tests for which Arch Linux has no support (Jelle van der Waa)
- test: Add compatibility for PAM configuration on Arch (Jelle van der Waa)
- test: Add Arch Linux packagekit mocking (Jelle van der Waa)
- tools: Add Arch Linux packaging files (Jelle van der Waa)
- shell: Add pacman compatibility to "About web console" (Jelle van der Waa)
- workflows: clone flathub repository from flathub (Allison Karlitskaya)
- flatpak: update desktop file in metainfo (Allison Karlitskaya)
- .github/deploy-keys: add a flathub deploy key (Allison Karlitskaya)
- workflows: new update-flathub.yml (Allison Karlitskaya)
- flatpak: don't push from update-flathub (Allison Karlitskaya)
- .github/deploy-keys.sh: rework (Allison Karlitskaya)
- test: Close port 8765 to update the pixel tests (Jelle van der Waa)
- flatpak: clean up build scripts (Allison Karlitskaya)
- Port shell header to masthead component (Katerina Koukiou)
- po: Update from Fedora Weblate (GitHub Workflow)
- shell: Clean up PatternFly 3 leftover (Martin Pitt)
- test: Robustify TestCurrentMetrics.testMemory (Martin Pitt)
- doc: Document how to connect to a non-standard D-Bus with giving an address (Martin Pitt)
- flatpak: Add browser integration smoke test (Martin Pitt)
- client: Add run-js action (Martin Pitt)
- flatpak: Restructure test (Martin Pitt)
- systemd: Fix spelling mistake (Ettore Atalan)
- Update pixel test references (Katerina Koukiou)
- tests: remove uneeded wait_visible check before click (Katerina Koukiou)
- shell: Stop using PF3 (Katerina Koukiou)
- shell: port sidebar toggle to patternfly 4 and react (Katerina Koukiou)
- shell: port early failure dialogs to patternfly 4 and react (Katerina Koukiou)
- users: use superuser for `useradd -D` (Jelle van der Waa)
- lib: Ensure empty expander in ListingTable cell has right class (Marius Vollmer)
- tests: Updated pixel test references (Marius Vollmer)
- storage: Don't handle partitioned logical volumes in-line (Marius Vollmer)
- storage: Don't use compact tables anywhere (Marius Vollmer)
- storage: Use a Flex to control details/sidebar layout (Marius Vollmer)
- storage: Remove cellWidth() everywhere (Marius Vollmer)
- storage: Use PF4 pf-c-table__action for content row actions (Marius Vollmer)
- storage: Full physical LVM2 volumes are not critical (Marius Vollmer)
- storage: Add back the PF padding for nested table rows (Marius Vollmer)
- storage: Reduce length of "used" sizes a bit (Marius Vollmer)
- storage: More information in content rows (Marius Vollmer)
- ws: only spawn cockpit-session on known auth types (Allison Karlitskaya)
- common: fix up const-correctness of cockpit_conf_strv() (Allison Karlitskaya)
- common: remove cockpit_web_server_add_socket() (Allison Karlitskaya)
- bridge: remove "internal" connection option (Allison Karlitskaya)
- cockpitpipechannel: tweak "internal" handling (Allison Karlitskaya)
- test: stop publishing internal: "/test-server" (Allison Karlitskaya)
- base1: stop using internal: in test-http.js (Allison Karlitskaya)
- cockpitpackages: stop listening on a TCP port (Allison Karlitskaya)
- test: don't shortcut connection to cockpitpackages (Allison Karlitskaya)
- cockpithttpstream: connect directly to packages (Allison Karlitskaya)
- cockpitpackages: add cockpit_packages_connect() (Allison Karlitskaya)
- cockpitwebserver: add "connect" API (Allison Karlitskaya)
- common: remove GInitable from CockpitWebServer (Allison Karlitskaya)
- bridge: cleanup connectable use in http stream (Allison Karlitskaya)
- bridge: g_autoptr(CockpitConnectable) (Allison Karlitskaya)
- test-fs: fix minor leak (Allison Karlitskaya)
- po: Update from Fedora Weblate (GitHub Workflow)
- flatpak: add a dbus activation test (Allison Karlitskaya)
- client: use DBusActivatable=true (Allison Karlitskaya)
- flatpak: make test slightly less evil (Allison Karlitskaya)
- workflows: enable flatpak environment (Allison Karlitskaya)
- flatpak: set WEBPACK_PACKAGES=static for make dist (Allison Karlitskaya)
- bridge: remove "ssh-agent" internal address (Allison Karlitskaya)
- selinux: fix onSelect callback for selinux page (Katerina Koukiou)
- storaged: Change VDO package installation alert to a helper text (Martin Pitt)
- lib: remove listingActions property from ListingPanel component (Katerina Koukiou)
- tests: autoconvert all python string formatting to fstring (Katerina Koukiou)
- package.json: Update @patternfly/patternfly (github-actions[bot])
- test/reference: update TestStorageStratis.testEncrypted pixels (Allison Karlitskaya)
- test: Add Arch support to MachineCase.system_before() (Martin Pitt)
- Fix title case strings and make `filesystem` consistent (Matej Marusak)
- testlib: Correctly deal with older shell versions (Matej Marusak)
- flatpak: tweak our manifest to match downstream (Allison Karlitskaya)
- workflows: use merge instead of head for flatpak test (Allison Karlitskaya)
- client: remove all mentions of --wildly-insecure (Allison Karlitskaya)
- cockpit-client: work around pygobject bug (Allison Karlitskaya)
- tools: unset git envvars in git-utils.sh (Allison Karlitskaya)
- flatpak: improve the test script (Allison Karlitskaya)
- cockpit-client: add 'quit' GAction (Allison Karlitskaya)
- workflows: don't jumpstart the flatpak test (Allison Karlitskaya)
- workflows: split out flatpak test script (Allison Karlitskaya)
- tools/node-modules: default to "friendly messages" (Allison Karlitskaya)
- webpack-jumpstart: look past merge commit for --rebase (Allison Karlitskaya)
- flatpak: add screenshots to cockpit-client metainfo (Allison Karlitskaya)
- cockpit-client: add a reload button (Allison Karlitskaya)
- package.json: Update @patternfly/react-core, @patternfly/react-icons, @patternfly/react-styles, @patternfly/react-table (GitHub Workflow)
- cockpit-client: disable and hide forward/back (Allison Karlitskaya)
- cockpit-client: fix assertion in cockpit-client-ssh (Allison Karlitskaya)
- flatpak: add packaging metadata and scripts (Allison Karlitskaya)
- cockpit-client: add a 'open-path' GAction (Allison Karlitskaya)
- build: add containers/flatpak Makefile (Allison Karlitskaya)
- cockpit-client: install as a desktop application (Allison Karlitskaya)
- cockpit-client: add icons (Garrett LeSage)
- cockpit-client: add flatpak support (Allison Karlitskaya)
- static: set login page title to "Login" for cockpit-client (Allison Karlitskaya)
- static: hide server name in cockpit-client (Allison Karlitskaya)
- cockpit-client: add support for standalone mode (Allison Karlitskaya)
- cockpit-client: add --no-ui option (Allison Karlitskaya)
- cockpit-client: use GtkBuilder for UI (Allison Karlitskaya)
- cockpit-client: open help in external browser (Allison Karlitskaya)
- cockpit-client: add .is_ephemeral=True to WebView (Allison Karlitskaya)
- cockpit-client: add an inspector shortcut (Allison Karlitskaya)
- cockpit-client: add ^N for new window (Allison Karlitskaya)
- cockpit-client: use GtkApplication for accelerators (Allison Karlitskaya)
- cockpit-client: Use a property binding for title (Allison Karlitskaya)
- cockpit-client: use GtkApplication (Allison Karlitskaya)
- cockpit-client: split from cockpit-desktop (Allison Karlitskaya)
- po: Update from Fedora Weblate (GitHub Workflow)
- ws: disable TLS in Cockpit Client mode (Allison Karlitskaya)
- ws: report cockpit-ssh stderr to cockpit-client (Allison Karlitskaya)
- static: show different fields for cockpit-client (Allison Karlitskaya)
- ws: add new X-For-CockpitClient config option (Allison Karlitskaya)
- static: re-enable autologin if hostname was given (Allison Karlitskaya)
- storaged: Use pkg/lib's fmt_to_fragments (Jelle van der Waa)
- static: change logic for showing host expander (Allison Karlitskaya)
- build: set up separate install rule for -ws (Allison Karlitskaya)
- static: don't attempt autologin in RequireHost mode (Allison Karlitskaya)
- ws: disable system proxy in cockpit-desktop (Allison Karlitskaya)
- configure.ac: don't link cockpit-ws against pam (Allison Karlitskaya)
- build: clean up libexec_SCRIPTS var (Allison Karlitskaya)
- tools: Fix SELinux module installation in non-SELinux environments (Martin Pitt)
- storaged: Create VDO devices as LVM LV type (Martin Pitt)
- logs: Don't make titles monospace (Garrett LeSage)
- logs: port abrt logs details to DescriptionList away from the info-table-ct custom class (Katerina Koukiou)
- logs: port log details to DescriptionList away from deprecated custom info-table-ct (Katerina Koukiou)
- logs: show systemd unit instead of syslog identifier in the logs details card header (Katerina Koukiou)
- login: Use × icon as input clear; show when needed (Garrett LeSage)
- packagekit: Show "Web Console restart" for Arch and derivates (Jelle van der Waa)
- test: Drop focus from close button (Jelle van der Waa)
- services: make minus/plus icons in create timer dialog align with the selectors (Katerina Koukiou)
- storaged: Properly represent LVM VDO pools (Martin Pitt)
- test: Rename TestStorageVDO to TestStorageLegacyVDO (Martin Pitt)
- test: Fix race condition in TestStorageVDO.testVdo (Martin Pitt)
- Stop including page.scss in the cockpit-components-dialog.scss (Katerina Koukiou)
- Start including scss files that are or can be made autonomous with @use keyword (Katerina Koukiou)
- po: Update from Fedora Weblate (GitHub Workflow)
- Eliminate obsolete cockpit.extend() (Martin Pitt)
- packit: Enable CentOS Stream 9 (Martin Pitt)
- common: drop mock-io-stream.[ch] (Allison Karlitskaya)
- bridge: modernise ssh-agent spawning code (Allison Karlitskaya)
- networkmanager: Update firewall documentation URL (Martin Pitt)
- login: Add toggle button to view password (Garrett LeSage)
- Update pixel test references (Katerina Koukiou)
- package.json: Update @patternfly/react-core, @patternfly/react-icons, @patternfly/react-styles, @patternfly/react-table (GitHub Workflow)
- tests: fedora-coreos is now based on fedora-35 - adjust conditions accordingly (Katerina Koukiou)
- lib: remove some unused screen size variables (Katerina Koukiou)
- Remove last occurences of ct-form and remove the file (Katerina Koukiou)
- storage: move ct-form usages to the DescriptionList PF4 component (Katerina Koukiou)
- lib: port servertime dialog away from ct-form to PF4 (Katerina Koukiou)
- firewall: drop form-layout import - it's not used (Katerina Koukiou)
- lib: Remove hack for bootstrap compilation in global-variables (Katerina Koukiou)
- shell: delete listing.scss file as it's not imported by anything (Katerina Koukiou)
- overview: remove duplicate css imports - these are now auto-imported from js (Katerina Koukiou)
- users: Clear password errors when password is changed (Jelle van der Waa)
- test: Use add_loopback_disk() to create loopback disks (Matej Marusak)
- test: Fix SELinux message matching (Martin Pitt)
- test: Fix unexpected pcp-archive messages in TestStoragePackagesNFS (Martin Pitt)
- test: Allow SELinux connection failures to user bus for user_u restricted users (Martin Pitt)
- package.json: Remove unused jquery and bootstrap modules (Matej Marusak)
- fmf: Fix TEST_OS mappings (Martin Pitt)
- package.json: Update @patternfly/react-core, @patternfly/react-icons, @patternfly/react-styles, @patternfly/react-table (GitHub Workflow)
- shell: Rewrite top navigation into React (Matej Marusak)
- shell: Move proxy out of superuser (Matej Marusak)
- shell: Rewrite active pages modal (Matej Marusak)
- shell: Stop using jQuery (Matej Marusak)
- tools: add a valgrind suppression (Allison Karlitskaya)
- guide: remove mention of cockpit-ws group (Allison Karlitskaya)
- common: remove certificate splitting code (Allison Karlitskaya)
- ws: remove support for split certificates (Allison Karlitskaya)
- tls: support merged cert/key only for cockpit-tls (Allison Karlitskaya)
- tls: use cockpit-certificate-ensure --for-cockpit-tls (Allison Karlitskaya)
- tls: test cockpit-certificate-ensure (Allison Karlitskaya)
- common: add g_assert_no_errno() (Allison Karlitskaya)
- common: mark a function inline in cockpithacks (Allison Karlitskaya)
- tls: copy cert/key in cockpit-certificate-ensure (Allison Karlitskaya)
- selinux: allow systemd to clean up /run/cockpit/tls (Allison Karlitskaya)
- tls: remove expiry() accessor from certificate.c (Allison Karlitskaya)
- tls: largely rewrite cockpit-certificate-ensure (Allison Karlitskaya)
- tls: change the client certificates directory (Allison Karlitskaya)
- tls: add O_NOFOLLOW to client certificate code (Allison Karlitskaya)
- guide: drop instructions for merged cert files (Allison Karlitskaya)
- session: define client certificate directory macro (Allison Karlitskaya)
- .gitignore: add 'tags' (Allison Karlitskaya)
- Fix DatePicker's start of week for most cases (Martin Pitt)
- apps: if any of the API calls fail then the ex is an object with a message property (Katerina Koukiou)
- 'Close' button in dialogs should be styled as secondary button (Katerina Koukiou)
- po: Update from Fedora Weblate (GitHub Workflow)
- tests: remove runlevel.target sysv unit check as it's ancient (Katerina Koukiou)
- test: robustify testBasic pixel test (Katerina Koukiou)
- tests: add a cleanup to stop mem-hog service in the teardown (Katerina Koukiou)
- services: show user owned systemd units in the services page (Katerina Koukiou)
- services: move toolbar filters to seperate component so as to increase code readability (Katerina Koukiou)
- services: split the ServicesPage component into smaller sub components (Katerina Koukiou)
- apps: fix packagekit progress bar backword percentages (Katerina Koukiou)
- tools: Use our own SELinux policy on RHEL/CentOS 8 as well (Martin Pitt)
- test: Work around race in chromium's Security.handleCertificateError handler (Martin Pitt)
- bridge: Block signals initially for the default CockpitDBusCache (Marius Vollmer)
- base1: tweak error message check in test-dbus.js (Allison Karlitskaya)
- package.json: Update @patternfly/react-core, @patternfly/react-icons, @patternfly/react-styles, @patternfly/react-table (github-actions[bot])
- networking: Add ipv6 methods 'disabled' and 'shared' (Patrick Talbert)
- test: Don't restart NM while deleting devices at the same time (Marius Vollmer)
- systemd: Handle react DOM validation error (Jelle van der Waa)
- networkmanager: Fix JavaScript error when applying settings (Jelle van der Waa)
- test: One more udev trigger for TestStorageLvm2.testSnapshots (Marius Vollmer)
- storage: Don't offer to encrypt or format extended partitions (Marius Vollmer)
- storage: Consider pool members when deleting a pool (Marius Vollmer)
- storage: Don't offer to deactivate or activate thin pools (Marius Vollmer)
- package.json: Update @patternfly/react-core, @patternfly/react-icons, @patternfly/react-styles, @patternfly/react-table (GitHub Workflow)
- storage: Support Stratis API version 3.0 (Marius Vollmer)
- apps: remove some unused CSS code (Katerina Koukiou)
- apps: port empty state to EmptyStatePanel (Katerina Koukiou)
- apps: fix react warning about missing key (Katerina Koukiou)
- apps: move progress state of install/remove applications into root component (Katerina Koukiou)
- apps: move loading state handling to the root component to avoid duplicating code (Katerina Koukiou)
- apps: stop using helpers for filtering out clicks (Katerina Koukiou)
- apps: rewrite all components in applications page to functinal (Katerina Koukiou)
- apps: rewrite the main app component to be more React-y (Katerina Koukiou)
- sosreport: Drop useless tracking of archive_files (Martin Pitt)
- lib: use new PF4 table (ComposableTable) implementation for all Table variants (Katerina Koukiou)
- storage: Allow mounting all NFS directories (Marius Vollmer)
- sosreport: Rewrite in React (Martin Pitt)
- test: Generalize set_input_text() blurring (Martin Pitt)
- po: Update from Fedora Weblate (GitHub Workflow)
- hwinfo: Fix and localize memory string (Matej Marusak)
- networking: Localize graphs titles (Matej Marusak)
- test: Fix unstable TestKeys.testPrivateKeys pixel test (Martin Pitt)
- test: Verify that tuned dialog reacts to privilege changes (Martin Pitt)
- lib: Fix service.js for privilege changes (Martin Pitt)
- lib: Simplify service.js refresh_interface() (Martin Pitt)
- lib: service.js ES6/Promise code cleanup (Martin Pitt)
- Revert "lib: Tolerate D-Bus disconnect after reloading systemd" (Martin Pitt)
- metrics: change the URL when changing the date filter (Katerina Koukiou)
- package.json: Update @patternfly/patternfly, @patternfly/react-core, @patternfly/react-styles, @patternfly/react-table (GitHub Workflow)
- test: Disable browser log deduplication with --trace (Martin Pitt)
- systemd: Add "performance" as metrics keyword (Jelle van der Waa)
- lib: Move package removal icon in install dialog to PF4 (Martin Pitt)
- packagekit: Drop obsolete CSS rules (Martin Pitt)
- packagekit: Fix "bundle" icon in package history (Martin Pitt)
- test: Clean up NSS users more thoroughly (Martin Pitt)
- overview: Stop pulling in PatternFly 3 (Martin Pitt)
- lib: Port serverTime from FontAwesome to PF4 icons (Martin Pitt)
- systemd/logs: Convert FontAwesome icons to PF4 (Martin Pitt)
- systemd: Fix external link icon in CPU mitigation dialog (Martin Pitt)
- networkmanager: Remove obsolete FontAwesome CSS (Martin Pitt)
- systemd: Drop obsolete FontAwesome CSS (Martin Pitt)
- lib: Drop obsolete FontAwesome CSS from journal.css (Martin Pitt)
- examples: Drop FontAwesome icons (Martin Pitt)
- test: Fix unexpected messages from TestLogin.testLogging (Martin Pitt)
- test: Fix TestFirewall.testNetworkingPage on ubuntu-stable (Martin Pitt)
- systemd: Fix race condition in machine name detection (Martin Pitt)
- tuned: port change profile dialog body to Patternfly 4 (Katerina Koukiou)
- tuned: Port dialog to react (Katerina Koukiou)
- playground: Remove PatternFly 3 (Martin Pitt)
- playground: Drop nonexisting "OnOff Switch" demo section (Martin Pitt)
- sosreport: Convert progress bar to PF4 (Martin Pitt)
- base1: Fix comment about cockpit.css (Martin Pitt)
- storage: Improve error message when org.storage.stratis2 is not found (Marius Vollmer)
- packagekit: Stop pulling in PatternFly 3 (Martin Pitt)
- packagekit: Use standard PF4 ExpandableSection (Martin Pitt)
- packagekit: Move page status icons to PF4 (Martin Pitt)
- apps: Stop pulling in PatternFly 3 (Martin Pitt)
- systemd: Move standard page status icons to PF4 (Martin Pitt)
- services: Add a label to the filter icon (Katerina Koukiou)
- services: collapse toggle in mobile view only (Katerina Koukiou)
- po: Update from Fedora Weblate (GitHub Workflow)
- tls: regenerate 100-year-expiry self-signed certs (Allison Karlitskaya)
- package.json: Drop bootstrap-select (Martin Pitt)
- selinux: Avoid `seboolean` Ansible module to support Ansible Core (Martin Pitt)
- test: Simplify testing of generated SELinux role (Martin Pitt)
- storage: Update pixel test references (Marius Vollmer)
- storage: Hatch background for others in a group (Garrett LeSage)
- storage: Track parents when fixing fstab by adding a new entry (Marius Vollmer)
- storage: Label volume groups explicitly as "LVM2" (Marius Vollmer)
- storage: Work around stratisd notification bug (Marius Vollmer)
- storage: Support for Stratis (Marius Vollmer)
- storage: Add "offset", "total", and "small" props to the usage bar (Marius Vollmer)
- storage: Make sure indices are always up-to-date (Marius Vollmer)
- storage: Run first render after enabling features (Marius Vollmer)
- storage: Support forced fstab options (Marius Vollmer)
- storage: Allow feature enablement to fail (Marius Vollmer)
- Drop mustache (Matej Marusak)
- shell: Remove old machines dialogs (Matej Marusak)
- shell: Rewrite machines dialogs to React and PF4 (Matej Marusak)
- doc: Fix "administative" typo (Martin Pitt)
- package.json: Drop patternfly-react (GitHub Workflow)
- storage: Wait for UDisks2 to get into very precise states during testing (Marius Vollmer)
- Revert "storage: Wrap edit_config in a mutex" (Marius Vollmer)
- guide: Fix conflicting and redundant advice for ListenStream= (Martin Pitt)
- packagekit: Fix one accidentally untranslated UI string (Marius Vollmer)
- lib: port ListingPanel component away from the deprecated tertiary Nav to Tabs (Katerina Koukiou)
- test: Ubuntu 20.10 has fixed sudo for kerberos authentication (Martin Pitt)
- shell: add pixel test for the SSH keys modal (Katerina Koukiou)
- shell: make custom css for host switcher more specific because it breaks the credentials modal (Katerina Koukiou)
- shell: make 'add key' a secondary button (Katerina Koukiou)
- shell: don't let ssh keys dialog table go into mobile layout (Katerina Koukiou)
- po: Update from Fedora Weblate (GitHub Workflow)
- webpack: include jquery only in packages which use it (Katerina Koukiou)
- networkmanager: remove last usages of jquery (Katerina Koukiou)
- networkmanager: Port from jquery `each` to JS standard `forEach` (Katerina Koukiou)
- networkmanager: Port from jquery promise to standard Promise API (Katerina Koukiou)
- shell: rewrite credentials dialog to React and Patternfly 4 (Katerina Koukiou)
- lib: ListingPanel: stop using href for the tab items (Katerina Koukiou)
- storage: Show "Keys" panel also without Clevis (Marius Vollmer)
- test: allow chromium-freeworld as chromium browser (Pino Toscano)
- test: replace one subprocess.Popen() with check_call() (Pino Toscano)
- test: simplify browser type check (Pino Toscano)
- test: unroll CDP.browser_cmd() into CDP.start() (Pino Toscano)
- test: add Browser.cmd() (Pino Toscano)
- test: add Browser.CDP_DRIVER_FILENAME (Pino Toscano)
- test: use Browser.find_exe() more (Pino Toscano)
- test: move browser_path() to Browser (Pino Toscano)
- test: create an actual Browser subclass (Pino Toscano)
- test: add path search for Browser (Pino Toscano)
- test: add base Browser class structure (Pino Toscano)
- test: rename self.browser to self.browser_name (Pino Toscano)
- terminal: Fix spacing (Matej Marusak)
- test: Use shorter PS1 so it does not wrap on mobile (Matej Marusak)
- metrics: Initialize top most timestamp to something usable (Matej Marusak)
- test: fix linter warning: expected 2 blank lines after class or function definition, found 1 (Katerina Koukiou)
- networkmanager: Fix interface table alignment (Garrett LeSage)
- tests: networkmanager: check nmcli for the tteam new device (Katerina Koukiou)
- networkmanager: Update pixel test references (Katerina Koukiou)
- tests: after closing dialogs wait till operation is really done before continuing (Katerina Koukiou)
- networkmanager: move reactivateConnection to it's only consumer file (Katerina Koukiou)
- networkmanager: fix <b> appearing as a string in cockpit.format (Katerina Koukiou)
- networkmanager: stop including PF3 - this page is brand new (Katerina Koukiou)
- networkmanager: show curtain methods to react (Katerina Koukiou)
- networkmananer: remove some unused at this point imports (Katerina Koukiou)
- networkmanager: replace jquery utility method with JS equivalent (Katerina Koukiou)
- networkmanager: confirm breaking change popup to React (Katerina Koukiou)
- networkmanager: show_unexpected_message to React (Katerina Koukiou)
- networkmanager: Port edit network ip settings dialog to React - PF4 (Katerina Koukiou)
- networkmanager: Port add and edit network bridge port dialog to React - PF4 (Katerina Koukiou)
- networkmanager: Port add and edit network team port dialog to React - PF4 (Katerina Koukiou)
- networkmanager: Port add and edit network mac dialog to React - PF4 (Katerina Koukiou)
- networkmanager: move errors on the top of the modal dialogs (Katerina Koukiou)
- networkmanager: move team* and bond* constant to their files respectively (Katerina Koukiou)
- networkmanager: fix '0' appearing before the edit button when no text is shown (Katerina Koukiou)
- networkmanager: Port edit network mtu dialog to React - PF4 (Katerina Koukiou)
- networkmanager: set idPrefix variable once per file and use it (Katerina Koukiou)
- networkmanager: identify shared code between dialogs and move it in a shared file (Katerina Koukiou)
- networkmanager: Port add and edit network vlan dialog to React - PF4 (Katerina Koukiou)
- networkmanager: Port add and edit network bridge dialog to React - PF4 (Katerina Koukiou)
- networkmanager: Port add and edit network team dialog to React - PF4 (Katerina Koukiou)
- networkmanager: Port add and edit network bond dialog to React - PF4 (Katerina Koukiou)
- lib: support passing an 'id' property to the ModalError component (Katerina Koukiou)
- systemd: Fix realmd join crash if given address is not the domain name (Martin Pitt)
- tools: Fix webpack-make's detection of files outside the project directory (Martin Pitt)
- storaged: Drop dead code for "Clear mount point configuration" (Martin Pitt)
- containers/unit-tests: Move to pycodestyle (Martin Pitt)
- webpack: Use relative resolve path for npm 7 compatibility (Martin Pitt)
- tools: Never generate webpack dependencies to files outside of the project (Martin Pitt)
- package.json: Update @patternfly/react-icons (GitHub Workflow)
- Revert "webpack: Use relative resolve path for npm 7 compatibility" (Martin Pitt)
- test: Fix pycodestyle error (Martin Pitt)
- storage: Don't initially assume encryption type is LUKS1 (Marius Vollmer)
- storage: Don't crash when luksmeta is missing (Marius Vollmer)
- test: Fix race in firefox CDP addScriptToEvaluateOnNewDocument() emulation (Martin Pitt)
- tls: Fix auto-renewal of FreeIPA issued ws certificates (Martin Pitt)
- tls: Fix SELinux policy and documentation for certmonger certificates (Martin Pitt)
- po: Update from Fedora Weblate (GitHub Workflow)
- storage: Update pixel test references (Katerina Koukiou)
- storage: Align filesystem usage bars and total sizes at the right (Marius Vollmer)
- storage: Properly nest FormGroups to avoid extra white space (Marius Vollmer)
- storage: Align usage bars better in the filesystem panels (Marius Vollmer)
- storage: Say "Overwrite" instead of "Erase" (Marius Vollmer)
- storage: Polish for the "Format disk" dialog (Marius Vollmer)
- storage: Put exclamation icon in title of all dangerous dialogs (Marius Vollmer)
- storage: Move teardown info into dialog body (Marius Vollmer)
- storage: Limit width of usage bars (Marius Vollmer)
- storage: Use standard Patternfly layout for DescriptionLists, mostly (Marius Vollmer)
- webpack: Use relative resolve path for npm 7 compatibility (Martin Pitt)
- package.json: Add @patternfly/react-icons (Martin Pitt)
- package.json: Revert no-var rule override (Martin Pitt)
- shell: Fix up navigation, improve clickable area (Garrett LeSage)
- systemd: Use React hooks in ConfigurationCard (Martin Pitt)
- test: Add pixel tests for realm join/leave (Martin Pitt)
- test: Fix race condition in check-realms testClientCertAuthentication (Martin Pitt)
- systemd: realmd superuser change code cleanup (Martin Pitt)
- Add script to (re-)generate GitHub deploy keys (Martin Pitt)
- storaged: this page does not use jquery (Katerina Koukiou)
- websocket: Avoid -fanalyzer-null-dereference warning in send_prefixed_message_rfc6455() (Martin Pitt)
- common: Fix -fanalyzer-null-dereference warning in test_expand() (Martin Pitt)
- systemd: Rewrite realmd configuration in React and standard PF4 (Martin Pitt)
- po: Update from Fedora Weblate (GitHub Workflow)
- workflows: run npm-update workflow with deploy key (Allison Karlitskaya)
- systemd: Drop computer-ou input field from realm join dialog (Martin Pitt)
- systemd: Drop unused ConfigurationCard serverTime state (Martin Pitt)
- test: Expect days without leading zeros (Matej Marusak)
- fmf: Avoid mozilla-openh264 (Martin Pitt)
- tools: Conditionalize cockpit-packagekit dependency on dnf (Martin Pitt)
- po: Update from Fedora Weblate (GitHub Workflow)
- po/Makefile.am: remove weblate syncing rules (Allison Karlitskaya)
- weblate-sync-po: rewrite, avoiding COCKPITUOUS_TOKEN (Allison Karlitskaya)
- .github: split po-refresh into two workflows (Allison Karlitskaya)
- users: Add an list of recent logins to the account details (Jelle van der Waa)
- po-refresh.yml: split out pot upload to weblate (Allison Karlitskaya)
- bridge: Tone down ENODEV message about reading cgroups (Martin Pitt)
- po: Update from Fedora Weblate (Cockpit Project)
- base1: Update setTimeout documentation URL (Martin Pitt)
- test: Fix test.service cleanup in TestServices (Martin Pitt)
- systemd: Set auto-detected realm domain/admin as proper input values (Martin Pitt)
- systemd: Fix realm Join button spinner (Martin Pitt)
- lib: Move ServerTime component to PF4 TimePicker (Martin Pitt)
- test: Robustify cleanup of dmidecode in TestSystemInfo.testHardwareInfo (Martin Pitt)
- shell: Eliminate `var` keyword (Martin Pitt)
- systemd: Eliminate `var` keyword (Martin Pitt)
- shell: Eliminate `var` from machines.js (Martin Pitt)
- shell: Eliminate unused `problem` variable (Martin Pitt)
- selinux: replace some custom CSS in the header with PF4 components instead (Katerina Koukiou)
- storaged: stop using ct-form-relax on storage links (Katerina Koukiou)
- storaged: 'Create new logical volume' is a button and should look like one (Katerina Koukiou)
- systemd: port health card to use PF4 icons and layouts (Katerina Koukiou)
- systemd: servertime: use PF4 icons and layouts (Katerina Koukiou)
- test: Remove old storage hack (Matej Marusak)
- configure.ac: use AC_CONFIG_FILES (Allison Karlitskaya)
- configure.ac: simplify Python check (Allison Karlitskaya)
- test: Add pixel tests for Overview page (Martin Pitt)
- test: Fix TestShutdownRestart.testBasic for different OS timezones (Martin Pitt)
- test: Wait until kernel dump is present (Martin Pitt)
- kdump: Port from cockpit.defer() to standard Promise API (Martin Pitt)
- kdump: Simplify unit test (Martin Pitt)
- kdump: Restart failed kdump.service after configuration changes (Martin Pitt)
- kdump: Show "Directory" field for NFS mounts (Martin Pitt)
- test: Factorize kernel crash in check-kdump (Martin Pitt)
- kdump: Fix ID of ssh directory input field (Martin Pitt)
- test: Allow `/dev/vda` for raid creations (Matej Marusak)
- metrics: Make WebKit happy with absolute position (Garrett LeSage)
- tests: add rhel-8-6 special cases (Katerina Koukiou)
- bridge: Switch off CockpitDBusCache while it has no name owner (Marius Vollmer)
- networkmanager: Eliminate `var` keyword (Martin Pitt)
- static: Eliminate `var` keyword (Martin Pitt)
- package.json: Update qunit (Cockpit Project)
- lib/patternfly: Fix "form select" padding (Garrett LeSage)
- lib: Pass Python scripts via "-c" instead of stdin (Marius Vollmer)
- systemd: Move last login into the Health card (Jelle van der Waa)
- eslint: Enable no-var rule (Martin Pitt)
- selinux: Eliminate `var` keyword (Martin Pitt)
- sosreport: Eliminate `var` keyword (Martin Pitt)
- playground: Eliminate `var` keyword (Martin Pitt)
- metrics: Eliminate `var` keyword (Martin Pitt)
- users: Eliminate `var` keyword (Martin Pitt)
- tuned: Eliminate `var` keyword (Martin Pitt)
- apps: Eliminate `var` keyword (Martin Pitt)
- kdump: Eliminate `var` keyword (Martin Pitt)
- base1: Eliminite `var` keyword (Martin Pitt)
- packagekit: Improve visuals of history & flow list (Garrett LeSage)
- po: Update from Fedora Weblate (Cockpit Project)
- realmd: React on privileges change (Matej Marusak)
- base1: Fix DBusCache.each() to actually work (Martin Pitt)
- base1: Fix variable shadowing in cockpit.location() (Martin Pitt)
- base1: Fix cockpit.user() to actually cache the result (Martin Pitt)
- storage: Eliminate "var" (Marius Vollmer)
- packagekit: Eliminate `var` keyword (Martin Pitt)
- lib: Eliminate `var` keyword (Martin Pitt)
- storage: Replace all "var" keywords with "let" or "const" (Marius Vollmer)
- common: Restrict frame embedding to same origin (Martin Pitt)
- test: Verify that cross-domain frame embedding does not work (Martin Pitt)
- test: Fix race in TestStorageMounting.testEncryptedMountingHelp harder (Martin Pitt)
- tools: Bump Debian debhelper compat to 12, Standards-Version to 4.6.0 (Martin Pitt)
- systemd: Use patternfly variables for spacing (Jelle van der Waa)
- branding: Add Arch Linux branding (Jelle van der Waa)
- test: Update pixel test references after Chromium update (Marius Vollmer)
- systemd: show last 24 hours of logs by default (Jelle van der Waa)
- tools: Move ownership of /usr/share/cockpit to cockpit-bridge.rpm (Martin Pitt)
- test: Add check-kdump full end-to-end NFS dump test (Martin Pitt)
- test: Fix race in TestStorageMounting.testEncryptedMountingHelp (Martin Pitt)
- storage: Read /etc/os-release from current host (Marius Vollmer)
- test/reference: remove wrongly placed pixel test image from c-machines (Katerina Koukiou)
- systemd: keep terminal scrollbar working and make test expect new inline style (Katerina Koukiou)
- package.json: Update xterm (Cockpit Project)
- test: check-kdump cleanup (Martin Pitt)
- storage: Wait for the watch during init, not the unwatched proxies (Marius Vollmer)
- network: Change STP label and group options (Garrett LeSage)
- bridge: Robust JSON object comparison in test-httpstream.c (Martin Pitt)
- test: Ignore cockpit-session chown SELinux failure on fedora-35 (Martin Pitt)
- test: Check nginx reverse proxy mode with embedding (Martin Pitt)
- examples: Delete broken embed-cockpit/ (Martin Pitt)
- test: embed-cockpit/embed.js ES6 modernization (Martin Pitt)
- test: Make check-embed nondestructive (Martin Pitt)
- test: Split out CSS from embed-cockpit (Martin Pitt)
- test: Fix conflict in embed-cockpit/ HTML (Martin Pitt)
- po: Update from Fedora Weblate (Cockpit Project)
- lib/listing-panel: Fix tab / action wrapping (Garrett LeSage)
- selinux: Fix width constraint on small sizes (Garrett LeSage)
- bridge: Filter more DBus signals by sender when cache watching (Marius Vollmer)
- pkg: Fix usage of `ngettext` (Matej Marusak)
- selinux: abuse pf-c-table__action class to limit the width of the last table cells (Katerina Koukiou)
- selinux: add vertical spacing between the solutions (Katerina Koukiou)
- lib/table: add right padding to panel head (Katerina Koukiou)
- lib/table: fix miscalculated colSpan from PF4 (Katerina Koukiou)
- test: Fix check-pages for mobile (Martin Pitt)
- test: Fix check-shell-host-switching for mobile (Martin Pitt)
- test: Fix check-shell-multi-machine for mobile (Martin Pitt)
- test: Fix check-system-journal for mobile (Martin Pitt)
- test: Fix TestKerberos.testNegotiate for mobile (Martin Pitt)
- test: Fix check-{users-roles,static-login} for mobile (Martin Pitt)
- test: Fix check-packages for mobile (Martin Pitt)
- test: Fix check-session for mobile (Martin Pitt)
- test: Fix check-shell-menu for mobile (Martin Pitt)
- test: Fix TestServices.test{NotifyFailed,HiddenFailure} for mobile (Martin Pitt)
- test: Fix TestServices.testLogs for mobile (Martin Pitt)
- test: Factorize clicking on system menu item, make it work for mobile tests (Martin Pitt)
- test: Fix TestSystemInfo.testHardwareInfo for mobile (Martin Pitt)
- test: Fix Browser.{become,drop}_superuser() for mobile mode (Martin Pitt)
- test: Factor out becoming/dropping superuser (Martin Pitt)
- lib: page.scss: dropdown-kebab-pf class is not used anywhere (Katerina Koukiou)
- lib: page.scss: well class is not used anywhere (Katerina Koukiou)
- lib: page.scss: btn-group-vertical class is not used anywhere (Katerina Koukiou)
- lib: page.scss: btn class is not used with fa-* classes anywhere (Katerina Koukiou)
- shell: use isLoading button variant to indicate the dialog op is in progress (Katerina Koukiou)
- lib/pf, lib/page: Move number input mod & fix URL (Garrett LeSage)
- lib/pf: We no longer use well with PF3 blank slate (Garrett LeSage)
- lib: Some page.scss cleanups (Martin Pitt)
- Do not step on PF4 when adjusting PF3 headings (Garrett LeSage)
- package.json: Update qunit (Cockpit Project)
- test: Re-drop redundant Browser.is_mobile (Martin Pitt)
- test: Add pixel tests for Services list and details (Martin Pitt)
- test: Add Browser.is_mobile flag (Martin Pitt)
- lib: Port credentials.js from jQuery to event_target (Martin Pitt)
- shell: Declare constants as such (Martin Pitt)
- shell: Port credentials from jQuery to standard JS Promise (Martin Pitt)
- po: Update from Fedora Weblate (Cockpit Project)
- po: Drop 'ca' language (Cockpit Project)
- test: Port pixeldiff.html from jQuery to standard DOM API (Martin Pitt)
- package.json: Drop bootstrap-datepicker (Martin Pitt)
- systemd: Port system time change from bootstrap to PF4 date picker (Martin Pitt)
- selinux: Fix client.getAlerts() documentation (Martin Pitt)
- sosreport: Port from jQuery to DOM API (Martin Pitt)
- lib: attach issue to patternfly-overrides for wrongly aligned card actions (Katerina Koukiou)
- users: remove duplicate CSS (Katerina Koukiou)
- lib: remove duplicated css from page.scss (Katerina Koukiou)
- lib: patternfly: use pf-m-sticky-top instead of our custom class to make toolbars sticky (Katerina Koukiou)
- lib: patternfly: remove workaround for broken focus wrong on input group (Katerina Koukiou)
- playground: Port from jQuery to DOM/JS standard API (Martin Pitt)
- tools: Provide eslint mode for webpack-watch (Martin Pitt)
- tests: Introduce mobile screenshots for all existing pixel tests (Katerina Koukiou)
- tests: skip some test in mobile scenario (Katerina Koukiou)
- tests: terminal: make tests work also on mobile scenario (Katerina Koukiou)
- tests: superuser: make tests work also on mobile scenario (Katerina Koukiou)
- tests: packagekit: make tests work also on mobile scenario (Katerina Koukiou)
- tests: skip grafana tests on mobile test scenario (Katerina Koukiou)
- tests: Introduce skipMobile test decorator (Katerina Koukiou)
- tests: Add mobile variant to pixel tests screenshots (Katerina Koukiou)
- Support running tests in mobile screen size browser window (Katerina Koukiou)
- containers/unit-tests: Add missing ddebs for security updates (Martin Pitt)
- package.json: Update qunit (Cockpit Project)
- tools: convert webpack-watch into a symlink of webpack-make (Jelle van der Waa)
- tools: add a --no-eslint option to webpack-make (Jelle van der Waa)
- overview: remove some unused CSS (Katerina Koukiou)
- services: fix missing icons from the services details UI (Katerina Koukiou)
- tools: Simplify special cases in the spec (Martin Pitt)
- test: Drop special cases for fedora-33 (Martin Pitt)
- packit: Enable Fedora 35 (Martin Pitt)
- packit: Drop fedora-33 (Martin Pitt)
- test: Update supported and default OSes in README.md (Martin Pitt)
- tests: Add pixel tests for selinux page (Katerina Koukiou)
- selinux: allow bulk deletion of selinux notifications (Katerina Koukiou)
- selinux: fix title of the second card in the page (Katerina Koukiou)
- workflows: Tag node-cache on releases (Martin Pitt)
- containers: Fix SELinux context of SSH private key (Martin Pitt)
- test: Add another random PCP unexpected message (Martin Pitt)
- package.json: Move argparse to devDependencies (Martin Pitt)
- storage: Wrap edit_config in a mutex (Marius Vollmer)
- storage: Move to new-style promise API (Marius Vollmer)
- Make TestUpdates.testBasic more robust (Simon Kobyda)
- test: Drop libvirt startup in check-networkmanager-firewall (Martin Pitt)
- test: Relax expected "instance name lookup failed" PCP message (Martin Pitt)
- test: Drop waiting for team MAC address (Martin Pitt)
- Utilize PF4 components for the superuser dialog (Katerina Koukiou)
- ws: remove cockpit_certificate_create_selfsigned() (Allison Karlitskaya)
- ws: remove remotectl (Allison Karlitskaya)
- containers: replace remotectl with cockpit-certificate-ensure (Allison Karlitskaya)
- test: use cockpit-certificate-ensure instead of remotectl (Allison Karlitskaya)
- test: use .restore_dir() instead of env redirects (Allison Karlitskaya)
- test: drop some useless code in check-connection (Allison Karlitskaya)
- docs: replace mention of remotectl (Allison Karlitskaya)
- cockpit-certificate-ensure: add --check (Allison Karlitskaya)
- tests: consolidate libexecdir logic (Allison Karlitskaya)
- po: Update from Fedora Weblate (Cockpit Project)
- base1: Fix long shutdown hang of test-dbus{,-address} (Martin Pitt)
- ws: Fix on_handle_never_return() method signature (Martin Pitt)
- base1: Fix wrong assert invocation in test-dbus (Martin Pitt)
- ws: Drop dead mock_service_{start,stop}() from mock-service.c (Martin Pitt)
- package.json: Update @patternfly/react-styles, @patternfly/react-table, @patternfly/patternfly, @patternfly/react-core (Cockpit Project)
- test: Allow another variant of pcp-archive messages (Martin Pitt)
- shell: Use PF's about modal (Matej Marusak)
- systemd: Ignore "To Be Filled By O.E.M." DMI values (Martin Pitt)
- po plugin: add po/ dependencies (Allison Karlitskaya)
- po plugin: use LINGUAS file, if available (Allison Karlitskaya)
- po plugin: remove Webpack 4 support (Allison Karlitskaya)
- webpack-watch: update webpack-make invocation (Jelle van der Waa)
- cockpituous: Stop releasing to Fedora 33 (Martin Pitt)
- containers: Bump bastion and ws containers to Fedora 34 (Martin Pitt)
- storage: Remove debugging output (Marius Vollmer)
- test: Adapt TestStorageLuks.testReboot for recent changes (Marius Vollmer)
- storage: Combine crypto and fsys rows (Marius Vollmer)
- webpack-make: convert -d to a position argument (Allison Karlitskaya)
- node_modules: switch to argparse from stdio (Allison Karlitskaya)
- pkg/lib: remove -f option from {html,manifest}2po (Allison Karlitskaya)
- pkg/lib: require packages in the usual way (Allison Karlitskaya)
- cockpituous: Release to Fedora 35 (Matej Marusak)
- test: Check rebooting with passphrase input (Marius Vollmer)
- Check g_setenv() failure (Martin Pitt)
- build: re-prevent node from messing with stdio (Allison Karlitskaya)
- test: Re-generalize missing kernel.all.cpu.nice metrics message (Martin Pitt)
- test: Adjust special cases for debian-stable moving to Debian 11 (Martin Pitt)
- selinux: allow login to read motd file (Ludwig Nussel)
- test: Put terminal content into output when wait_line fails (Marius Vollmer)
- test: Put actual text into output when wait_text or wait_in_text fail (Marius Vollmer)
- test: Don't expect to go back to idle after hogging memory (Marius Vollmer)
- test: Switch off swap also on Fedora 35 (Marius Vollmer)
- test: Backtraces now have "Found module" messages (Marius Vollmer)
- test: Fedora 35 doesn't have kpatch (Marius Vollmer)
- test: It's "Fedora Linux" now (Marius Vollmer)
- systemd: Don't show the current year for logins (Jelle van der Waa)
- lib: Update PF link (Matej Marusak)
- fmf: Don't remove policycoreutils-python-utils (Matej Marusak)
- fmf: Use firefox instead for chrome (Matej Marusak)
- fmf: Add hack for stuck chpasswd (Matej Marusak)
- po: Update from Fedora Weblate (Cockpit Project)
- po: Update from Fedora Weblate (Cockpit Project)
- test: allow for existing /var/cache/krb5rcache (Allison Karlitskaya)
- test: re-fix "zebra" text in check-selinux (Allison Karlitskaya)
- test: allow a wider match on an selinux test string (Allison Karlitskaya)
- testlib: add wait_text_matches() (Allison Karlitskaya)
- test: change match string in selinux modifications table (Allison Karlitskaya)
- storage: Use HelpIcon and Popover for dialog explanations (Marius Vollmer)
- test: "pcp: Unknown metric" also happens in TestCurrentMetrics (Marius Vollmer)
- test: fix an allowed journal message regexp (Allison Karlitskaya)
- tests: Fix pyflakes warnings (Matej Marusak)
- bridge: Fix PCP archives on 32 bit architectures (Martin Pitt)
- shell: Show transient hostname (Jelle van der Waa)
- systemd: Show transient hostname (Jelle van der Waa)
- session: Drop cockpit-session- prefix from client-certificate.[hc] (Martin Pitt)
- session: Move PAM and session handling from session-utils into main program (Martin Pitt)
- ws: Move cockpit-session to src/session (Martin Pitt)
- logs: Remove role "cell" for elements that are inside "cell" already (Matej Marusak)
- test: Split up TestServices.testBasic (Matej Marusak)
- logs: Port overview to React and PF4 (Katerina Koukiou)
- packagekit: remove content-header-extra class as it's not used (Katerina Koukiou)
- networkmanager: Align add button next to adresses selection (Jelle van der Waa)
- test: Re-ignore variant of PCP error message (Martin Pitt)
- test: Check S4U sudo and ssh authentication in TestIPA.testClientCertAuthentication (Martin Pitt)
- ws: Create S4UProxy user ticket on tlscert authentication (Martin Pitt)
- tls: Create HTTP/ kerberos principal with --ok-to-auth-as-delegate (Martin Pitt)
- selinux:  Allow cockpit_ws_t get attributes of fs_t filesystems (Matej Marusak)
- tools: Update user-agent in urls-check script (Matej Marusak)
- test: Relax system DMI string test (Martin Pitt)
- systemd: Read hardware info from DeviceTree (Martin Pitt)
- test: Make unexpected PCP error messages more specific (Martin Pitt)
- lib: Drop form-table-ct class (Martin Pitt)
- examples: Drop form-table-ct and cockpit.css (Martin Pitt)
- examples: Drop poc-cim (Martin Pitt)
- examples: Drop docker-info (Martin Pitt)
- test: Fix TestServices.testBasic for different VM/browser time zones (Martin Pitt)
- base1: Fix and simplify cockpit.js loading (Martin Pitt)
- test: fedora-testing does not have kpatch (Martin Pitt)
- packagekit: don't make the progress bar jump (jelle van der Waa)
- doc: Document paths in cockpit.file (Matej Marusak)
- workflows: Fix unit-tests timeout (Martin Pitt)
- containers: Properly run test-static-code during unit tests (Martin Pitt)
- test: Fix pycodestyle errors in check-packagekit (Martin Pitt)
- common: Fix memory leak coverity warning (Martin Pitt)
- ws: Prevent calling strlen() on NULL result (Martin Pitt)
- bridge: Check cockpit_close_range() errors (Martin Pitt)
- package.json: Update @patternfly/react-styles, @patternfly/react-table, @patternfly/react-core, @patternfly/patternfly (Cockpit Project)
- HACKING: Link the mailing list address (Jelle van der Waa)
- build: Remove obsolete autoconf macros (Jelle van der Waa)
- .gitignore: Generalize ignoring test output files (Jelle van der Waa)
- storage: Use semantic HTML in verify key modal and use ClipboardCopy (Garrett LeSage)
- test: Reset failed units in TestKerberos.testNegotiate terminal test (Martin Pitt)
- po: Update from Fedora Weblate (Cockpit Project)
- test: Add IdentitiesOnly to the ssh config example (Jelle van der Waa)
- test: Refresh packagekit cache at start of test (Matej Marusak)
- packagekit: Introduce kpatch integration (Matej Marusak)
- shell: Change user icon in the top menu (Matej Marusak)
- abrt: Update url to gnome API (Matej Marusak)
- test: Adjust for PackageKit 1.2.4 severity parsing support (Martin Pitt)
- test: Stop PackageKit in TestUpdates.testNoPackageKit (Martin Pitt)
- tls: make test-server runtime dir in /dev/shm (Allison Karlitskaya)
- tls: use random client certificate filenames (Allison Karlitskaya)
- session: rename a local variable (Allison Karlitskaya)
- session: add comment to security-critical check (Allison Karlitskaya)
- session: remove a redundant error check (Allison Karlitskaya)
- connection: close metadata_fd on connection close (Allison Karlitskaya)
- tls: Fix build failure on nonexisting fingerprint with DEBUG (Martin Pitt)
- package.json: Update @patternfly/patternfly, @patternfly/react-table, @patternfly/react-styles, @patternfly/react-core (Cockpit Project)
- webpack-jumpstart.yml: use node:14 (Allison Karlitskaya)
- tools/node-modules: add `--` to `rm` call (Allison Karlitskaya)
- tools/git-utils.sh: add second "ref exists?" check (Allison Karlitskaya)
- containers: lower timeout for debug output (Allison Karlitskaya)
- cockpithex: use mallocx() for memory allocation (Allison Karlitskaya)
- tls: remove some uses of Fingerprint struct (Allison Karlitskaya)
- tls: write expected cgroup name into certfile (Allison Karlitskaya)
- session: use the provided client certificate filename (Allison Karlitskaya)
- session: remove hedging against no certificate (Allison Karlitskaya)
- session: drop and merge cockpitwsinstancecert.c (Allison Karlitskaya)
- tls: add a "client-certificate" field to metadata (Allison Karlitskaya)
- ws: prevent client sending "Authorize: tls-cert" (Allison Karlitskaya)
- tls: move certfile creation to _handshake() (Allison Karlitskaya)
- tls: rework metadata blob creation (Allison Karlitskaya)
- tls: support connections from AF_UNIX (Allison Karlitskaya)
- ws: factor out some logic for rhost handling (Allison Karlitskaya)
- package.json: Update @patternfly/react-styles, @patternfly/react-core, @patternfly/react-table, @patternfly/patternfly (Cockpit Project)
- test: Drop unnecessary systemctl daemon-reload in check-system-s4u (Martin Pitt)
- test: Factorize S4U ticket location and make it more realistic (Martin Pitt)
- test: More targeted delegated ticket setup in check-system-s4u (Martin Pitt)
- test: Drop unused $KRB5RCACHEDIR setting in check-system-s4u (Martin Pitt)
- test: Restructure the setup in check-system-s4u (Martin Pitt)
- test: Rename S4U proof of concept (Martin Pitt)
- common: Drop cockpitunixfd in favor of official glib API (Martin Pitt)
- common: Simplify cockpit_close_range() (Martin Pitt)
- common: Drop configure check for fdwalk() (Martin Pitt)
- common: Clean up fdwalk duplication, move to Linux close_range API (Martin Pitt)
- bridge: Read dbus-daemon address from stdout (Martin Pitt)
- bridge: Rewrite dbus-daemon setup using GSubprocess (Martin Pitt)
- pam-ssh-add: Add missing -fPIC compiler option (Martin Pitt)
- pam-ssh-add: Fix duplicate file list entry in Makefile (Martin Pitt)
- overview: Improve visibility of admin access alert (Garrett LeSage)
- shell: Style limited access for better visibility (Garrett LeSage)
- ws: Add alternative error message filtering in cockpit-session (Martin Pitt)
- ws: Don't write service credentials to root's public keyring (Martin Pitt)
- ws: Split out service credentials acquiring in cockpit-session (Martin Pitt)
- .gitignore: ignore /bots even if it's a symlink (Allison Karlitskaya)
- users: Don't allow locking of the current account (Matej Marusak)
- po: Update from Fedora Weblate (Cockpit Project)
- ws: Move to session specific kerberos keyring (Martin Pitt)
- packit.yaml: use webpack-jumpstart --rebase (Allison Karlitskaya)
- tools/webpack-jumpstart: strengthen consistency check (Allison Karlitskaya)
- tools/webpack-jumpstart: add --rebase option (Allison Karlitskaya)
- git-utils.sh: (re)introduce cat_from_cache helper (Allison Karlitskaya)
- tools/webpack-jumpstart: wait to clone node_modules (Allison Karlitskaya)
- tools/webpack-jumpstart: add better args parsing (Allison Karlitskaya)
- packagekit: Handle unregistered RHEL systems with non-CDN OS repository (Martin Pitt)
- webpack-jumpstart.yml: perform merge for ourselves (Allison Karlitskaya)
- webpack-jumpstar.tar: include tree id in tar (Allison Karlitskaya)
- ws: Use cockpitmemory allocation functions (Martin Pitt)
- tools: Drop unused 0BSD license paragraph from debian/copyright.template (Martin Pitt)
- tools: Structure debian/copyright by webpack instead of by license (Martin Pitt)
- tools: Fix debian/copyright Files: matches (Martin Pitt)
- tools: Fix Copyright: continuation lines in debian/copyright (Martin Pitt)
- package.json: update PF dependencies (Katerina Koukiou)
- build-debian-copyright: ignore errors on devel builds (Allison Karlitskaya)
- build: fix debian/copyright in builddir != srcdir (Allison Karlitskaya)
- Makefile.am: tweak debian/copyright rule (Allison Karlitskaya)
- build: stop disting COPYING.node (Allison Karlitskaya)
- webpack.config.js: drop included-modules plugin (Allison Karlitskaya)
- tools/build-debian-copyright: entirely new approach (Allison Karlitskaya)
- webpack.config.js: use default comment handling (Allison Karlitskaya)
- ws: fix a warning about an uninitialized variable (Allison Karlitskaya)
- docs build: don't clober noinst_DATA (Allison Karlitskaya)
- doc build: tweak rule visual output (Allison Karlitskaya)
- lib: Move po conversion scripts to lib (Martin Pitt)
- systemd: Update Insights URLs to console.redhat.com (Martin Pitt)
- test: Replace kinit for cockpit service in check-system-s4u-ssh (Martin Pitt)
- test: Drop unnecessary kinit admin@COCKPIT.LAN in check-system-s4u-ssh (Martin Pitt)
- build: stop disting the guide (Allison Karlitskaya)
- tools/release-guide: build the docs from the tarball (Allison Karlitskaya)
- build: drop doc/guide/version.in from EXTRA_DIST (Allison Karlitskaya)
- guide: copy fonts from dist/static/ (Allison Karlitskaya)
- guide: drop toplevel index page (Allison Karlitskaya)
- tools/release-guide: only install to latest/ (Allison Karlitskaya)
- build: drop stray use of SKIP_NODE (Allison Karlitskaya)
- doc: Update broken PCP manpage links (jpall12)
- build: override `distdir` rule (Allison Karlitskaya)
- build: stop accidentally disting cockpitassets.[ch] (Allison Karlitskaya)
- metrics: Adjust history metrics graph labels to avoid overlapping (Martin Pitt)
